/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(tb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function rb(sb){var r=sb.a;var s=r.buffer;r.grow=pb;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=sb.abort;var M=NaN;var N=Infinity;var O=sb.b;var P=sb.c;var Q=sb.d;var R=sb.e;var S=sb.f;var T=sb.g;var U=sb.h;var V=sb.i;var W=sb.j;var X=sb.k;var Y=sb.l;var Z=sb.m;var _=sb.n;var $=sb.o;var aa=sb.p;var ba=sb.q;var ca=sb.r;var da=sb.s;var ea=sb.t;var fa=sb.u;var ga=sb.v;var ha=sb.w;var ia=sb.x;var ja=sb.y;var ka=sb.z;var la=sb.A;var ma=sb.B;var na=sb.C;var oa=sb.D;var pa=sb.E;var qa=sb.F;var ra=sb.G;var sa=sb.H;var ta=sb.I;var ua=sb.J;var va=sb.K;var wa=sb.L;var xa=sb.M;var ya=sb.N;var za=sb.O;var Aa=sb.P;var Ba=sb.Q;var Ca=sb.R;var Da=sb.S;var Ea=sb.T;var Fa=sb.U;var Ga=sb.V;var Ha=sb.W;var Ia=sb.X;var Ja=sb.Y;var Ka=sb.Z;var La=sb._;var Ma=sb.$;var Na=sb.aa;var Oa=sb.ba;var Pa=sb.ca;var Qa=sb.da;var Ra=sb.ea;var Sa=sb.fa;var Ta=sb.ga;var Ua=sb.ha;var Va=sb.ia;var Wa=sb.ja;var Xa=sb.ka;var Ya=sb.la;var Za=sb.ma;var _a=sb.na;var $a=sb.oa;var ab=sb.pa;var bb=sb.qa;var cb=sb.ra;var db=sb.sa;var eb=sb.ta;var fb=5711392;var gb=0;var hb=0;var ib=0;
// EMSCRIPTEN_START_FUNCS
function NI(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,T=0,V=C(0),W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=C(0),Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=C(0),ab=0;ea=fb-32|0;fb=ea;fa=ea+24|0;v[fa>>2]=49728;v[fa>>2]=49628;e=MI(ea+16|0);f=MI(ea+8|0);ga=b;oa=c;pa=v[e>>2];Fa=w[e+4|0];qa=v[f>>2];Ga=w[f+4|0];c=0;T=fb-112|0;fb=T;d=a;ra=a+24604|0;a=ra;a:{if(!v[a+16>>2]){break a}b=v[a+20>>2];if(b>>>0>4|!(1<<b&22)){break a}a=v[a+28>>2];if(a>>>0>4){break a}c=23>>>a&1}if(!c){a=T+96|0;aM(a,9104,12976,220,45);b=fb+-64|0;fb=b;v[b+56>>2]=0;e=bM(b+56|0);c=Qb(b+24|0,17697);v[23220]=0;U(5,b+8|0,1,17360);f=v[23220];v[23220]=0;b:{c:{d:{e:{if((f|0)!=1){v[23220]=0;U(2,b+40|0,c|0,b+8|0);f=v[23220];v[23220]=0;if((f|0)==1){break e}v[23220]=0;da(815,e|0,a|0,1,13578,b+40|0);a=v[23220];v[23220]=0;if((a|0)!=1){break b}a=P()|0;O()|0;vb(b+40|0);break d}a=P()|0;O()|0;break c}a=P()|0;O()|0}vb(b+8|0)}vb(c);S(a|0);L()}vb(b+40|0);vb(b+8|0);vb(c);fb=b- -64|0}sa=d+8204|0;ta=d+397452|0;ua=d+397448|0;ba=d+393352|0;J=d+397456|0;Z=d+12|0;Ha=d+1074376|0;Ia=d+1298420|0;Ja=d+1074365|0;while(1){f:{g:{a=v[d+480208>>2];if(!(!ga|a&512)){h:{if(v[d+1074380>>2]){break h}b=a|512;i:{if(a&256){break i}p=0;k=fb-48|0;fb=k;A=fb-32|0;fb=A;q=d+1074312|0;c=d+1074992|0;i=d+1298264|0;j=d+1074424|0;l=d+1074448|0;n=d+1074376|0;b=v[d+1074392>>2];E=d+480188|0;s=d+480180|0;m=d+484360|0;r=d+484348|0;M=d+480210|0;F=d+484376|0;G=d+484364|0;j:{k:{l:while(1){m:{a=b+1|0;v[d+1074392>>2]=a;if(Ok(n)>>>0>a>>>0){break m}sN(A+24|0,v[s>>2],x[E>>1],n,(v[d+480208>>2]&524288)>>>19|0);n:{o:{p:{q:{r:{if(w[d+480208|0]&32){h=v[r>>2];g=v[d+484344>>2];b=x[d+1074446>>1];break r}b=65535;o=v[m>>2];H=w[m+16|0];a=Vb(o,H);e=v[a>>2];a=Ic(e,v[a+4>>2]);f=x[l>>1];if(a>>>0>f>>>0){b=x[ac(e,f)>>1]}u[d+1074446>>1]=b;s:{t:{g=v[d+484344>>2];h=v[r>>2];a=b&65535;if(lf(g,h)>>>0<=a>>>0){break t}a=Xb(g,a);if(Nb(v[a>>2],v[a+4>>2])){break t}a=0;break s}a=1}while(1){u:{v:{if(!a){b=65534;u[d+1074446>>1]=65534;break v}w:{x:{y:{a=b&65535;if(lf(g,h)>>>0<=a>>>0){z:{A:{if((a|0)==65535){e=Vb(o,H);break A}e=Vb(o,H);if(Ic(v[e>>2],v[e+4>>2])>>>0>(f&65535)>>>0){break z}}b=x[e+28>>1];if(b){g=v[e>>2];h=Ic(g,v[e+4>>2]);break x}a=f&65535;g=v[e>>2];h=Ic(g,v[e+4>>2]);if(!a|h>>>0<a>>>0){break y}while(1){b=a;a=a-1|0;if(!a){break y}if(x[ac(g,a)>>1]!=65535){continue}break}break x}f=f+1|0;u[l>>1]=f;break w}u[d+1074450>>1]=f;break r}b=0}u[d+1074448>>1]=b;v[d+480208>>2]=v[d+480208>>2]&-524289;while(1){a=b&65535;if(a>>>0>=h>>>0){break q}if(x[ac(g,a)>>1]==65534){b=b+1|0;u[l>>1]=b;continue}break}if(!iq(e,a)){break q}f=x[l>>1];o=v[m>>2];H=w[m+16|0];e=Vb(o,H)}b=65535;a=f&65535;if(Ic(v[e>>2],v[e+4>>2])>>>0>a>>>0){b=x[ac(v[Vb(o,H)>>2],a)>>1]}u[d+1074446>>1]=b;g=v[d+484344>>2];h=v[r>>2];a=b&65535;if(lf(g,h)>>>0<=a>>>0){break v}a=Xb(g,a);if(!Nb(v[a>>2],v[a+4>>2])){break u}}a=1;continue}a=0;continue}}a=b&65535;if(!ke(g,h,a)){break k}b=v[j>>2];if(b>>>0>=y[Xb(g,a)+12>>2]){v[j>>2]=0;b=0}if(v[d+480208>>2]&32?v[d+480272>>2]!=-1:0){break n}if(!Ys(i,x[l>>1],b,xp(A+16|0,c),w[A+24|0])){break n}a=v[d+480272>>2];if(a){if((a|0)>0){v[d+480272>>2]=a-1}Mn(i,1);Ys(i,x[l>>1],v[j>>2],xp(A+16|0,c),w[A+24|0]);break n}if(!(w[M|0]&64)){break q}b=0;if(FN(i,l,j)){break o}v[d+1074448>>2]=0;v[d+1074424>>2]=0;v[d+1074428>>2]=0;f=gj(v[d+484360>>2],v[G>>2])-1|0;a=w[F|0];if((f|0)>(a|0)){break p}xi(m,0)}Mn(i,1);break k}xi(m,a+1&255);Mn(i,1)}while(1){if((b|0)==256){RL(d);v[d+1074416>>2]=v[d+480196>>2];v[d+1074420>>2]=v[d+480204>>2];v[d+1074456>>2]=v[d+480200>>2];a=x[d+1074448>>1];u[d+1074450>>1]=a;b=v[d+1074424>>2];v[d+1074428>>2]=b;e=Vb(v[d+484360>>2],w[F|0]);f=v[e>>2];if(Ic(f,v[e+4>>2])>>>0>a>>>0){Za=d,_a=x[ac(f,a)>>1],u[Za+1074446>>1]=_a}Ys(i,a,b,xp(A+16|0,c),w[A+24|0]);if(!ke(v[d+484344>>2],v[r>>2],x[d+1074446>>1])){break k}}else{Qn((B(b,872)+d|0)+1074992|0,d,b&65535,134217728);b=b+1|0;continue}break}}rN(d,n,(v[d+480208>>2]&32)>>>5|0);a=Xb(v[d+484344>>2],x[d+1074446>>1]);a=$c(v[a>>2],v[v[a+48>>2]+12>>2],v[d+1074424>>2],0);f=c+B(x[d+480188>>1],872)|0;b=c;while(1){if((b|0)==(f|0)){B:{C:{a=v[d+484344>>2];b=x[d+1074446>>1];if(om(a,v[d+484348>>2],b)){a=Xb(a,b);b=v[a+16>>2];a=v[a+20>>2];if(oN(b,a)){break C}}v[d+1074408>>2]=v[d+480216>>2];a=v[d+480220>>2];break B}v[d+1074408>>2]=b}v[d+1074412>>2]=a;if(!w[A+24|0]){break m}b=v[d+1074416>>2];v[d+1074392>>2]=b;continue l}xb(A+16|0,q,82);D:{if(!yb(v[v[A+16>>2]>>2],v[A+20>>2])|w[b+805|0]!=1){break D}e=w[a+3|0];if((e|0)!=2&(e|0)!=3){break D}Za=b,_a=Lg(d,w[b+800|0],u[b+772>>1],v[b+704>>2]),v[Za+700>>2]=_a}xb(A+16|0,q,91);E:{if(!yb(v[v[A+16>>2]>>2],v[A+20>>2])){break E}if(Oc(w[a|0])){break E}e=w[b+788|0];if(!Oc(e)|w[b+791|0]!=19){break E}h=w[b+793|0];if((h&240)!=208|y[d+1074416>>2]>(h&15)>>>0){break E}Za=b,_a=Lg(d,e,u[b+772>>1],0),v[Za+700>>2]=_a}xb(A+16|0,q,92);F:{if(!yb(v[v[A+16>>2]>>2],v[A+20>>2])){break F}xb(A+8|0,q,5);if(yb(v[v[A+8>>2]>>2],v[A+12>>2])|v[d+1074416>>2]!=1|w[b+791|0]!=17){break F}v[d+1074420>>2]=B(w[b+793|0],1e4)}e=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[b+788|0]=e;t[b+789|0]=e>>>8;t[b+790|0]=e>>>16;t[b+791|0]=e>>>24;e=w[a+4|0]|w[a+5|0]<<8;t[b+792|0]=e;t[b+793|0]=e>>>8;e=v[b+676>>2];v[b+20>>2]=v[b+672>>2];v[b+24>>2]=e;v[b+88>>2]=v[b+88>>2]&-393217;xb(A+16|0,q,21);if(!yb(v[v[A+16>>2]>>2],v[A+20>>2])){t[b+831|0]=0}v[b+860>>2]=0;t[b+805|0]=0;a=a+6|0;b=b+872|0;continue}}break}a=v[d+1074416>>2];if(!a){v[d+1074416>>2]=1;a=1}b=v[d+480208>>2];c=v[d+1074392>>2];G:{H:{if(c){g=b&-4097;v[d+480208>>2]=g;e=v[d+480180>>2];if(e&1048580|(b&2097152?0:(e|0)==1)){break G}if(Ok(n)>>>0<=c>>>0){break G}if(!((c>>>0)%(v[d+1074400>>2]+a>>>0)|0)){break H}break G}g=b&-528385}v[d+480208>>2]=g|4096}j=fb-16|0;fb=j;u[d+1074444>>1]=65535;a=d+1074436|0;v[a>>2]=-1;v[a+4>>2]=-1;F=d+480180|0;_=d+1075809|0;r=d+1074312|0;E=d+480208|0;G=d+1074376|0;Y=d+480188|0;$=d+480210|0;X=d+480190|0;N=d+480192|0;while(1){I:{if(x[Y>>1]<=p>>>0){J:{if(!(w[E+1|0]&16)){break J}if(!hN(d,G,Vb(v[d+484360>>2],w[d+484376|0]),1)){break J}v[E>>2]=v[E>>2]|524288}fb=j+16|0;break I}n=B(p,872)+d|0;i=n+1075785|0;e=w[i|0];l=n+1075784|0;s=w[l|0];R=n+1075781|0;c=w[R|0];a=v[d+1074392>>2];b=v[d+1074400>>2];f=v[d+1074416>>2];Q=n+1075782|0;g=w[Q|0];m=n+1075783|0;H=w[m|0];h=Us(g,H);q=n+1075843|0;t[q|0]=v[d+480208>>2]>>>12&1|w[q|0]&254;f=(a>>>0)%(b+f>>>0)|0;I=n+1075780|0;a=w[I|0];K:{L:{M:{if((a|0)==252){o=Rj(g,s);M=Rj(H,e);a=252;if((c-1&255)>>>0>249){break M}b=v[(B(c,160)+d|0)+906140>>2];if(!b){break M}jb[v[v[b>>2]+44>>2]](b,o,C(C(M>>>0)/C(999)));a=w[I|0]}if((a&255)==251){break L}}if(z[n+1075852>>2]==C(0)|H){break K}}o=v[E>>2]&4096;N:{if(!o){b=w[n+1075862|0];break N}b=w[R|0];t[n+1075862|0]=b}if((b-1&255)>>>0>249){break K}M=(B(b&255,160)+d|0)+906140|0;b=v[M>>2];if(!b){break K}O:{if(!o){a=x[n+1075860>>1];break O}a=Ey(w[Q|0],w[l|0]);u[n+1075860>>1]=a;V=C(C(Ey(w[m|0],w[i|0])>>>0)/C(999));z[n+1075856>>2]=V;Za=n+1075852|0,$a=C(C(V-C(jb[v[v[b>>2]+48>>2]](b,a)))/C(Ok(G)>>>0)),z[Za>>2]=$a;b=v[M>>2]}i=a;a=(v[d+1074392>>2]+1|0)==(Ok(G)|0);jb[v[v[b>>2]+(a?44:104)>>2]](b,i,z[(a?n+1075856|0:n+1075852|0)>>2]);a=w[I|0]}i=n+1074992|0;if(YM(a&255)){b=fb-16|0;fb=b;u[b+12>>1]=0;v[b+8>>2]=0;a=Rh(b+8|0);c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[i+788|0]=c;t[i+789|0]=c>>>8;t[i+790|0]=c>>>16;t[i+791|0]=c>>>24;a=w[a+4|0]|w[a+5|0]<<8;t[i+792|0]=a;t[i+793|0]=a>>>8;fb=b+16|0;h=0;H=0;s=0;g=0;e=0;c=0}P:{if(!(w[E+1|0]&16)){CM(d,i);break P}if(!c){break P}v[n+1075752>>2]=0}Q:{R:{if((H|0)==33){xb(j+8|0,r,30);a=e>>>4|0;vy(d,p&65535,a+(e&15)|0,yb(v[v[j+8>>2]>>2],v[j+12>>2]));break R}a=0;if((H-19&255)>>>0>1){break R}S:{if(!(!(v[F>>2]&16777250)|e)){e=w[n+1075825|0];break S}t[n+1075825|0]=e}b=e&240;if((b|0)==208){b=e&15;if(!b){b=v[F>>2];if(b&16777248){a=1;break R}if((b|0)!=2){break R}break Q}if(b>>>0>=v[d+1074400>>2]+v[d+1074416>>2]>>>0){xb(j+8|0,r,14);a=b;if(!yb(v[v[j+8>>2]>>2],v[j+12>>2])){break R}if(!c){break Q}t[n+1075795|0]=c;break Q}a=b;break R}if(!(w[E+1|0]&16)|(b|0)!=224){break R}b=v[F>>2];if(v[d+1074396>>2]?b&16777250:0){break R}l=b&2;b=e&15;if(b?0:l){break R}v[d+1074396>>2]=b+1}b=v[F>>2]==16&(H|0)==19&(e&240)==208;M=b?0:a;T:{if(!M|w[I|0]!=255|w[Q|0]!=2){break T}xb(j+8|0,r,74);if(!yb(v[v[j+8>>2]>>2],v[j+12>>2])){break T}t[Q|0]=0}W=e&15;a=v[d+1074392>>2];xb(j+8|0,r,72);U:{if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){o=0;if(M>>>0>=y[d+1074416>>2]){break U}}xb(j+8|0,r,88);o=(f|0)==(M|0)|(a|0)==(M|0);if(!(!yb(v[v[j+8>>2]>>2],v[j+12>>2])|!M)){break U}o=(a|0)==(M|0)}xb(j+8|0,r,44);b=b?W|144:e;V:{if(!yb(v[v[j+8>>2]>>2],v[j+12>>2])){a=w[q|0];break V}a=w[q|0]&-2|(f|0)==(M|0)}t[q|0]=a&253|(o?2:0);xb(j+8|0,r,66);h=(!M|yb(v[v[j+8>>2]>>2],v[j+12>>2])^1)&h;W:{X:{if(!(v[d+1074392>>2]|(!(w[$|0]&32)|!c))){v[n+1075652>>2]=0;if(o){break X}if(!ni(v[i+8>>2],v[i+12>>2])){break W}t[n+1075795|0]=c;if(x[X>>1]<c>>>0){break W}a=B(c,104)+d|0;v[n+1075680>>2]=x[a+484410>>1];u[n+1075764>>1]=t[a+484417|0];break W}if(!o){break W}}e=w[I|0];if(c){t[n+1075795|0]=c}Y:{Z:{if(!Oc(e)){break Z}xb(j+8|0,r,67);if(!yb(v[v[j+8>>2]>>2],v[j+12>>2])){break Z}a=u[n+1075762>>1];_:{if(!c|h){break _}f=Jy(d,e,c);if(!f){break _}a=t[Xj(d,f)+36|0]}e=(a+e|0)-132>>>0<4294967176?0:e;break Y}if(!(v[F>>2]&25165856)){break Y}l=x[N>>1];if(!l){break Y}if(e){a=Oc(e)}else{a=1}if(!a){break Y}f=c;$:{if(!c){f=w[n+1075796|0];if(!f){break $}}if(v[((f<<2)+d|0)+900380>>2]?f>>>0<=l>>>0:0){break Y}e=0}c=0}if(!((H|0)!=25|b)){xb(j+8|0,r,55);a=yb(v[v[j+8>>2]>>2],v[j+12>>2]);c=a?0:c;e=a?0:e}xb(j+8|0,r,65);a=(c|0)!=0;l=yb(v[v[j+8>>2]>>2],v[j+12>>2]);ca=!e;K=1;aa:{if(v[F>>2]&16777248){break aa}xb(j+8|0,r,107);if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){break aa}xb(j,r,85);K=0;if(!yb(v[v[j>>2]>>2],v[j+4>>2])){break aa}if(ni(v[i+8>>2],v[i+12>>2])){break aa}K=1;f=v[n+1075096>>2];if(!f){break aa}K=Md(v[f>>2],v[f+20>>2])^1}m=a&l;a=a&ca;ba:{ca:{da:{ea:{fa:{ga:{ha:{if(!(v[F>>2]&1048580)){break ha}ia:{if((e|0)!=255){break ia}if(!(!((g|0)==1|c)&(H|0)!=13)){xb(j+8|0,r,55);if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){break ia}}f=v[n+1075648>>2];if(t[f+60|0]&1?f:0){break ia}v[n+1075680>>2]=0;a=n+1075080|0;v[a>>2]=v[a>>2]|2097152;ja:{if(!(v[d+480208>>2]&4096)){break ja}xb(j+8|0,r,86);if(!yb(v[v[j+8>>2]>>2],v[j+12>>2])){break ja}v[a>>2]=v[a>>2]|4096}c=0;e=0;a=0;f=0;l=1;if(m){break ca}break ba}xb(j+8|0,r,59);if(!yb(v[v[j+8>>2]>>2],v[j+12>>2])|v[E>>2]&4096){break ha}if(!e){e=w[n+1075789|0]-w[n+1075762|0]|0;break ga}if(e>>>0>250){K=0;m=1;e=0;break ga}if(!c){xb(j+8|0,r,98);if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){break ga}}K=1;m=1;break ga}f=0;if(!a){break ea}break fa}f=e;h=0}xb(j+8|0,r,65);if(!yb(v[v[j+8>>2]>>2],v[j+12>>2])){break da}e=f;f=1}a=e;l=1;if(m){break ca}break ba}e=f;f=1;l=m}ka:{la:{if(!x[N>>1]){if(x[X>>1]<c>>>0){break ka}a=(B(c,104)+d|0)+484380|0;break la}a=v[n+1075096>>2];if(!a){break ka}}ma:{if(u[a+34>>1]<0){break ma}if(v[F>>2]==2){if(!Md(v[a>>2],v[a+20>>2])){break ma}}v[n+1075680>>2]=x[a+30>>1]}if(!l){break ka}Fp(i,x[a+28>>1],d)}a=e}xb(j+8|0,r,71);if(!(!yb(v[v[j+8>>2]>>2],v[j+12>>2])|!c)){t[n+1075831|0]=32}na:{if(!x[N>>1]){break na}xb(j+8|0,r,100);if(!yb(v[v[j+8>>2]>>2],v[j+12>>2])|!c){break na}if(Oc(a&255)){break na}e=v[E>>2];oa:{if(h){if(e&8){break oa}break na}if(!(e&4)){break na}}Ol(i);v[n+1075688>>2]=65536;e=n+1075080|0;v[e>>2]=v[e>>2]|2097152}if(f){xb(j+8|0,r,11);pa:{qa:{ra:{if(!(yb(v[v[j+8>>2]>>2],v[j+12>>2])|v[F>>2]==268435456)){e=x[N>>1];break ra}xb(j+8|0,r,87);f=0;if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){f=ni(v[i+8>>2],v[i+12>>2])^1}e=x[N>>1];sa:{if(e){if(c>>>0>e>>>0){break qa}if(v[n+1075648>>2]!=v[((c<<2)+d|0)+900380>>2]|f){break sa}break qa}if((f^-1)&v[n+1075096>>2]==((B(c,104)+d|0)+484380|0)){break pa}}a=w[n+1075789|0]}if(!(e&65535)){break pa}}if(!(v[F>>2]&1048588)){break pa}Ol(i);t[n+1075810|0]=0;v[n+1075748>>2]=0;v[n+1075688>>2]=65536;e=n+1075080|0;v[e>>2]=v[e>>2]&-2101249|2097152;xb(j+8|0,r,86);if(!yb(v[v[j+8>>2]>>2],v[j+12>>2])){break pa}v[e>>2]=v[e>>2]&-2049}c=K?c:0}l=a&255;ta:{if(l>>>0<251){break ta}xb(j+8|0,r,50);ua:{if(!yb(v[v[j+8>>2]>>2],v[j+12>>2])|!c){break ua}e=Jy(d,w[n+1075791|0],c);if(!e){break ua}e=B(e,104)+d|0;if(u[e+484414>>1]<0){break ua}v[n+1075680>>2]=x[e+484410>>1]}xb(j+8|0,r,100);if(Za=yb(v[v[j+8>>2]>>2],v[j+12>>2]),_a=0,ab=v[E>>2]&4,ab?Za:_a){break ta}c=0}e=Oc(l);if(e){t[n+1075794|0]=a;t[n+1075791|0]=a;if(!h){DM(d,p&65535,c,l,0)}QO(i)}va:{wa:{xa:{ya:{za:{if(c){f=n+1075096|0;m=v[f>>2];wp(d,i,c,h,1,1);a=v[f>>2];Aa:{if(!a|!(w[a+35|0]&2)){break Aa}K=v[d+1298300>>2];if(!sd(K)){break Aa}cz(K,p&65535,a+68|0)}Ba:{Ca:{if(v[F>>2]==1){if(!h){break Ca}xb(j+8|0,r,85);if(!yb(v[v[j+8>>2]>>2],v[j+12>>2])){break Ca}break Ba}xb(j+8|0,r,50);if((e|yb(v[v[j+8>>2]>>2],v[j+12>>2])^1)!=1){break Ba}}t[n+1075795|0]=0}xb(j+8|0,r,42);if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){if(!e|(m|0)==v[f>>2]){break ya}break za}if(v[F>>2]&16777248){a=0;if(e&(m|0)!=v[f>>2]){break xa}}xb(j+8|0,r,107);Da:{if(!yb(v[v[j+8>>2]>>2],v[j+12>>2])|(m|0)==v[f>>2]){break Da}if((e^1|h)==1){a=n+1075068|0;if(y[a>>2]>=y[i+4>>2]){break Da}v[a>>2]=0;break ya}h=0}xb(j+8|0,r,85);if(!yb(v[v[j+8>>2]>>2],v[j+12>>2])){break ya}if(!ni(v[i+8>>2],v[i+12>>2])){break za}break ya}if(!l){a=h;break va}f=0;m=n+1075795|0;a=w[m|0];if(!(!a|e^1)){wp(d,i,a,h,!(v[n+1075096>>2]?1:v[n+1075648>>2]),!(v[F>>2]&1048580));t[m|0]=0;f=1}a=h;break wa}v[i>>2]=0;v[i+4>>2]=0}a=h}f=0;if(!l){break va}}e=v[n+1075096>>2];Ea:{if(!e|!(w[e+35|0]&2)){break Ea}h=v[d+1298300>>2];if(!sd(h)){break Ea}if(!f){if(EM(h,p&65535)){break Ea}}cz(h,p&65535,e+68|0)}e=p&65535;Ss(d,i,l,a,!(v[F>>2]&1048580),0,e);mN(v[F>>2],x[Y>>1],G,e);if(!(!a|(!(v[F>>2]&1048580)|!c))){c=n+1075080|0;v[c>>2]=v[c>>2]|2097152;Ol(i);t[n+1075810|0]=0;v[n+1075748>>2]=0}if(!(v[n+1075080>>2]&512)){break va}if(!sd(v[d+1298300>>2])){break va}if(l>>>0<=253){if((l|0)!=253){break va}xb(j+8|0,r,99);if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){break va}}xb(j+8|0,r,110);if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){dz(v[d+1298300>>2],e,0,1,0)}Sj(v[d+1298300>>2],e)}Fa:{Ga:{switch(g-1|0){case 0:s=s>>>0<64?s:64;v[n+1075680>>2]=s<<2;c=n+1075080|0;v[c>>2]=v[c>>2]|2097152;break Fa;case 1:break Ga;default:break Fa}}Pl(d,i,s,6)}if(x[d+480192>>1]){BM(d,p&65535)}h=a}xb(j+8|0,r,77);if(Za=yb(v[v[j+8>>2]>>2],v[j+12>>2]),_a=0,ab=v[((p<<5)+d|0)+480280>>2]&1024,ab?Za:_a){break Q}a=v[d+1074392>>2];xb(j+8|0,r,75);f=a>>>0>=M>>>0;Ha:{Ia:{Ja:{Ka:{if(!yb(v[v[j+8>>2]>>2],v[j+12>>2])|!M){break Ka}c=v[d+1074392>>2];if(!c){break Ja}f=1;if((c|0)!=(M|0)){break Ka}f=!w[R|0]&(g|0)!=11}a=g;if(!f|a>>>0<3){break Ja}if((a|0)==11){a=j+8|0;Iy(a,d,w[I+3|0],w[I+4|0],M);a=w[Qe(a)|0];Dn(d,i,x[j+8>>1]);if(a){break Ia}g=11;break Ja}xb(j+8|0,r,62);La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{if(!(!yb(v[v[j+8>>2]>>2],v[j+12>>2])|s)){s=0;g=0;Sa:{switch(a-8|0){case 0:break Ra;case 1:break Sa;default:break Ja}}if(w[E+1|0]&16){break Ja}v[n+1075684>>2]=0;break Ja}xb(j+8|0,r,41);Ta:{if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){break Ta}if(s){t[n+1075826|0]=s;break Ta}s=w[n+1075826|0]}Ua:{switch(a-3|0){case 0:case 1:Va:{Wa:{if(s){break Wa}xb(j+8|0,r,41);if(!yb(v[v[j+8>>2]>>2],v[j+12>>2])){break Wa}s=w[n+1075826|0];if(s){break Va}s=0;break Ja}t[n+1075826|0]=s}Jn(d,i,((a|0)==3?s<<4:s)&255);break Ja;case 2:if((M|0)!=v[d+1074392>>2]){xb(j+8|0,r,41);g=5;if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){break Ja}}xb(j+8|0,r,41);In(d,i,s,yb(v[v[j+8>>2]>>2],v[j+12>>2]));g=5;break Ja;case 3:if((M|0)!=v[d+1074392>>2]){xb(j+8|0,r,41);g=6;if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){break Ja}}xb(j+8|0,r,41);Hn(d,i,s,yb(v[v[j+8>>2]>>2],v[j+12>>2]));g=6;break Ja;case 11:break La;case 12:break Ma;case 10:break Na;case 9:break Oa;case 7:break Pa;case 6:break Qa;case 5:break Ra;case 4:break Ua;default:break Ja}}xb(j+8|0,r,53);if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){t[n+1075815|0]=s&15;g=7;break Ja}Nk(i,s<<4);g=7;break Ja}Nk(i,s);g=8;break Ja}xb(j+8|0,r,62);uy(d,i,s,yb(v[v[j+8>>2]>>2],v[j+12>>2])^1);g=9;break Ja}xb(j+8|0,r,62);uy(d,i,s<<4&240,yb(v[v[j+8>>2]>>2],v[j+12>>2])^1);g=10;break Ja}g=12;xb(j+8|0,r,12);AM(d,p&65535,s<<2&252,yb(v[v[j+8>>2]>>2],v[j+12>>2]));break Ja}xb(j+8|0,r,12);zM(d,p&65535,s<<2&252,yb(v[v[j+8>>2]>>2],v[j+12>>2]));g=13;break Ja}g=15;if(!o){break Ja}a=v[n+1075096>>2];if(!a|s>>>0>9){break Ja}Xa:{if(!s){c=v[n+1075656>>2];break Xa}c=v[zb(a+68|0,s-1|0)>>2];v[n+1075656>>2]=c}Kn(d,i,c);break Ja}g=14;if(s>>>0>1){break Ja}t[q|0]=w[q|0]&247|!s<<3}c=b;Ya:{Za:{_a:{$a:{switch(H-1|0){case 12:if(!(w[E+1|0]&16)){break Ia}a=B(p,872)+d|0;v[a+1075680>>2]=b>>>0<64?b<<2:256;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Ia;case 1:if(!b){c=0;if(t[F|0]&1){break Ha}}AM(d,p&65535,b,0);break Ia;case 2:if(!b){c=0;if(t[F|0]&1){break Ha}}zM(d,p&65535,b,0);break Ia;case 10:if(!b){c=0;if(v[F>>2]==1){break Ha}}Jn(d,i,b);break Ia;case 3:Dn(d,i,b);break Ia;case 5:if(!(!b&v[F>>2]==1)){Jn(d,i,b)}Dn(d,i,0);break Ia;case 4:Nk(i,b);break Ia;case 6:if(!(!b&v[F>>2]==1)){Jn(d,i,b)}Nk(i,0);break Ia;case 15:if(!(w[E+1|0]&16)){break Ia}break Ya;case 16:xb(j+8|0,r,5);if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){if(!(w[E+1|0]&16)){break Ia}if(b){break Ya}break Ia}c=Gn(d,x[d+1074446>>1],v[d+1074424>>2],p&65535,0);ab:{if(!(v[d+480180>>2]&16777250)){break ab}if(c){t[(B(p,872)+d|0)+1075827|0]=c;break ab}c=w[(B(p,872)+d|0)+1075827|0]}v[j+8>>2]=B(c,1e4);uc(j+8|0,B(v[v[d+8>>2]+24>>2],1e4));a=fb-16|0;fb=a;e=v[j+8>>2];v[a+8>>2]=e;b=v[d+8>>2];bb:{if(e>>>0>=(v[d+480180>>2]&16393?1e4:32e4)>>>0){e=v[d+480208>>2];xb(a,d+1074312|0,92);if((yb(v[v[a>>2]>>2],v[a+4>>2])|0)==((e&4096)>>>12|0)){break bb}v[a>>2]=B(v[b+24>>2],1e4);Za=d+1074420|0,_a=v[Eb(a+8|0,a)>>2],v[Za>>2]=_a;break bb}if(w[d+480209|0]&16){break bb}f=d+1074420|0;e=(e>>>0)/1e4|0;h=B(e&15,1e4);v[f>>2]=v[f>>2]+((e&240)==16?h:0-h|0);e=v[b+20>>2];b=v[b+24>>2];xb(a,d+1074312|0,8);xo(f,B(e,1e4),yb(v[v[a>>2]>>2],v[a+4>>2])?255e4:B(b,1e4))}fb=a+16|0;break Ha;case 9:if(!o|v[F>>2]==4&h){break Ia}lN(d,i,p&65535,v[d+1074424>>2],x[d+1074446>>1]);break Ia;case 43:if(!o){break Ia}c=Bia(v[(B(p,872)+d|0)+1075068>>2],0,b,0);a=ib;f=a>>>8|0;Kn(d,i,Pc((a&255)<<24|c>>>8,f));break Ia;case 0:if(v[d+1074392>>2]){break Ia}a=B(p,872)+d|0;cb:{if(w[a+1075789|0]?v[a+1075692>>2]:0){break cb}a=v[a+1075648>>2];if(a){if(jj(w[a+31|0])){break cb}}xb(j+8|0,r,13);if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){break cb}if(v[F>>2]&16777248){break Ia}}if(!b){c=0;if(w[F|0]&5){break Ha}t[(B(p,872)+d|0)+1075797|0]=1;break Ha}a=B(p,872)+d|0;t[a+1075798|0]=b;t[a+1075797|0]=1;break Ia;case 14:if(v[F>>2]&1048580){b=b&240?b:w[(B(p,872)+d|0)+1075799|0]&240|b;if(!(b&15)){b=w[(B(p,872)+d|0)+1075799|0]&15|b}b=b|256}c=b;xb(j+8|0,r,23);if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){b=d;f=p&65535;if(c){t[(B(p,872)+d|0)+1075799|0]=c;a=c}else{a=w[(B(p,872)+d|0)+1075799|0]}ty(b,f,a&255,(g|0)==15?s+1|0:0);break Ha}db:{if(c){t[(B(p,872)+d|0)+1075799|0]=c;break db}c=w[(B(p,872)+d|0)+1075799|0]}ty(d,p&65535,c,(g|0)==15?s+1|0:0);break Ha;case 17:if(!(w[E+1|0]&16)){break Ia}xb(j+8|0,r,22);eb:{fb:{if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){if(!b){b=0;break fb}if(w[E|0]&4){break fb}a=b&240?b-16|0:b;b=a-((a&15)!=0)|0;t[(B(p,872)+d|0)+1075832|0]=b;break fb}xb(j+8|0,r,71);if(!yb(v[v[j+8>>2]>>2],v[j+12>>2])){break eb}}a=(B(p,872)+d|0)+1075831|0;t[a|0]=w[a|0]|128}a=B(p,872)+d|0;t[a+1075797|0]=18;if(!b){c=0;break Ha}t[a+1075832|0]=b;break Ia;case 22:if(!(w[E+1|0]&16)){break Ia}a=v[F>>2];c=b<<!(a&59593760);if(c>>>0<=128){v[d+1074456>>2]=c<<1;break Ha}if(a&16777250){break Ha}v[d+1074456>>2]=256;break Ha;case 23:xb(j+8|0,r,9);if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){yM(d,b,(B(p,872)+d|0)+1075809|0);break Ia}yM(d,b,_);break Ia;case 8:if(!(w[E+1|0]&16)){break Ia}Pl(d,i,b,8);break Ia;case 28:uy(d,i,b,1);break Ia;case 7:dN(i,b);break Ia;case 25:eN(d,i,b);break Ia;case 18:h=d+1074376|0;e=p&65535;f=B(e,872);c=(h+f|0)+616|0;a=b&15;gb:{hb:{switch(b>>>4|0){case 0:c=(b&1)<<14;e=x[d+480188>>1];a=0;while(1){if((a|0)==(e|0)){break gb}f=(B(a,872)+d|0)+1075080|0;v[f>>2]=(c|v[f>>2]&-16385)^16384;a=a+1|0;continue};case 1:if(a){sy(d,c,a);break gb}if(!(v[d+480180>>2]&1048580)){break gb}sy(d,c,0);break gb;case 2:if(a){ry(d,c,a);break gb}if(!(v[d+480180>>2]&1048580)){break gb}ry(d,c,0);break gb;case 3:c=(d+f|0)+1075080|0;v[c>>2]=v[c>>2]&-1048577|((a|0)!=0)<<20;break gb;case 4:t[(d+f|0)+1075814|0]=b&7;break gb;case 5:if(!(w[d+480209|0]&16)){break gb}f=v[d+480180>>2];if(f&69206025){c=B(e,872)+d|0;u[c+1075764>>1]=a<<28>>24;f=c+1075692|0;if(!v[f>>2]){break gb}if(!Oc(w[c+1075780|0])){break gb}c=B(e,872)+d|0;Za=f,_a=Lg(d,w[c+1075789|0],a<<28>>24,v[c+1075696>>2]),v[Za>>2]=_a;break gb}c=Oc(w[(B(e,872)+d|0)+1075780|0]);if((f|0)==16){if(!c){break gb}c=B(e,872)+d|0;f=v[c+1075096>>2];if(!f){break gb}t[f+37|0]=a;u[c+1075764>>1]=a;c=c+1075692|0;if(!v[c>>2]){break gb}f=c;c=B(e,872)+d|0;Za=f,_a=Lg(d,w[c+1075789|0],a,v[c+1075696>>2]),v[Za>>2]=_a;break gb}if(!c){break gb}a=B(e,872)+d|0;c=(b<<4^-128)<<24>>24;u[a+1075764>>1]=c;e=a+1075692|0;if(!v[e>>2]){break gb}Za=e,_a=Lg(d,w[a+1075789|0],c,v[a+1075696>>2]),v[Za>>2]=_a;break gb;case 6:if(!(w[d+480209|0]&16)){break gb}Hy(d,h,c,a);break gb;case 7:t[(d+f|0)+1075817|0]=b&7;break gb;case 8:if(!(w[d+480209|0]&16)){break gb}Pl(d,c,a,4);break gb;case 9:ty(d,e,a,0);break gb;case 10:if(a){In(d,c,a,0);break gb}if(!(v[d+480180>>2]&1048580)){break gb}In(d,c,0,0);break gb;case 11:if(a){Hn(d,c,a,0);break gb}if(!(v[d+480180>>2]&1048580)){break gb}Hn(d,c,0,0);break gb;case 12:vy(d,e,a,0);break gb;case 15:break hb;default:break gb}}if(v[d+480180>>2]==1){t[(B(e,872)+d|0)+1075838|0]=a;if(!(w[d+480209|0]&16)){break gb}CM(d,c);break gb}t[(B(e,872)+d|0)+1075836|0]=a}break Ia;case 19:xM(d,p&65535,b);break Ia;case 24:xb(j+8|0,r,55);if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){if(v[d+1074392>>2]!=(b|0)){break Ia}a=v[(B(p,872)+d|0)+1075648>>2];if(t[a+60|0]&1?a:0){break Za}if(!(!(w[Q|0]?1:w[R|0])|b)){a=(B(p,872)+d|0)+1075080|0;v[a>>2]=v[a>>2]|4096;break Za}a=B(p,872)+d|0;v[a+1075680>>2]=0;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Za}if(w[E+1|0]&16){break Za}break Ia;case 27:a=(b&240)-16>>>4|0;if(a>>>0>9){break Ia}if(!(1<<a&880)){if(!a){break _a}if((a|0)!=1){break Ia}wM(d,i,b&15);break Ia}xb(j+8|0,r,58);if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){break Ia}xM(d,p&65535,b);break Ia;case 34:case 35:if(!(w[E+1|0]&16)&(H|0)!=36){break Ia}c=p&65535;iN(d,c,G,(H|0)==36);a=Ls(d,v[i+88>>2],v[i+656>>2]);if(!a){break Ia}jb[v[v[a>>2]+80>>2]](a,(x[i+774>>1]&65532)>>>2^8192,c);break Ia;case 20:if(!(w[E+1|0]&16)|b>>>0>64){break Ia}a=B(p,872)+d|0;v[a+1075740>>2]=b;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Ia;case 21:g=v[d+480180>>2];e=v[d+480208>>2];a=b;ib:{if(a){t[i+816|0]=a;break ib}a=w[i+816|0]}f=a&255;h=a&240;c=a&15;jb:{kb:{if(!(!h|(c|0)!=15)){if(!(e&4096)){break jb}a=f>>>4|0;break kb}e=e&4096;if(!(!c|(h|0)!=240)){if(!e){break jb}a=0-c|0;break kb}if(e){break jb}if(c){a=0-c|0;if(!(g&25690144)|!h){break kb}break jb}if((a&255)>>>0<16){break jb}a=f>>>4|0}Za=i,_a=Ub(a+v[i+748>>2]|0,0,64),v[Za+748>>2]=_a}break Ia;case 26:cN(i,b);break Ia;case 29:if(!(w[E+1|0]&16)){break Ia}a=B(p,872)+d|0;v[a+1075716>>2]=b;xb(j+8|0,r,60);if(Za=0,_a=yb(v[v[j+8>>2]>>2],v[j+12>>2]),ab=w[a+1075722|0]&4,ab?Za:_a){break Ia}a=B(p,872)+d|0;v[a+1075732>>2]=b;v[a+1075724>>2]=b;break Ia;case 11:gN(d,G,p&65535);break Ia;case 13:a=fN(d,G,p&65535,b);if((a|0)==-1){break Ia}v[d+1074436>>2]=a;if(!(w[d+480208|0]&32)){break Ia}u[d+1074444>>1]=x[d+1074448>>1];break Ia;case 37:case 38:case 39:case 40:c=(H|0)==38|(H|0)==40;e=(H&254)==40;lb:{mb:{nb:{if(w[d+480209|0]&16){a=w[i+848|0];f=b&240;if(f){a=f|a&15;t[i+848|0]=a}f=b&15;if(f){a=f|a&-16;t[i+848|0]=a}t[i+849|0]=(a&240)>>>4;if(v[d+480180>>2]!=32768){break lb}break nb}if(v[d+480180>>2]==32768){break nb}a=w[i+849|0]-1|0;t[i+849|0]=a;if(a&255){break lb}a=w[i+848|0];break mb}a=w[i+848|0];if((a&240)==16){break mb}if(!(w[d+480209|0]&16)){break lb}}t[i+849|0]=(a&240)>>>4;a=a&15;a=c?a:0-a|0;c=v[i+656>>2];ob:{if(lj(c)){v[i+852>>2]=v[i+852>>2]+B(a,v[v[c+44>>2]+36>>2]);break ob}Za=i,_a=Lg(d,Ks(d,v[i+700>>2],u[i+772>>1],v[i+704>>2])+a|0,u[i+772>>1],v[i+704>>2]),v[Za+700>>2]=_a}if(!e){break lb}v[i>>2]=0;v[i+4>>2]=0}break Ia;case 41:kN(i,b);break Ia;case 42:if(v[d+1074392>>2]|W>>>0>1|b>>>0>47){break Ia}a=(b&240)==16;f=a?x[d+480188>>1]-1|0:p;c=a?0:p;a=((W|0)==1)<<26;while(1){e=c&65535;if(e>>>0>(f&65535)>>>0){break Ia}h=((e<<5)+d|0)+480280|0;v[h>>2]=a|v[h>>2]&-67108865;e=(B(e,872)+d|0)+1075080|0;v[e>>2]=a|v[e>>2]&-67108865;c=c+1|0;continue};case 44:break $a;default:break Ha}}jN(i,b);break Ia}vM(d,i,b&15);break Ia}Fn(d,i);break Ia}pN(d,G,b)}c=b}xb(j+8|0,r,78);if(!(!yb(v[v[j+8>>2]>>2],v[j+12>>2])|!c)){$M(i,c&255)}a=w[R|0];if(!a){break Q}t[n+1075796|0]=a}p=p+1|0;continue}break}a=1;break j}a=0}fb=A+32|0;N=!v[d+1074420>>2]|a^1;pb:{if(N){break pb}a=nN(d,d+1074376|0);v[d+1074380>>2]=a;v[d+1074404>>2]=a;b=Pd(x[d+480188>>1],1,31);qb:{if(Nd(w[d+1074366|0])){a=v[d+24628>>2];if((a|0)>=129){a=((B(a-128|0,b+4|0)|0)/16|0)+128|0}l=((B(v[d+480228>>2],a)<<1&-128)>>>0)/w[(b>>>1|0)+32144|0]|0;break qb}l=v[d+480228>>2]}u[d+480212>>1]=0;j=d+1074312|0;R=d+1074365|0;F=d+480180|0;G=d+480210|0;H=d+480209|0;Q=d+1074366|0;W=d+1074364|0;Y=d+1074360|0;s=0;while(1){if((s|0)==256){a=v[d+24608>>2];f=x[d+480212>>1];if(a>>>0>f>>>0){break pb}e=fb-16|0;fb=e;v[e+8>>2]=d;b=d+1074478|0;c=b;f=b+(f<<1)|0;rb:{a=b+(a<<1)|0;b=a-b|0;if((b|0)<3){break rb}h=b>>1;b=(h-2|0)/2|0;while(1){if((b|0)<0){break rb}$x(c,v[e+8>>2],h,c+(b<<1)|0);b=b-1|0;continue}}h=a-c>>1;b=a;while(1){if((b|0)!=(f|0)){if(op(v[e+8>>2],x[b>>1],x[c>>1])){ay(b,c);$x(c,v[e+8>>2],h,c)}b=b+2|0;continue}break}b=a-c>>1;while(1){if((b|0)>1){a=a-2|0;ay(c,a);b=b-1|0;$x(c,v[e+8>>2],b,c);continue}break}fb=e+16|0}else{m=B(s,872)+d|0;q=m+1075080|0;sb:{if(!(v[q>>2]&4096)|(v[m+1075016>>2]|(v[m+1075012>>2]|v[m+1075688>>2]))){break sb}xb(k+16|0,j,64);if(yb(v[v[k+16>>2]>>2],v[k+20>>2])){break sb}v[m+1075068>>2]=0;a=m+1075084|0;v[a>>2]=0;v[a+4>>2]=0}a=x[d+480188>>1];c=v[q>>2];tb:{if(v[m+1075068>>2]|a>>>0>s>>>0?c&1024:1){if(a>>>0>s>>>0){HL(d,s&65535)}u[m+1075834>>1]=0;break tb}e=0;I=m+1075712|0;v[I>>2]=0;A=m+1075672|0;v[A>>2]=0;r=m+1075e3|0;b=r;v[b>>2]=0;v[b+4>>2]=0;v[m+1075092>>2]=0;v[k+44>>2]=1065353216;u[k+42>>1]=0;M=m+1075648|0;E=v[M>>2];v[k+36>>2]=0;g=0;n=m+1075692|0;g=v[n>>2]?v[m+1075068>>2]!=0:g;i=m+1074992|0;ub:{vb:{wb:{if(a>>>0<=s>>>0){break wb}if(w[((s<<5)+d|0)+480288|0]){break vb}if(!E){break wb}e=w[E+34|0]!=0}if((e|g)!=1){break ub}}v[k+8>>2]=v[m+1075680>>2];v[k+32>>2]=v[m+1075744>>2];xb(k+16|0,j,28);b=k+8|0;a=yb(v[v[k+16>>2]>>2],v[k+20>>2])?k+32|0:b;c=fb-16|0;fb=c;e=d+1074312|0;xb(c+8|0,e,28);xb:{if(yb(v[v[c+8>>2]>>2],v[c+12>>2])){v[a>>2]=v[a>>2]+u[i+776>>1];ee(a,0,64);break xb}xb(c+8|0,e,1);e=u[i+776>>1];if(yb(v[v[c+8>>2]>>2],v[c+12>>2])){v[a>>2]=e+v[a>>2];ee(a,0,256);break xb}v[i+688>>2]=e+v[i+688>>2];ee(i+688|0,0,256);v[a>>2]=v[i+688>>2];u[i+776>>1]=0}fb=c+16|0;a=fb-16|0;fb=a;c=d+1074312|0;xb(a+8|0,c,28);yb:{zb:{if(!yb(v[v[a+8>>2]>>2],v[a+12>>2])){xb(a,c,1);if(!yb(v[v[a>>2]>>2],v[a+4>>2])){break zb}}v[i+684>>2]=v[i+692>>2]+u[i+778>>1];ee(i+684|0,0,256);break yb}v[i+692>>2]=v[i+692>>2]+u[i+778>>1];ee(i+692|0,0,256);u[i+778>>1]=0;v[i+684>>2]=v[i+692>>2]}fb=a+16|0;c=fb-16|0;fb=c;Ab:{if(!(w[i+90|0]&4)|(v[d+480208>>2]&2101248)==2101248){break Ab}Bb:{if(v[b>>2]<=0){xb(c+8|0,d+1074312|0,21);if(!yb(v[v[c+8>>2]>>2],v[c+12>>2])){break Bb}}f=5;if(!(v[d+480180>>2]&5)){xb(c+8|0,d+1074312|0,21);f=yb(v[v[c+8>>2]>>2],v[c+12>>2])?5:6}a=dy(d,w[i+825|0],w[i+820|0]);Cb:{if((w[i+825|0]&3)!=1){break Cb}xb(c+8|0,d+1074312|0,89);if(!yb(v[v[c+8>>2]>>2],v[c+12>>2])){break Cb}a=w[i+819|0];h=w[i+820|0];e=h<<2&124;a=(!(w[i+90|0]&2)|w[d+480209|0]&16?a:w[i+823|0]+a|0)&32?e^127:e;a=h&32?0-a|0:a}if(v[d+480180>>2]!=131072){a=v[b>>2]+((B(w[i+827|0],a)|0)/(1<<f)|0)|0}else{f=64-a|0;a=v[b>>2];a=((B(w[i+827|0],B(f,a))|0)/-8192|0)+a|0}v[b>>2]=a}a=v[d+480208>>2];if(!(v[d+480180>>2]&16777248)|a&4?a&4096:0){break Ab}xb(c+8|0,d+1074312|0,21);a=w[i+826|0];e=w[i+820|0];f=yb(v[v[c+8>>2]>>2],v[c+12>>2]);t[i+820|0]=(f?a<<2:e)+(f?e:a)}fb=c+16|0;h=s&65535;c=fb-16|0;fb=c;a=d+1074312|0;xb(c+8|0,a,71);Db:{if(yb(v[v[c+8>>2]>>2],v[c+12>>2])){a=(B(h,872)+d|0)+1075831|0;e=t[a|0];if((e|0)>=0){break Db}if(!(w[d+480209|0]&16|w[(B(h,872)+d|0)+1075797|0]!=18)){f=e&-33;t[a|0]=f;Eb:{Fb:{if((f|0)!=-64){e=e&223;if((e|0)!=128){break Fb}e=w[(B(h,872)+d|0)+1075832|0]>>>4|-64;break Eb}e=w[(B(h,872)+d|0)+1075832|0]&15|-128;break Eb}e=e-1|0}t[a|0]=e;a=(B(h,872)+d|0)+1075080|0;v[a>>2]=v[a>>2]|2097152}if((e&224)!=128){break Db}v[b>>2]=0;break Db}if(w[(B(h,872)+d|0)+1075797|0]!=18){break Db}xb(c+8|0,a,22);Gb:{if(yb(v[v[c+8>>2]>>2],v[c+12>>2])){o=B(h,872)+d|0;a=o+1075831|0;f=w[a|0];e=f<<24>>24;if(!((e|0)>=0|!v[o+1075068>>2])){Hb:{Ib:{if((f|0)!=192){if((f|0)!=128){break Ib}e=w[(B(h,872)+d|0)+1075832|0]>>>4|-64;break Hb}e=w[(B(h,872)+d|0)+1075832|0]&15|-128;break Hb}e=e-1|0}t[a|0]=e}if((e&192)!=128){break Gb}v[b>>2]=0;break Gb}a=w[(B(h,872)+d|0)+1075832|0];p=a>>>4|0;o=p+(a&15)|0;f=v[d+480180>>2];if(!(w[d+480208|0]&4?0:f&16777248)){p=p+1|0;o=o+2|0}a=(B(h,872)+d|0)+1075831|0;e=w[a|0];if(!(f&4)){e=(e&255)>>>0<o>>>0?e:0;if((e&255)>>>0>=p>>>0){v[b>>2]=0}t[a|0]=e+1;break Gb}Jb:{if(w[d+480209|0]&16){e=e&255?e-1|0:0;break Jb}t[a|0]=e+1}if(((e&255)>>>0)%(o>>>0)>>>0<p>>>0){break Gb}v[b>>2]=0}a=(B(h,872)+d|0)+1075080|0;v[a>>2]=v[a>>2]|2097152}a=B(h,872)+d|0;Kb:{if(w[a+1075797|0]!=18){break Kb}e=v[a+1075648>>2];if(!e){break Kb}a=w[e+34|0];if(!a|w[e+15|0]&2){break Kb}f=B(h,872)+d|0;if(v[f+1075080>>2]&134218752){break Kb}f=f+1075791|0;o=w[f|0];if(!Oc(o)){break Kb}a=v[(B(a,160)+d|0)+906140>>2];if(!a){break Kb}o=jb[v[v[a>>2]+100>>2]](a,o,h)|0;p=v[b>>2];if(!(!o|p)){jb[v[v[a>>2]+92>>2]](a,e,w[f|0]+255|0,0,h);break Kb}if(o|!p){break Kb}jb[v[v[a>>2]+92>>2]](a,e,w[f|0],x[(B(h,872)+d|0)+1075680>>1],h)}fb=c+16|0;ee(b,0,256);v[k+8>>2]=v[k+8>>2]<<6;Lb:{if(E){xb(k+16|0,j,31);if(yb(v[v[k+16>>2]>>2],v[k+20>>2])){Ps(d,i)}b=k+8|0;a=fb-16|0;fb=a;Mb:{if(!by(d,i,0)){break Mb}c=v[i+656>>2];f=d+1074312|0;xb(a+8|0,f,31);Nb:{if(yb(v[v[a+8>>2]>>2],v[a+12>>2])){e=v[i+724>>2];if(e){break Nb}break Mb}e=v[i+724>>2]}xb(a+8|0,f,31);p=e-yb(v[v[a+8>>2]>>2],v[a+12>>2])|0;e=Ep(c+48|0,p,256,64);K=w[c+65|0];Ob:{if((K|0)==255){break Ob}o=u[i+728>>1];if((o|0)==-1){break Ob}K=zb(v[c+48>>2],K);c=w[K+2|0];K=x[K>>1];xb(a+8|0,f,94);f=c<<2;e=(p|0)==(K|0)?f:e;if(yb(v[v[a+8>>2]>>2],v[a+12>>2])){e=o+(e-f<<1)|0;break Ob}if(!c){e=0;break Ob}e=(B(e,o)|0)/(f|0)|0}Za=b,_a=(B(Ub(e,0,512),v[b>>2])|0)/256|0,v[Za>>2]=_a}fb=a+16|0;UM(i,b);a=fb-16|0;fb=a;Pb:{if(!by(d,i,1)){break Pb}b=v[i+656>>2];c=d+1074312|0;xb(a+8|0,c,31);Qb:{if(yb(v[v[a+8>>2]>>2],v[a+12>>2])){e=v[i+732>>2];if(e){break Qb}break Pb}e=v[i+732>>2]}xb(a+8|0,c,31);c=Ep(b+68|0,e-yb(v[v[a+8>>2]>>2],v[a+12>>2])|0,64,64)-32|0;b=v[i+684>>2];Za=i,_a=Ub(((B(c,(b|0)>127?256-b|0:b)|0)/32|0)+b|0,0,256),v[Za+684>>2]=_a}fb=a+16|0;xb(k+16|0,j,115);if(yb(v[v[k+16>>2]>>2],v[k+20>>2])){break Lb}b=w[m+1075789|0];if(!b){break Lb}a=v[M>>2];if(!a|!w[a+26|0]){break Lb}WM(m+1075676|0,b,w[a+26|0],w[a+27|0]);break Lb}if(!(w[q+1|0]&16)){break Lb}v[m+1075688>>2]=0;v[k+8>>2]=0}Rb:{if(w[m+1075843|0]&8){f=0;v[k+8>>2]=0;break Rb}f=v[k+8>>2];if(!f){f=0;break Rb}if(w[q+3|0]&8){v[A>>2]=0;break Rb}if(Nd(w[R|0])){a=B(v[k+32>>2],v[m+1075740>>2]);b=a;c=a>>31;a=f<<8;Za=A,_a=Dc(Cia(Bia(b,c,a,a>>31),ib,1048576,0),ib),v[Za>>2]=_a;break Rb}a=B(v[k+32>>2],v[m+1075740>>2]);b=a;c=a>>31;a=B(v[d+1074456>>2],f);Za=A,_a=Dc(Cia(Bia(b,c,a,a>>31),ib,1048576,0),ib),v[Za>>2]=_a}v[I>>2]=f;Sb:{Tb:{f=v[n>>2];if(!(v[F>>2]==2|(f|0)>=v[d+480260>>2])){if(!cj(d)){break Tb}f=v[n>>2]}if((f|0)<v[d+480264>>2]){break Sb}xb(k+16|0,j,113);if(!yb(v[v[k+16>>2]>>2],v[k+20>>2])){break Sb}if(cj(d)){break Sb}v[n>>2]=v[d+480264>>2];break Sb}v[n>>2]=v[d+480260>>2]}xb(k+16|0,j,73);a=v[n>>2];v[k+36>>2]=a;Ub:{if((v[q>>2]&1572864)!=1572864){break Ub}b=v[d+480208>>2];if(b&2097152){if(!Us(w[m+1075782|0],w[m+1075783|0])|b&4096){break Ub}}b=m+1075704|0;Vb:{if((a|0)==v[b>>2]){f=v[m+1075708>>2];break Vb}v[b>>2]=a;c=a;a=m+1075764|0;b=m+1075696|0;f=Lg(d,Ks(d,c,u[a>>1],v[b>>2]),u[a>>1],v[b>>2]);v[m+1075708>>2]=f}v[k+36>>2]=f}o=fb-16|0;fb=o;p=B(h,872)+d|0;a=v[p+1075648>>2];Wb:{if(!a){break Wb}b=w[a+34|0];if(!b|w[a+15|0]&2|(!v[(B(b,160)+d|0)+906140>>2]|v[(B(h,872)+d|0)+1075080>>2]&134218752)){break Wb}b=B(h,872)+d|0;X=b+1075783|0;K=w[X|0];c=0;e=w[b+1075791|0];if(Oc(e)){c=w[Hb(a+108|0,e-1|0)|0]}b=b+1075780|0;Xb:{Yb:{if((K|0)==1){f=0;Zb:{_b:{switch((y[d+1074392>>2]%3|0)-1|0){case 0:f=w[(B(h,872)+d|0)+1075798|0]>>>4|0;break Zb;case 1:break _b;default:break Zb}}f=w[(B(h,872)+d|0)+1075798|0]&15}a=B(h,872)+d|0;t[a+1075793|0]=c;if(w[a+1075792|0]==(c+f|0)){break Xb}a=c;if(!(w[d+480209|0]&16)){break Yb}a=c;if(!Oc(w[b|0])){break Yb}break Xb}f=0;if(w[b|0]){break Xb}a=B(h,872)+d|0;if(!w[a+1075792|0]){break Xb}a=w[a+1075793|0]}Nl(d,h,(a&255)+f|0,x[(B(h,872)+d|0)+1075680>>1])}a=(B(h,872)+d|0)+1075792|0;e=w[a|0];$b:{if(!e){if(!(w[d+480209|0]&16)|(K|0)!=1){break $b}if(Oc(w[b|0])){break $b}e=c;if(!Oc(e)){break $b}}Nl(d,h,(e&255)+255|0,0)}t[a|0]=w[X|0]==1?w[(B(h,872)+d|0)+1075793|0]+f|0:0}ac:{if(w[p+1075797|0]!=1){break ac}if(lj(v[p+1075648>>2])){c=0;bc:{cc:{dc:{switch(y[d+1074392>>2]%3|0){case 1:c=w[(B(h,872)+d|0)+1075798|0]>>>4|0;break cc;case 0:break cc;case 2:break dc;default:break bc}}c=w[(B(h,872)+d|0)+1075798|0]&15}u[k+42>>1]=c}a=(B(h,872)+d|0)+1075843|0;t[a|0]=w[a|0]|96;break ac}if(!(!(w[d+480209|0]&16)|v[d+480180>>2]!=1048576)){a=B(h,872)+d|0;b=Lg(d,w[a+1075789|0],u[a+1075764>>1],v[a+1075696>>2]);v[k+36>>2]=b;v[a+1075692>>2]=b}a=d+1074312|0;xb(o+8|0,a,13);if(yb(v[v[o+8>>2]>>2],v[o+12>>2])){c=w[(B(h,872)+d|0)+1075798|0];if(!c){break ac}a=65536;ec:{switch(((y[d+1074392>>2]%(v[d+1074400>>2]+v[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:c=c<<4;case 0:a=v[((c&240)<<2)+37296>>2];break;default:break ec}}e=cj(d);b=v[k+36>>2];c=b;b=b>>31;if(e){a=Bia(c,b,a,a>>31)+32768|0;f=ib;a=Cia(a,a>>>0<32768?f+1|0:f,65536,0)}else{e=(a|0)/2|0;f=e>>31;b=b<<16|c>>>16;h=e;e=c<<16;c=h+e|0;f=b+f|0;a=Cia(c,c>>>0<e>>>0?f+1|0:f,a,a>>31)}b=ib;Za=k,_a=Dc(a,b),v[Za+36>>2]=_a;break ac}xb(o+8|0,a,51);if(yb(v[v[o+8>>2]>>2],v[o+12>>2])){if(w[d+480209|0]&16){break ac}fc:{gc:{a=v[d+1074416>>2];a=a-(y[d+1074392>>2]%(a>>>0)|0)|0;if((a|0)>16){break gc}if((a|0)==16){break ac}f=0;hc:{switch((a|0)%3|0){case 0:break ac;case 2:break gc;case 1:break hc;default:break fc}}f=w[(B(h,872)+d|0)+1075798|0]>>>4|0;break fc}f=w[(B(h,872)+d|0)+1075798|0]&15}a=B(h,872)+d|0;b=a+1075764|0;a=a+1075696|0;c=Ks(d,v[k+36>>2],u[b>>1],v[a>>2])+f|0;b=Lg(d,c,u[b>>1],v[a>>2]);v[k+36>>2]=b;if(c>>>0<109){break ac}v[o+8>>2]=b;Za=o,_a=Lg(d,109,0,v[a>>2]),v[Za+4>>2]=_a;Za=k,_a=v[Sc(o+8|0,o+4|0)>>2],v[Za+36>>2]=_a;break ac}b=v[d+1074392>>2];e=d+480180|0;c=v[e>>2];ic:{if((c|0)!=1){f=w[(B(h,872)+d|0)+1075789|0];break ic}c=B(h,872)+d|0;f=Ks(d,v[k+36>>2],u[c+1075764>>1],v[c+1075696>>2]);c=v[e>>2]}jc:{kc:{switch((((c&67633152?b+2|0:b)>>>0)%3|0)-1|0){case 0:f=(w[(B(h,872)+d|0)+1075798|0]>>>4|0)+f|0;break jc;case 1:break kc;default:break jc}}f=(w[(B(h,872)+d|0)+1075798|0]&15)+f|0}if(!(c&67633408|w[(B(h,872)+d|0)+1075789|0]!=(f&255))){xb(o+8|0,a,82);if(!yb(v[v[o+8>>2]>>2],v[o+12>>2])){break ac}}if(w[d+480210|0]&32){b=f&255;if((b|0)==85){v[k+36>>2]=2147483647;break ac}f=b>>>0>85?f-37|0:f}b=B(h,872)+d|0;c=Lg(d,f&255,u[b+1075764>>1],v[b+1075696>>2]);v[k+36>>2]=c;if(v[d+480180>>2]&71860480){v[b+1075692>>2]=c;break ac}xb(o+8|0,a,82);if(!yb(v[v[o+8>>2]>>2],v[o+12>>2])){break ac}t[(B(h,872)+d|0)+1075792|0]=f}fb=o+16|0;if(!(!(w[G|0]&33)|v[k+36>>2]==2147483647)){lc:{if(v[F>>2]==2){f=452;a=3424;break lc}a=B(x[m+1075764>>1]>>>4&15,24);b=x[a+33030>>1]>>>1|0;f=b>>>0>452?b:452;a=x[a+33008>>1]<<1}ee(k+36|0,f,a);ee(n,f,a)}aN(d,i);c=v[q>>2]}mc:{if(!(c&256)|w[H|0]&64){break mc}xb(k+16|0,j,37);if(!yb(v[v[k+16>>2]>>2],v[k+20>>2])){break mc}v[m+1075676>>2]=128}n=s&65535;HL(d,n);nc:{if(!g){break nc}a=VM(d,i,k+36|0);if((a|0)<0|!(w[q+1|0]&2)){break nc}b=v[d+1298300>>2];if(!sd(b)){break nc}Dp(b,n,a>>>2&255,1)}oc:{if(w[m+1075782|0]!=8){break oc}pc:{qc:{a=w[m+1075783|0];switch(a-5|0){case 1:break oc;case 0:case 2:break pc;default:break qc}}if((a|0)!=26){break oc}}a=v[F>>2];if((a|0)==4){if(w[H|0]&16){break oc}a=m+1075811|0;t[a|0]=w[a|0]+w[m+1075815|0];break oc}if(!(a&16777248)){break oc}Nk(i,w[m+1075784|0]);GL(d,n,k+36|0,k+44|0)}GL(d,n,k+36|0,k+44|0);rc:{if(!g){break rc}v[k+32>>2]=0;b=k+36|0;p=fb-16|0;fb=p;e=v[i+104>>2];sc:{if(!e|!w[e+40|0]){break sc}K=lj(v[i+656>>2]);g=cj(d);xb(p+8|0,d+1074312|0,21);a=g?38320:37296;f=g?37296:38320;if(!(K|!yb(v[v[p+8>>2]>>2],v[p+12>>2])|v[d+480180>>2]==1048576)){o=w[e+41|0];if(!o){break sc}c=w[i+818|0];v[p+4>>2]=v[i+756>>2]+w[e+39|0];Uh(p+4|0,w[e+40|0]<<8);h=v[p+4>>2];t[i+818|0]=c+o;v[i+756>>2]=h;h=(h|0)/256|0;tc:{uc:{switch(w[e+38|0]-1|0){case 3:c=EL(En(d))+-64|0;break tc;case 2:c=64-(c+1>>>1|0)|0;break tc;case 1:c=(c+1>>>1|0)+-64|0;break tc;case 0:c=(c>>>1^-1)&64;break tc;default:break uc}}c=t[c+33600|0]}Uh(b,8388607);e=v[b>>2]<<8;v[b>>2]=e;h=B(c,h);o=(h|0)/64|0;c=o>>31;o=(c^o)-c|0;K=o>>>2|0;c=e;vc:{wc:{if((h|0)<=-64){h=e>>31;a=v[(K<<2)+a>>2];a=Dc(Cia(Bia(e,h,a,a>>31),ib,65536,0),ib)-e|0;f=o&3;if(!f){break vc}f=(f<<2)+(g?37232:37168)|0;break wc}h=e>>31;a=v[f+(K<<2)>>2];a=Dc(Cia(Bia(e,h,a,a>>31),ib,65536,0),ib)-e|0;f=o&3;if(!f){break vc}f=(f<<2)+(g?37168:37232)|0}g=a;a=v[f>>2];a=(g+Dc(Cia(Bia(a,a>>31,e,h),ib,65536,0),ib)|0)-e|0}v[b>>2]=(a+c|0)/256;v[k+32>>2]=a&255;break sc}h=v[d+480180>>2]&16777248;c=w[e+39|0];xc:{if(!(h|c)){v[i+756>>2]=w[e+40|0]<<8;break xc}yc:{zc:{if(h){o=c<<1;g=v[i+756>>2];c=i+756|0;break zc}if(w[i+89|0]&8){break yc}g=((w[e+40|0]<<8&65280)>>>0)/(c>>>0)|0;o=v[i+756>>2];c=i+756|0}v[c>>2]=g+o}Uh(i+756|0,w[e+40|0]<<8)}c=w[i+818|0]+w[e+41|0]|0;t[i+818|0]=c;c=c<<24>>24;Ac:{Bc:{switch(w[e+38|0]-1|0){case 3:t[i+818|0]=c+1;h=t[(c&63)+33536|0];break Ac;case 2:h=(64-(c>>>1|0)&127)+-64|0;break Ac;case 1:h=((c>>>1|0)- -64&127)+-64|0;break Ac;case 0:h=(c|0)>=0?-64:64;break Ac;default:break Bc}}h=0-t[(c&255)+33600|0]|0;if(v[d+480180>>2]!=1048576){break Ac}h=(64-t[(c+-64&255)+33600|0]|0)/2<<16>>16}c=h;h=B(c,v[i+756>>2]);g=(h|0)/256|0;if(K){z[k+44>>2]=z[k+44>>2]+C(C(C(C(w[e+40|0])*C(.05000000074505806))*C(c|0))*C(.000244140625));t[i+851|0]=w[i+851|0]|64;break sc}if(v[d+480180>>2]!=4){Cc:{if((h|0)<=-256){g=0-g|0;e=0-h>>>16|0;c=(e<<2)+a|0;break Cc}a=f;e=(h|0)/65536|0;c=a+(e<<2)|0}f=v[b>>2];e=v[((e<<2)+a|0)+4>>2];a=v[c>>2];a=((B(e-a|0,(g|0)/4&63)|0)/64|0)+a|0;a=Dc(Cia(Bia(f,f>>31,a,a>>31),ib,256,0),ib);v[b>>2]=a;v[k+32>>2]=a&255;v[b>>2]=v[b>>2]/256;break sc}v[b>>2]=v[b>>2]+((h|0)/16384|0)}fb=p+16|0;g=v[k+36>>2];if((g|0)<=v[d+480260>>2]){xb(k+16|0,j,81);if(yb(v[v[k+16>>2]>>2],v[k+20>>2])){v[m+1075068>>2]=0}g=v[d+480260>>2];v[k+36>>2]=g}Dc:{if(!lj(v[i+656>>2])){break Dc}a=m+1075843|0;b=w[a|0];if(!(v[d+1074392>>2]|!(b&32)?b&64:1)){break Dc}PO(i,z[k+44>>2],u[k+42>>1],d);b=a;a=w[a|0];t[b|0]=(a&64?-65:-33)&a}a=k+16|0;Ky(a,d,i,g,v[k+32>>2]);b=Cb(a);a=Bia(v[k+16>>2],v[k+20>>2],v[d+480240>>2],0);f=ib;c=Cia(a,f,65536,0);e=ib;a=a+65535|0;f=a>>>0<65535?f+1|0:f;a=!f&a>>>0<131071;c=a?1:c;v[k+16>>2]=c;a=a?0:e;v[k+20>>2]=a;v[r>>2]=c;v[r+4>>2]=a;if((v[q>>2]&134219264)!=512){break rc}if(!sd(v[d+1298300>>2])){break rc}xb(k+8|0,j,99);Ec:{Fc:{if(Za=yb(v[v[k+8>>2]>>2],v[k+12>>2]),_a=1,ab=w[q+1|0]&16,ab?Za:_a){a=v[F>>2];break Fc}a=v[F>>2];if((a|0)!=2){break Ec}}c=v[q>>2];e=c&2048;Gc:{if(e?(a|0)==2:0){break Gc}b=Bia(v[b>>2],0,261625,0)+66904|0;a=ib;b=Pc(Eia(b,b>>>0<66904?a+1|0:a,133808,0),ib);a=1;Hc:{if(e){break Hc}a=0;if(!(c&4096)){break Hc}a=!v[m+1075688>>2]}xb(k+8|0,j,110);if(Za=yb(v[v[k+8>>2]>>2],v[k+12>>2]),_a=0,ab=a,ab?Za:_a){break Gc}c=v[d+1298300>>2];xb(k+8|0,j,95);dz(c,n,b,a,yb(v[v[k+8>>2]>>2],v[k+12>>2]))}b=v[d+1298300>>2];a=Bia(B(v[m+1075744>>2],B(v[m+1075740>>2],v[I>>2])),0,63,0)+33554432|0;f=ib;f=a>>>0<33554432?f+1|0:f;Dp(b,n,Pc((f&67108863)<<6|a>>>26,f>>>26|0)&255,0);a=m+1075676|0;e=a;b=v[a>>2];g=0;a=v[d+1298300>>2];c=Tk(a,n);Ic:{if((c|0)==255){break Ic}f=v[a>>2];if(Tj(f)){break Ic}h=Hb(Dd(a+318|0,c),10);g=v[a+4>>2];c=ct(c)|192;a=w[h|0]&-49;a=(b|0)<171?a|16:a;a=((b|0)>84?a|32:a)&255;Ng(f,g,n,c,a);g=(a>>>5&1)+(a<<27>>31)|0}v[e>>2]=(g<<7)+128}Jc:{a=v[M>>2];if(!a|(w[a+60|0]&7)!=1){break Jc}b=v[a+48>>2];a=v[a+52>>2];if(rc(b,a)){break Jc}b=v[FL(i,0)>>2];a=zn(a);if(b>>>0<x[a>>1]|w[a+2|0]){break Jc}fj(v[d+1298300>>2],n,1);xb(k+8|0,j,109);a=v[q>>2];Za=q,_a=(yb(v[v[k+8>>2]>>2],v[k+12>>2])?a:a&-4609)|4096,v[Za>>2]=_a;v[m+1075688>>2]=0;break rc}xb(k+8|0,j,99);if(!yb(v[v[k+8>>2]>>2],v[k+12>>2])|!(w[q+1|0]&16)|v[m+1075688>>2]){break rc}fj(v[d+1298300>>2],n,1);v[q>>2]=v[q>>2]&-513}Kc:{if(!E){break Kc}xb(k+16|0,j,31);if(yb(v[v[k+16>>2]>>2],v[k+20>>2])){break Kc}Ps(d,i)}b=v[q>>2];a=b&-65537;n=m+1075012|0;h=v[A>>2];p=m+1075016|0;f=v[n>>2]|(h|v[p>>2])?(a|b<<7&65536)^65536:a;v[q>>2]=f;A=m+1075664|0;a=A;v[a>>2]=0;v[a+4>>2]=0;e=m+1075834|0;a=w[e|0];b=a-4|0;c=a>>>0<b>>>0?0:b;t[e|0]=c;o=m+1075835|0;a=w[o|0];b=a-4|0;a=a>>>0<b>>>0?0:b;t[o|0]=a;Lc:{Mc:{Nc:{Oc:{Pc:{Qc:{Rc:{Sc:{Tc:{b=v[m+1075096>>2];Uc:{if(!b){break Uc}g=v[b+20>>2];if(!Md(v[b>>2],g)|!v[m+1075068>>2]){break Uc}if(ni(v[i+8>>2],v[i+12>>2])){break Tc}}v[m+1075008>>2]=0;break Sc}v[m+1075008>>2]=g;if(g){break Rc}}if(!Qj(v[i+656>>2])){break Qc}g=0;if(f&6144){break Qc}}E=v[m+1075676>>2];b=(B(h,256-E|0)|0)/16384|0;b=b>>>0<127?b:127;if(c<<24>>24<0){t[e|0]=b;c=b}b=b>>>1|0;if((c&255)>>>0<b>>>0){t[e|0]=b}b=(B(h,E)|0)/16384|0;b=b>>>0<127?b:127;c=b>>>1|0;if(a<<24>>24<0){t[o|0]=b;a=b}if((a&255)>>>0<c>>>0){break Pc}break Oc}if((c&255)>>>0>=129){t[e|0]=0}g=0;c=0;if((a&255)>>>0<129){break Nc}}t[o|0]=c}if(!g){break Nc}g=128;e=v[d+24624>>2];if(e>>>0>=2){g=Ub(v[m+1075676>>2],0,256)}v[k+16>>2]=g;b=B(h,l)>>>(Nd(w[Q|0])?7:8)|0;Vc:{Wc:{Xc:{switch(w[W|0]){case 0:if(!(w[d+24616|0]&16)){break Wc}case 1:if((g|0)<=127){a=b>>>1|0;b=(B(b,g)|0)/256|0;break Vc}a=(B(b,256-g|0)|0)/256|0;b=b>>>1|0;break Vc;case 3:break Xc;default:break Wc}}Uh(k+16|0,255);c=v[k+16>>2];if((c|0)<=0){a=65536}else{a=x[(0-c<<1)+39856>>1]}a=B(a,b)>>>16|0;b=B(b,x[(c<<1)+39344>>1])>>>16|0;break Vc}a=(B(b,256-g|0)|0)/256|0;b=(B(b,g)|0)/256|0}c=v[M>>2];Yc:{if(c){g=w[c+14|0];if(qo(g)){break Yc}}g=w[d+480268|0];if(qo(g)){break Yc}c=w[d+24648|0];g=w[G|0]&128?v[d+24668>>2]?-1:c:c}h=m+1075668|0;o=m+1075786|0;t[o|0]=g;c=v[r>>2];n=v[r+4>>2];if(!(f&131072|((c|0)!=0|(n|0)!=1)|(v[m+1075748>>2]|(g&255)==255))){t[o|0]=0}g=a;a=1<<v[Y>>2];v[A>>2]=(g|0)/(a|0);a=(b|0)/(a|0)|0;v[h>>2]=(f&256)>>>8|0?(e|0)==2?0-a|0:a:a;if(f&128){v[r>>2]=0-c;v[r+4>>2]=0-(((c|0)!=0)+n|0)}g=0;h=fb-16|0;fb=h;v[i+28>>2]=0;v[i+32>>2]=0;Uh(i+672|0,524287);Uh(i+676|0,524287);Zc:{_c:{c=v[i+88>>2];if(!(c&65536)){b=v[i+676>>2];a=v[i+672>>2];break _c}a=v[i+20>>2];f=v[i+672>>2];$c:{if((a|0)!=(f|0)){b=v[i+24>>2];e=v[i+676>>2];break $c}b=v[i+24>>2];e=v[i+676>>2];if((b|0)==(e|0)){break _c}}c=v[d+24620>>2];e=(a|0)<(f|0)|(b|0)<(e|0);ad:{if(e){a=gt(c,v[d+24636>>2]);break ad}a=gt(c,v[d+24640>>2])}xb(h,d+1074312|0,4);if(!(!yb(v[v[h>>2]>>2],v[h+4>>2])|!(v[d+480180>>2]&4))){a=v[d+24620>>2];a=Bia(a,a>>31,5,0)+500|0;f=ib;a=Dc(Cia(a,a>>>0<500?f+1|0:f,1e3,0),ib)}c=v[i+656>>2];bd:{if(!c){b=a;break bd}b=a;if(!e){break bd}c=x[c+12>>1];if(c){b=(B(c,v[d+24620>>2])>>>0)/1e5|0}g=(c|0)!=0}p=b?b:1;e=v[i+672>>2];o=v[i+20>>2];n=e-o<<12;r=i;c=v[i+676>>2];b=v[i+24>>2];f=c-b<<12;if(!(w[i+90|0]&32|(!(c|e)|(!(b|o)|g)))){v[h+12>>2]=v[d+1074380>>2];ee(h+12|0,a,2048);p=v[h+12>>2]}f=(f|0)/(p|0)|0;v[r+32>>2]=f;g=(n|0)/(p|0)|0;v[i+28>>2]=g;b=c+((B(f,p)|0)/-4096|0)|0;v[i+24>>2]=b;a=e+((B(g,p)|0)/-4096|0)|0;v[i+20>>2]=a;if(f|g){v[i+100>>2]=p;c=v[i+88>>2];break Zc}v[i+24>>2]=c;v[i+20>>2]=e;b=c;a=e;c=v[i+88>>2]&-65537;break Zc}v[i+24>>2]=b;v[i+20>>2]=a;c=c&-65537}v[i+88>>2]=c&-2097153;v[i+40>>2]=b<<12;v[i+36>>2]=a<<12;fb=h+16|0;f=v[q>>2];if(!(f&512)){break Mc}break Lc}v[n>>2]=0;v[p>>2]=0;v[m+1075068>>2]=0;if(v[m+1075088>>2]){break Mc}if(!v[m+1075084>>2]){break Lc}}a=x[d+480212>>1];u[d+480212>>1]=a+1;u[((a<<1)+d|0)+1074478>>1]=s}v[m+1075660>>2]=f}s=s+1|0;continue}break}}fb=k+48|0;if(N^1){a=v[d+480208>>2];break h}if(Nd(w[Ia|0])){b=v[d+480208>>2]|512;break i}k=0;cd:{a=v[d+24620>>2]/10|0;c=Dc(a,a>>31);if(!c){break cd}b=c>>>0<1048576?c:1048576;v[d+1074380>>2]=b;f=x[d+480212>>1];e=d+1074376|0;while(1){if((f|0)==(k|0)){break cd}a=e+B(x[(e+(k<<1)|0)+102>>1],872)|0;h=a+1288|0;v[h>>2]=0;v[h+4>>2]=0;v[a+716>>2]=b;h=v[a+640>>2]<<12;v[a+656>>2]=h;g=v[a+636>>2]<<12;v[a+652>>2]=g;v[a+704>>2]=v[a+704>>2]|65536;v[a+644>>2]=(0-g|0)/(b|0);v[a+648>>2]=(0-h|0)/(b|0);k=k+1|0;continue}}a=v[d+480208>>2];b=a|256;if(c){break i}b=a|512}a=b;v[d+480208>>2]=a}if(!(a&512)){break g}Za=d+1074392|0,_a=Ok(Ha),v[Za>>2]=_a}fb=T+112|0;break f}v[T+96>>2]=512;a=v[d+1074380>>2];v[T+104>>2]=ga;v[T+100>>2]=a;i=rB(T+96|0);if(v[d+24632>>2]){m=0;a=fb-48|0;fb=a;b=i<<2;while(1){if((m|0)==4){dd:{m=0;while(1){if((m|0)==4){break dd}v[(a+32|0)+(m<<2)>>2]=((m<<11)+d|0)+16396;m=m+1|0;continue}}}else{v[a+32>>2]=0;c=((m<<11)+d|0)+16396|0;Pz(c,b+c|0,a+32|0);m=m+1|0;continue}break}b=Qg(a+16|0,a+32|0,v[d+24632>>2],i);c=v[v[fa>>2]+8>>2];v[a+8>>2]=v[b+8>>2];e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;jb[c|0](fa,a);fb=a+48|0}if(Nd(Ga)){a=0;while(1){if((a|0)==4){a=Qg(T+80|0,T+96|0,v[d+24632>>2],i);b=v[v[qa>>2]+8>>2];v[T+40>>2]=v[a+8>>2];c=v[a+4>>2];v[T+32>>2]=v[a>>2];v[T+36>>2]=c;jb[b|0](qa,T+32|0)}else{v[(T+96|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}break}}K=0;ha=0;G=fb-48|0;fb=G;if(i){p=d+12|0;r=d+24592|0;F=d+24588|0;zm(p,i,r,F);if(y[d+24624>>2]>=3){zm(d+8204|0,i,d+24600|0,d+24596|0)}u[G+42>>1]=0;va=d+1074312|0;Ka=d+24648|0;La=d+24596|0;Ma=d+24600|0;Na=d+8204|0;A=d+397452|0;E=d+397448|0;n=d+393352|0;wa=d+397456|0;ma=d+1074376|0;Oa=d+480190|0;while(1){if(x[d+480212>>1]<=K>>>0){Za=d,_a=x[Re(d+480214|0,G+42|0)>>1],u[Za+480214>>1]=_a}else{f=(K<<1)+ma|0;s=x[f+102>>1];a=B(s,872);R=a+ma|0;ed:{fd:{if(v[R+632>>2]){break fd}b=a+d|0;if(v[b+1075088>>2]){break fd}if(!v[b+1075084>>2]){break ed}}k=a+d|0;a=w[k+1075786|0]+1|0;if((a&255)>>>0<=5){g=v[(a<<24>>24<<2)+27776>>2]}else{g=0}I=k+1075080|0;h=v[I>>2];gd:{if(!(!(h&16777216)&w[d+24612|0]>>>5)){a=r;b=F;c=h;e=p;if(!(c&8388608)){break gd}}a=E;b=A;if(!w[wa+12|0]){zm(n,i,a,b)}t[wa+12|0]=1;s=x[f+102>>1];c=v[I>>2];e=n}f=b;b=c>>>8&y[d+24624>>2]>2;W=b?La:f;H=b?Ma:a;c=b?Na:e;na=ml(d,ma,s,2,1);xa=(na-1&255)>>>0>249;hd:{if(xa){break hd}b=v[(B(na,160)+d|0)+906140>>2];if(!b){break hd}a=v[b+24>>2];if(!a){break hd}W=b+36|0;H=b+40|0;if(!(t[b+28|0]&1)){zm(a,i,H,W);v[b+28>>2]=v[b+28>>2]|1}c=a}l=R+616|0;if(w[k+1075843|0]&8){WC(l,c,i);a=k+1075084|0;v[H>>2]=v[H>>2]+v[a>>2];v[W>>2]=v[W>>2]+v[k+1075088>>2];v[a>>2]=0;v[a+4>>2]=0;break ed}ia=0;e=fb-16|0;fb=e;a=G+16|0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;b=e+8|0;f=d+1074312|0;xb(b,f,33);Za=a,_a=yb(v[v[e+8>>2]>>2],v[e+12>>2]),t[Za+16|0]=_a;xb(b,f,116);Za=a,_a=yb(v[v[e+8>>2]>>2],v[e+12>>2])^1,t[Za+17|0]=_a;if(v[l+16>>2]){UC(a,l);q=v[l+8>>2];m=v[l+12>>2];b=m>>31;m=(b^m)-((b>>>0>(b^q)>>>0)+b|0)|0;b=m;v[a+12>>2]=b>>>0>8191?2:16384/(b+1>>>0)|0}Pa=h>>>12&8|(h>>>5&2|(g|h&1));Qa=ha&65535;Ra=k+1075795|0;Sa=k+1075778|0;Ta=k+1075688|0;Ua=k+1075024|0;Va=k+1075020|0;Wa=k+1075668|0;Xa=k+1075664|0;Y=k+1075088|0;X=k+1075084|0;ya=k+1075016|0;za=k+1075012|0;ja=k+1075096|0;_=k+1075076|0;Q=k+1075068|0;N=k+1075e3|0;ka=k+1075072|0;$=k+1075092|0;fb=e+16|0;j=a;a=i;while(1){id:{b=v[$>>2];la=b?a>>>0>b>>>0?b:a:a;v[G+8>>2]=la;jd:{kd:{if(!la){break kd}k=v[N>>2];g=v[N+4>>2];if(!(k|g)){break kd}q=v[Q>>2];if(!q){break kd}e=v[j>>2];if(!e){break kd}b=v[I>>2];o=v[ka>>2];v[R+632>>2]=e;f=v[l+4>>2];h=f;e=v[l>>2];ld:{md:{m=o&b<<30>>31;if((m|0)>(f|0)){if((g|0)<0){e=Bg(0,m<<1,e,h);f=ib;h=f;v[l>>2]=e;v[l+4>>2]=f;if(!(f>>>0<m+q>>>1>>>0&(f|0)>=(m|0))){e=0;v[l>>2]=e;h=m;v[l+4>>2]=h}nd:{if(b&4){b=b&-129;v[I>>2]=b;g=0-(((k|0)!=0)+g|0)|0;k=0-k|0;v[N>>2]=k;v[N+4>>2]=g;break nd}f=q-1|0;h=f;v[l>>2]=e;v[l+4>>2]=f}if(!(b&2)){break kd}if(h>>>0<q>>>0){break ld}break kd}if((h|0)>0|(h|0)>=0){break ld}h=0;break md}if(f>>>0<q>>>0){break ld}if(!(b&2)){break kd}if(b&4){if(!!k&(g|0)>=0|(g|0)>0){g=0-(((k|0)!=0)+g|0)|0;k=0-k|0;v[N>>2]=k;v[N+4>>2]=g}b=b|128;v[I>>2]=b;if(w[G+33|0]){s=w[G+32|0];M=v[_>>2]-(s+o|0)|0;e=Bg(e,h,0,q);f=ib;h=f;if(f>>>0<M>>>0){e=Bg(0,q-s|0,e,h);h=ib;break md}e=0;h=o;break md}h=f;f=1-((e|0)!=0)|0;e=0-e|0;f=(q<<1)-(h+f|0)|0;s=e;v[l>>2]=e;M=0;h=M|f;v[l+4>>2]=h;if(f>>>0<q>>>0&f>>>0>o>>>0){break ld}v[G+44>>2]=w[G+32|0]+1;e=s;h=M|q-v[Eb(Q,G+44|0)>>2];break md}if((g|0)<0){g=0-(((k|0)!=0)+g|0)|0;k=0-k|0;v[N>>2]=k;v[N+4>>2]=g}Ob(l,0,m-q|0);b=v[I>>2]|8192;v[I>>2]=b;e=v[l>>2];h=v[l+4>>2];break ld}v[l>>2]=e;v[l+4>>2]=h}ca=h;od:{if((h|0)<(m|0)){if((h|0)<0){break kd}if((g|0)>0|(g|0)>=0){break od}break kd}if((h|0)<0){break kd}}o=v[Q>>2];if(o>>>0<=ca>>>0){break kd}v[G+44>>2]=la;uc(G+8|0,v[G+28>>2]);f=g>>31;q=f;s=f^k;Ya=f^g;aa=v[ka>>2];Aa=aa+16|0;Ba=v[G+8>>2];Df(e,h,af(k,g,Ba-1|0),ib);M=ib;Ca=ca>>>0<aa>>>0;if(!(!Ca&ca>>>0<Aa>>>0)){b=b&-8193;v[I>>2]=b}aa=s-q|0;s=Ya-((q>>>0>s>>>0)+f|0)|0;q=M;pd:{qd:{M=v[G+20>>2];rd:{if(M){f=v[G+24>>2];if(f>>>0<=ca>>>0){sd:{if((g|0)<0){k=0;g=f;break sd}k=e;g=h;e=0;h=v[_>>2]}Za=G,_a=yo(Bg(Bg(e,h,k,g),ib,1,0),ib,aa,s)+1|0,v[Za+44>>2]=_a;v[R+632>>2]=M;break pd}if(!(Ca|!(b&8192)|ca>>>0>=Aa>>>0)){Za=G,_a=yo(Bg(Bg(0,m+16|0,e,h),ib,1,0),ib,aa,s)+1|0,v[Za+44>>2]=_a;Za=R,_a=M+B(v[_>>2]-m|0,ik(x[v[ja>>2]+34>>1]))|0,v[Za+632>>2]=_a;break pd}if(!k&(g|0)<=0|(g|0)<0){break rd}if(la>>>0<2|f>>>0>q>>>0){break qd}Za=G,_a=yo(Bg(Bg(0,f,e,h),ib,1,0),ib,aa,s)+1|0,v[Za+44>>2]=_a;break pd}if((g|0)>0|(g|0)>=0){break qd}}if((m|0)<=(q|0)){break pd}Za=G,_a=yo(Bg(Bg(e,h,0,m),ib,1,0),ib,aa,s)+1|0,v[Za+44>>2]=_a;break pd}if((o|0)>(q|0)){break pd}Za=G,_a=yo(Bg(Bg(0,o,e,h),ib,1,0),ib,aa,s)+1|0,v[Za+44>>2]=_a}xo(G+44|0,1,Ba);f=v[G+44>>2];if((f|0)>0){break jd}}v[R+632>>2]=0;v[Q>>2]=0;v[l>>2]=0;v[l+4>>2]=0;v[$>>2]=0;WC(l,c,a);v[H>>2]=v[H>>2]+v[X>>2];v[W>>2]=v[W>>2]+v[Y>>2];v[Y>>2]=0;v[X>>2]=0;v[I>>2]=v[I>>2]&-129;break id}td:{ud:{if(Qa>>>0<y[d+24608>>2]){b=4;if(v[$>>2]){break ud}b=0;if(v[ya>>2]|v[za>>2]){break ud}}Ob(l,Bia(v[N>>2],v[N+4>>2],f,f>>31),ib);ia=0;v[Y>>2]=0;v[X>>2]=0;c=(f<<3)+c|0;break td}e=(f<<3)+c|0;h=e-8|0;v[X>>2]=0-v[h>>2];g=e-4|0;v[Y>>2]=0-v[g>>2];jb[v[((b|Pa)<<2)+27392>>2]](l,Ka,c,f);v[X>>2]=v[X>>2]+v[h>>2];v[Y>>2]=v[Y>>2]+v[g>>2];ia=1;c=e}b=v[$>>2];vd:{if(!b){break vd}if(b>>>0<=f>>>0){v[$>>2]=0;v[za>>2]=v[Xa>>2];v[ya>>2]=v[Wa>>2];v[Va>>2]=0;v[Ua>>2]=0;if(v[Ta>>2]|!(w[I+1|0]&16)){break vd}v[Q>>2]=0;v[R+632>>2]=0;break vd}v[$>>2]=b-f}m=0;s=0;b=v[l+4>>2];s=b>>>0>=y[_>>2]?(w[I|0]&2)>>>1|0:s;e=b;b=v[Q>>2];m=e>>>0<b>>>0|(!b|w[I|0]&2)?m:!x[Sa>>1];a=a-f|0;xb(G+8|0,va,85);wd:{xd:{yd:{zd:{if(!yb(v[v[G+8>>2]>>2],v[G+12>>2])){break zd}b=w[Ra|0];if(!b|b>>>0>x[Oa>>1]){break zd}b=B(b,104)+d|0;e=b+484380|0;f=v[ja>>2];if((e|0)==(f|0)|(m|s)!=1){break yd}v[ja>>2]=e;v[R+632>>2]=v[b+484400>>2];e=x[b+484414>>1];v[I>>2]=e|v[I>>2]&-768;f=e<<30>>31;e=v[b+484388>>2];v[Q>>2]=f&e;b=v[b+484384>>2];v[ka>>2]=b;v[_>>2]=e;v[l+4>>2]=b;UC(j,l);if(!v[R+632>>2]){break id}if((a|0)>0){continue}break id}if(s){break xd}break wd}if(!s|(e|0)!=(f|0)){break wd}}xb(G+8|0,va,83);if(!yb(v[v[G+8>>2]>>2],v[G+12>>2])|v[ka>>2]){break wd}v[l>>2]=v[l>>2];v[l+4>>2]=0;b=v[v[ja>>2]+8>>2];v[Q>>2]=b;v[_>>2]=b}if((a|0)>0){continue}}break}v[R+632>>2]=v[j>>2];ha=ia+ha|0;u[G+42>>1]=ha;if(xa|!ia){break ed}a=v[(B(na,160)+d|0)+906140>>2];if(!a){break ed}jb[v[v[a>>2]+148>>2]](a)}K=K+1|0;continue}break}}fb=G+48|0;n=v[d+1298300>>2];if(sd(n)){a=Z;b=i;c=(B(v[d+480232>>2],v[d+480236>>2])>>>0)/48|0;k=fb-16|0;fb=k;Ad:{if(!w[n+534|0]){break Ad}e=Bia(c,0,6169,0);c=ib;f=c>>>16|0;p=Pc((c&65535)<<16|e>>>16,f);while(1){if(!b){break Ad}g=v[n>>2];h=v[g>>2];c=v[g+4>>2];while(1){if((c|0)>=(h|0)){v[g+8>>2]=v[g+12>>2];h=0;l=0;m=0;c=fb-16|0;fb=c;while(1){if((m|0)==18){e=(h|0)<32767?h:32767;u[g+12>>1]=(e|0)>-32768?e:-32768;e=(l|0)<32767?l:32767;u[g+14>>1]=(e|0)>-32768?e:-32768;u[g+3832>>1]=x[g+3832>>1]+1;e=(x[g+3834>>1]+1>>>0)%13440|0;u[g+3834>>1]=e;e=e>>>0<6720?e:13440-e|0;u[g+3836>>1]=(e&65280)>>>8;if(!w[g+3843|0]){u[g+3836>>1]=(e&64512)>>>10}e=x[g+3838>>1]+1|0;u[g+3838>>1]=e;if((e&65535)>>>0>=1024){u[g+3838>>1]=0;u[g+3840>>1]=x[g+3840>>1]+1&7}fb=c+16|0}else{f=g+B(m,44)|0;Bd:{if(!w[f+56|0]){u[c+12>>1]=0;u[c+14>>1]=0;break Bd}q=v[f+32>>2];e=x[q+3840>>1];if(e&3){q=(x[f+36>>1]>>>7&7)>>>(w[q+3844|0]^1)>>>(e&1)<<x[f+38>>1];e=e&4?0-q|0:q}else{e=0}q=v[f+52>>2];Cd:{if(q){F=x[q+32>>1];r=x[f+48>>1];q=Wf(v[f+16>>2],v[f+40>>2],e<<16>>16,0,u[f+46>>1]);o=v[f+40>>2];j=v[f+20>>2];if(!F){if(!r){e=e<<16>>16;q=Wf(j,o,e,q,0);q=Wf(v[f+24>>2],v[f+40>>2],e,q,0);e=Wf(v[f+28>>2],v[f+40>>2],e,q,0);break Cd}e=e<<16>>16;o=Wf(j,o,e,0,0);o=Wf(v[f+24>>2],v[f+40>>2],e,o,0);e=Wf(v[f+28>>2],v[f+40>>2],e,o,0)+q|0;break Cd}if(!r){e=e<<16>>16;q=Wf(j,o,e,q,0);o=Wf(v[f+24>>2],v[f+40>>2],e,0,0);e=Wf(v[f+28>>2],v[f+40>>2],e,o,0)+q|0;break Cd}e=e<<16>>16;o=Wf(j,o,e,0,0);e=(Wf(v[f+24>>2],v[f+40>>2],e,o,0)+q|0)+Wf(v[f+28>>2],v[f+40>>2],e,0,0)|0;break Cd}r=x[f+48>>1];e=e<<16>>16;q=Wf(v[f+16>>2],v[f+40>>2],e,0,u[f+46>>1]);o=v[f+40>>2];j=v[f+20>>2];if(!r){e=Wf(j,o,e,q,0);break Cd}e=Wf(j,o,e,0,0)+q|0}u[c+14>>1]=w[f+57|0]?e:0;u[c+12>>1]=w[f+58|0]?e:0}m=m+1|0;l=u[c+12>>1]+l|0;h=u[c+14>>1]+h|0;continue}break}h=v[g>>2];c=v[g+4>>2]-h|0;v[g+4>>2]=c;continue}break}e=h-c|0;u[k+14>>1]=(B(u[g+12>>1],c)+B(e,u[g+8>>1])|0)/(h|0);u[k+12>>1]=(B(u[g+14>>1],c)+B(e,u[g+10>>1])|0)/(h|0);v[g+4>>2]=c+49716;v[a>>2]=v[a>>2]+B(p,u[k+14>>1]);v[a+4>>2]=v[a+4>>2]+B(p,u[k+12>>1]);a=a+8|0;b=b-1|0;continue}}fb=k+16|0}a=w[J+12|0];if(v[J+16>>2]?1:a){if(!a){zm(ba,i,ua,ta)}a=v[J>>2];b=v[J+80>>2];c=B(a,b)>>>4|0;c=c>>>0<32767?c:32767;u[J+98>>1]=c;u[J+96>>1]=c;c=v[J+49948>>2];e=B(c,a)>>>4|0;e=e>>>0<65536?e:65536;f=e+127>>>3|0;u[J+49946>>1]=f;e=e+255>>>4|0;u[J+49944>>1]=e;u[J+49942>>1]=e;u[J+49940>>1]=f;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0>8?a:8)|0;a=16-(B((b|0)<32768?b:32768,a>>>0>16?0:a)>>15)|0;m=0;while(1){if((i|0)!=(m|0)){b=m<<3;c=b+Z|0;v[c>>2]=v[c>>2]+B(a,v[b+ba>>2]>>4);b=b|4;c=b+Z|0;v[c>>2]=v[c>>2]+B(a,v[b+ba>>2]>>4);m=m+1|0;continue}break}q=J+68|0;k=0;b=u[J+84>>1];c=v[J+40>>2];h=v[J+36>>2];while(1){if((i|0)==(k|0)){v[J+40>>2]=c;v[J+36>>2]=h;f=i}else{a=(k<<3)+ba|0;e=v[a>>2]>>12;h=(B(b,e-h|0)>>15)+e|0;v[a>>2]=h;f=a;a=v[a+4>>2]>>12;c=(B(b,a-c|0)>>15)+a|0;v[f+4>>2]=c;k=k+1|0;continue}break}if(f){b=ba;a=f;s=v[q>>2]-1|0;o=x[q+22>>1];e=u[q+26>>1];j=u[q+18>>1];c=x[q+20>>1];h=u[q+24>>1];n=u[q+16>>1];m=v[q+4>>2];g=q+32928|0;while(1){if(a){k=ad(v[b>>2]);l=ad(v[b+4>>2]);c=ad((c<<16>>16)-k|0);o=ad((o<<16>>16)-l|0);c=Rc(ad((B(c,n)|0)/65536<<1)+k|0);o=Rc(ad((B(j,o)|0)/65536<<1)+l|0);l=g+(m<<2)|0;p=u[l>>1];k=Rc(((B(p,h)|0)/-65536|0)+c|0);m=m+1&127;r=g+(m<<2)|0;l=u[l+2>>1];F=Rc(((B(l,e)|0)/-65536|0)+o|0);u[r+2>>1]=F;u[r>>1]=k;s=s+1&8191;r=q+(s<<2)|0;Za=r,_a=Rc(p+((B(h,k)|0)/65536|0)|0),u[Za+160>>1]=_a;Za=r,_a=Rc(l+((B(e,F)|0)/65536|0)|0),u[Za+162>>1]=_a;b=b+8|0;a=a-1|0;continue}break}u[q+22>>1]=o;u[q+20>>1]=c;v[q+4>>2]=m}l=J+49892|0;M=J+33508|0;b=f;a=ba;while(1){if(b){e=v[J+76>>2];h=e&4095;o=M+(h<<2)|0;c=a;h=4096-h|0;F=e-v[J+49892>>2]&4095;e=4096-F|0;e=e>>>0>h>>>0?h:e;e=b>>>0<e>>>0?b:e;h=e>>>0<64?e:64;m=h;e=0;j=fb-32|0;fb=j;g=v[q>>2];while(1){if((e|0)==7){Dd:{p=u[q+28>>1]/8<<16>>16;Ed:while(1){if(!m){break Dd}m=m-1|0;e=0;k=0;g=0;while(1)if((e|0)==4){e=4;s=0;r=Rc((g|0)/32768|0);A=Rc((k|0)/32768|0);k=0;while(1)if((e|0)==7){e=Rc(r+((k|0)/32768|0)|0);u[o>>1]=e;v[c>>2]=B(e,p);e=Rc(A+((s|0)/32768|0)|0);u[o+2>>1]=e;v[c+4>>2]=B(e,p);c=c+8|0;o=o+4|0;continue Ed}else{g=j+(e<<2)|0;n=v[g>>2]+1&8191;v[g>>2]=n;n=q+(n<<2)|0;E=u[n+160>>1];g=q+(e<<4)|0;n=u[n+162>>1];s=(B(E,u[g+44>>1])+s|0)+B(n,u[g+46>>1])|0;k=(B(E,u[g+40>>1])+k|0)+B(n,u[g+42>>1])|0;e=e+1|0;continue}}else{n=j+(e<<2)|0;r=v[n>>2]+1&8191;v[n>>2]=r;s=k;k=q+(r<<2)|0;r=u[k+160>>1];n=q+(e<<4)|0;A=u[k+162>>1];k=(s+B(r,u[n+44>>1])|0)+B(A,u[n+46>>1])|0;g=(B(r,u[n+40>>1])+g|0)+B(A,u[n+42>>1])|0;e=e+1|0;continue}}}}else{v[j+(e<<2)>>2]=g+(v[(q+(e<<4)|0)+32>>2]^-1);e=e+1|0;continue}break}fb=j+32|0;m=M+(F<<2)|0;e=a;c=h;g=v[l+4>>2];k=l+8256|0;o=l- -64|0;j=l+24640|0;n=l+16448|0;while(1){p=g&2047;if(c){s=u[k+((g+1206&2047)<<2)>>1];G=u[(k+((g+754&2047)<<2)|0)+2>>1];E=u[(o+((g+1602&2047)<<2)|0)+2>>1];H=u[o+((g+1750&2047)<<2)>>1];r=u[m>>1];F=u[m+2>>1];A=j+((g+502&2047)<<2)|0;I=u[A>>1];K=ad(u[l+32>>1]-I|0);A=u[A+2>>1];N=ad(u[l+34>>1]-A|0);R=u[l+26>>1];Q=j+((g+22&2047)<<2)|0;W=u[Q>>1];Y=ad(u[l+36>>1]-W|0);X=u[l+28>>1];Q=u[Q+2>>1];_=ad(u[l+38>>1]-Q|0);$=u[l+30>>1];I=Rc(ad((B(K,u[l+24>>1])|0)/65536<<1)+I|0);u[l+32>>1]=I;Za=l,_a=Rc(ad((B(N,R)|0)/65536<<1)+A|0),u[Za+34>>1]=_a;Za=l,_a=Rc(ad((B(Y,X)|0)/65536<<1)+W|0),u[Za+36>>1]=_a;A=Rc(ad((B(_,$)|0)/65536<<1)+Q|0);u[l+38>>1]=A;I=ad((B(I,u[l+16>>1])|0)/32768|0);A=ad((B(A,u[l+22>>1])|0)/32768|0);I=ad(I+((r|0)/4<<16>>16)|0);K=ad(A+((F|0)/4<<16>>16)|0);r=u[l+8>>1];N=ad(I+((B(r,H)|0)/-65536|0)|0);F=p<<2;R=F+o|0;A=u[l+10>>1];Q=ad(K+((B(A,E)|0)/-65536|0)|0);u[R+2>>1]=Q;u[R>>1]=N;H=ad(H+((B(r,N)|0)/65536|0)|0);N=n+F|0;E=ad(E+((B(A,Q)|0)/65536|0)|0);u[N+2>>1]=E;u[N>>1]=H;H=ad(H+I|0);I=ad(E+K|0);E=n+((g+682&2047)<<2)|0;K=u[E+2>>1];N=u[E>>1];E=ad((B(K,u[l+42>>1])+B(N,u[l+40>>1])|0)/32768|0);g=n+((g+426&2047)<<2)|0;R=u[g+2>>1];Q=u[g>>1];g=ad((B(R,u[l+46>>1])+B(Q,u[l+44>>1])|0)/32768|0);N=ad(ad(H+N|0)-E|0);K=ad(ad(I+K|0)-g|0);H=ad(ad(H+Q|0)-E|0);I=ad(ad(I+R|0)-g|0);E=ad(E+((B(r,s)|0)/-65536|0)|0);R=k+F|0;Q=ad(g+((B(A,G)|0)/-65536|0)|0);u[R+2>>1]=Q;u[R>>1]=E;r=(B(r,E)|0)/65536|0;g=ad(r+s|0);F=j+F|0;A=(B(A,Q)|0)/65536|0;E=ad(A+G|0);u[F+2>>1]=E;u[F>>1]=g;Za=e,_a=(v[e>>2]+B(ad(g+N|0),u[l+48>>1])|0)+B(ad(E+K|0),u[l+50>>1])|0,v[Za>>2]=_a;Za=e,_a=(v[e+4>>2]+B(ad(ad(r)+H|0),u[l+52>>1])|0)+B(ad(ad(A)+I|0),u[l+54>>1])|0,v[Za+4>>2]=_a;e=e+8|0;g=p+1|0;m=m+4|0;c=c-1|0;continue}break}v[l+4>>2]=p;v[J+76>>2]=h+v[J+76>>2]&4095;v[J+68>>2]=h+v[J+68>>2]&8191;b=b-h|0;a=(h<<3)+a|0;continue}break}v[J+68>>2]=v[J+68>>2]&8191;k=ba;e=Z;c=f;h=0;g=0;l=v[J+56>>2];b=v[J- -64>>2];m=v[J+52>>2];a=v[J+60>>2];while(1){if(c){h=v[k>>2];g=v[k+4>>2];b=b-g|0;b=(((b|0)/1024|0)-b|0)+l|0;v[e+4>>2]=b+v[e+4>>2];a=a-h|0;a=(((a|0)/1024|0)-a|0)+m|0;v[e>>2]=a+v[e>>2];l=b+((b|0)/-512|0)|0;m=a+((a|0)/-512|0)|0;e=e+8|0;k=k+8|0;c=c-1|0;a=h;b=g;continue}break}v[J+64>>2]=g;v[J+60>>2]=h;v[J+56>>2]=l;v[J+52>>2]=m;a=v[J+20>>2];Fd:{if(w[J+12|0]){break Fd}a=v[J+16>>2];if(a>>>0>f>>>0){a=a-f|0;break Fd}QJ(J,ua,ta);a=0}t[J+12|0]=0;v[J+16>>2]=a}if(v[d+946300>>2]){Gd:{g=0;e=0;f=i<<2;o=x[d+480214>>1]!=0;Da=z[d+1074336>>2];V=z[d+1074332>>2];while(1)if((g|0)==250){h=d+12|0;m=d+12300|0;q=d+14348|0;_u(h,m,q,i,V);a=d+1074476|0;F=w[a|0];t[a|0]=0;a=q;c=m;while(1){Hd:{Id:{Jd:{if((e|0)!=250){j=(B(e,160)+d|0)+906300|0;k=v[j>>2];if(!k|!v[k+24>>2]){break Hd}if(!Th(k+44|0)){break Hd}l=k;Kd:{if(Zu(w[j+24|0])){break Kd}b=jb[v[v[k>>2]+144>>2]](k)|0;l=v[j>>2];if(b){break Kd}g=0;if(w[l+28|0]&2){break Kd}while(1){if((e|0)==(g|0)){break Hd}b=B(g,160);g=g+1|0;if((xm(v[(b+d|0)+906328>>2])|0)!=(e|0)){continue}break}}b=v[k+44>>2];n=zc(b,0);r=zc(b,1);p=(c|0)==(n|0);c=p?m:c;b=c;a=p?q:a;g=v[j+28>>2];f=a;Ld:{if(!g){break Ld}b=c;g=xm(g);f=a;if(g>>>0<=e>>>0){break Ld}f=a;if(g>>>0>249){break Ld}g=v[(B(g,160)+d|0)+906300>>2];f=a;if(!g){break Ld}if(!(w[l+28|0]&4)){jb[v[v[g>>2]+148>>2]](g)}f=a;if(!Th(g+44|0)){break Ld}f=v[g+44>>2];b=zc(f,0);f=zc(f,1)}if(!Zu(w[j+24|0])){break Id}g=0;Md:{if(p){break Md}while(1){if((g|0)==(i|0)){break Md}p=g<<2;A=p+n|0;E=c+p|0;z[A>>2]=z[E>>2]+z[A>>2];A=p+r|0;p=a+p|0;z[A>>2]=z[p>>2]+z[A>>2];v[E>>2]=0;v[p>>2]=0;g=g+1|0;continue}}a=f;c=b;if(!(o&1)){break Id}a=v[j>>2];if(a){jb[v[v[a>>2]+148>>2]](a)}g=xm(v[j+28>>2]);a=e;while(1){c=g;g=c&255;if(g>>>0>249|g>>>0<=(a&255)>>>0){break Jd}p=B(g,160)+d|0;g=xm(v[p+906328>>2]);a=c;c=v[p+906300>>2];if(!c){continue}jb[v[v[c>>2]+148>>2]](c);continue}}b=0;while(1){if((b|0)!=(i|0)){V=C(z[c>>2]*Da);Nd:{if(C(D(V))<C(2147483648)){f=~~V;break Nd}f=-2147483648}v[h>>2]=f;V=C(z[a>>2]*Da);Od:{if(C(D(V))<C(2147483648)){f=~~V;break Od}f=-2147483648}v[h+4>>2]=f;b=b+1|0;h=h+8|0;a=a+4|0;c=c+4|0;continue}break}break Gd}a=f;c=b}g=0;Pd:{Qd:{p=w[j+24|0];if(!((p&2)>>>1|0)){if(!SC(p)|!(w[l+28|0]&4)){break Qd}}while(1){if((g|0)==(i|0)){break Pd}k=g<<2;j=k+b|0;z[j>>2]=z[k+n>>2]+z[j>>2];j=f+k|0;z[j>>2]=z[k+r>>2]+z[j>>2];g=g+1|0;continue}}if(F){jb[v[v[k>>2]+128>>2]](k)}jb[v[v[k>>2]+60>>2]](k,b,f,i);v[l+32>>2]=i+v[l+32>>2];if(!SC(w[j+24|0])){break Pd}if((jb[v[v[k>>2]+156>>2]](k)|0)<=0|y[l+32>>2]<v[d+24620>>2]<<2>>>0){break Pd}Rd:{while(1){if((g|0)==(i|0)){break Rd}k=g<<2;V=z[k+b>>2];Sd:{if(V>=C(1.1920928955078125e-7)|V<=C(-1.1920928955078125e-7)){break Sd}V=z[f+k>>2];if(V>=C(1.1920928955078125e-7)){break Sd}g=g+1|0;if(!(V<=C(-1.1920928955078125e-7))){continue}}break}v[l+32>>2]=0;break Pd}v[l+28>>2]=v[l+28>>2]|4}v[l+28>>2]=v[l+28>>2]&-3}e=e+1|0;continue}}else{h=(B(g,160)+d|0)+906300|0;a=v[h>>2];Td:{if(!a|!v[a+24>>2]){break Td}if(!Th(a+44|0)){break Td}if(!(jb[v[v[a>>2]+112>>2]](a)|0)){jb[v[v[a>>2]+108>>2]](a,1);jb[v[v[a>>2]+120>>2]](a)}c=v[a+44>>2];b=zc(c,0);c=zc(c,1);Ud:{if(t[a+28|0]&1){_u(v[a+24>>2],b,c,i,V);break Ud}k=a+40|0;if(v[a+36>>2]?1:v[k>>2]){zm(v[a+24>>2],i,k,a+36|0);_u(v[a+24>>2],b,c,i,V);break Ud}Sb(b,0,f);Sb(c,0,f)}b=a;a=v[a+28>>2];v[b+28>>2]=a&-2;if(Zu(w[h+24|0])){break Td}o=!(a&4)|o}g=g+1|0;continue}}}if(v[d+24624>>2]==1){b=0;while(1){if((b|0)!=(i|0)){a=(b<<3)+Z|0;v[(b<<2)+Z>>2]=(v[a+4>>2]+v[a>>2]|0)/2;b=b+1|0;continue}break}}if(Nd(w[Ja|0])){c=0;f=fb-16|0;fb=f;Vd:{if(!v[d+1074376>>2]){k=d+1074460|0;a=k;v[a>>2]=0;v[a+4>>2]=0;a=v[d+1074456>>2];v[d+1074468>>2]=a;break Vd}a=v[d+1074456>>2];b=v[d+1074468>>2];Wd:{if((a|0)==(b|0)){e=v[d+1074460>>2];break Wd}v[d+1074468>>2]=a;e=v[d+24620>>2];h=d+1074460|0;Xd:{if((a|0)>(b|0)){e=gt(e,v[d+24636>>2]);break Xd}e=gt(e,v[d+24640>>2])}v[h>>2]=e;v[d+1074464>>2]=e;b=a}k=d+1074460|0;if((e|0)<=0){break Vd}b=(b<<12)-v[d+1074472>>2]|0;c=(b|0)/(e|0)|0;if(w[d+1074368|0]!=2){break Vd}v[f+12>>2]=50;h=v[d+1074464>>2];v[f+8>>2]=1e4/(h+1|0);g=v[Ke(f+12|0,f+8|0)>>2];while(1){l=c>>31;if((g|0)>=((l^c)-l|0)){break Vd}e=e+h|0;v[k>>2]=e;c=(b|0)/(e|0)|0;continue}}Yd:{Zd:{switch(v[d+24624>>2]-1|0){case 0:b=0;g=(i|0)>0?i:0;l=a<<12;e=d+12|0;m=a>>31;while(1){if((b|0)==(g|0)){break Yd}_d:{if(v[k>>2]>0){h=v[d+1074472>>2]+c|0;v[d+1074472>>2]=h;q=v[e>>2];Za=e,_a=Dc(Cia(Bia(q,q>>31,h,h>>31),ib,1048576,0),ib),v[Za>>2]=_a;v[d+1074460>>2]=v[d+1074460>>2]-1;break _d}h=v[e>>2];Za=e,_a=Dc(Cia(Bia(h,h>>31,a,m),ib,256,0),ib),v[Za>>2]=_a;v[d+1074472>>2]=l}b=b+1|0;e=e+4|0;continue};case 1:b=0;l=(i|0)>0?i:0;m=a<<12;e=d+12|0;h=a>>31;while(1){if((b|0)==(l|0)){break Yd}$d:{if(v[k>>2]>0){g=v[d+1074472>>2]+c|0;v[d+1074472>>2]=g;q=v[e>>2];Za=e,_a=Dc(Cia(Bia(q,q>>31,g,g>>31),ib,1048576,0),ib),v[Za>>2]=_a;g=v[d+1074472>>2];q=g;o=g>>31;g=v[e+4>>2];Za=e,_a=Dc(Cia(Bia(q,o,g,g>>31),ib,1048576,0),ib),v[Za+4>>2]=_a;v[d+1074460>>2]=v[d+1074460>>2]-1;break $d}g=v[e>>2];Za=e,_a=Dc(Cia(Bia(g,g>>31,a,h),ib,256,0),ib),v[Za>>2]=_a;g=v[e+4>>2];Za=e,_a=Dc(Cia(Bia(g,g>>31,a,h),ib,256,0),ib),v[Za+4>>2]=_a;v[d+1074472>>2]=m}b=b+1|0;e=e+8|0;continue};case 3:break Zd;default:break Yd}}g=0;m=(i|0)>0?i:0;q=a<<12;e=d+8204|0;b=d+12|0;h=a>>31;while(1){if((g|0)==(m|0)){break Yd}ae:{if(v[k>>2]>0){l=v[d+1074472>>2]+c|0;v[d+1074472>>2]=l;o=v[b>>2];Za=b,_a=Dc(Cia(Bia(o,o>>31,l,l>>31),ib,1048576,0),ib),v[Za>>2]=_a;l=v[d+1074472>>2];o=l;r=l>>31;l=v[b+4>>2];Za=b,_a=Dc(Cia(Bia(o,r,l,l>>31),ib,1048576,0),ib),v[Za+4>>2]=_a;l=v[d+1074472>>2];o=l;r=l>>31;l=v[e>>2];Za=e,_a=Dc(Cia(Bia(o,r,l,l>>31),ib,1048576,0),ib),v[Za>>2]=_a;l=v[d+1074472>>2];o=l;r=l>>31;l=v[e+4>>2];Za=e,_a=Dc(Cia(Bia(o,r,l,l>>31),ib,1048576,0),ib),v[Za+4>>2]=_a;v[d+1074460>>2]=v[d+1074460>>2]-1;break ae}l=v[b>>2];Za=b,_a=Dc(Cia(Bia(l,l>>31,a,h),ib,256,0),ib),v[Za>>2]=_a;l=v[b+4>>2];Za=b,_a=Dc(Cia(Bia(l,l>>31,a,h),ib,256,0),ib),v[Za+4>>2]=_a;l=v[e>>2];Za=e,_a=Dc(Cia(Bia(l,l>>31,a,h),ib,256,0),ib),v[Za>>2]=_a;l=v[e+4>>2];Za=e,_a=Dc(Cia(Bia(l,l>>31,a,h),ib,256,0),ib),v[Za+4>>2]=_a;v[d+1074472>>2]=q}g=g+1|0;e=e+8|0;b=b+8|0;continue}}fb=f+16|0}if(v[ra>>2]!=128){b=d+12|0;c=d+8204|0;a=v[d+24604>>2];e=v[d+24624>>2];be:{if((a|0)==128|e>>>0<2){break be}CL(b,i,a);if(e>>>0<4){break be}CL(c,i,a)}}if(v[d+24624>>2]==4){a=i;while(1){a=a-1|0;if((a|0)>=0){b=(a<<4)+Z|0;c=a<<3;e=c|4;v[b+12>>2]=v[e+sa>>2];v[b+8>>2]=v[c+sa>>2];v[b+4>>2]=v[e+Z>>2];v[b>>2]=v[c+Z>>2];continue}break}}if(Nd(Fa)){a=Qg(T- -64|0,Z,v[d+24624>>2],i);b=v[v[pa>>2]+8>>2];v[T+24>>2]=v[a+8>>2];c=v[a+4>>2];v[T+16>>2]=v[a>>2];v[T+20>>2]=c;jb[b|0](pa,T+16|0)}a=Qg(T+48|0,Z,v[d+24624>>2],i);b=v[v[oa>>2]+8>>2];v[T+8>>2]=v[a+8>>2];c=v[a+4>>2];v[T>>2]=v[a>>2];v[T+4>>2]=c;jb[b|0](oa,T);v[d+1074380>>2]=v[d+1074380>>2]-i;v[d+1074376>>2]=i+v[d+1074376>>2];ga=ga-i|0;Ea=i+Ea|0;continue}break}fb=ea+32|0;return Ea}function hg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),m=0,o=0,p=0,r=0,s=0,E=C(0),F=0,G=0,H=C(0),I=0,J=0,K=0,M=0,N=0;i=fb-2608|0;fb=i;a:{b:{c:{d:{e:{f:{if(av(v[c>>2])){uc(b,268435456);J=v[c+8>>2];G=i+2584|0;e=G;v[e>>2]=0;v[e+4>>2]=0;Ib(e+8|0);v[i+2580>>2]=0;g:{h:{i:{j:{k:{l:{e=w[a+3|0];m:{n:{if((e-4&255)>>>0<=4){v[23220]=0;d=T(189,c|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break l}v[i+2580>>2]=d;break n}if(e>>>0>17){break m}o:{g=1<<e;if(!(g&63503)){if(!(g&198144)){break m}break o}if(w[a|0]){break o}break n}e=0;f=KA(a,v[b>>2]);v[23220]=0;U(190,i+416|0,c|0,f|0);f=v[23220];v[23220]=0;if((f|0)==1){break k}d=i+416|0;f=v[d+4>>2];v[G>>2]=v[d>>2];v[G+4>>2]=f;hm(G+8|0,d+8|0);Jc(d);f=te(G);d=v[G>>2];v[i+2580>>2]=d;if(!f){break g}}e=w[a+3|0]}h=1;p:{q:{switch(e&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:h=!w[a|0];break p;case 9:case 10:case 16:case 17:break q;default:break p}}h=0}g=v[b>>2];if(!(g>>>0<262145|h)){e=e&255;v[i+416>>2]=((e|0)==10)<<4;h=d-v[Eb(i+416|0,i+2580|0)>>2]|0;if(e>>>0>15){break j}r:{if(!(1<<e&63503)){if((e|0)==10){break r}break j}if(!(w[a|0]&7)){break j}}e=(h|0)>=0?h<<1:-1;break i}e=e&255;if(e>>>0>8){break h}if(!(1<<e&432)){if((e|0)!=6){break h}e=0;if(d>>>0<10){break g}v[23220]=0;Q(175,c|0,4)|0;d=v[23220];v[23220]=0;if((d|0)==1){break l}v[23220]=0;e=T(144,c|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){v[i+416>>2]=e;v[i+392>>2]=v[i+2580>>2];d=v[Eb(i+416|0,i+392|0)>>2];jg(c,8);e=((d>>>0>50529027?-1:B(d,85))>>>0)/(w[a|0]>>>3>>>0)|0;break i}a=P()|0;O()|0;break a}e=8/(Up(w[a+1|0])>>>0)|0;Bia(e,0,d,0);e=ib?-1:B(e,d);break i}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}g=0;d=Up(w[a+1|0]);s:{t:{switch(e|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:g=w[a|0];break s;case 9:g=16;break s;case 10:g=4;break s;case 16:case 17:break t;default:break s}}g=8}e=B(d,g&255)>>>3|0;d=(e+h|0)-1|0;e=((d>>>0<h>>>0?-1:d)>>>0)/(e>>>0)|0}uc(b,e);g=v[b>>2]}if(!g){e=0;break g}u[b+34>>1]=x[b+34>>1]&65470|w[a|0]>15|(w[a+1|0]!=1)<<6;if(!wg(b)){e=0;v[b>>2]=0;break g}u:{if(ce(a,Uc(i+416|0,8,1,0,10))){v[23220]=0;d=Q(191,c|0,i+416|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){e=0;if(!d){break u}a=v[b>>2];d=0;v[23220]=0;v[i+392>>2]=a+1>>>1;e=T(189,c|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break b}uc(i+392|0,e);a=f+16|0;b=v[b+20>>2];h=v[i+392>>2];e=h;while(1)if(e){g=i+416|0;f=d+w[g|w[a|0]&15]|0;t[b|0]=f;d=w[g|w[a|0]>>>4]+(f&255)|0;t[b+1|0]=d;e=e-1|0;a=a+1|0;b=b+2|0;continue}else{e=h+16|0;break u}}a=P()|0;O()|0;break a}v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{g=w[a+3|0];switch(g-4|0){case 3:break D;case 4:break E;case 5:break F;case 2:break G;case 0:case 1:break H;default:break B}}v[23220]=0;b=fa(192,i+1488|0,c|0,b|0,(g|0)==5|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break f}wb(b);e=v[c+8>>2]-J|0;break u}if(w[a+1|0]!=1){break C}v[23220]=0;Q(175,c|0,4)|0;a=v[23220];v[23220]=0;if((a|0)==1){break f}v[23220]=0;f=T(144,c|0)|0;a=v[23220];v[23220]=0;I:{J:{K:{if((a|0)!=1){v[23220]=0;v[i+392>>2]=f;h=T(193,c|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break K}v[23220]=0;U(194,i+416|0,c|0,f|0);a=v[23220];v[23220]=0;if((a|0)==1){break I}uc(i+392|0,v[i+416>>2]);g=v[i+392>>2];e=te(i+416|0);d=x[b+34>>1];f=v[b+20>>2];b=v[b>>2];a=v[i+416>>2];v[23220]=0;da(195,e|0,a|0,f|0,sj(b,d)|0,h<<24>>24);a=v[23220];v[23220]=0;if((a|0)!=1){break J}a=P()|0;O()|0;Jc(i+416|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}e=g+9|0;Jc(i+416|0);break u}a=P()|0;O()|0;break a}if(w[a+1|0]!=1|w[a|0]!=16){break C}e=v[i+2580>>2];d=Ql(i+1480|0);a=v[b>>2];b=v[b+20>>2];g=x[d>>1];h=fb-16|0;fb=h;v[h+12>>2]=e>>>1;v[h+8>>2]=a;d=v[Eb(h+12|0,h+8|0)>>2];e=d;while(1){if(e){a=w[f|0]+g|0;g=a+w[f+1|0]|0;u[b>>1]=g<<8|a&255;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}fb=h+16|0;e=d<<1;break u}if(w[a+1|0]!=1|w[a|0]>16){break C}d=v[c+8>>2];f=v[c>>2];e=0;v[23220]=0;d=W(143,f|0,d|0,8)|0;f=v[23220];v[23220]=0;if((f|0)==1){break f}if(!d){break u}v[23220]=0;d=T(144,c|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break f}v[i+2580>>2]=d;if(d>>>0<4){break u}v[23220]=0;U(177,i+392|0,c|0,d|0);f=v[23220];v[23220]=0;if((f|0)==1){break c}f=i+392|0;s=Yq(i+416|0,f);wb(f);f=v[s>>2];v[23220]=0;d=T(196,f|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break e}e=d+4|0;p=w[a|0];m=(p|0)!=16;g=0;h=0;while(1){if(y[b>>2]<=h>>>0){break w}L:{if(m){break L}v[23220]=0;r=Q(151,s|0,8)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break L}a=V(30480)|0;break x}v[23220]=0;j=Q(151,s|0,1)|0;a=v[23220];v[23220]=0;if((a|0)==1){break y}v[23220]=0;f=Q(151,s|0,1)|0;a=v[23220];v[23220]=0;if((a|0)==1){break y}M:{N:{O:{if(!f){f=8;while(1){v[23220]=0;d=Q(151,s|0,1)|0;a=v[23220];v[23220]=0;if((a|0)==1){break M}if(d){break O}f=f+16|0;continue}}v[23220]=0;a=Q(151,s|0,3)|0;f=v[23220];v[23220]=0;if((f|0)!=1){break N}break y}v[23220]=0;d=Q(151,s|0,4)|0;a=v[23220];v[23220]=0;if((a|0)==1){break y}a=f+d|0}g=(g&255)+(((j?-1:0)^a)&255)|0;P:{if((p|0)!=16){t[v[b+20>>2]+h|0]=g;break P}u[v[b+20>>2]+(h<<1)>>1]=r&255|g<<8}h=h+1|0;continue}break}a=V(30480)|0;break x}if(w[a+1|0]!=1){break B}break A}if((g|0)!=7){break B}if(w[a+1|0]==1){break A}}e=w[a|0];break z}e=w[a|0];if(e>>>0>16){break z}e=0;if(y[i+2580>>2]<5){break u}d=x[b+34>>1];f=v[b+20>>2];a=v[b>>2];v[23220]=0;e=W(197,c|0,f|0,sj(a,d)|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break u}break f}Q:{if((g&254)!=16|(e&255)!=16){break Q}d=w[a+1|0];if((d-1&255)>>>0>1){break Q}K=i,M=B(v[b>>2],Up(d)),v[K+416>>2]=M;uc(i+416|0,v[i+2580>>2]);a=v[b+20>>2];e=v[i+416>>2];if((g|0)==16){b=e;while(1){if(!b){break u}K=a,M=x[ac(30512,w[f|0])>>1],u[K>>1]=M;a=a+2|0;f=f+1|0;b=b-1|0;continue}}b=e;while(1){if(!b){break u}K=a,M=x[ac(31024,w[f|0])>>1],u[K>>1]=M;a=a+2|0;f=f+1|0;b=b-1|0;continue}}d=(e&255)!=8;if(!(d|w[a+1|0]!=1)){R:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=fb-16|0;fb=d;v[d+12>>2]=v[i+2580>>2];v[d+8>>2]=a;a=v[Eb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0];b=b+1|0;f=f+1|0;e=e-1|0;continue}break};fb=d+16|0;e=a;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=fb-16|0;fb=d;v[d+12>>2]=v[i+2580>>2];v[d+8>>2]=a;a=v[Eb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0]^128;b=b+1|0;f=f+1|0;e=e-1|0;continue}break};fb=d+16|0;e=a;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break R}}e=v[i+2580>>2];d=Oy(i+384|0);a=v[b>>2];b=v[b+20>>2];g=w[d|0];d=fb-16|0;fb=d;v[d+12>>2]=e;v[d+8>>2]=a;a=v[Eb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=w[f|0]+g|0;t[b|0]=g;b=b+1|0;f=f+1|0;e=e-1|0;continue}break}fb=d+16|0;e=a;break u}if(!(w[a+1|0]!=3|d)){S:{switch(g|0){case 0:j=fb-16|0;fb=j;e=v[i+2580>>2];v[j+12>>2]=e;d=v[b>>2];v[j+8>>2]=d;a=j+8|0;g=v[Eb(a,j+12|0)>>2];v[j+8>>2]=d;v[j+4>>2]=e-g;e=v[Eb(a,j+4|0)>>2];h=v[b+20>>2];a=g;d=f;while(1){if(a){t[h|0]=w[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=v[b+20>>2]+1|0;d=v[b>>2]+f|0;a=e;while(1){if(a){t[h|0]=w[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};fb=j+16|0;e=e+g|0;break u;case 1:j=fb-16|0;fb=j;e=v[i+2580>>2];v[j+12>>2]=e;d=v[b>>2];v[j+8>>2]=d;a=j+8|0;g=v[Eb(a,j+12|0)>>2];v[j+8>>2]=d;v[j+4>>2]=e-g;e=v[Eb(a,j+4|0)>>2];h=v[b+20>>2];a=g;d=f;while(1){if(a){t[h|0]=w[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=v[b+20>>2]+1|0;d=v[b>>2]+f|0;a=e;while(1){if(a){t[h|0]=w[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};fb=j+16|0;e=e+g|0;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break S}}h=v[i+2580>>2];e=w[Oy(i+376|0)|0];p=fb-16|0;fb=p;v[p+12>>2]=h;g=v[b>>2];v[p+8>>2]=g;d=p+8|0;j=v[Eb(d,p+12|0)>>2];v[p+8>>2]=g;v[p+4>>2]=h-j;h=v[Eb(d,p+4|0)>>2];m=b;r=v[b+20>>2];d=e;b=j;g=f;while(1){if(b){d=w[g|0]+d|0;t[r|0]=d;r=r+2|0;g=g+1|0;b=b-1|0;continue}break}r=v[m+20>>2]+1|0;g=v[m>>2]+f|0;b=h;while(1){if(b){e=w[g|0]+e|0;t[r|0]=e;r=r+2|0;g=g+1|0;b=b-1|0;continue}break}fb=p+16|0;e=h+j|0;if(w[a+3|0]!=11){break u}a=v[m+20>>2];b=a+(v[m>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break u}t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;continue}}d=e&255;if(!((d|0)!=8|w[a+1|0]!=2)){e=0;T:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=fb-16|0;fb=d;v[d+12>>2]=v[i+2580>>2]>>>1;v[d+8>>2]=a;a=v[Eb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0];t[b+1|0]=w[f+1|0];b=b+2|0;f=f+2|0;e=e-1|0;continue}break};fb=d+16|0;e=a<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=fb-16|0;fb=d;v[d+12>>2]=v[i+2580>>2]>>>1;v[d+8>>2]=a;a=v[Eb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0]^128;t[b+1|0]=w[f+1|0]^128;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};fb=d+16|0;e=a<<1;break u;case 2:break T;default:break u}}e=v[i+2580>>2];a=Oy(i+368|0);d=v[b>>2];g=v[b+20>>2];a=w[a|0];h=fb-16|0;fb=h;v[h+12>>2]=e>>>1;v[h+8>>2]=d;b=a;e=v[Eb(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=w[f|0]+a|0;t[g|0]=a;b=w[f+1|0]+b|0;t[g+1|0]=b;g=g+2|0;f=f+2|0;d=d-1|0;continue}break}fb=h+16|0;e=e<<1;break u}if(!(w[a+2|0]|((d|0)!=16|w[a+1|0]!=1))){U:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=fb-16|0;fb=d;v[d+12>>2]=v[i+2580>>2]>>>1;v[d+8>>2]=a;a=v[Eb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=w[f|0]|w[f+1|0]<<8;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};fb=d+16|0;e=a<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=fb-16|0;fb=d;v[d+12>>2]=v[i+2580>>2]>>>1;v[d+8>>2]=a;a=v[Eb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=(w[f|0]|w[f+1|0]<<8)^32768;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};fb=d+16|0;e=a<<1;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break U}}e=v[i+2580>>2];d=Ql(i+360|0);a=v[b>>2];b=v[b+20>>2];g=x[d>>1];d=fb-16|0;fb=d;v[d+12>>2]=e>>>1;v[d+8>>2]=a;a=v[Eb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=(w[f|0]+g|0)+(w[f+1|0]<<8)|0;u[b>>1]=g;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}fb=d+16|0;e=a<<1;break u}d=e&255;if(!((d|0)!=16|w[a+1|0]!=1|w[a+2|0]!=1)){e=0;V:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];g=fb-16|0;fb=g;v[g+12>>2]=v[i+2580>>2]>>>1;v[g+8>>2]=a;d=v[Eb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=a<<8|a>>>8;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};fb=g+16|0;e=d<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];g=fb-16|0;fb=g;v[g+12>>2]=v[i+2580>>2]>>>1;v[g+8>>2]=a;d=v[Eb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=(a<<8|a>>>8)^32768;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};fb=g+16|0;e=d<<1;break u;case 2:break V;default:break u}}e=v[i+2580>>2];d=Ql(i+352|0);a=v[b>>2];b=v[b+20>>2];g=x[d>>1];d=fb-16|0;fb=d;v[d+12>>2]=e>>>1;v[d+8>>2]=a;a=v[Eb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=(w[f+1|0]+g|0)+(w[f|0]<<8)|0;u[b>>1]=g;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}fb=d+16|0;e=a<<1;break u}h=a;if(!(w[a+2|0]|((d|0)!=16|w[a+1|0]!=3))){W:{switch(g|0){case 0:m=fb-16|0;fb=m;d=v[i+2580>>2];v[m+12>>2]=d;j=v[b>>2]<<1;v[m+8>>2]=j;a=m+8|0;g=v[Eb(a,m+12|0)>>2];v[m+8>>2]=j;v[m+4>>2]=d-g;a=v[Eb(a,m+4|0)>>2];e=v[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){u[e>>1]=w[d|0]|w[d+1|0]<<8;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+j|0;d=v[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){u[d>>1]=w[e|0]|w[e+1|0]<<8;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};fb=m+16|0;e=a+h<<1;break u;case 1:m=fb-16|0;fb=m;d=v[i+2580>>2];v[m+12>>2]=d;j=v[b>>2]<<1;v[m+8>>2]=j;a=m+8|0;g=v[Eb(a,m+12|0)>>2];v[m+8>>2]=j;v[m+4>>2]=d-g;a=v[Eb(a,m+4|0)>>2];e=v[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){u[e>>1]=(w[d|0]|w[d+1|0]<<8)^32768;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+j|0;d=v[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){u[d>>1]=(w[e|0]|w[e+1|0]<<8)^32768;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};fb=m+16|0;e=a+h<<1;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break W}}g=v[i+2580>>2];a=x[Ql(i+344|0)>>1];s=fb-16|0;fb=s;v[s+12>>2]=g;p=v[b>>2]<<1;v[s+8>>2]=p;d=s+8|0;e=v[Eb(d,s+12|0)>>2];v[s+8>>2]=p;v[s+4>>2]=g-e;m=v[Eb(d,s+4|0)>>2];g=b;d=v[g+20>>2];b=a;j=e>>>1|0;r=j;e=f;while(1){if(r){b=(w[e|0]+b|0)+(w[e+1|0]<<8)|0;u[d>>1]=b;d=d+4|0;e=e+2|0;r=r-1|0;continue}break}e=f+p|0;d=v[g+20>>2]+2|0;b=m>>>1|0;r=b;while(1){if(r){a=(w[e|0]+a|0)+(w[e+1|0]<<8)|0;u[d>>1]=a;d=d+4|0;e=e+2|0;r=r-1|0;continue}break}fb=s+16|0;e=b+j<<1;if(w[h+3|0]!=11){break u}a=v[g+20>>2];b=a+(v[g>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break u}u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;continue}}a=e&255;if(!((a|0)!=16|w[h+1|0]!=3|w[h+2|0]!=1)){e=0;X:{switch(g|0){case 0:p=fb-16|0;fb=p;d=v[i+2580>>2];v[p+12>>2]=d;m=v[b>>2]<<1;v[p+8>>2]=m;a=p+8|0;g=v[Eb(a,p+12|0)>>2];v[p+8>>2]=m;v[p+4>>2]=d-g;j=v[Eb(a,p+4|0)>>2];e=v[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){a=w[d|0]|w[d+1|0]<<8;u[e>>1]=a<<8|a>>>8;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+m|0;d=v[b+20>>2]+2|0;b=j>>>1|0;g=b;while(1){if(g){a=w[e|0]|w[e+1|0]<<8;u[d>>1]=a<<8|a>>>8;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};fb=p+16|0;e=b+h<<1;break u;case 1:p=fb-16|0;fb=p;d=v[i+2580>>2];v[p+12>>2]=d;m=v[b>>2]<<1;v[p+8>>2]=m;a=p+8|0;g=v[Eb(a,p+12|0)>>2];v[p+8>>2]=m;v[p+4>>2]=d-g;j=v[Eb(a,p+4|0)>>2];e=v[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){a=w[d|0]|w[d+1|0]<<8;u[e>>1]=(a<<8|a>>>8)^32768;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+m|0;d=v[b+20>>2]+2|0;b=j>>>1|0;g=b;while(1){if(g){a=w[e|0]|w[e+1|0]<<8;u[d>>1]=(a<<8|a>>>8)^32768;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};fb=p+16|0;e=b+h<<1;break u;case 2:break X;default:break u}}e=v[i+2580>>2];a=x[Ql(i+336|0)>>1];r=fb-16|0;fb=r;v[r+12>>2]=e;p=v[b>>2]<<1;v[r+8>>2]=p;d=r+8|0;g=v[Eb(d,r+12|0)>>2];v[r+8>>2]=p;v[r+4>>2]=e-g;m=v[Eb(d,r+4|0)>>2];e=b;h=v[b+20>>2];b=a;j=g>>>1|0;d=j;g=f;while(1){if(d){b=(w[g+1|0]+b|0)+(w[g|0]<<8)|0;u[h>>1]=b;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}g=f+p|0;h=v[e+20>>2]+2|0;b=m>>>1|0;d=b;while(1){if(d){a=(w[g+1|0]+a|0)+(w[g|0]<<8)|0;u[h>>1]=a;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}fb=r+16|0;e=b+j<<1;break u}if(!(w[h+2|0]|((a|0)!=16|w[h+1|0]!=2))){e=0;Y:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=fb-16|0;fb=d;v[d+12>>2]=v[i+2580>>2]>>>2;v[d+8>>2]=a;a=v[Eb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=w[f|0]|w[f+1|0]<<8;u[b+2>>1]=w[f+2|0]|w[f+3|0]<<8;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};fb=d+16|0;e=a<<2;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=fb-16|0;fb=d;v[d+12>>2]=v[i+2580>>2]>>>2;v[d+8>>2]=a;a=v[Eb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=(w[f|0]|w[f+1|0]<<8)^32768;u[b+2>>1]=(w[f+2|0]|w[f+3|0]<<8)^32768;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};fb=d+16|0;e=a<<2;break u;case 2:break Y;default:break u}}e=v[i+2580>>2];a=Ql(i+328|0);d=v[b>>2];g=v[b+20>>2];a=x[a>>1];h=fb-16|0;fb=h;v[h+12>>2]=e>>>2;v[h+8>>2]=d;b=a;e=v[Eb(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=(w[f|0]+a|0)+(w[f+1|0]<<8)|0;u[g>>1]=a;b=(w[f+2|0]+b|0)+(w[f+3|0]<<8)|0;u[g+2>>1]=b;g=g+4|0;f=f+4|0;d=d-1|0;continue}break}fb=h+16|0;e=e<<2;break u}a=e&255;if(!((a|0)!=16|w[h+1|0]!=2|w[h+2|0]!=1)){e=0;Z:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];g=fb-16|0;fb=g;v[g+12>>2]=v[i+2580>>2]>>>2;v[g+8>>2]=a;d=v[Eb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=a<<8|a>>>8;a=w[f+2|0]|w[f+3|0]<<8;u[b+2>>1]=a<<8|a>>>8;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};fb=g+16|0;e=d<<2;break u;case 1:a=v[b>>2];b=v[b+20>>2];g=fb-16|0;fb=g;v[g+12>>2]=v[i+2580>>2]>>>2;v[g+8>>2]=a;d=v[Eb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=(a<<8|a>>>8)^32768;a=w[f+2|0]|w[f+3|0]<<8;u[b+2>>1]=(a<<8|a>>>8)^32768;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};fb=g+16|0;e=d<<2;break u;case 2:break Z;default:break u}}e=v[i+2580>>2];a=Ql(i+320|0);d=v[b>>2];g=v[b+20>>2];a=x[a>>1];h=fb-16|0;fb=h;v[h+12>>2]=e>>>2;v[h+8>>2]=d;b=a;e=v[Eb(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=(w[f+1|0]+a|0)+(w[f|0]<<8)|0;u[g>>1]=a;b=(w[f+3|0]+b|0)+(w[f+2|0]<<8)|0;u[g+2>>1]=b;g=g+4|0;f=f+4|0;d=d-1|0;continue}break}fb=h+16|0;e=e<<2;break u}if(!(g|w[h+1|0]!=1|(a|0)!=24)){a=v[b+20>>2];d=v[b>>2];b=v[i+2580>>2];if(!w[h+2|0]){g=fb-16|0;fb=g;v[g+12>>2]=(b>>>0)/3;v[g+8>>2]=d;b=v[Eb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=dd(w[f+1|0]<<16|w[f|0]<<8|w[f+2|0]<<24,16),u[K>>1]=M;a=a+2|0;f=f+3|0;e=e-1|0;continue}break}fb=g+16|0;e=B(b,3);break u}g=fb-16|0;fb=g;v[g+12>>2]=(b>>>0)/3;v[g+8>>2]=d;b=v[Eb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=dd(w[f+1|0]<<16|w[f+2|0]<<8|w[f|0]<<24,16),u[K>>1]=M;a=a+2|0;f=f+3|0;e=e-1|0;continue}break}fb=g+16|0;e=B(b,3);break u}a=e&255;if(!(g|w[h+1|0]!=2|(a|0)!=24)){a=v[b+20>>2];d=v[b>>2];b=v[i+2580>>2];if(!w[h+2|0]){g=fb-16|0;fb=g;v[g+12>>2]=(b>>>0)/6;v[g+8>>2]=d;b=v[Eb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=dd(w[f+1|0]<<16|w[f|0]<<8|w[f+2|0]<<24,16),u[K>>1]=M;K=a,M=dd(w[f+4|0]<<16|w[f+3|0]<<8|w[f+5|0]<<24,16),u[K+2>>1]=M;a=a+4|0;f=f+6|0;e=e-1|0;continue}break}fb=g+16|0;e=B(b,6);break u}g=fb-16|0;fb=g;v[g+12>>2]=(b>>>0)/6;v[g+8>>2]=d;b=v[Eb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=dd(w[f+1|0]<<16|w[f+2|0]<<8|w[f|0]<<24,16),u[K>>1]=M;K=a,M=dd(w[f+4|0]<<16|w[f+5|0]<<8|w[f+3|0]<<24,16),u[K+2>>1]=M;a=a+4|0;f=f+6|0;e=e-1|0;continue}break}fb=g+16|0;e=B(b,6);break u}if(!(g|w[h+1|0]!=1|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[i+2580>>2];if(!w[h+2|0]){g=fb-16|0;fb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Eb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=dd(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),16),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}fb=g+16|0;e=b<<2;break u}g=fb-16|0;fb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Eb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);K=a,M=dd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}fb=g+16|0;e=b<<2;break u}a=e&255;if(!(g|w[h+1|0]!=2|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[i+2580>>2];if(!w[h+2|0]){g=fb-16|0;fb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Eb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=dd(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),16),u[K>>1]=M;K=a,M=dd(w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24),16),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}fb=g+16|0;e=b<<3;break u}g=fb-16|0;fb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Eb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);K=a,M=dd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[K>>1]=M;d=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);K=a,M=dd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}fb=g+16|0;e=b<<3;break u}if(!(g|w[h+1|0]!=1|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[i+2580>>2];if(!w[h+2|0]){g=fb-16|0;fb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Eb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=Lc(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24),48),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}fb=g+16|0;e=b<<3;break u}m=fb-16|0;fb=m;v[m+12>>2]=b>>>3;v[m+8>>2]=d;h=v[Eb(m+12|0,m+8|0)>>2];e=h;while(1){if(e){b=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=b<<24|b<<8&16711680;r=b>>>8|0;j=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);d=r|j<<24;b=b>>>24|0;K=a,M=Lc((r|(j&255)<<24)&-16777216|(b|(j&16777215)<<8)&16711680|(j>>>8&65280|j>>>24),g|(d&65280|(b|j<<8)&255),48),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}fb=m+16|0;e=h<<3;break u}a=e&255;if(!(g|w[h+1|0]!=2|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[i+2580>>2];if(!w[h+2|0]){g=fb-16|0;fb=g;v[g+12>>2]=b>>>4;v[g+8>>2]=d;b=v[Eb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=Lc(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24),48),u[K>>1]=M;K=a,M=Lc(w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24),w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24),48),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}fb=g+16|0;e=b<<4;break u}m=fb-16|0;fb=m;v[m+12>>2]=b>>>4;v[m+8>>2]=d;h=v[Eb(m+12|0,m+8|0)>>2];e=h;while(1){if(e){b=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=b<<24|b<<8&16711680;r=b>>>8|0;j=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);d=r|j<<24;b=b>>>24|0;K=a,M=Lc((r|(j&255)<<24)&-16777216|(b|(j&16777215)<<8)&16711680|(j>>>8&65280|j>>>24),g|(d&65280|(b|j<<8)&255),48),u[K>>1]=M;j=w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24);d=j<<24|j<<8&16711680;g=w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24);b=g<<24|j>>>8;K=a,M=Lc(((g&255)<<24|j>>>8)&-16777216|((g&16777215)<<8|j>>>24)&16711680|(g>>>8&65280|g>>>24),d|(b&65280|(g<<8|j>>>24)&255),48),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}fb=m+16|0;e=h<<4;break u}if(!(w[h+1|0]!=1|(g|0)!=3|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[i+2580>>2];if(!w[h+2|0]){g=fb-16|0;fb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Eb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){k=tf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));k=Nh(C(Ld(ag(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));_:{if(C(D(k))<C(2147483648)){d=~~k;break _}d=-2147483648}K=a,M=Rc(d),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}fb=g+16|0;e=b<<2;break u}g=fb-16|0;fb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Eb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);k=tf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=Nh(C(Ld(ag(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));$:{if(C(D(k))<C(2147483648)){d=~~k;break $}d=-2147483648}K=a,M=Rc(d),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}fb=g+16|0;e=b<<2;break u}a=e&255;if(!(w[h+1|0]!=2|(g|0)!=3|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[i+2580>>2];if(!w[h+2|0]){g=fb-16|0;fb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Eb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){k=tf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));k=Nh(C(Ld(ag(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));aa:{if(C(D(k))<C(2147483648)){d=~~k;break aa}d=-2147483648}K=a,M=Rc(d),u[K>>1]=M;k=tf((l(2,w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24)),q()));k=Nh(C(Ld(ag(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));ba:{if(C(D(k))<C(2147483648)){d=~~k;break ba}d=-2147483648}K=a,M=Rc(d),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}fb=g+16|0;e=b<<3;break u}g=fb-16|0;fb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Eb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);k=tf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=Nh(C(Ld(ag(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));ca:{if(C(D(k))<C(2147483648)){d=~~k;break ca}d=-2147483648}K=a,M=Rc(d),u[K>>1]=M;d=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);k=tf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=Nh(C(Ld(ag(k)?k>=C(0)?C(1):C(-1):k,C(-1))*C(32768)));da:{if(C(D(k))<C(2147483648)){d=~~k;break da}d=-2147483648}K=a,M=Rc(d),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}fb=g+16|0;e=b<<3;break u}if(!(w[h+1|0]!=1|(g|0)!=3|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[i+2580>>2];if(!w[h+2|0]){g=fb-32|0;fb=g;v[g+24>>2]=b>>>3;v[g+16>>2]=d;d=v[Eb(g+24|0,g+16|0)>>2];e=d;while(1){if(e){b=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);l(0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));l(1,b|0);o=$f(+n());K=g,N=Xe(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;o=de(A[ug(g+24|0,g+16|0,g+8|0)>>3]*32768);ea:{if(D(o)<2147483648){b=~~o;break ea}b=-2147483648}K=a,M=Rc(b),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}fb=g+32|0;e=d<<3;break u}m=fb-32|0;fb=m;v[m+24>>2]=b>>>3;v[m+16>>2]=d;g=v[Eb(m+24|0,m+16|0)>>2];e=g;while(1){if(e){j=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);d=j<<24|j<<8&16711680;r=j>>>8|0;h=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);b=r|h<<24;j=j>>>24|0;l(0,(r|(h&255)<<24)&-16777216|(j|(h&16777215)<<8)&16711680|(h>>>8&65280|h>>>24));l(1,d|(b&65280|(j|h<<8)&255));o=$f(+n());K=m,N=Xe(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[m+16>>2]=0;v[m+20>>2]=-1074790400;v[m+8>>2]=0;v[m+12>>2]=1072693248;o=de(A[ug(m+24|0,m+16|0,m+8|0)>>3]*32768);fa:{if(D(o)<2147483648){b=~~o;break fa}b=-2147483648}K=a,M=Rc(b),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}fb=m+32|0;e=g<<3;break u}a=e&255;if(!(w[h+1|0]!=2|(g|0)!=3|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[i+2580>>2];if(!w[h+2|0]){g=fb-32|0;fb=g;v[g+24>>2]=b>>>4;v[g+16>>2]=d;d=v[Eb(g+24|0,g+16|0)>>2];e=d;while(1){if(e){b=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);l(0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));l(1,b|0);o=$f(+n());K=g,N=Xe(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;o=de(A[ug(g+24|0,g+16|0,g+8|0)>>3]*32768);ga:{if(D(o)<2147483648){b=~~o;break ga}b=-2147483648}K=a,M=Rc(b),u[K>>1]=M;b=w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24);l(0,w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24));l(1,b|0);o=$f(+n());K=g,N=Xe(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;o=de(A[ug(g+24|0,g+16|0,g+8|0)>>3]*32768);ha:{if(D(o)<2147483648){b=~~o;break ha}b=-2147483648}K=a,M=Rc(b),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}fb=g+32|0;e=d<<4;break u}m=fb-32|0;fb=m;v[m+24>>2]=b>>>4;v[m+16>>2]=d;h=v[Eb(m+24|0,m+16|0)>>2];e=h;while(1){if(e){b=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=b<<24|b<<8&16711680;r=b>>>8|0;j=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);d=r|j<<24;b=b>>>24|0;l(0,(r|(j&255)<<24)&-16777216|(b|(j&16777215)<<8)&16711680|(j>>>8&65280|j>>>24));l(1,g|(d&65280|(b|j<<8)&255));o=$f(+n());K=m,N=Xe(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[m+16>>2]=0;v[m+20>>2]=-1074790400;v[m+8>>2]=0;v[m+12>>2]=1072693248;o=de(A[ug(m+24|0,m+16|0,m+8|0)>>3]*32768);ia:{if(D(o)<2147483648){b=~~o;break ia}b=-2147483648}K=a,M=Rc(b),u[K>>1]=M;j=w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24);d=j<<24|j<<8&16711680;r=j>>>8|0;g=w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24);b=r|g<<24;j=j>>>24|0;l(0,(r|(g&255)<<24)&-16777216|(j|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24));l(1,d|(b&65280|(j|g<<8)&255));o=$f(+n());K=m,N=Xe(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[m+16>>2]=0;v[m+20>>2]=-1074790400;v[m+8>>2]=0;v[m+12>>2]=1072693248;o=de(A[ug(m+24|0,m+16|0,m+8|0)>>3]*32768);ja:{if(D(o)<2147483648){b=~~o;break ja}b=-2147483648}K=a,M=Rc(b),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}fb=m+32|0;e=h<<4;break u}if(!((g|0)!=15|(w[h+1|0]-1&255)>>>0>1|(a|0)!=24)){v[i+416>>2]=-2147483648;d=v[i+2580>>2];ka:{if(!w[h+2|0]){v[i+8>>2]=v[i+312>>2];v[i+308>>2]=0;a=v[i+308>>2];v[i>>2]=v[i+304>>2];v[i+4>>2]=a;r=i+416|0;s=fb-16|0;fb=s;K=s,M=B(v[b>>2],Cd(x[b+34>>1])),v[K+12>>2]=M;uc(s+12|0,(d>>>0)/3|0);e=v[i+4>>2];a=f;g=v[s+12>>2];h=g;while(1){if(h){j=w[a+1|0]<<16|w[a|0]<<8|w[a+2|0]<<24;la:{ma:{na:{if((j|0)>=0){d=j;break na}d=-2147483648;if((j|0)==-2147483648){break ma}d=0-j|0}if(d>>>0<=e>>>0){break la}}e=d}h=h-1|0;a=a+3|0;continue}else{oa:{if(!e){break oa}p=e-1|0;m=e>>>1|0;h=v[b+20>>2];a=g;while(1){if(!a){break oa}d=w[f+1|0]<<16|w[f|0]<<8|w[f+2|0]<<24;j=d>>31<<31|d>>>1;d=m|d<<31;pa:{if((j|0)>0|(j|0)>=0){d=Eia(d,j,e,0);j=ib;break pa}j=Eia(p-d|0,0-((d>>>0>p>>>0)+j|0)|0,e,0);d=0-j|0;j=0-(ib+((j|0)!=0)|0)|0}K=h,M=dd(Dc(d,j),16),u[K>>1]=M;a=a-1|0;f=f+3|0;h=h+2|0;continue}}}break}if(r){v[r>>2]=e}fb=s+16|0;e=B(g,3);break ka}v[i+24>>2]=v[i+296>>2];v[i+292>>2]=0;a=v[i+292>>2];v[i+16>>2]=v[i+288>>2];v[i+20>>2]=a;r=i+416|0;s=fb-16|0;fb=s;K=s,M=B(v[b>>2],Cd(x[b+34>>1])),v[K+12>>2]=M;uc(s+12|0,(d>>>0)/3|0);e=v[i+20>>2];a=f;g=v[s+12>>2];h=g;while(1){if(h){j=w[a+1|0]<<16|w[a+2|0]<<8|w[a|0]<<24;qa:{ra:{sa:{if((j|0)>=0){d=j;break sa}d=-2147483648;if((j|0)==-2147483648){break ra}d=0-j|0}if(d>>>0<=e>>>0){break qa}}e=d}h=h-1|0;a=a+3|0;continue}else{ta:{if(!e){break ta}p=e-1|0;m=e>>>1|0;h=v[b+20>>2];a=g;while(1){if(!a){break ta}d=w[f+1|0]<<16|w[f+2|0]<<8|w[f|0]<<24;j=d>>31<<31|d>>>1;d=m|d<<31;ua:{if((j|0)>0|(j|0)>=0){d=Eia(d,j,e,0);j=ib;break ua}j=Eia(p-d|0,0-((d>>>0>p>>>0)+j|0)|0,e,0);d=0-j|0;j=0-(ib+((j|0)!=0)|0)|0}K=h,M=dd(Dc(d,j),16),u[K>>1]=M;a=a-1|0;f=f+3|0;h=h+2|0;continue}}}break}if(r){v[r>>2]=e}fb=s+16|0;e=B(g,3)}if(!e){break u}a=v[i+416>>2];if((a|0)==-2147483648){break u}f=Bia(x[b+32>>1],0,a,0)+1073741824|0;a=ib;a=f>>>0<1073741824?a+1|0:a;K=b,M=Pd(Pc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),u[K+32>>1]=M;u[b+34>>1]=x[b+34>>1]|8192;break u}va:{a=e&255;if((a|0)!=32){break va}if(!((g|0)!=15|(w[h+1|0]-1&255)>>>0>1)){v[i+416>>2]=-2147483648;d=v[i+2580>>2];wa:{if(!w[h+2|0]){v[i+40>>2]=v[i+280>>2];v[i+276>>2]=0;a=v[i+276>>2];v[i+32>>2]=v[i+272>>2];v[i+36>>2]=a;r=i+416|0;s=fb-16|0;fb=s;K=s,M=B(v[b>>2],Cd(x[b+34>>1])),v[K+12>>2]=M;uc(s+12|0,d>>>2|0);a=v[i+36>>2];e=f;h=f;g=v[s+12>>2];f=g;while(1){if(f){j=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);xa:{ya:{za:{if((j|0)>=0){d=j;break za}d=-2147483648;if((j|0)==-2147483648){break ya}d=0-j|0}if(d>>>0<=a>>>0){break xa}}a=d}f=f-1|0;h=h+4|0;continue}else{Aa:{if(!a){break Aa}p=a-1|0;m=a>>>1|0;h=v[b+20>>2];f=g;while(1){if(!f){break Aa}d=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);j=d>>31<<31|d>>>1;d=m|d<<31;Ba:{if((j|0)>0|(j|0)>=0){d=Eia(d,j,a,0);j=ib;break Ba}j=Eia(p-d|0,0-((d>>>0>p>>>0)+j|0)|0,a,0);d=0-j|0;j=0-(ib+((j|0)!=0)|0)|0}K=h,M=dd(Dc(d,j),16),u[K>>1]=M;f=f-1|0;e=e+4|0;h=h+2|0;continue}}}break}if(r){v[r>>2]=a}fb=s+16|0;e=g<<2;break wa}v[i+56>>2]=v[i+264>>2];v[i+260>>2]=0;a=v[i+260>>2];v[i+48>>2]=v[i+256>>2];v[i+52>>2]=a;r=i+416|0;s=fb-16|0;fb=s;K=s,M=B(v[b>>2],Cd(x[b+34>>1])),v[K+12>>2]=M;uc(s+12|0,d>>>2|0);a=v[i+52>>2];e=f;h=f;g=v[s+12>>2];f=g;while(1){if(f){d=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);j=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);Ca:{Da:{Ea:{if((j|0)>=0){d=j;break Ea}d=-2147483648;if((j|0)==-2147483648){break Da}d=0-j|0}if(a>>>0>=d>>>0){break Ca}}a=d}f=f-1|0;h=h+4|0;continue}else{Fa:{if(!a){break Fa}p=a-1|0;m=a>>>1|0;h=v[b+20>>2];f=g;while(1){if(!f){break Fa}d=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);j=d>>31<<31|d>>>1;d=m|d<<31;Ga:{if((j|0)>0|(j|0)>=0){d=Eia(d,j,a,0);j=ib;break Ga}j=Eia(p-d|0,0-((d>>>0>p>>>0)+j|0)|0,a,0);d=0-j|0;j=0-(ib+((j|0)!=0)|0)|0}K=h,M=dd(Dc(d,j),16),u[K>>1]=M;f=f-1|0;e=e+4|0;h=h+2|0;continue}}}break}if(r){v[r>>2]=a}fb=s+16|0;e=g<<2}if(!e){break u}a=v[i+416>>2];if((a|0)==-2147483648){break u}f=Bia(x[b+32>>1],0,a,0)+1073741824|0;a=ib;a=f>>>0<1073741824?a+1|0:a;K=b,M=Pd(Pc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),u[K+32>>1]=M;u[b+34>>1]=x[b+34>>1]|8192;break u}if((g|0)!=14|(w[h+1|0]-1&255)>>>0>1){break va}v[i+416>>2]=1065353216;d=v[i+2580>>2];Ha:{if(!w[h+2|0]){v[i+244>>2]=0;v[i+248>>2]=1065353216;a=v[i+252>>2];v[i+72>>2]=v[i+248>>2];v[i+76>>2]=a;a=v[i+244>>2];v[i+64>>2]=v[i+240>>2];v[i+68>>2]=a;e=i+416|0;h=fb-16|0;fb=h;K=h,M=B(v[b>>2],Cd(x[b+34>>1])),v[K+12>>2]=M;uc(h+12|0,d>>>2|0);E=z[(i- -64|0)+4>>2];g=f;d=v[h+12>>2];a=d;while(1){if(a){k=tf((l(2,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24)),q()));k=C(D(ag(k)?k>=C(0)?C(1):C(-1):k));E=k>E?k:E;a=a-1|0;g=g+4|0;continue}else{Ia:{a=E==C(0);if(a){break Ia}H=a?C(1):C(C(1)/E);g=v[b+20>>2];a=d;while(1){if(!a){break Ia}k=tf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));k=Nh(C(Ld(C(H*(ag(k)?k>=C(0)?C(1):C(-1):k)),C(-1))*C(32768)));Ja:{if(C(D(k))<C(2147483648)){j=~~k;break Ja}j=-2147483648}K=g,M=Rc(j),u[K>>1]=M;a=a-1|0;f=f+4|0;g=g+2|0;continue}}if(e){z[e>>2]=E}fb=h+16|0;e=d<<2}break}break Ha}v[i+228>>2]=0;v[i+232>>2]=1065353216;a=v[i+236>>2];v[i+88>>2]=v[i+232>>2];v[i+92>>2]=a;a=v[i+228>>2];v[i+80>>2]=v[i+224>>2];v[i+84>>2]=a;e=i+416|0;j=fb-16|0;fb=j;K=j,M=B(v[b>>2],Cd(x[b+34>>1])),v[K+12>>2]=M;uc(j+12|0,d>>>2|0);E=z[i+84>>2];g=f;d=v[j+12>>2];a=d;while(1){if(a){h=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);k=tf((l(2,h<<24|h<<8&16711680|(h>>>8&65280|h>>>24)),q()));k=C(D(ag(k)?k>=C(0)?C(1):C(-1):k));E=k>E?k:E;a=a-1|0;g=g+4|0;continue}else{Ka:{a=E==C(0);if(a){break Ka}H=a?C(1):C(C(1)/E);g=v[b+20>>2];a=d;while(1){if(!a){break Ka}h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);k=tf((l(2,h<<24|h<<8&16711680|(h>>>8&65280|h>>>24)),q()));k=Nh(C(Ld(C(H*(ag(k)?k>=C(0)?C(1):C(-1):k)),C(-1))*C(32768)));La:{if(C(D(k))<C(2147483648)){h=~~k;break La}h=-2147483648}K=g,M=Rc(h),u[K>>1]=M;a=a-1|0;f=f+4|0;g=g+2|0;continue}}if(e){z[e>>2]=E}fb=j+16|0;e=d<<2}break}}if(!e){break u}k=z[i+416>>2];if(k==C(1)){break u}k=Nh(Ny(C(k*C(x[b+32>>1])),C(1),C(64)));a=65535;Ma:{if(k>=C(65535)){break Ma}a=0;if(k<=C(0)){break Ma}a=~~k>>>0;if(k<C(4294967296)&k>=C(0)){break Ma}a=0}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break u}if(!((g|0)!=14|(w[h+1|0]-1&255)>>>0>1|(a|0)!=64)){v[i+416>>2]=0;v[i+420>>2]=1072693248;d=v[i+2580>>2];Na:{if(!w[h+2|0]){v[i+208>>2]=0;v[i+212>>2]=1072693248;v[i+200>>2]=0;v[i+204>>2]=0;v[i+104>>2]=0;v[i+108>>2]=0;v[i+112>>2]=0;v[i+116>>2]=1072693248;a=v[i+220>>2];v[i+120>>2]=v[i+216>>2];v[i+124>>2]=a;a=v[i+196>>2];v[i+96>>2]=v[i+192>>2];v[i+100>>2]=a;h=i+416|0;j=fb-32|0;fb=j;K=j,M=B(v[b>>2],Cd(x[b+34>>1])),v[K+4>>2]=M;uc(j+4|0,d>>>3|0);F=A[i+104>>3];d=f;e=v[j+4>>2];a=e;while(1){if(a){g=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);l(0,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));l(1,g|0);o=$f(+n());o=D(Xe(o)?o>=0?1:-1:o);F=o>F?o:F;a=a-1|0;d=d+8|0;continue}else{Oa:{a=F==0;if(a){break Oa}I=a?1:1/F;d=v[b+20>>2];a=e;while(1){if(!a){break Oa}g=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);l(0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));l(1,g|0);o=$f(+n());K=j,N=I*(Xe(o)?o>=0?1:-1:o),A[K+24>>3]=N;v[j+16>>2]=0;v[j+20>>2]=-1074790400;v[j+8>>2]=0;v[j+12>>2]=1072693248;o=de(A[ug(j+24|0,j+16|0,j+8|0)>>3]*32768);Pa:{if(D(o)<2147483648){g=~~o;break Pa}g=-2147483648}K=d,M=Rc(g),u[K>>1]=M;a=a-1|0;f=f+8|0;d=d+2|0;continue}}if(h){A[h>>3]=F}fb=j+32|0;e=e<<3}break}break Na}v[i+176>>2]=0;v[i+180>>2]=1072693248;v[i+168>>2]=0;v[i+172>>2]=0;v[i+136>>2]=0;v[i+140>>2]=0;v[i+144>>2]=0;v[i+148>>2]=1072693248;a=v[i+188>>2];v[i+152>>2]=v[i+184>>2];v[i+156>>2]=a;a=v[i+164>>2];v[i+128>>2]=v[i+160>>2];v[i+132>>2]=a;j=i+416|0;p=fb-32|0;fb=p;K=p,M=B(v[b>>2],Cd(x[b+34>>1])),v[K+4>>2]=M;uc(p+4|0,d>>>3|0);F=A[i+136>>3];d=f;g=v[p+4>>2];a=g;while(1){if(a){e=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);h=e<<24|e<<8&16711680;r=e>>>8|0;m=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);e=e>>>24|0;h=h|((r|m<<24)&65280|(e|m<<8)&255);l(0,(r|(m&255)<<24)&-16777216|(e|(m&16777215)<<8)&16711680|(m>>>8&65280|m>>>24));l(1,h|0);o=$f(+n());o=D(Xe(o)?o>=0?1:-1:o);F=o>F?o:F;a=a-1|0;d=d+8|0;continue}else{Qa:{a=F==0;if(a){break Qa}I=a?1:1/F;d=v[b+20>>2];a=g;while(1){if(!a){break Qa}m=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);e=m<<24|m<<8&16711680;r=m>>>8|0;h=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);m=m>>>24|0;e=e|((r|h<<24)&65280|(m|h<<8)&255);l(0,(r|(h&255)<<24)&-16777216|(m|(h&16777215)<<8)&16711680|(h>>>8&65280|h>>>24));l(1,e|0);o=$f(+n());K=p,N=I*(Xe(o)?o>=0?1:-1:o),A[K+24>>3]=N;v[p+16>>2]=0;v[p+20>>2]=-1074790400;v[p+8>>2]=0;v[p+12>>2]=1072693248;o=de(A[ug(p+24|0,p+16|0,p+8|0)>>3]*32768);Ra:{if(D(o)<2147483648){e=~~o;break Ra}e=-2147483648}K=d,M=Rc(e),u[K>>1]=M;a=a-1|0;f=f+8|0;d=d+2|0;continue}}if(j){A[j>>3]=F}fb=p+32|0;e=g<<3}break}}if(!e){break u}o=A[i+416>>3];if(o==1){break u}o=de(My(o*+x[b+32>>1],1,64));a=65535;Sa:{if(o>=65535){break Sa}a=0;if(o<=0){break Sa}a=~~o>>>0;if(o<4294967296&o>=0){break Sa}a=0}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break u}Ta:{Ua:{Va:{Wa:{a=(e&255)!=32;Xa:{if(!(a|(w[h+1|0]!=1|(g|0)!=12))){E=C(30517578125e-15);e=v[i+2580>>2];if(!w[h+2|0]){break Xa}break Ta}if(!(w[h+1|0]!=2|(g|0)!=12|a)){E=C(30517578125e-15);e=v[i+2580>>2];if(!w[h+2|0]){break Va}break Ua}a=(e&255)!=32;if(a|(w[h+1|0]!=1|(g|0)!=13)){break Wa}E=C(1.1920928955078125e-7);e=v[i+2580>>2];if(w[h+2|0]){break Ta}}a=v[b>>2];b=v[b+20>>2];d=fb-16|0;fb=d;v[d+12>>2]=e>>>2;v[d+8>>2]=a;a=v[Eb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){k=tf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));k=Nh(C(Ld(C((ag(k)?k>=C(0)?C(1):C(-1):k)*E),C(-1))*C(32768)));Ya:{if(C(D(k))<C(2147483648)){g=~~k;break Ya}g=-2147483648}K=b,M=Rc(g),u[K>>1]=M;b=b+2|0;f=f+4|0;e=e-1|0;continue}break}fb=d+16|0;e=a<<2;break u}e=0;if(w[h+1|0]!=2|(g|0)!=13|a){break u}E=C(1.1920928955078125e-7);e=v[i+2580>>2];if(w[h+2|0]){break Ua}}a=v[b>>2];b=v[b+20>>2];d=fb-16|0;fb=d;v[d+12>>2]=e>>>3;v[d+8>>2]=a;a=v[Eb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){k=tf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));k=Nh(C(Ld(C((ag(k)?k>=C(0)?C(1):C(-1):k)*E),C(-1))*C(32768)));Za:{if(C(D(k))<C(2147483648)){g=~~k;break Za}g=-2147483648}K=b,M=Rc(g),u[K>>1]=M;k=tf((l(2,w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24)),q()));k=Nh(C(Ld(C((ag(k)?k>=C(0)?C(1):C(-1):k)*E),C(-1))*C(32768)));_a:{if(C(D(k))<C(2147483648)){g=~~k;break _a}g=-2147483648}K=b,M=Rc(g),u[K+2>>1]=M;b=b+4|0;f=f+8|0;e=e-1|0;continue}break}fb=d+16|0;e=a<<3;break u}a=v[b>>2];b=v[b+20>>2];g=fb-16|0;fb=g;v[g+12>>2]=e>>>3;v[g+8>>2]=a;a=v[Eb(g+12|0,g+8|0)>>2];e=a;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);k=tf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=Nh(C(Ld(C((ag(k)?k>=C(0)?C(1):C(-1):k)*E),C(-1))*C(32768)));$a:{if(C(D(k))<C(2147483648)){d=~~k;break $a}d=-2147483648}K=b,M=Rc(d),u[K>>1]=M;d=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);k=tf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=Nh(C(Ld(C((ag(k)?k>=C(0)?C(1):C(-1):k)*E),C(-1))*C(32768)));ab:{if(C(D(k))<C(2147483648)){d=~~k;break ab}d=-2147483648}K=b,M=Rc(d),u[K+2>>1]=M;b=b+4|0;f=f+8|0;e=e-1|0;continue}break}fb=g+16|0;e=a<<3;break u}a=v[b>>2];b=v[b+20>>2];g=fb-16|0;fb=g;v[g+12>>2]=e>>>2;v[g+8>>2]=a;a=v[Eb(g+12|0,g+8|0)>>2];e=a;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);k=tf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));k=Nh(C(Ld(C((ag(k)?k>=C(0)?C(1):C(-1):k)*E),C(-1))*C(32768)));bb:{if(C(D(k))<C(2147483648)){d=~~k;break bb}d=-2147483648}K=b,M=Rc(d),u[K>>1]=M;b=b+2|0;f=f+4|0;e=e-1|0;continue}break}fb=g+16|0;e=a<<2;break u}a=V(30480)|0}if((O()|0)!=(ea(30480)|0)){break d}_(a|0)|0;v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)==1){break v}}wb(s);break u}a=P()|0;O()|0;break d}v[23220]=0;Q(142,c|0,e+J|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break f}}Jc(G)}fb=i+2608|0;return e|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}wb(s);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Jc(G);S(a|0);L()}function iha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=fb-640|0;fb=e;wc(b);d=fb-16|0;fb=d;h=e+448|0;sq(d+8|0,h);j=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],j);l=v[d+4>>2];if((l|0)==(j|0)){Yb(b,v[d+12>>2])}fb=d+16|0;d=(j|0)==(l|0);if(!d){VS(h)}a:{b:{c:{if(!d){break c}if(!XS(e+448|0)){break c}if(!Lb(v[b>>2],v[b+8>>2],Pc(WS(e+448|0),ib))){break c}if(!c){g=1;break c}zd(a,32);t[e+447|0]=0;j=Gb(e+432|0);d:{e:{f:{g:{h:{i:{j:{k:{if(!Mb(e+448|0,16224,4)){v[23220]=0;R(358,a|0,16777216);d=v[23220];v[23220]=0;if((d|0)==1){break b}d=v[b>>2];v[23220]=0;d=T(147,d|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break b}v[23220]=0;Q(142,b|0,d-4|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}v[23220]=0;z=T(144,b|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break k}break b}l:{m:{n:{o:{p:{q:{if((x[e+488>>1]-2185&65535)>>>0>1910){break q}d=v[b>>2];v[23220]=0;d=T(147,d|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break b}v[23220]=0;Q(142,b|0,d-4|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}v[23220]=0;z=T(144,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}if(z>>>0<256){break q}d=v[b>>2];v[23220]=0;d=T(147,d|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break b}if(d>>>0<=z>>>0){break q}v[23220]=0;d=Q(142,b|0,z|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break b}if(!d){break q}v[23220]=0;d=T(359,b|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break b}if(!d){break q}v[23220]=0;R(358,a|0,16777216);d=v[23220];v[23220]=0;if((d|0)==1){break b}d=x[e+488>>1];if(d>>>0>=4096){v[23220]=0;c=Q(1,e+168|0,16439)|0;b=v[23220];v[23220]=0;if((b|0)==1){break j}a=v[a+1298464>>2];v[23220]=0;U(360,a|0,1,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(c);break d}b=P()|0;O()|0;vb(c);break a}if(d>>>0<2194){break q}v[23220]=0;d=Q(1,e+416|0,15963)|0;g=v[23220];v[23220]=0;if((g|0)==1){break p}g=v[a+1298464>>2];v[23220]=0;U(360,g|0,4,d|0);g=v[23220];v[23220]=0;if((g|0)==1){break o}vb(d)}if(v[a+480180>>2]!=32){break k}d=x[e+488>>1];if((d&61440)!=20480){break l}d=d&4095;g=d<<16;if(Mb(e+508|0,13593,4)){break n}t[e+447|0]=1;break m}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(d);break a}if(d>>>0<297){break m}g=x[e+508>>1]|g}v[a+1074308>>2]=g;break k}g=x[e+490>>1];if(!((g|0)!=2184&(d|0)!=2184)){t[e+447|0]=1;v[a+1074308>>2]=18284544;break k}r:{switch(d-532|0){default:if(v[e+508>>2]|((d|0)!=768|(g|0)!=768)|(x[e+480>>1]!=256|w[e+500|0]!=128)){break k}if(w[e+501|0]){break k}v[a+1074308>>2]=18285088;t[e+447|0]=1;break k;case 3:if(v[e+508>>2]|(g|0)!=512){break k}s:{if(PA(e+512|0,255,64)){v[a+1074308>>2]=18219008;v[23220]=0;g=Q(1,e+400|0,14800)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break s}b=P()|0;O()|0;break a}v[a+1074308>>2]=18284544;v[23220]=0;g=Q(1,e+400|0,16813)|0;d=v[23220];v[23220]=0;if((d|0)==1){break i}}Db(j,g);vb(g);t[e+447|0]=1;break k;case 1:case 2:break k;case 0:break r}}if(v[e+508>>2]|(g|0)!=514){break k}v[a+1074308>>2]=17367040;v[23220]=0;d=Q(1,e+400|0,14692)|0;g=v[23220];v[23220]=0;if((g|0)==1){break f}Db(j,d);vb(d);t[e+447|0]=1}d=x[e+492>>1];g=d>>>2|0;v[a+480208>>2]=d<<3&32768|(g&8|(g&4|(v[a+480208>>2]&-32797|d<<1&16)));d=e+280|0;Kq(d,e+448|4);v[23220]=0;R(209,e+168|0,d|0);d=v[23220];v[23220]=0;if((d|0)==1){break h}d=e+168|0;xc(a+1298308|0,d);ub(d);if(!(!(w[e+494|0]&4)|v[a+1074308>>2]-18285314>>>0>4276681982)){v[a+480216>>2]=w[e+478|0];v[a+480220>>2]=w[e+479|0]}d=w[e+496|0];v[a+480200>>2]=d>>>0>128?256:d<<1;d=w[e+498|0];if(d){v[a+480196>>2]=d}t[e+168|0]=31;t[e+280|0]=w[e+499|0];d=e+168|0;g=e+280|0;I=a,J=B(w[$e(d,g)|0],1e4),v[I+480204>>2]=J;t[e+168|0]=w[e+497|0];t[e+280|0]=128;I=a,J=w[Rb(d,g)|0],v[I+480228>>2]=J;g=0;while(1){if((g|0)==64){t:{v[23220]=0;Q(142,b|0,192)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}if(v[a+480180>>2]==16777216&(x[e+488>>1]-2187&65535)>>>0<=2){break t}d=w[a+484376|0];g=v[a+484360>>2];v[23220]=0;da(333,Vb(g,d)|0,b|0,x[e+480>>1],255,254);d=v[23220];v[23220]=0;if((d|0)==1){break b}break e}}else{l=(e+448|0)+g|0;i=l- -64|0;u:{if(w[i|0]==255){break u}h=(g<<5)+a|0;d=h+480280|0;Pe(d);I=h+480286|0,J=Pd(w[l+128|0],0,64),u[I>>1]=J;l=t[i|0];if((l|0)<0){v[d>>2]=v[d>>2]|1024}l=l&127;if(l>>>0<=64){u[h+480284>>1]=l<<2;break u}if((l|0)!=100){break u}v[d>>2]=v[d>>2]|256}g=g+1|0;continue}break}g=0;v[23220]=0;d=T(181,b|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break g}if(d){break d}v[23220]=0;d=T(144,b|0)|0;h=v[23220];v[23220]=0;v:{if((h|0)==1){break v}if(d>>>0>4e3){break d}h=w[a+484376|0];l=v[a+484360>>2];v[23220]=0;d=W(361,Vb(l,h)|0,b|0,d|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break v}if(!d){break d}break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}s=Ib(e+384|0);p=Ib(e+368|0);g=0;l=Ib(e+352|0);v[23220]=0;d=W(362,b|0,s|0,x[e+482>>1])|0;h=v[23220];v[23220]=0;w:{x:{y:{if((h|0)==1){break y}if(!d){break w}v[23220]=0;d=W(362,b|0,p|0,x[e+484>>1])|0;h=v[23220];v[23220]=0;if((h|0)==1){break y}if(!d){break w}v[23220]=0;d=W(362,b|0,l|0,x[e+486>>1])|0;h=v[23220];v[23220]=0;if((h|0)==1){break y}if(!d){break w}v[e+348>>2]=-1;I=e,J=Ab(v[s>>2]),v[I+168>>2]=J;g=Ab(v[s+4>>2]);while(1){d=v[e+168>>2];if(Nb(d,g)){d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);if(!(!d|d>>>0>=y[e+348>>2])){v[e+348>>2]=d}ye(e+168|0);continue}else{I=e,J=Ab(v[p>>2]),v[I+168>>2]=J;g=Ab(v[p+4>>2]);while(1){d=v[e+168>>2];if(Nb(d,g)){d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);if(!(!d|d>>>0>=y[e+348>>2])){v[e+348>>2]=d}ye(e+168|0);continue}else{I=e,J=Ab(v[l>>2]),v[I+168>>2]=J;g=Ab(v[l+4>>2]);z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{while(1){d=v[e+168>>2];if(Nb(d,g)){d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);if(!(!d|d>>>0>=y[e+348>>2])){v[e+348>>2]=d}ye(e+168|0);continue}else{if(t[e+494|0]&1){v[e+168>>2]=v[e+504>>2];I=e,J=v[Eb(e+348|0,e+168|0)>>2],v[I+348>>2]=J}if(x[e+490>>1]!=532){break H}d=x[e+488>>1];if(w[e+479|0]|(d?(d|0)!=532:0)|(w[e+478|0]|w[e+501|0])){break H}if(v[e+508>>2]|w[e+492|0]&192){break H}if(x[e+482>>1]){break I}d=x[e+484>>1];if(!d){break I}if((v[b+8>>2]+(sc(v[p>>2],v[p+4>>2])<<2)|0)+2>>>0>y[e+348>>2]){break I}}break}g=0;while(1){if((g&65535)>>>0<(d&65535)>>>0){v[23220]=0;d=T(144,b|0)|0;f=v[23220];v[23220]=0;J:{if((f|0)!=1){if(!d){break J}jg(b,((g&65535)<<2)+4|0);break I}b=P()|0;O()|0;break x}g=g+1|0;d=x[e+484>>1];continue}break}v[23220]=0;d=Q(1,e+336|0,14950)|0;f=v[23220];v[23220]=0;if((f|0)==1){break G}Db(j,d);vb(d)}f=1;if(x[e+488>>1]){break H}v[23220]=0;d=Q(1,e+320|0,15372)|0;g=v[23220];v[23220]=0;if((g|0)==1){break F}Db(j,d);vb(d)}d=x[e+494>>1];K:{if(d&2){v[23220]=0;g=T(181,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break A}d=v[b+8>>2];h=v[b>>2];v[23220]=0;i=d;d=g<<3;h=W(143,h|0,i|0,d|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break A}if(!(!h|y[e+348>>2]<d+v[b+8>>2]>>>0)){v[23220]=0;d=a+1298408|0;R(363,d|0,g|0);h=v[23220];v[23220]=0;if((h|0)==1){break A}I=e,J=Ab(v[d>>2]),v[I+280>>2]=J;h=Ab(v[d+4>>2]);L:{M:{while(1){d=v[e+280>>2];if(!Nb(d,h)){if(!(!g&f)){break K}if(!(w[e+494|0]&4)){break L}v[23220]=0;d=Q(1,e+304|0,15405)|0;f=v[23220];v[23220]=0;if((f|0)==1){break M}Db(j,d);vb(d);break K}v[23220]=0;R(364,b|0,e+168|0);i=v[23220];v[23220]=0;if((i|0)!=1){Sb(d,0,44);i=w[e+168|0]|w[e+169|0]<<8;if(i|(w[e+170|0]|w[e+171|0]<<8)){v[d+20>>2]=((i&65024)>>>9|0)+80;I=d,J=Ub((w[e+168|0]|w[e+169|0]<<8)>>>5&15,1,12)-1|0,v[I+16>>2]=J;I=d,J=Ub((w[e+168|0]|w[e+169|0]<<8)&31,1,31),v[I+12>>2]=J;I=d,J=Ub((w[e+170|0]|w[e+171|0]<<8)>>>11|0,0,23),v[I+8>>2]=J;I=d,J=Ub((w[e+170|0]|w[e+171|0]<<8)>>>5&63,0,59),v[I+4>>2]=J;I=d,J=Ub((w[e+170|0]|w[e+171|0]<<8)<<1&62,0,59),v[I>>2]=J}v[d+44>>2]=w[e+172|0]|w[e+173|0]<<8|(w[e+174|0]<<16|w[e+175|0]<<24);v[e+280>>2]=v[e+280>>2]+48;continue}break}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}v[23220]=0;d=Q(1,e+304|0,14977)|0;f=v[23220];v[23220]=0;if((f|0)!=1){Db(j,d);vb(d);break K}b=P()|0;O()|0;break x}jg(b,2);break K}if(!(d>>>0<2&f)){break K}v[23220]=0;d=T(181,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break z}if(!d){v[23220]=0;d=Q(1,e+304|0,14950)|0;f=v[23220];v[23220]=0;if((f|0)!=1){Db(j,d);vb(d);break K}b=P()|0;O()|0;break x}jg(b,2)}N:{if(!(w[e+494|0]&8?1:w[e+492|0]&128)){break N}v[23220]=0;d=a+901404|0;f=Q(365,b|0,d|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break E}if(!f){break N}OA(d)}if(x[e+488>>1]<=531){Vp(a+901404|0)}v[23220]=0;A=T(161,e+280|0)|0;d=v[23220];v[23220]=0;O:{P:{Q:{if((d|0)!=1){v[23220]=0;d=Q(355,b|0,13830)|0;f=v[23220];v[23220]=0;if((f|0)==1){break Q}if(d){v[23220]=0;d=T(144,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break P}v[23220]=0;U(177,e+256|0,b|0,d|0);d=v[23220];v[23220]=0;if((d|0)==1){break P}d=e+256|0;f=gc(e+168|0,d);Yc(A,f);wb(f);wb(d)}u[a+480188>>1]=1;v[23220]=0;d=Q(355,b|0,13835)|0;f=v[23220];v[23220]=0;if((f|0)==1){break Q}if(!d){break C}v[23220]=0;d=T(144,b|0)|0;f=v[23220];v[23220]=0;if((f|0)!=1){v[23220]=0;U(177,e+256|0,b|0,d|0);d=v[23220];v[23220]=0;if((d|0)!=1){break O}}b=P()|0;O()|0;break B}b=P()|0;O()|0;break x}b=P()|0;O()|0;break B}b=P()|0;O()|0;break B}f=e+256|0;d=gc(e+168|0,f);wb(f);f=v[d>>2];v[23220]=0;f=T(147,f|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break D}u[e+256>>1]=(f>>>0)/20;f=x[Tc(26644,e+256|0)>>1];u[a+480188>>1]=f;g=0;while(1){if((f|0)==(g|0)){wb(d);break C}v[23220]=0;U(366,d|0,((g<<5)+a|0)+480289|0,20);h=v[23220];v[23220]=0;if((h|0)!=1){g=g+1|0;continue}break}break D}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;wb(d);break B}R:{d=v[e+348>>2];f=v[b+8>>2];S:{if(d>>>0>=f>>>0){g=d-f|0;break S}v[23220]=0;g=T(189,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break R}}v[23220]=0;U(177,e+168|0,b|0,g|0);d=v[23220];v[23220]=0;if((d|0)==1){break R}d=e+168|0;D=gc(e+256|0,d);wb(d);v[23220]=0;E=Q(367,a|0,D|0)|0;d=v[23220];v[23220]=0;T:{U:{V:{if((d|0)==1){break V}if(!(t[e+494|0]&1)|!x[e+502>>1]){break U}v[23220]=0;d=Q(142,b|0,v[e+504>>2])|0;f=v[23220];v[23220]=0;if((f|0)==1){break V}if(!d){break U}v[23220]=0;X(322,a+1298332|0,b|0,x[e+502>>1],4);d=v[23220];v[23220]=0;if((d|0)!=1){break U}}b=P()|0;O()|0;break T}u[a+480192>>1]=0;d=0;if(w[e+492|0]&4){u[e+168>>1]=x[e+482>>1];u[e+96>>1]=255;d=x[Tc(e+168|0,e+96|0)>>1];u[a+480192>>1]=d}f=a+480192|0;g=0;W:{while(1){if((d&65535)>>>0<=g>>>0){v[e+252>>2]=0;f=x[e+484>>1];if(f){d=zb(v[p>>2],f-1|0);v[e+252>>2]=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+80}u[e+168>>1]=f;u[e+96>>1]=3999;d=x[Tc(e+168|0,e+96|0)>>1];u[a+480190>>1]=d;n=c&2;q=e+188|0;o=a+480190|0;C=a+1298464|0;g=0;while(1){X:{Y:{Z:{_:{$:{aa:{ba:{ca:{if((d&65535)>>>0>g>>>0){d=zb(v[p>>2],g);d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);if(!d){break Y}v[23220]=0;d=Q(142,b|0,d|0)|0;f=v[23220];v[23220]=0;da:{ea:{fa:{ga:{ha:{if((f|0)==1){break ha}if(!d){break Y}v[23220]=0;d=Q(368,b|0,e+168|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break ha}if(!d){break Y}v[23220]=0;h=g+1|0;d=B(h,104)+a|0;f=d+484380|0;i=Q(369,e+168|0,f|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break ga}k=e+152|0;Kq(k,q);v[23220]=0;R(209,e+96|0,k|0);k=v[23220];v[23220]=0;if((k|0)==1){break fa}k=e+96|0;yc(((h<<5)+a|0)+946304|0,k);ub(k);v[23220]=0;i=Q(142,b|0,i|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break ga}if(!i){break Y}d=x[d+484414>>1];if(!(d&512)){break ea}v[23220]=0;d=Q(370,b|0,e+96|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break ca}if(!d){break da}v[e+8>>2]=v[e+104>>2];d=v[e+100>>2];v[e>>2]=v[e+96>>2];v[e+4>>2]=d;cl(f,1,e);break da}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}if(!(d&16384)){r=x[e+488>>1];h=w[e+186|0];k=h&2;d=w[e+214|0];i=Uc(e+96|0,k?16:8,1,0,(d^-1)&1);if(!(!(h&4)|r>>>0<532)){so(i,3)}ia:{ja:{if(h&8){h=d&4?5:4;break ja}if(!k){h=10;if((d|0)==255){break ja}}if(d&2){t[i+2|0]=1}if(d&4){Qf(i,2)}if(!(d&8)){break ia}h=9;if(!k){break ia}}Qf(i,h)}if(n){d=0;v[23220]=0;W(206,e+96|0,f|0,b|0)|0;h=v[23220];v[23220]=0;if((h|0)!=1){break _}break X}d=1;h=w[e+99|0];if(h>>>0>17){break Z}h=1<<h;if(!(h&63503)){if(!(h&198144)){break Z}break $}if(w[e+96|0]){break $}break _}v[23220]=0;R(371,b|0,e+80|0);d=v[23220];v[23220]=0;if((d|0)==1){break aa}f=v[e+80>>2];if(!(!n|!f)){d=Gb(e+96|0);v[23220]=0;U(258,b|0,d|0,f|0);f=v[23220];v[23220]=0;ka:{la:{ma:{na:{oa:{pa:{qa:{if((f|0)!=1){v[23220]=0;R(372,e+136|0,16361);f=v[23220];v[23220]=0;if((f|0)==1){break qa}v[e+64>>2]=h;v[23220]=0;U(11,e+120|0,0,d|0);f=v[23220];v[23220]=0;if((f|0)==1){break pa}v[23220]=0;X(373,e+152|0,e+136|0,e- -64|0,e+120|0);f=v[23220];v[23220]=0;if((f|0)==1){break oa}f=v[C>>2];v[23220]=0;U(360,f|0,2,e+152|0);f=v[23220];v[23220]=0;if((f|0)==1){break na}vb(e+152|0);vb(e+120|0);bc(e+136|0);ub(d);break da}b=P()|0;O()|0;break ka}b=P()|0;O()|0;break ka}b=P()|0;O()|0;break la}b=P()|0;O()|0;break ma}b=P()|0;O()|0;vb(e+152|0)}vb(e+120|0)}bc(e+136|0)}ub(d);break T}v[23220]=0;Q(175,b|0,f|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break aa}}d=0;break Z}u[e+168>>1]=1;u[e+96>>1]=d;I=a,J=x[Re(e+168|0,e+96|0)>>1],u[I+480190>>1]=J;if(!(x[e+488>>1]==516&m)|x[e+490>>1]!=512|(x[e+494>>1]|v[e+508>>2])){break ba}if((x[e+492>>1]&65527)!=21|w[e+496|0]!=128|(w[e+497|0]!=48|w[e+500|0]!=128)){break ba}if(w[e+501|0]|x[e+502>>1]){break ba}f=e+512|0;d=0;g=1;while(1)if((d|0)==64){f=e+576|0;d=0;while(1)if((d|0)==64){d=20;while(1){if((d|0)==26){ra:{if(!(g&1)){break ba}v[23220]=0;d=Q(1,e+152|0,9840)|0;f=v[23220];v[23220]=0;if((f|0)==1){break ra}Db(j,d);vb(d);break ba}}else{g=!w[(d+e|0)+452|0]&g;d=d+1|0;continue}break}b=P()|0;O()|0;break T}else{g=w[d+f|0]==64&g;d=d+1|0;continue}}else{g=(w[d+f|0]&127)==32&g;d=d+1|0;continue}}b=P()|0;O()|0;break T}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;d=sc(v[l>>2],v[l+4>>2]);u[e+168>>1]=d;q=x[Tc(e+168|0,v[a+8>>2]+10|0)>>1];u[e+118>>1]=q;sa:{ta:{ua:{va:{if((d|0)!=(q|0)){v[23220]=0;Y(374,e+96|0);d=v[23220];v[23220]=0;if((d|0)==1){break sa}d=v[l+4>>2];f=v[l>>2];v[23220]=0;I=e,J=sc(f,d),v[I+136>>2]=J;X(375,e+168|0,e+96|0,e+136|0,e+118|0);d=v[23220];v[23220]=0;if((d|0)==1){break ua}d=v[a+1298464>>2];v[23220]=0;U(360,d|0,2,e+168|0);d=v[23220];v[23220]=0;if((d|0)==1){break va}vb(e+168|0);bc(e+96|0)}if(!(c&1)){u[e+118>>1]=0;q=0}n=a+480188|0;m=0;wa:{xa:{ya:{za:{Aa:{Ba:{while(1){Ca:{if((m|0)==(q|0)){Da:{Ea:{c=v[e+252>>2];if(!c){break Ea}v[23220]=0;Q(142,b|0,c|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break Da}if(!(r&1)){break Ea}while(1){Fa:{c=v[b+8>>2];d=v[b>>2];v[23220]=0;c=W(143,d|0,c|0,4)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Fa}if(!c){break Ea}v[23220]=0;c=Q(355,b|0,13804)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Fa}Ga:{if(!c){v[23220]=0;c=Q(355,b|0,13809)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Fa}if(!c){break Ga}}v[23220]=0;c=T(144,b|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){jg(b,8);if(!(c&1616928864)|c&-2139062144){break Ga}break Ea}b=P()|0;O()|0;break T}v[23220]=0;c=T(181,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Fa}v[23220]=0;Q(175,b|0,c|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){continue}}break}b=P()|0;O()|0;break T}v[23220]=0;c=Q(376,a|0,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Da}c=c|w[e+447|0];t[e+447|0]=c;if(!(!c|E)){Ut(a+1074312|0);t[a+1074368|0]=0}v[23220]=0;X(377,a|0,b|0,0,e+447|0);c=v[23220];v[23220]=0;if((c|0)==1){break Da}v[23220]=0;o=a+484344|0;R(212,o|0,q|0);c=v[23220];v[23220]=0;if((c|0)==1){break Da}C=a+480188|0;H=a+480183|0;m=0;Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{while(1){Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{if((m|0)!=(q|0)){c=zb(v[l>>2],m);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);if(c){v[23220]=0;c=Q(142,b|0,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break ab}if(c){break $a}}v[23220]=0;c=W(213,o|0,m&65535,64)|0;d=v[23220];v[23220]=0;if((d|0)==1){break ab}if(c){break bb}u[e+48>>1]=m;v[23220]=0;Y(378,e+96|0);c=v[23220];v[23220]=0;if((c|0)==1){break fb}v[23220]=0;U(379,e+168|0,e+96|0,e+48|0);c=v[23220];v[23220]=0;if((c|0)==1){break eb}c=v[a+1298464>>2];v[23220]=0;U(360,c|0,2,e+168|0);c=v[23220];v[23220]=0;if((c|0)==1){break db}vb(e+168|0);bc(e+96|0)}if(!v[a+1074308>>2]){g=x[e+488>>1];if((g|0)!=2184){break Za}v[a+1074308>>2]=18284544}if(!ah(v[j+4>>2],w[j+11|0])){break _a}v[23220]=0;c=Q(1,e+96|0,17558)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Ra}d=v[a+1074308>>2];v[23220]=0;R(127,e- -64|0,d|0);d=v[23220];v[23220]=0;if((d|0)==1){break Ta}v[23220]=0;U(2,e+168|0,c|0,e- -64|0);d=v[23220];v[23220]=0;if((d|0)==1){break Ua}f=e+168|0;d=Db(j,f);vb(f);vb(e- -64|0);vb(c);if(!Mb(e+508|0,13593,4)|(x[e+488>>1]&61440)!=20480){break Ya}v[23220]=0;c=Q(1,e+168|0,16825)|0;f=v[23220];v[23220]=0;if((f|0)==1){break Va}v[23220]=0;Q(85,d|0,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Wa}vb(c);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break cb}b=P()|0;O()|0;vb(e+168|0)}bc(e+96|0);break T}c=v[o>>2];v[23220]=0;R(380,Xb(c,m)|0,A|0);c=v[23220];v[23220]=0;if((c|0)!=1){break Pa}}b=P()|0;O()|0;break T}v[23220]=0;c=T(181,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Ha}v[23220]=0;F=T(181,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Ia}v[23220]=0;d=Q(175,b|0,4)|0;f=v[23220];v[23220]=0;if((f|0)==1){break Ia}if(!d){break Pa}v[23220]=0;d=W(213,o|0,m&65535,F|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break Ia}if(!d){break Pa}v[23220]=0;U(177,e+96|0,b|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break Ja}c=e+96|0;n=gc(e+168|0,c);wb(c);c=v[o>>2];v[23220]=0;R(380,Xb(c,m)|0,A|0);c=v[23220];v[23220]=0;if((c|0)==1){break La}c=x[C>>1];v[23220]=0;k=Q(381,e+120|0,c|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break Ma}c=x[C>>1];d=e+96|0;sh(d);v[23220]=0;i=W(382,e+80|0,c|0,d|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break Oa}I=e,J=Ab(v[Xb(v[o>>2],m)>>2]),v[I+64>>2]=J;r=0;while(1){gb:{hb:{ib:{jb:{if(r>>>0>=F>>>0){break jb}c=v[n>>2];v[23220]=0;c=W(143,c|0,v[e+176>>2],1)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Qa}if(!c){break jb}v[23220]=0;c=T(193,n|0)|0;d=v[23220];v[23220]=0;kb:{if((d|0)!=1){c=c<<24>>24;if(c){break kb}gT(e- -64|0,x[C>>1]);r=r+1|0;continue}break Qa}lb:{d=c&127;h=d?d-1&65535:0;if(Wc(v[k>>2],v[e+124>>2])>>>0>h>>>0){break lb}v[23220]=0;t[e+96|0]=0;d=h+1|0;U(383,k|0,d|0,e+96|0);f=v[23220];v[23220]=0;if((f|0)==1){break Qa}f=e+96|0;sh(f);v[23220]=0;U(384,i|0,d|0,f|0);d=v[23220];v[23220]=0;if((d|0)!=1){break lb}break Qa}if((c|0)<0){v[23220]=0;c=T(193,n|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Qa}I=Hb(v[k>>2],h),J=c,t[I|0]=J}d=e+96|0;sh(d);if(h>>>0<x[a+480188>>1]){d=yd(v[e+64>>2],h)}c=Hb(v[k>>2],h);f=w[c|0];if(f&16){I=d,J=w[yd(v[i>>2],h)|0],t[I|0]=J;f=w[c|0]}if(f&32){I=d,J=w[yd(v[i>>2],h)+1|0],t[I+1|0]=J;f=w[c|0]}if(f&64){f=yd(v[i>>2],h);t[d+2|0]=w[f+2|0];t[d+4|0]=w[f+4|0];f=w[c|0]}if(f<<24>>24<0){f=yd(v[i>>2],h);t[d+3|0]=w[f+3|0];t[d+5|0]=w[f+5|0];f=w[c|0]}if(f&1){v[23220]=0;c=T(193,n|0)|0;f=v[23220];v[23220]=0;mb:{nb:{if((f|0)!=1){c=c+(((c^-1)&128)>>>7|0)|0;if(!(t[H|0]&1)){break nb}f=c;break mb}break Qa}f=253;if((c-121&255)>>>0<132){break mb}f=(c&255)==253?0:c}t[d|0]=f;I=yd(v[i>>2],h),J=f,t[I|0]=J;c=Hb(v[k>>2],h)}if(w[c|0]&2){v[23220]=0;c=T(193,n|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break Qa}t[d+1|0]=c;I=yd(v[i>>2],h),J=c,t[I+1|0]=J;c=Hb(v[k>>2],h)}if(!(w[c|0]&4)){break gb}v[23220]=0;c=T(193,n|0)|0;f=v[23220];v[23220]=0;ob:{pb:{if((f|0)!=1){if(c>>>0>64){break pb}t[d+4|0]=c;f=1;break ob}break Qa}if(c<<24>>24<=-64){f=2;t[d+2|0]=2;c=c^-128;t[d+4|0]=c;break hb}if(c>>>0<=74){f=5;t[d+2|0]=5;c=c-65|0;t[d+4|0]=c;break hb}if(c>>>0<=84){f=6;t[d+2|0]=6;c=c-75|0;t[d+4|0]=c;break hb}if(c>>>0<=94){f=3;t[d+2|0]=3;c=c-85|0;t[d+4|0]=c;break hb}if(c>>>0<=104){f=4;t[d+2|0]=4;c=c-95|0;t[d+4|0]=c;break hb}if(c>>>0<=114){f=13;t[d+2|0]=13;c=c-105|0;t[d+4|0]=c;break hb}if(c>>>0<=124){f=12;t[d+2|0]=12;c=c-115|0;t[d+4|0]=c;break hb}g=c+63|0;if((g&255)>>>0<=9){t[d+4|0]=g;f=11;t[d+2|0]=11;c=g;break hb}g=c+53|0;G=g&255;if(G>>>0<=9){t[d+4|0]=g;f=8;t[d+2|0]=8;if(!G){c=0;break hb}if(v[a+1074308>>2]-1>>>0>18285139){break ib}f=7;t[d+2|0]=7;break ib}c=c+33|0;if((c&255)>>>0>=10){c=w[d+4|0];f=w[d+2|0];break hb}t[d+4|0]=c;f=15}t[d+2|0]=f;break hb}qh(i);$b(k);wb(n);break Pa}c=g}g=yd(v[i>>2],h);t[g+4|0]=c;t[g+2|0]=f;c=Hb(v[k>>2],h)}if(!(w[c|0]&8)){continue}v[23220]=0;R(250,e+32|0,n|0);c=v[23220];v[23220]=0;if((c|0)!=1){t[d+3|0]=w[e+32|0];I=d,J=w[gd(e+32|0)|0],t[I+5|0]=J;LA(d,1);c=yd(v[i>>2],h);t[c+3|0]=w[d+3|0];t[c+5|0]=w[d+5|0];continue}break}break Qa}g=x[e+488>>1]}qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{c=g&65535;switch(c>>>12|0){case 13:break rb;case 7:break sb;case 6:break tb;case 4:break ub;case 1:break wb;case 0:break xb;default:break Xa}}if(E){v[23220]=0;c=Q(1,e+168|0,8327)|0;d=v[23220];v[23220]=0;if((d|0)!=1){Db(j,c);vb(c);break Xa}b=P()|0;O()|0;break T}yb:{zb:{Ab:{Bb:{Cb:{Db:{Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{if((g&65535)==532){d=x[e+490>>1];if((d|0)!=532){if((d|0)!=512){g=532;break Kb}Mb:{if(x[e+494>>1]|x[e+492>>1]!=9|(w[e+479|0]|w[e+478|0])){break Mb}if(x[e+482>>1]|x[e+480>>1]!=(x[e+486>>1]+1|0)|(w[e+496|0]!=128|w[e+497|0]!=100)){break Mb}if(w[e+498|0]!=1|w[e+500|0]!=128|(w[e+501|0]|x[e+502>>1])){break Mb}if(v[e+504>>2]|v[e+508>>2]){break Mb}v[23220]=0;c=Q(1,e+168|0,9821)|0;d=v[23220];v[23220]=0;if((d|0)!=1){Db(j,c);vb(c);break Xa}b=P()|0;O()|0;break T}g=532;if(v[e+508>>2]|(w[e+479|0]|w[e+478|0])){break Jb}v[a+1074308>>2]=16777381;v[23220]=0;c=Q(1,e+168|0,14881)|0;d=v[23220];v[23220]=0;if((d|0)!=1){Db(j,c);vb(c);t[e+447|0]=1;break Xa}b=P()|0;O()|0;break T}if(!Mb(e+508|0,14069,4)){v[23220]=0;c=Q(1,e+168|0,8365)|0;d=v[23220];v[23220]=0;if((d|0)!=1){Db(j,c);vb(c);g=a+1074312|0;d=38;break vb}b=P()|0;O()|0;break T}g=532;if(w[e+501|0]|x[e+494>>1]>1|(v[e+508>>2]|(x[e+492>>1]&4294)!=4)){break Lb}if(!x[a+480190>>1]){break Lb}v[23220]=0;f=Q(52,e+96|0,13451)|0;c=v[23220];v[23220]=0;if((c|0)==1){break Hb}c=fb-16|0;fb=c;d=fb-16|0;fb=d;Uu(d+8|0,a+484527|0);ES(c+8|0,v[d+8>>2],v[d+12>>2]);fb=d+16|0;re(c,f);d=Hc(v[c+8>>2],v[c+12>>2],v[c>>2],v[c+4>>2]);fb=c+16|0;ub(f);if(d){break Ib}g=x[e+488>>1]}if(g&65535){break Lb}if(ah(v[j+4>>2],w[j+11|0])){break Fb}}d=x[e+490>>1]}if((d&65535)>>>0>767){break Xa}}if(!ah(v[j+4>>2],w[j+11|0])){break Xa}if((d&65535)>>>0<533){break Db}v[23220]=0;c=Q(1,e- -64|0,14914)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Eb}Db(j,c);vb(c);break Cb}v[23220]=0;c=Q(1,e+168|0,8391)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Gb}Db(j,c);vb(c);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}v[23220]=0;c=Q(1,e+168|0,9711)|0;d=v[23220];v[23220]=0;if((d|0)!=1){Db(j,c);vb(c);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}if((g&65535)>>>0>=533){v[23220]=0;R(385,e- -64|0,3976);c=v[23220];v[23220]=0;Nb:{if((c|0)!=1){v[23220]=0;v[e+48>>2]=x[e+488>>1]-532;U(386,e+168|0,e- -64|0,e+48|0);c=v[23220];v[23220]=0;if((c|0)==1){break Nb}c=e+168|0;Db(j,c);vb(c);bc(e- -64|0);break Cb}b=P()|0;O()|0;break T}b=P()|0;O()|0;bc(e- -64|0);break T}v[23220]=0;R(256,e- -64|0,4275);c=v[23220];v[23220]=0;if((c|0)==1){break Bb}c=x[e+488>>1];v[e+32>>2]=c>>>8&15;v[23220]=0;v[e+16>>2]=c&255;R(387,e+48|0,e+16|0);c=v[23220];v[23220]=0;if((c|0)==1){break Ab}v[23220]=0;X(373,e+168|0,e- -64|0,e+32|0,e+48|0);c=v[23220];v[23220]=0;if((c|0)==1){break zb}c=e+168|0;Db(j,c);vb(c);vb(e+48|0);bc(e- -64|0)}if(!rc(v[a+1298408>>2],v[a+1298412>>2])){break Xa}c=v[e+508>>2];if(!c){break Xa}c=JC(x[e+488>>1],c);d=jq(e+168|0);v[d+44>>2]=c;v[23220]=0;R(388,a+1298408|0,d|0);c=v[23220];v[23220]=0;if((c|0)!=1){break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break yb}b=P()|0;O()|0;vb(e+48|0)}bc(e- -64|0);break T}d=v[e+508>>2];v[23220]=0;U(389,e+168|0,c|0,v[e+508>>2]);f=v[23220];v[23220]=0;Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{if((f|0)!=1){f=e+168|0;Db(j,f);vb(f);c=(c|0)==8191?d:c-4176|0;if((c|0)>1915){break Tb}d=v[a+480208>>2];if(!(d&16)){break Sb}v[23220]=0;Q(255,a+1074312|0,7)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break Rb}break qb}b=P()|0;O()|0;break T}if(c>>>0>4200){break Pb}d=v[a+480208>>2]}if(!(d&16)){v[23220]=0;Q(255,a+1074312|0,7)|0;d=v[23220];v[23220]=0;if((d|0)==1){break qb}}if((c|0)>2385){break Qb}}v[23220]=0;Q(255,a+1074312|0,38)|0;c=v[23220];v[23220]=0;if((c|0)==1){break qb}}v[23220]=0;c=Q(255,a+1074312|0,102)|0;d=v[23220];v[23220]=0;if((d|0)==1){break qb}v[23220]=0;Q(255,c|0,48)|0;c=v[23220];v[23220]=0;if((c|0)==1){break qb}break Ob}if(c>>>0>4383){break Xa}}v[23220]=0;g=W(254,a+1074312|0,116,1)|0;c=v[23220];v[23220]=0;d=115;if((c|0)==1){break qb}}v[23220]=0;Q(255,g|0,d|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break qb}break Xa}v[23220]=0;Y(390,e+96|0);c=v[23220];v[23220]=0;Ub:{Vb:{Wb:{if((c|0)!=1){c=x[e+488>>1];v[e+48>>2]=c>>>8&15;v[23220]=0;v[e+32>>2]=c&255;R(387,e- -64|0,e+32|0);c=v[23220];v[23220]=0;if((c|0)==1){break Wb}v[23220]=0;X(373,e+168|0,e+96|0,e+48|0,e- -64|0);c=v[23220];v[23220]=0;if((c|0)==1){break Vb}c=e+168|0;Db(j,c);vb(c);vb(e- -64|0);bc(e+96|0);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break Ub}b=P()|0;O()|0;vb(e- -64|0)}bc(e+96|0);break T}v[23220]=0;c=Q(1,e+168|0,8327)|0;d=v[23220];v[23220]=0;if((d|0)!=1){Db(j,c);vb(c);break Xa}b=P()|0;O()|0;break T}if(!((c|0)!=32767|x[e+490>>1]!=533)){v[23220]=0;c=Q(1,e+168|0,5003)|0;d=v[23220];v[23220]=0;if((d|0)!=1){Db(j,c);vb(c);break Xa}b=P()|0;O()|0;break T}v[23220]=0;R(124,e+96|0,4111);c=v[23220];v[23220]=0;Xb:{if((c|0)!=1){c=x[e+488>>1];v[e+64>>2]=c>>>8&15;v[e+48>>2]=c>>>4&15;v[23220]=0;v[e+32>>2]=c&15;da(125,e+168|0,e+96|0,e- -64|0,e+48|0,e+32|0);c=v[23220];v[23220]=0;if((c|0)==1){break Xb}c=e+168|0;Db(j,c);vb(c);bc(e+96|0);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;bc(e+96|0);break T}v[23220]=0;c=Q(1,e+168|0,6084)|0;d=v[23220];v[23220]=0;if((d|0)!=1){Db(j,c);vb(c);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}if(!SD(v[a+1074308>>2])){break Xa}v[23220]=0;c=Q(1,e+168|0,17061)|0;f=v[23220];v[23220]=0;Yb:{if((f|0)!=1){v[23220]=0;Q(85,d|0,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Yb}vb(c);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;vb(c);break T}g=v[a+480180>>2];if(!((g|0)!=16777216|x[e+488>>1]<2186)){v[23220]=0;c=Q(142,b|0,z|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Da}if(c){v[23220]=0;U(391,a|0,b|0,x[e+488>>1]);b=v[23220];v[23220]=0;if((b|0)==1){break Da}}g=v[a+480180>>2]}Zb:{_b:{$b:{ac:{bc:{cc:{if((g|0)==16777216){v[23220]=0;Q(1,e+48|0,13777)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break cc}b=P()|0;O()|0;break T}v[23220]=0;R(256,e+32|0,4275);b=v[23220];v[23220]=0;if((b|0)==1){break bc}b=x[e+490>>1];v[e+28>>2]=b>>>8;v[23220]=0;v[e+12>>2]=b&255;R(387,e+16|0,e+12|0);b=v[23220];v[23220]=0;if((b|0)==1){break ac}v[23220]=0;X(373,e+48|0,e+32|0,e+28|0,e+16|0);b=v[23220];v[23220]=0;if((b|0)==1){break $b}}b=e+48|0;Db(a+1298344|0,b);vb(b);if((g|0)!=16777216){vb(e+16|0);bc(e+32|0)}b=v[a+480180>>2];v[23220]=0;b=Q(1,e+48|0,((b|0)==16777216?10085:6088)|0)|0;c=v[23220];v[23220]=0;g=1;if((c|0)==1){break Zb}Db(a+1298356|0,b);vb(b);Db(a+1298368|0,j);v[a+1298404>>2]=v[a+1074308>>2]?8:5;wb(D);wb(A);break w}b=P()|0;O()|0;break T}b=P()|0;O()|0;break _b}b=P()|0;O()|0;vb(e+16|0)}bc(e+32|0);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;vb(c);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;vb(e- -64|0);break Sa}b=P()|0;O()|0}vb(c);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;u[e+48>>1]=m;qh(i);break Na}m=m+1|0;continue}break}b=P()|0;O()|0;u[e+48>>1]=m}$b(k);break Ka}b=P()|0;O()|0;u[e+48>>1]=m;break Ka}b=P()|0;O()|0;u[e+48>>1]=m}wb(n);break T}b=P()|0;O()|0;u[e+48>>1]=m;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}dc:{c=zb(v[l>>2],m);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);ec:{if(!c){break ec}v[23220]=0;c=Q(142,b|0,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Ba}if(!c){break ec}v[23220]=0;c=T(181,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break wa}v[23220]=0;k=T(181,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break xa}if((k-1025&65535)>>>0<64512){break ec}v[23220]=0;d=Q(175,b|0,4)|0;f=v[23220];v[23220]=0;if((f|0)==1){break xa}if(!d){break ec}v[23220]=0;U(177,e+96|0,b|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break ya}c=e+96|0;d=gc(e+168|0,c);wb(c);c=x[n>>1];h=0;v[23220]=0;f=Q(381,e+136|0,c|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break Aa}fc:{while(1){if(h>>>0>=k>>>0){break fc}c=v[d>>2];v[23220]=0;c=W(143,c|0,v[e+176>>2],1)|0;g=v[23220];v[23220]=0;if((g|0)==1){break dc}if(!c){break fc}v[23220]=0;c=T(193,d|0)|0;g=v[23220];v[23220]=0;gc:{if((g|0)!=1){c=c<<24>>24;if(c){break gc}h=h+1|0;continue}break Ca}hc:{g=c&127;o=g?g-1|0:0;i=o&65535;if(Wc(v[f>>2],v[e+140>>2])>>>0>i>>>0){break hc}v[23220]=0;t[e+96|0]=0;U(383,f|0,i+1|0,e+96|0);g=v[23220];v[23220]=0;if((g|0)!=1){break hc}break Ca}ic:{if((c|0)<0){v[23220]=0;c=T(193,d|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break ic}I=Hb(v[f>>2],i),J=c,t[I|0]=J}g=Hb(v[f>>2],i);c=w[g|0];if(!(!(c&15)|i>>>0<x[n>>1])){u[a+480188>>1]=o+1;c=w[g|0]}if(c&1){v[23220]=0;Q(175,d|0,1)|0;c=v[23220];v[23220]=0;if((c|0)==1){break ic}g=Hb(v[f>>2],i)}if(w[g|0]&2){v[23220]=0;Q(175,d|0,1)|0;c=v[23220];v[23220]=0;if((c|0)==1){break ic}g=Hb(v[f>>2],i)}if(w[g|0]&4){v[23220]=0;Q(175,d|0,1)|0;c=v[23220];v[23220]=0;if((c|0)==1){break ic}g=Hb(v[f>>2],i)}if(!(w[g|0]&8)){continue}v[23220]=0;Q(175,d|0,2)|0;c=v[23220];v[23220]=0;if((c|0)!=1){continue}}break}break Ca}v[e+96>>2]=v[b+8>>2];I=e,J=v[Sc(e+252|0,e+96|0)>>2],v[I+252>>2]=J;$b(f);wb(d)}m=m+1|0;continue}}break}b=P()|0;O()|0;$b(f);break za}b=P()|0;O()|0;break T}b=P()|0;O()|0}wb(d);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;vb(e+168|0);break ta}b=P()|0;O()|0}bc(e+96|0);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}d=0;h=KA(e+96|0,v[f>>2]);v[23220]=0;Q(175,b|0,h|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break X}}if(w[e+99|0]!=1){break Z}m=v[f>>2]!=0|m}v[e+96>>2]=v[b+8>>2];I=e,J=v[Sc(e+252|0,e+96|0)>>2],v[I+252>>2]=J;r=(d|0)!=0}g=g+1|0;d=x[o>>1];continue}break}b=P()|0;O()|0;break T}jc:{d=zb(v[s>>2],g);d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);kc:{if(!d){break kc}v[23220]=0;d=Q(142,b|0,d|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break jc}if(!d){break kc}d=v[b+8>>2];h=v[b>>2];v[23220]=0;d=W(143,h|0,d|0,554)|0;h=v[23220];v[23220]=0;if((h|0)==1){break jc}if(!d){break kc}v[23220]=0;d=W(241,a|0,g+1&65535,0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break W}if(!d){break kc}v[23220]=0;X(392,a|0,b|0,d|0,x[e+490>>1]);h=v[23220];v[23220]=0;if((h|0)==1){break W}t[d+33|0]=w[e+501|0]}g=g+1|0;d=x[f>>1];continue}break}b=P()|0;O()|0;break T}b=P()|0;O()|0}wb(D);break B}b=P()|0;O()|0}wb(A);break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}}}}}b=P()|0;O()|0}lc(l);lc(p);lc(s);break a}lc(l);lc(p);lc(s)}vb(j)}fb=e+640|0;return g|0}b=P()|0;O()|0}vb(j);S(b|0);L()}function Ffa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0;d=fb-1680|0;fb=d;wc(b);a:{if(!Xh(b,d+1672|0)){break a}if(!OR(d+1672|0)){break a}if(!c){f=1;break a}o=w[d+1675|0];t[d+1671|0]=o;v[d+1664>>2]=-1;v[d+1660>>2]=1048576;if(o>>>0>=5){e=mg(b);v[d+1664>>2]=e;if(!Lb(v[b>>2],v[b+8>>2],e)){break a}v[d+240>>2]=134217727;M=d,N=v[Eb(d+240|0,d+1664|0)>>2]<<5,v[M+1660>>2]=N}z=Ib(d+1648|0);v[d+240>>2]=v[d+1676>>2];e=v[Eb(d+1660|0,d+240|0)>>2];v[23220]=0;R(497,z|0,e|0);e=v[23220];v[23220]=0;b:{c:{d:{e:{f:{if((e|0)!=1){v[23220]=0;e=W(498,b|0,z|0,v[d+1676>>2])|0;i=v[23220];v[23220]=0;g:{if((i|0)==1){break g}if(!e){break b}if(o>>>0>=5){v[23220]=0;Q(142,b|0,v[d+1664>>2]+12|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break g}}v[23220]=0;R(236,a|0,0);e=v[23220];v[23220]=0;if((e|0)==1){break g}yg(a);ge(d+1616|0,v[z>>2],v[z+4>>2]);e=Xd(d+1608|0);i=v[e+4>>2];e=v[e>>2];v[23220]=0;l=ga(499,d+1624|0,v[d+1616>>2],v[d+1620>>2],e|0,i|0)|0;e=v[23220];v[23220]=0;h:{i:{j:{if((e|0)!=1){v[23220]=0;U(343,l|0,a+1298308|0,-1);e=v[23220];v[23220]=0;if((e|0)==1){break j}v[23220]=0;U(343,l|0,a+1298332|0,-1);e=v[23220];v[23220]=0;if((e|0)==1){break j}v[23220]=0;e=Q(500,l|0,d+1184|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break f}if(!e){break c}e=t[d+1184|0];if((e|0)<=0|(w[d+1193|0]|w[d+1194|0]<<8)>>>0>255|(w[d+1195|0]|w[d+1196|0]<<8)>>>0>3999){break c}u[a+480188>>1]=e&255;Ve(Vb(v[a+484360>>2],w[a+484376|0]),w[d+1187|0]|w[d+1188|0]<<8);u[a+480192>>1]=w[d+1193|0]|w[d+1194|0]<<8;u[a+480190>>1]=w[d+1195|0]|w[d+1196|0]<<8;e=w[d+1197|0];v[a+480196>>2]=e?e:6;e=w[d+1198|0];v[a+480204>>2]=B(e?e:125,1e4);i=w[d+1199|0]|w[d+1200|0]<<8|(w[d+1201|0]<<16|w[d+1202|0]<<24);e=32;k:{if(i&256){break k}e=2;if(i&2){break k}e=1;if(i&128){break k}e=i&8?16:4}v[23220]=0;R(358,a|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){break f}i=v[a+480208>>2];g=i|16777216;v[a+480208>>2]=g;e=w[d+1199|0]|w[d+1200|0]<<8|(w[d+1201|0]<<16|w[d+1202|0]<<24);if(e&1){g=i|16777232;v[a+480208>>2]=g}j=v[a+480180>>2];f=(j|0)==32;i=f&!(e&1024);h=(j|0)==2;n=h&e>>>2;h=h&e>>>4;f=f&!(e&2048);s=e&2097152;if(s?1:n|h|(f|i)){g=h?g|65536:g;g=n?g|2:g;g=f?g|4:g;v[a+480208>>2]=s>>>6|(i?g|8:g)}if(e&524288){v[23220]=0;W(254,a+1074312|0,5,1)|0;e=v[23220];v[23220]=0;if((e|0)==1){break f}j=v[a+480180>>2]}if((j|0)==2){break i}if((j|0)!=32){break h}t[d+240|0]=w[d+1203|0];t[d+160|0]=128;M=a,N=w[Rb(d+240|0,d+160|0)|0]<<1,v[M+480200>>2]=N;break h}e=P()|0;O()|0;break d}e=P()|0;O()|0;break e}t[d+240|0]=w[d+1203|0];t[d+160|0]=64;M=a,N=w[Rb(d+240|0,d+160|0)|0]<<2,v[M+480200>>2]=N}I=a+480188|0;e=t[d+1205|0];l:{if((e|0)<0){e=e+52|0;break l}F=tx(+(e|0)*3.1/20);m:{if(F<4294967296&F>=0){e=~~F>>>0;break m}e=0}e=e+51|0}v[a+480228>>2]=e;u[d+240>>1]=64;i=x[Tc(I,d+240|0)>>1];g=0;h=(j|0)!=32;n=(j|0)==4;f=0;while(1)if((f|0)==(i|0)){f=0;h=0;while(1){if((g|0)!=16){h=w[(d+g|0)+1334|0]!=0|h;g=g+1|0;continue}break}while(1){if((f|0)!=128){h=w[((f<<1)+d|0)+1351|0]!=0|h;f=f+1|0;continue}break}n:{if(!(h&1)){break n}e=a+901692|0;i=a+901404|0;f=0;while(1){if((f|0)==16){e=i+800|0;f=0;while(1){if((f|0)!=128){i=(d+1184|0)+(f<<1)|0;o:{if(w[i+167|0]){v[23220]=0;Y(501,d+160|0);g=v[23220];v[23220]=0;p:{q:{r:{s:{t:{if((g|0)!=1){g=w[i+167|0];v[23220]=0;v[d+184>>2]=g-1;R(502,d+1128|0,d+184|0);g=v[23220];v[23220]=0;if((g|0)==1){break t}i=w[i+166|0];v[23220]=0;t[d+128|0]=i;R(503,d+1104|0,d+128|0);i=v[23220];v[23220]=0;if((i|0)==1){break s}v[23220]=0;X(504,d+240|0,d+160|0,d+1128|0,d+1104|0);i=v[23220];v[23220]=0;if((i|0)==1){break r}i=d+240|0;re(d+1160|0,i);Te(le(e,f),v[d+1160>>2],v[d+1164>>2]);ub(i);ub(d+1104|0);ub(d+1128|0);Pb(d+160|0);break o}e=P()|0;O()|0;break e}e=P()|0;O()|0;break p}e=P()|0;O()|0;break q}e=P()|0;O()|0;ub(d+1104|0)}ub(d+1128|0)}Pb(d+160|0);break e}i=oc(d+1152|0,21598);Te(le(e,f),v[i>>2],v[d+1156>>2])}f=f+1|0;continue}break}j=v[a+480180>>2];break n}g=(d+f|0)+1334|0;u:{if(w[g|0]){v[23220]=0;Y(505,d+160|0);h=v[23220];v[23220]=0;v:{w:{x:{if((h|0)!=1){g=w[g|0];v[23220]=0;v[d+1104>>2]=g-1;R(502,d+1128|0,d+1104|0);g=v[23220];v[23220]=0;if((g|0)==1){break x}v[23220]=0;U(278,d+240|0,d+160|0,d+1128|0);g=v[23220];v[23220]=0;if((g|0)==1){break w}g=d+240|0;re(d+1176|0,g);Te(le(e,f),v[d+1176>>2],v[d+1180>>2]);ub(g);ub(d+1128|0);Pb(d+160|0);break u}e=P()|0;O()|0;break e}e=P()|0;O()|0;break v}e=P()|0;O()|0;ub(d+1128|0)}Pb(d+160|0);break e}g=oc(d+1168|0,21598);Te(le(e,f),v[g>>2],v[d+1172>>2])}f=f+1|0;continue}}e=w[a+484376|0];i=v[a+484360>>2];v[23220]=0;i=Vb(i,e);e=j&5;da(333,i|0,l|0,w[d+1185|0]|w[d+1186|0]<<8,(e?65535:255)|0,(e?65535:254)|0);e=v[23220];v[23220]=0;if((e|0)!=1){v[23220]=0;U(177,d+240|0,l|0,B(w[d+1184|0],w[d+1189|0]|w[d+1190|0]<<8)<<1);e=v[23220];v[23220]=0;if((e|0)!=1){e=d+240|0;G=gc(d+1128|0,e);wb(e);v[23220]=0;U(177,e|0,l|0,(w[d+1189|0]|w[d+1190|0]<<8)<<1);e=v[23220];v[23220]=0;y:{if((e|0)!=1){e=d+240|0;H=gc(d+1104|0,e);wb(e);v[23220]=0;s=Q(205,d+1088|0,w[d+1191|0]|w[d+1192|0]<<8)|0;e=v[23220];v[23220]=0;z:{if((e|0)!=1){M=d,N=Ab(v[s>>2]),v[M+184>>2]=N;e=Ab(v[s+4>>2]);A:{B:{C:{while(1){i=v[d+184>>2];if(!Nb(i,e)){e=v[a+480180>>2];m=c&1;if(!m){break B}v[23220]=0;R(212,a+484344|0,w[d+1189|0]|w[d+1190|0]<<8);i=v[23220];v[23220]=0;if((i|0)!=1){break B}e=P()|0;O()|0;break A}v[23220]=0;g=T(144,l|0)|0;f=v[23220];v[23220]=0;if((f|0)!=1){v[23220]=0;U(177,d+160|0,l|0,g|0);g=v[23220];v[23220]=0;if((g|0)==1){break C}f=i;i=d+160|0;g=gc(d+240|0,i);Yc(f,g);wb(g);wb(i);rh(d+184|0);continue}break}e=P()|0;O()|0;break A}e=P()|0;O()|0;break A}p=(e|0)==16?14:(e|0)==32?1:13;D=a+484344|0;j=0;n=1;while(1){D:{E:{F:{G:{H:{I:{if((w[d+1189|0]|w[d+1190|0]<<8)>>>0<=j>>>0){switch(v[a+480180>>2]-1|0){case 0:break G;case 3:break I;default:break F}}v[23220]=0;e=T(181,H|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break H}v[d+160>>2]=e;if(!m){break D}v[23220]=0;e=W(213,D|0,j&65535,e|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break H}i=0;if(!e){break D}while(1){f=i&65535;if(f>>>0>=w[d+1184|0]){break D}v[23220]=0;e=T(181,G|0)|0;g=v[23220];v[23220]=0;J:{if((g|0)!=1){g=v[s>>2];if(Bf(g,v[s+4>>2])>>>0<=e>>>0){break J}q=xg(g,e);wc(q);g=0;e=Xb(v[D>>2],j);f=$c(v[e>>2],v[v[e+48>>2]+12>>2],0,f);K:while(1){if(y[d+160>>2]<=g>>>0){break J}v[23220]=0;e=T(193,q|0)|0;h=v[23220];v[23220]=0;if((h|0)!=1){if(!e){break J}A=e>>>4|0;C=e&15;sh(d+240|0);h=0;while(1){L:{M:{N:{if(C>>>0>(h&255)>>>0){v[23220]=0;R(506,q|0,d+184|0);e=v[23220];v[23220]=0;if((e|0)==1){break N}O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{e=w[d+184|0];switch(e-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break O;case 33:break S;case 30:case 31:break T;case 29:break U;case 28:break V;case 26:break W;case 19:case 20:break X;case 17:break Y;case 15:break Z;case 14:break _;case 10:break $;case 6:break aa;case 5:break ba;case 1:break ca;case 0:break da;default:break ea}}switch(e-48|0){case 4:break P;case 1:case 2:break Q;case 0:break R;default:break O}}e=w[d+185|0];fa:{if(e>>>0<=119){e=e+p|0;break fa}ga:{switch(e-254|0){case 1:e=255;break fa;case 0:e=254;break fa;default:break ga}}e=253}t[d+240|0]=e;n=SA(e)&n;break L}t[d+241|0]=w[d+185|0]+1;break L}ha:{if(w[d+242|0]){break ha}e=v[a+480180>>2];if((e|0)!=32){if((e|0)!=4){break ha}e=w[d+185|0];if(e&15){break ha}t[d+242|0]=11;t[d+244|0]=e>>>4;break L}e=0;k=w[d+185|0];while(1){if((e|0)==10){break ha}if((k|0)==w[e+43904|0]){t[d+244|0]=e;t[d+242|0]=11;break L}else{e=e+1|0;continue}}}t[d+243|0]=4;t[d+245|0]=w[d+185|0];break L}e=w[d+185|0];if(!(w[d+242|0]|e>>>0>9|v[a+480180>>2]!=32)){t[d+244|0]=e;t[d+242|0]=8;break L}t[d+245|0]=e;t[d+243|0]=5;break L}if(w[d+242|0]){e=w[d+185|0];break M}k=v[a+480180>>2];r=(k|0)!=32;e=w[d+185|0];if(!(r|(e|0)!=255)){t[d+244|0]=64;t[d+242|0]=2;break L}ia:{if(!r){if(e&3){break M}break ia}if(e&15|(k|0)!=4){break M}}t[d+242|0]=2;t[d+244|0]=(e&252)>>>2;break L}e=w[d+185|0];if(!(w[d+242|0]|e>>>0>64|v[a+480180>>2]==1)){t[d+244|0]=e;t[d+242|0]=1;break L}t[d+245|0]=e;t[d+243|0]=13;break L}t[d+243|0]=14;e=w[d+185|0];t[d+245|0]=e;if(v[a+480180>>2]==32){break L}t[d+245|0]=B((e&240)>>>4|0,10)+(e&15);break L}e=w[d+185|0];t[d+245|0]=e;if(e>>>0<=31){t[d+243|0]=16;break L}t[d+243|0]=17;break L}k=w[d+185|0];if(k>>>0>=16){t[d+244|0]=k>>>4;t[d+242|0]=(e|0)==20?3:5;break L}t[d+244|0]=k;t[d+242|0]=(e|0)==20?4:6;break L}e=w[d+185|0];if(e>>>0>=16){t[d+242|0]=10;t[d+244|0]=e>>>4;break L}t[d+244|0]=e;t[d+242|0]=9;break L}t[d+243|0]=28;t[d+245|0]=w[d+185|0]|16;break L}t[d+243|0]=28;t[d+245|0]=w[d+185|0]|32;break L}t[d+244|0]=w[d+185|0];t[d+242|0]=w[e+26816|0];break L}t[d+245|0]=w[d+185|0];e=w[d+243|0];t[d+243|0]=(e|0)==4?6:(e|0)==5?7:11;break L}e=w[d+185|0];t[d+244|0]=(e>>>0)%10;if(e>>>0<=9){t[d+242|0]=5;break L}if(e>>>0<=19){t[d+242|0]=6;break L}if(e>>>0<=29){t[d+242|0]=3;break L}if(e>>>0>39){break L}t[d+242|0]=4;break L}t[d+244|0]=w[d+185|0];t[d+242|0]=w[e+26816|0];break L}e=w[d+185|0]+33|0;if((e&255)>>>0>9){break L}t[d+244|0]=e;t[d+242|0]=15;break L}if(e>>>0>57){break L}t[d+245|0]=w[d+185|0];t[d+243|0]=w[e+26816|0];break L}v[d+184>>2]=g+A;e=v[Eb(d+184|0,d+160|0)>>2];e=e>>>0<g>>>0?g:e;while(1){if((e|0)!=(g|0)){h=v[d+240>>2];t[f|0]=h;t[f+1|0]=h>>>8;t[f+2|0]=h>>>16;t[f+3|0]=h>>>24;h=x[d+244>>1];t[f+4|0]=h;t[f+5|0]=h>>>8;g=g+1|0;f=B(w[d+1184|0],6)+f|0;continue}break}g=e;continue K}e=P()|0;O()|0;break A}t[d+245|0]=e;t[d+243|0]=9}h=h+1|0;continue}}break}e=P()|0;O()|0;break A}e=P()|0;O()|0;break A}i=i+1|0;continue}}f=x[a+480192>>1];e=0;break E}e=P()|0;O()|0;break A}if((n^1)&1|x[a+480188>>1]!=4){break F}v[a+480208>>2]=v[a+480208>>2]|8454144}f=0;e=!((w[d+1199|0]|w[d+1200|0]<<8|(w[d+1201|0]<<16|w[d+1202|0]<<24))&512)}v[23220]=0;A=Q(507,d+1072|0,f|0)|0;i=v[23220];v[23220]=0;ja:{ka:{la:{ma:{na:{if((i|0)!=1){j=o>>>0<5;h=1;oa:{while(1){f=h&65535;if(f>>>0>x[a+480192>>1]){break oa}pa:{qa:{ra:{sa:{if(!e){v[23220]=0;g=W(241,a|0,f|0,0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break sa}if(g){break ra}}while(1){v[23220]=0;i=T(193,l|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break ka}if(i){continue}break}if(!j){while(1){v[23220]=0;i=T(193,l|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){e=P()|0;O()|0;break ja}if(i){continue}break}}v[23220]=0;Q(175,l|0,826)|0;i=v[23220];v[23220]=0;if((i|0)!=1){break qa}}e=P()|0;O()|0;break ja}i=Gb(d+160|0);v[23220]=0;U(343,l|0,i|0,-1);n=v[23220];v[23220]=0;if((n|0)==1){break pa}yc(g+492|0,i);if(!j){v[23220]=0;U(343,l|0,i|0,-1);n=v[23220];v[23220]=0;if((n|0)==1){break pa}yc(g+524|0,i)}v[23220]=0;n=Q(508,l|0,d+240|0)|0;q=v[23220];v[23220]=0;if((q|0)==1){break la}if(!n){break na}n=v[a+480180>>2];v[23220]=0;U(509,d+240|0,g|0,n|0);g=v[23220];v[23220]=0;if((g|0)==1){break la}if(v[a+480180>>2]==4){g=zb(v[A>>2],f-1|0);f=x[d+1042>>1]|x[d+1044>>1]<<16;t[g|0]=f;t[g+1|0]=f>>>8;t[g+2|0]=f>>>16;t[g+3|0]=f>>>24}ub(i)}h=h+1|0;continue}break}break la}if(!e){break ma}u[a+480192>>1]=0;break ma}e=P()|0;O()|0;break A}ub(i)}e=x[a+480190>>1];v[23220]=0;q=Q(510,d+224|0,e|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){K=!(t[d+1199|0]&1)|o>>>0>4;C=c&2;h=1;e=0;while(1){i=e;ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{k=h&65535;if(k>>>0<=x[a+480190>>1]){f=Gb(d+208|0);v[23220]=0;U(343,l|0,f|0,-1);c=v[23220];v[23220]=0;if((c|0)==1){break Fa}j=B(k,104)+a|0;yc(((k<<5)+a|0)+946304|0,f);e=o>>>0<5;if(!e){v[23220]=0;U(343,l|0,f|0,-1);c=v[23220];v[23220]=0;if((c|0)==1){break Fa}ue(j+484423|0,f)}v[23220]=0;c=Q(511,l|0,d+240|0)|0;g=v[23220];v[23220]=0;Ha:{Ia:{if((g|0)==1){break Ia}if(!c){break Ha}g=v[a+480180>>2];v[23220]=0;c=j+484380|0;X(512,d+240|0,c|0,g|0,K|0);g=v[23220];v[23220]=0;if((g|0)==1){break Ia}n=0;Ja:{if((x[d+260>>1]&61440)!=28672|e){break Ja}v[23220]=0;n=T(513,l|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){break Ja}e=P()|0;O()|0;break wa}if(!C){break ua}g=w[d+275|0]|w[d+276|0]<<8|(w[d+277|0]<<16|w[d+278|0]<<24);e=x[d+260>>1];m=e&61440;if(!(g|m)){e=Uc(d+160|0,e&1?16:8,e&1024?3:1,0,0);v[23220]=0;W(206,e|0,c|0,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break ua}e=P()|0;O()|0;break wa}if((g|0)<0){e=g+k|0;if((e|0)<=0){break ua}NR(c,(B(e,104)+a|0)+484380|0);break ua}if((g|0)<=0){break ua}if(e&1){p=j+484414|0;u[p>>1]=x[p>>1]|1}if(e&1024){p=j+484414|0;u[p>>1]=x[p>>1]|64}v[23220]=0;U(177,d+160|0,b|0,g|0);g=v[23220];v[23220]=0;Ka:{La:{Ma:{Na:{Oa:{Pa:{if((g|0)!=1){p=d+160|0;g=gc(d+184|0,p);wb(p);p=Cd(x[c+34>>1]);J=(m|0)==16384;if(!J&(m|0)!=8192){break Na}r=v[g>>2];v[23220]=0;r=T(147,r|0)|0;E=v[23220];v[23220]=0;if((E|0)==1){break Ka}E=4/(p>>>0)|0;Bia(E,0,r,0);uc(c,ib?-1:B(E,r));if((m|0)==8192){break Pa}if(!J){break Na}if(!wg(c)){break Ma}e=v[j+484400>>2];c=v[c>>2];if(!(t[d+260|0]&1)){break Oa}v[23220]=0;X(514,g|0,e|0,c|0,p|0);c=v[23220];v[23220]=0;e=i;if((c|0)==1){break ya}break La}e=P()|0;O()|0;break wa}if(!wg(c)){break Ma}e=v[j+484400>>2];c=v[c>>2];if(t[d+260|0]&1){v[23220]=0;X(515,g|0,e|0,c|0,p|0);c=v[23220];v[23220]=0;e=i;if((c|0)!=1){break La}break ya}v[23220]=0;X(516,g|0,e|0,c|0,p|0);c=v[23220];v[23220]=0;e=i;if((c|0)==1){break ya}break La}v[23220]=0;X(517,g|0,e|0,c|0,p|0);c=v[23220];v[23220]=0;e=i;if((c|0)==1){break ya}break La}if((e&45056)==12288){c=MR(d+160|0,g,w[d+279|0]|w[d+280|0]<<8,n);M=Yc(Zk(v[q>>2],k-1|0),c),N=v[c+20>>2],v[M+20>>2]=N;wb(c);break Ma}if((m|0)!=32768){e=1;if((m|0)!=4096){break La}n=fe(d+160|0,g);v[23220]=0;e=Q(518,d+152|0,g|0)|0;m=v[23220];v[23220]=0;if((m|0)!=1){Qa:{Ra:{if(!w[d+157|0]){break Ra}p=w[d+279|0]|w[d+280|0]<<8;m=x[d+154>>1]<<1;if(p>>>0<(m&65535)>>>0){break Ra}m=p-m|0;t[d+279|0]=m;t[d+280|0]=m>>>8;e=x[e>>1];v[23220]=0;Q(142,g|0,e|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break Qa}v[23220]=0;e=T(189,g|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break Qa}v[23220]=0;U(177,d+104|0,g|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){break Qa}e=d+104|0;m=gc(d+128|0,e);Yc(n,m);wb(m);wb(e)}v[23220]=0;k=W(519,a|0,k|0,n|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break Qa}e=1;if(k){e=w[d+279|0]|w[d+280|0]<<8;Sa:{if(!e){break Sa}k=x[c+34>>1];m=sj(v[c>>2],k);if(m>>>0<=e>>>0){break Sa}k=ik(k);j=v[j+484400>>2];Zi(j,e+j|0,m-e|0);v[c>>2]=v[c>>2]-((e>>>0)/(k>>>0)|0)}uc(c,v[d+248>>2]);e=i}wb(n);break La}}e=P()|0;O()|0;wb(n);break xa}v[23220]=0;e=Q(370,g|0,d+160|0)|0;j=v[23220];v[23220]=0;if((j|0)==1){break Ga}if(!e){break Ma}v[d+16>>2]=v[d+168>>2];e=v[d+164>>2];v[d+8>>2]=v[d+160>>2];v[d+12>>2]=e;cl(c,1,d+8|0)}e=i}wb(g);break ta}e=P()|0;O()|0;break xa}e=P()|0;O()|0;break wa}ub(f)}Ta:{Ua:{Va:{if(!C){break Va}n=1;while(1){f=n&65535;if(f>>>0>x[a+480190>>1]){break Va}b=Zk(v[q>>2],f-1|0);c=v[b>>2];v[23220]=0;c=T(165,c|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break Ta}Wa:{Xa:{if(!c){break Xa}e=x[b+22>>1];c=e+n&65535;h=x[b+20>>1];o=(e|0)!=0&(c|0)!=0&c>>>0<=x[a+480190>>1]&(h|0)!=0;Ya:{if(o){g=Zk(v[q>>2],c-1|0);break Ya}c=v[b>>2];v[23220]=0;h=T(147,c|0)|0;c=v[23220];v[23220]=0;g=b;if((c|0)==1){break Ua}}wc(g);Za:{if(o){c=v[g+8>>2];e=v[g>>2];j=x[b+20>>1];v[23220]=0;c=W(143,e|0,c|0,j|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break Ua}if(!c){break Xa}v[d+160>>2]=0;v[d+184>>2]=0;v[23220]=0;U(190,d+240|0,g|0,h|0);c=v[23220];v[23220]=0;_a:{if((c|0)!=1){j=iA(te(d+240|0),ui(v[d+240>>2]),d+160|0,d+184|0);v[23220]=0;Q(175,g|0,v[d+160>>2])|0;c=v[23220];v[23220]=0;if((c|0)==1){break _a}Jc(d+240|0);break Za}e=P()|0;O()|0;break va}e=P()|0;O()|0;Jc(d+240|0);break va}j=0;v[d+160>>2]=0;v[d+184>>2]=0}v[23220]=0;R(520,d+240|0,b|0);c=v[23220];v[23220]=0;$a:{ab:{if((c|0)!=1){e=te(d+240|0);h=v[d+240>>2];if(!o){j=iA(e,ui(h),d+160|0,d+184|0);v[23220]=0;c=v[d+160>>2];Q(175,b|0,c|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break Wa}h=h-c|0;e=c+e|0}if(j){break ab}i=1;break $a}e=P()|0;O()|0;break va}c=B(f,104)+a|0;o=c+484380|0;wg(o);C=c+484400|0;g=0;f=v[d+184>>2];while(1){bb:{if(!h|(f|0)!=1?f:0){break bb}c=v[o>>2];if(c>>>0<=g>>>0){break bb}if(!Md(c,v[o+20>>2])){break bb}v[d+128>>2]=0;v[d+104>>2]=0;f=LR(j,e,ui(h),d+128|0,d+208|0,d+104|0);v[23220]=0;v[d+160>>2]=f;Q(175,b|0,f|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break za}Uh(d+104|0,ui(v[o>>2]-g|0));c=v[d+104>>2];cb:{if((c|0)<=0){break cb}k=v[d+128>>2];r=x[o+34>>1];if((Cd(r)|0)!=(k|0)){break cb}m=B(g,k);p=v[C>>2];if(r&1){k=Qg(d+88|0,p+(m<<1)|0,k,c);m=v[Qg(d+72|0,v[d+208>>2],v[d+128>>2],c)>>2];k=v[k>>2];v[23220]=0;ka(521,k|0,v[d+92>>2],v[d+96>>2],m|0,v[d+76>>2],v[d+80>>2]);k=v[23220];v[23220]=0;if((k|0)!=1){break cb}break za}k=Qg(d+56|0,m+p|0,k,c);m=v[Qg(d+40|0,v[d+208>>2],v[d+128>>2],c)>>2];k=v[k>>2];v[23220]=0;ka(522,k|0,v[d+60>>2],v[d+64>>2],m|0,v[d+44>>2],v[d+48>>2]);k=v[23220];v[23220]=0;if((k|0)==1){break za}}h=h-f|0;e=e+f|0;f=KR(j);v[d+184>>2]=f;g=c+g|0;continue}break}JR(j)}Jc(d+240|0)}n=n+1|0;continue}break}break za}db:{if(v[a+480180>>2]!=4){break db}f=0;while(1){if(x[a+480192>>1]<=f>>>0){break db}b=zb(v[A>>2],f);c=w[b+3|0];e=w[b+2|0];g=w[b+1|0];b=w[b|0];v[23220]=0;f=f+1|0;ka(523,a|0,f&65535,b|0,g|0,e|0,c|0);b=v[23220];v[23220]=0;if((b|0)!=1){continue}break}e=P()|0;O()|0;break va}eb:{fb:{gb:{if(!(w[d+1201|0]&16)){break gb}b=v[l+8>>2];c=v[l>>2];v[23220]=0;b=W(143,c|0,b|0,1)|0;c=v[23220];v[23220]=0;hb:{ib:{jb:{if((c|0)!=1){if(!b){break gb}f=0;v[23220]=0;b=T(193,l|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break jb}if(!(b&1)){break hb}while(1){if(x[I>>1]<=f>>>0){break hb}v[23220]=0;b=T(144,l|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break ib}t[((f<<5)+a|0)+480288|0]=b;f=f+1|0;continue}}e=P()|0;O()|0;break va}e=P()|0;O()|0;break va}e=P()|0;O()|0;break va}while(1){b=v[l+8>>2];c=v[l>>2];v[23220]=0;b=W(143,c|0,b|0,1)|0;c=v[23220];v[23220]=0;if((c|0)==1){break Aa}if(!b){break gb}v[23220]=0;b=T(193,l|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break eb}if(!b){break gb}v[23220]=0;c=T(144,l|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break fb}v[23220]=0;U(177,d+160|0,l|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break fb}e=d+160|0;c=gc(d+240|0,e);wb(e);kb:{if(b>>>0<=250){v[23220]=0;R(393,c|0,(B(b,160)+a|0)+906140|0);b=v[23220];v[23220]=0;if((b|0)==1){break kb}}wb(c);continue}break}e=P()|0;O()|0;wb(c);break va}j=a+901404|0;c=Gb(d+128|0);n=a+480188|0;e=0;g=0;while(1){b=v[l+8>>2];f=v[l>>2];v[23220]=0;b=W(143,f|0,b|0,8)|0;f=v[23220];v[23220]=0;lb:{mb:{nb:{ob:{pb:{if((f|0)!=1){if(b){v[23220]=0;f=T(144,l|0)|0;b=v[23220];v[23220]=0;qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{if((b|0)!=1){v[23220]=0;b=T(144,l|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break xb}v[23220]=0;U(177,d+240|0,l|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break wb}h=d+240|0;b=gc(d+160|0,h);wb(h);if((f|0)==1229211981){break tb}if((f|0)==1229476432){break ub}if((f|0)==1397900630){break vb}if((f|0)!=1414548815){break lb}v[23220]=0;f=Q(355,b|0,13830)|0;h=v[23220];v[23220]=0;if((h|0)==1){break Ea}if(!f){break mb}v[23220]=0;f=T(144,b|0)|0;h=v[23220];v[23220]=0;if((h|0)!=1){v[23220]=0;U(177,d+240|0,b|0,f|0);f=v[23220];v[23220]=0;if((f|0)!=1){break sb}}e=P()|0;O()|0;break Da}e=P()|0;O()|0;break Ba}e=P()|0;O()|0;break Ba}e=P()|0;O()|0;break Ba}yb:{zb:{Ab:{f=v[a+480180>>2];switch(f-2|0){case 1:break lb;case 0:break rb;case 2:break zb;default:break Ab}}if((f|0)==16){break yb}if((f|0)!=32){break lb}v[23220]=0;e=T(181,b|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break Ea}v[23220]=0;g=T(181,b|0)|0;f=v[23220];v[23220]=0;if((f|0)!=1){break lb}break Ea}v[d+240>>2]=32;f=v[b>>2];v[23220]=0;f=T(147,f|0)|0;h=v[23220];v[23220]=0;if((h|0)!=1){v[d+184>>2]=f;f=v[Eb(d+240|0,d+184|0)>>2];v[23220]=0;U(524,b|0,c|0,f|0);f=v[23220];v[23220]=0;if((f|0)!=1){break lb}}e=P()|0;O()|0;break Da}v[23220]=0;f=T(193,b|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break qb}v[23220]=0;R(525,d+184|0,4172);h=v[23220];v[23220]=0;Bb:{if((h|0)!=1){v[d+208>>2]=f>>>4;v[23220]=0;v[d+24>>2]=f&15;X(291,d+240|0,d+184|0,d+208|0,d+24|0);f=v[23220];v[23220]=0;if((f|0)==1){break Bb}f=d+240|0;Db(c,f);vb(f);bc(d+184|0);break lb}e=P()|0;O()|0;break Da}e=P()|0;O()|0;bc(d+184|0);break Da}v[23220]=0;f=T(193,b|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break Ea}v[a+480216>>2]=f;v[23220]=0;f=T(193,b|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break Ea}v[a+480220>>2]=f;break lb}v[23220]=0;Q(365,b|0,j|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break Ea}OA(j);break lb}f=d+240|0;h=gc(d+184|0,f);wb(f);f=v[h>>2];v[23220]=0;f=T(147,f|0)|0;o=v[23220];v[23220]=0;if((o|0)==1){break nb}u[d+240>>1]=f>>>5;M=d,N=lf(v[D>>2],v[D+4>>2]),u[M+208>>1]=N;o=x[Tc(d+240|0,d+208|0)>>1];f=0;while(1){if((f|0)==(o|0)){wb(h);break mb}v[23220]=0;R(526,h|0,d+240|0);k=v[23220];v[23220]=0;Cb:{if((k|0)==1){break Cb}k=v[D>>2];v[23220]=0;R(527,Xb(k,f)|0,d+240|0);k=v[23220];v[23220]=0;if((k|0)==1){break Cb}f=f+1|0;continue}break}break nb}v[23220]=0;e=T(181,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break Ea}break lb}e=P()|0;O()|0;break Da}b=v[a+480180>>2];Db:{Eb:{Fb:{if((b|0)!=32){break Fb}f=e&65535;if(f>>>0<256){break Fb}if(f>>>0<532){break Eb}}b=(b|0)!=2;Gb:{if(b){break Gb}f=e&65535;if(f>>>0<12544){break Gb}if(f>>>0<12820){break Eb}}if(b){break Db}b=e&65535;if(b>>>0<4864|b>>>0>4895){break Db}}Vp(j)}Hb:{if(!(t[d+1201|0]&1)){break Hb}f=v[a+1074308>>2];if(!f){e=a+480192|0;h=a+480180|0;f=1;while(1){b=f&65535;if(b>>>0<=x[e>>1]){b=v[((b<<2)+a|0)+900380>>2];if(b){j=v[h>>2];v[23220]=0;R(528,Bi(b,2)|0,j|0);j=v[23220];v[23220]=0;if((j|0)==1){break pb}t[b+19|0]=w[b+19|0]+3>>>2}f=f+1|0;continue}break}f=v[a+1074308>>2]}if(f>>>0<=18350079){v[23220]=0;b=Q(255,a+1074312|0,27)|0;e=v[23220];v[23220]=0;if((e|0)==1){break Ca}v[23220]=0;Q(255,b|0,57)|0;b=v[23220];v[23220]=0;if((b|0)==1){break Ca}f=v[a+1074308>>2]}if(f>>>0<=19070975){v[23220]=0;Q(255,a+1074312|0,73)|0;b=v[23220];v[23220]=0;if((b|0)==1){break Ca}f=v[a+1074308>>2]}if(f>>>0>19267583){break Hb}v[23220]=0;Q(255,a+1074312|0,50)|0;b=v[23220];v[23220]=0;if((b|0)==1){break Ca}}Ib:{Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{if(ah(v[c+4>>2],w[c+11|0])){v[23220]=0;Y(529,d+160|0);b=v[23220];v[23220]=0;Wb:{if((b|0)!=1){v[23220]=0;U(494,d+240|0,d+160|0,d+1671|0);b=v[23220];v[23220]=0;if((b|0)==1){break Wb}break Vb}e=P()|0;O()|0;break Ba}e=P()|0;O()|0;bc(d+160|0);break Ba}v[23220]=0;Y(530,d+160|0);b=v[23220];v[23220]=0;if((b|0)==1){break Ub}v[23220]=0;X(531,d+240|0,d+160|0,d+1671|0,c|0);b=v[23220];v[23220]=0;if((b|0)==1){break Tb}}b=d+240|0;Db(c,b);vb(b);b=d+160|0;bc(b);v[23220]=0;R(493,b|0,3960);b=v[23220];v[23220]=0;if((b|0)==1){break Rb}v[23220]=0;U(494,d+240|0,d+160|0,d+1671|0);b=v[23220];v[23220]=0;if((b|0)==1){break Qb}b=d+240|0;Db(a+1298344|0,b);vb(b);bc(d+160|0);v[23220]=0;b=Q(1,b|0,14968)|0;e=v[23220];v[23220]=0;if((e|0)==1){break Pb}Db(a+1298356|0,b);vb(b);b=v[a+480180>>2];switch(b-1|0){case 2:break ob;case 1:break Lb;case 3:break Mb;case 0:break Nb;default:break Sb}}e=P()|0;O()|0;break Ba}e=P()|0;O()|0;bc(d+160|0);break Ba}if((b|0)==16){break Ob}if((b|0)==32){break Kb}if((b|0)!=16777216){break ob}v[23220]=0;b=Q(1,d+160|0,10085)|0;e=v[23220];v[23220]=0;if((e|0)==1){break Jb}Db(a+1298392|0,b);vb(b);v[23220]=0;b=Q(1,d+184|0,13777)|0;e=v[23220];v[23220]=0;if((e|0)==1){break Ib}Db(a+1298380|0,b);vb(b);break ob}e=P()|0;O()|0;break Ba}e=P()|0;O()|0;bc(d+160|0);break Ba}e=P()|0;O()|0;break Ba}v[23220]=0;b=Q(1,d+160|0,10090)|0;e=v[23220];v[23220]=0;Xb:{if((e|0)!=1){Db(a+1298392|0,b);vb(b);v[23220]=0;b=Q(1,d+184|0,8352)|0;e=v[23220];v[23220]=0;if((e|0)==1){break Xb}Db(a+1298380|0,b);vb(b);break ob}e=P()|0;O()|0;break Ba}e=P()|0;O()|0;break Ba}v[23220]=0;b=Q(1,d+160|0,12292)|0;e=v[23220];v[23220]=0;Yb:{if((e|0)!=1){Db(a+1298392|0,b);vb(b);v[23220]=0;b=Q(1,d+184|0,14240)|0;e=v[23220];v[23220]=0;if((e|0)==1){break Yb}Db(a+1298380|0,b);vb(b);break ob}e=P()|0;O()|0;break Ba}e=P()|0;O()|0;break Ba}v[23220]=0;b=Q(1,d+160|0,10063)|0;e=v[23220];v[23220]=0;Zb:{if((e|0)!=1){Db(a+1298392|0,b);vb(b);v[23220]=0;b=Q(1,d+184|0,15258)|0;e=v[23220];v[23220]=0;if((e|0)==1){break Zb}Db(a+1298380|0,b);vb(b);break ob}e=P()|0;O()|0;break Ba}e=P()|0;O()|0;break Ba}v[23220]=0;b=Q(1,d+160|0,10435)|0;e=v[23220];v[23220]=0;_b:{if((e|0)!=1){Db(a+1298392|0,b);vb(b);v[23220]=0;b=Q(1,d+184|0,15069)|0;e=v[23220];v[23220]=0;if((e|0)==1){break _b}Db(a+1298380|0,b);vb(b);break ob}e=P()|0;O()|0;break Ba}e=P()|0;O()|0;break Ba}v[23220]=0;b=Q(1,d+160|0,6088)|0;e=v[23220];v[23220]=0;$b:{ac:{bc:{cc:{dc:{if((e|0)!=1){Db(a+1298392|0,b);vb(b);if(!(g&65535)){break $b}v[23220]=0;R(256,d+208|0,4275);b=v[23220];v[23220]=0;if((b|0)==1){break dc}v[d+36>>2]=(g&65280)>>>8;v[23220]=0;v[d+20>>2]=g&255;R(387,d+24|0,d+20|0);b=v[23220];v[23220]=0;if((b|0)==1){break cc}v[23220]=0;X(373,d+184|0,d+208|0,d+36|0,d+24|0);b=v[23220];v[23220]=0;if((b|0)==1){break bc}b=d+184|0;Db(a+1298380|0,b);vb(b);vb(d+24|0);bc(d+208|0);break ob}e=P()|0;O()|0;break Ba}e=P()|0;O()|0;break Ba}e=P()|0;O()|0;break ac}e=P()|0;O()|0;vb(d+24|0)}bc(d+208|0);break Ba}v[23220]=0;b=Q(1,d+184|0,8528)|0;e=v[23220];v[23220]=0;if((e|0)!=1){Db(a+1298380|0,b);vb(b);break ob}e=P()|0;O()|0;break Ba}e=P()|0;O()|0;break Ba}e=P()|0;O()|0;break Ba}e=P()|0;O()|0;break Ba}e=P()|0;O()|0;break Ba}Db(a+1298368|0,c);ec:{if(v[a+1074308>>2]){v[a+1298404>>2]=8;break ec}if(v[a+480180>>2]==1){v[a+1298404>>2]=13;break ec}v[a+1298404>>2]=5}f=1;fc:{gc:{if(i&1){v[23220]=0;b=Q(1,d+208|0,16573)|0;e=v[23220];v[23220]=0;if((e|0)==1){break gc}a=v[a+1298464>>2];v[23220]=0;U(360,a|0,2,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break fc}vb(b)}vb(c);fA(q);lc(A);fd(s);wb(H);wb(G);break c}e=P()|0;O()|0;break Ba}e=P()|0;O()|0;vb(b);break Ba}e=P()|0;O()|0;wb(h);break Da}v[23220]=0;f=Q(355,b|0,13835)|0;h=v[23220];v[23220]=0;if((h|0)==1){break Ea}hc:{if(!f){break hc}v[23220]=0;f=T(144,b|0)|0;h=v[23220];v[23220]=0;ic:{if((h|0)!=1){v[23220]=0;U(177,d+184|0,b|0,f|0);f=v[23220];v[23220]=0;if((f|0)!=1){break ic}}e=P()|0;O()|0;break Da}f=d+184|0;h=gc(d+240|0,f);wb(f);f=v[h>>2];v[23220]=0;f=T(147,f|0)|0;o=v[23220];v[23220]=0;if((o|0)!=1){u[d+184>>1]=(f>>>0)/20;u[d+208>>1]=x[n>>1];o=x[Tc(d+184|0,d+208|0)>>1];f=0;while(1){if((f|0)==(o|0)){wb(h);break hc}v[23220]=0;U(366,h|0,((f<<5)+a|0)+480289|0,20);k=v[23220];v[23220]=0;if((k|0)!=1){f=f+1|0;continue}break}}e=P()|0;O()|0;wb(h);break Da}v[23220]=0;Q(376,a|0,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break Ea}v[23220]=0;X(377,a|0,b|0,1,0);f=v[23220];v[23220]=0;if((f|0)==1){break Ea}if((e-2186&65535)>>>0<=117){v[a+480180>>2]=16777216;v[23220]=0;U(391,a|0,b|0,e&65535);f=v[23220];v[23220]=0;if((f|0)==1){break Ea}}if(!v[a+1074308>>2]){break lb}v[23220]=0;f=Q(1,d+104|0,17558)|0;h=v[23220];v[23220]=0;jc:{kc:{lc:{if((h|0)!=1){h=v[a+1074308>>2];v[23220]=0;R(127,d+184|0,h|0);h=v[23220];v[23220]=0;if((h|0)==1){break lc}v[23220]=0;U(2,d+240|0,f|0,d+184|0);h=v[23220];v[23220]=0;if((h|0)==1){break kc}h=d+240|0;Db(c,h);vb(h);vb(d+184|0);vb(f);break lb}e=P()|0;O()|0;break Da}e=P()|0;O()|0;break jc}e=P()|0;O()|0;vb(d+184|0)}vb(f);break Da}wb(b);continue}}e=P()|0;O()|0;break va}e=P()|0;O()|0;break va}e=P()|0;O()|0;break va}e=P()|0;O()|0;break va}e=P()|0;O()|0;break xa}e=P()|0;O()|0;break wa}e=P()|0;O()|0}wb(b);break Ba}e=P()|0;O()|0}vb(c);break va}e=P()|0;O()|0;break va}e=P()|0;O()|0;Jc(d+240|0);break va}e=P()|0;O()|0}wb(g)}ub(f)}fA(q);break ja}e=i}ub(f);h=h+1|0;continue}}e=P()|0;O()|0;break ja}e=P()|0;O()|0;ub(i);break ja}e=P()|0;O()|0}lc(A);break A}j=j+1|0;continue}}fd(s);break z}e=P()|0;O()|0}wb(H);break y}e=P()|0;O()|0}wb(G);break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}else{mc:{nc:{if(!h){t[d+240|0]=w[(d+f|0)+1206|0];t[d+160|0]=64;M=((f<<5)+a|0)+480286|0,N=w[Rb(d+240|0,d+160|0)|0],u[M>>1]=N;break nc}if(n){break mc}}oc:{e=w[(d+f|0)+1270|0];if((e|0)!=255){if((e|0)!=127){break oc}v[((f<<5)+a|0)+480280>>2]=256;break mc}u[((f<<5)+a|0)+480284>>1]=256;break mc}u[((f<<5)+a|0)+480284>>1]=e}f=f+1|0;continue}}e=P()|0;O()|0;break d}e=P()|0;O()|0;break d}e=P()|0;O()|0}wb(l)}$b(z);S(e|0);L()}wb(l)}$b(z)}fb=d+1680|0;return f|0}function Sfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0;e=fb-976|0;fb=e;wc(b);a:{if(!ZR(b,e+920|0)){break a}if(!bS(e+920|0)){break a}if(!Lb(v[b>>2],v[b+8>>2],Pc(aS(e+920|0),ib))){break a}if(!c){d=1;break a}zd(a,8);yg(a);aa=w[e+923|0];J=aa-48|0;t[e+919|0]=J;Vc(b,_b(v[e+928>>2]));f=e+608|0;Qd(f,b,504);_=gc(e+896|0,f);wb(f);v[23220]=0;R(466,b|0,f|0);f=v[23220];v[23220]=0;b:{c:{d:{e:{f:{g:{if((f|0)!=1){if(w[e+891|0]>63){break b}if(Jb(x[e+608>>1])<<16>>16<0){break b}Sb(e+528|0,0,80);h:{d=_b(v[e+952>>2]);if(!d){break h}v[23220]=0;f=Q(142,b|0,d|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){if(!f){break h}v[23220]=0;R(467,b|0,e+528|0);d=v[23220];v[23220]=0;if((d|0)!=1){break h}}i=P()|0;O()|0;break e}v[23220]=0;U(468,e+520|0,b|0,J&255);d=v[23220];v[23220]=0;if((d|0)!=1){ba=Qe(e+520|0);d=0;f=x[e+520>>1];if((f-128&65535)>>>0<65409){break b}u[a+480188>>1]=f;K=Ib(e+504|0);f=_b(v[e+944>>2]);i:{if(f){v[23220]=0;Q(142,b|0,f|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break g}v[23220]=0;U(469,b|0,K|0,w[e+891|0]);d=v[23220];v[23220]=0;if((d|0)==1){break g}d=w[e+891|0];break i}f=0;if(w[e+891|0]){break c}}j=d&255;u[a+480192>>1]=j;u[a+480190>>1]=j;ca=(J&255)>>>0<2|t[e+872|0]>=0;p=!ca;o=c&2;s=1;C=1;while(1){j:{k:{l:{m:{n:{o:{g=C&65535;if(g>>>0<=(j&65535)>>>0){v[23220]=0;q=s&65535;f=W(241,a|0,g|0,q|0)|0;d=v[23220];v[23220]=0;p:{if((d|0)!=1){if(f){break p}break d}i=P()|0;O()|0;break f}y=v[((g<<2)+a|0)+900380>>2];u[e+84>>1]=0;v[e+80>>2]=0;v[23220]=0;D=T(161,e+480|0)|0;d=v[23220];v[23220]=0;q:{if((d|0)!=1){d=zb(v[K>>2],g-1|0);d=_b(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));r:{if(!d){break r}v[23220]=0;f=Q(142,b|0,d|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break k}if(!f){break r}v[23220]=0;R(470,b|0,e+80|0);d=v[23220];v[23220]=0;if((d|0)==1){break k}f=v[e+80>>2];d=x[e+84>>1];v[23220]=0;f=_b(f);d=Jb(d);U(177,e+120|0,b|0,f<<(d>>>5&1&d<<16>>16>0));d=v[23220];v[23220]=0;if((d|0)==1){break k}f=e+120|0;d=gc(e+192|0,f);Yc(D,d);wb(d);wb(f)}d=Jb(x[e+84>>1]);f=d&15;z=d<<16>>16;if((z|0)>=0){break q}It(y,0);ea=1;break o}i=P()|0;O()|0;break f}if(f>>>0>6){break o}A=w[f+26694|0];if(!f){break m}u[a+480190>>1]=(x[a+480190>>1]+A|0)-1;l=y+108|0;r=y+236|0;m=A-2|0;j=4;s:while(1){g=1;if((j|0)==10){break n}k=B(j,12);d=(m<<3)+j|0;h=w[d+26700|0]+s|0;g=w[d+26748|0];d=0;while(1)if((d|0)==12){j=j+1|0;continue s}else{f=d+k|0;fa=ac(r,f),ga=h,u[fa>>1]=ga;f=Hb(l,f);t[f|0]=g+w[f|0];d=d+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=_b(v[e+532>>2]);if(!d){break D}if(!Jb(x[e+536>>1])){break D}v[23220]=0;f=Q(142,b|0,d|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break C}if(!f){break D}fa=e,ga=Jb(x[e+536>>1]),u[fa+192>>1]=ga;u[e+120>>1]=w[e+891|0];f=e+120|0;o=x[Tc(e+192|0,f)>>1];d=e+128|0;l=f|4;z=Jb(x[e+538>>1]);r=z>>>0<19;m=z>>>0<21;k=z>>>0<15;h=z>>>0<6;j=0;while(1){if((j|0)==(o|0)){break D}v[23220]=0;U(471,b|0,e+192|0,z|0);f=v[23220];v[23220]=0;E:{F:{G:{if((f|0)!=1){j=j+1|0;q=v[((j<<2)+a|0)+900380>>2];p=w[e+192|0];if(p){g=_n(e+120|0,0,64);_n(l,p-1&65535,64);f=w[e+193|0];if(f){f=64/(f>>>0)|0}else{f=0}_n(d,f+p|0,0);v[23220]=0;p=q+48|0;U(472,p|0,g|0,3);f=v[23220];v[23220]=0;if((f|0)==1){break G}if(w[e+192|0]==1){g=v[dc(e+472|0,Ab(v[p>>2]))>>2];f=Ab(v[p>>2]);f=v[p>>2]+(Gt(g,f)<<2)|0;Jd(p,Gi(f+4|0,v[p+4>>2],f));Ab(f)}f=w[e+193|0];v[q>>2]=f?f<<9:32767;t[q+60|0]=w[q+60|0]|1;F=1}H:{if(r){break H}v[q+4>>2]=w[e+210|0]+1>>>1;if(m){break H}u[q+28>>1]=x[e+212>>1]}g=B(x[ac(q+236|0,61)>>1],104)+a|0;t[g+484417|0]=w[e+195|0]<<4;if(k){break F}f=_b(x[e+202>>1]|x[e+204>>1]<<16);v[g+484384>>2]=f;fa=g+484388|0,ga=_b(x[e+206>>1]|x[e+208>>1]<<16)+f|0,v[fa>>2]=ga;break E}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}if(h){continue}}f=g+484414|0;i=f;n=x[f>>1]&65529;f=w[e+197|0];u[i>>1]=n|f<<1&2|f>>>1&4;if(!(f&4)){continue}u[g+484412>>1]=0;continue}}I:{d=_b(v[e+548>>2]);if(!d){break I}if(!Jb(x[e+552>>1])){break I}v[23220]=0;f=Q(142,b|0,d|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break C}if(!f){break I}fa=e,ga=Jb(x[e+552>>1]),u[fa+192>>1]=ga;u[e+120>>1]=w[e+891|0];m=x[Tc(e+192|0,e+120|0)>>1];k=Jb(x[e+554>>1]);d=0;J:while(1){if((d|0)==(m|0)){break I}v[23220]=0;U(473,b|0,e+192|0,k|0);f=v[23220];v[23220]=0;if((f|0)==1){break t}f=e+80|0;nT(f,e+192|0);v[23220]=0;R(209,e+120|0,f|0);f=v[23220];v[23220]=0;if((f|0)==1){break u}d=d+1|0;r=((d<<2)+a|0)+900380|0;g=e+120|0;yc(v[r>>2]+492|0,g);ub(g);f=v[r>>2];v[23220]=0;R(474,g|0,f|0);f=v[23220];v[23220]=0;if((f|0)==1){break v}fa=e,ga=oj(v[e+120>>2]),v[fa+80>>2]=ga;h=wf(e+120|0);while(1){f=v[e+80>>2];if(Nb(f,h)){l=(x[Pp(f)>>1]<<5)+a|0;g=l+946328|0;o=v[r>>2];f=v[o+520>>2];v[g>>2]=v[o+516>>2];v[g+4>>2]=f;f=v[o+512>>2];g=l+946320|0;v[g>>2]=v[o+508>>2];v[g+4>>2]=f;f=v[o+504>>2];g=l+946312|0;v[g>>2]=v[o+500>>2];v[g+4>>2]=f;f=v[o+496>>2];g=l+946304|0;v[g>>2]=v[o+492>>2];v[g+4>>2]=f;Rg(e+80|0);continue}else{rA(e+120|0);continue J}}}}Vp(a+901404|0);d=oc(e+464|0,4901);Te(le(a+901692|0,0),v[d>>2],v[d+4>>2]);wc(b);D=c&1;G=a+484344|0;H=a+1298332|0;da=a+1298308|0;$=a+484360|0;c=0;C=0;while(1){K:{f=c&255;if(f>>>0<w[ba|0]){v[23220]=0;X(475,b|0,e+920|0,e+528|0,e+608|0);d=v[23220];v[23220]=0;L:{M:{N:{O:{P:{if((d|0)==1){break P}Q:{if(!f){d=0;break Q}v[23220]=0;f=T(262,$|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break P}d=c;if((f|0)==255){break d}}n=nj(v[$>>2],d&255);E=eg(e+448|0);Bc(n);I=J&255;if(I>>>0>1){break N}i=0;f=Jb(x[e+610>>1]);if(f>>>0>256|x[a+480188>>1]>16){break L}d=e+192|0;WR(d,e+608|0);v[23220]=0;U(476,n|0,d|0,f|0);d=v[23220];v[23220]=0;if((d|0)==1){break O}fa=e,ga=Ab(v[n>>2]),v[fa+192>>2]=ga;d=Ab(v[n+4>>2]);while(1){f=v[e+192>>2];if(Nb(f,d)){u[f>>1]=x[f>>1]+C;Oe(e+192|0);continue}else{th(a,1);f=x[a+480188>>1];d=0;while(1)if((d|0)==(f|0)){d=32;break M}else{t[e+192|0]=w[(d+e|0)+874|0];t[e+120|0]=64;fa=((d<<5)+a|0)+480286|0,ga=w[Rb(e+192|0,e+120|0)|0],u[fa>>1]=ga;d=d+1|0;continue}}}}i=P()|0;O()|0;break f}i=P()|0;O()|0;break w}WR(e+192|0,e+608|0);R:{S:{T:{U:{d=Jb(x[e+204>>1]);if(!(!d|d>>>0>64|x[a+480188>>1]>64)){l=_b(v[e+212>>2]);d=Jb(x[e+216>>1]);if(d){u[e+120>>1]=d;u[e+80>>1]=800;f=Pc(((x[Tc(e+120|0,e+80|0)>>1]<<5)+50>>>0)/100|0,0)}else{f=32}d=v[e+200>>2];v[23220]=0;g=Q(142,b|0,_b(d)|0)|0;d=v[23220];v[23220]=0;V:{if((d|0)==1){break V}d=0;W:{if(!g){break W}while(1){if(x[a+480188>>1]<=d>>>0){break W}v[23220]=0;h=T(193,b|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){t[e+120|0]=h;t[e+80|0]=64;fa=((d<<5)+a|0)+480286|0,ga=w[Rb(e+120|0,e+80|0)|0],u[fa>>1]=ga;d=d+1|0;continue}break}i=P()|0;O()|0;break w}X:{Y:{d=_b(v[e+208>>2]);if(!d){break Y}v[23220]=0;g=Q(142,b|0,d|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break V}d=0;if(!g){break Y}while(1){if(x[a+480188>>1]<=d>>>0){break X}v[23220]=0;h=T(477,b|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){fa=((d<<5)+a|0)+480284|0,ga=(Ub(h,-16,16)<<3)+128|0,u[fa>>1]=ga;d=d+1|0;continue}break}i=P()|0;O()|0;break w}th(a,1)}o=Ib(e+176|0);d=v[e+196>>2];v[23220]=0;g=Q(142,b|0,_b(d)|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break U}i=1;d=0;if(!g){break R}k=x[e+610>>1];h=v[b+8>>2];g=v[b>>2];v[23220]=0;h=W(143,g|0,h|0,Jb(k)<<1)|0;g=v[23220];v[23220]=0;if((g|0)==1){break U}if(!h){break R}g=x[e+610>>1];v[23220]=0;h=W(478,b|0,o|0,Jb(g)|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break U}if(!h){break R}fa=e,ga=Ab(v[o>>2]),v[fa+168>>2]=ga;r=Ab(v[e+180>>2]);while(1){d=v[e+168>>2];if(!Nb(d,r)){i=0;d=1;break R}g=Jb(w[d|0]|w[d+1|0]<<8);Z:{if(Jb(x[e+206>>1])>>>0<g>>>0){break Z}d=v[e+192>>2];v[23220]=0;Q(142,b|0,_b(d)+(g<<2)|0)|0;d=v[23220];v[23220]=0;_:{$:{aa:{ba:{ca:{if((d|0)==1){break ca}v[23220]=0;g=T(269,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break ca}v[23220]=0;g=Q(142,b|0,g|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break ca}if(!g){break Z}g=v[b+8>>2];d=v[b>>2];v[23220]=0;g=W(143,d|0,g|0,42)|0;d=v[23220];v[23220]=0;if((d|0)==1){break ca}if(!g){break Z}v[23220]=0;R(479,b|0,e+120|0);d=v[23220];v[23220]=0;da:{if((d|0)!=1){if(rc(v[n>>2],v[n+4>>2])){break da}v[23220]=0;R(480,n|0,65534);d=v[23220];v[23220]=0;if((d|0)!=1){break da}}i=P()|0;O()|0;break S}h=Jb(x[e+160>>1]);v[e+116>>2]=h;g=v[b+8>>2];d=v[b>>2];v[23220]=0;g=W(143,d|0,g|0,h|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break ba}if(!g){v[23220]=0;g=T(189,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break ba}uc(e+116|0,g)}uc(e+116|0,65534);h=v[n+4>>2];g=v[n>>2];d=0;v[23220]=0;m=v[e+116>>2];k=Ic(g,h);R(481,n|0,m+k|0);g=v[23220];v[23220]=0;if((g|0)==1){break $}while(1){ea:{if((d|0)==(m|0)){if(w[e+120|0]){break ea}break aa}v[23220]=0;h=T(261,b|0)|0;g=v[23220];v[23220]=0;fa:{if((g|0)!=1){g=h<<16>>16;if((g|0)<0){break fa}v[23220]=0;R(480,n|0,g+C&65535);g=v[23220];v[23220]=0;if((g|0)!=1){break fa}}i=P()|0;O()|0;break S}d=d+1|0;continue}break}vm(e+104|0,e+120|0);v[23220]=0;U(482,e+56|0,v[e+104>>2],v[e+108>>2]);d=v[23220];v[23220]=0;ga:{ha:{ia:{if((d|0)!=1){v[23220]=0;U(11,e+80|0,13,e+56|0);d=v[23220];v[23220]=0;if((d|0)==1){break ia}v[23220]=0;R(263,n|0,e+80|0);d=v[23220];v[23220]=0;if((d|0)==1){break ha}vb(e+80|0);ub(e+56|0);break aa}i=P()|0;O()|0;break S}i=P()|0;O()|0;break ga}i=P()|0;O()|0;vb(e+80|0)}ub(e+56|0);break S}i=P()|0;O()|0;break S}i=P()|0;O()|0;break S}d=_b(v[e+152>>2]);if(!d){break Z}v[23220]=0;g=Q(142,b|0,d|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break _}}i=P()|0;O()|0;break S}if(!g){break Z}while(1){ja:{v[23220]=0;g=Q(483,b|0,e+104|0)|0;d=v[23220];v[23220]=0;ka:{la:{ma:{if((d|0)!=1){if(!g){break Z}v[23220]=0;U(177,e+56|0,b|0,w[e+107|0]);d=v[23220];v[23220]=0;if((d|0)==1){break ma}d=e+56|0;m=gc(e+80|0,d);wb(d);d=Jb(x[e+104>>1]);g=fu(d+k|0);u[e+56>>1]=g;if((d|0)==65535){break ja}d=v[n>>2];if(Ic(d,v[n+4>>2])>>>0<=g>>>0){break ja}na:{switch(w[e+106|0]-1|0){case 1:break ka;case 0:break la;default:break na}}wb(m);continue}i=P()|0;O()|0;break S}i=P()|0;O()|0;break S}fa=ac(d,g),ga=65535,u[fa>>1]=ga;wb(m);continue}v[23220]=0;h=T(261,m|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break T}v[23220]=0;g=Q(484,E|0,e+56|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break T}u[g>>1]=h;fa=ac(v[n>>2],x[e+56>>1]),ga=65534,u[fa>>1]=ga;wb(m);continue}break}wb(m)}Oe(e+168|0);continue}}i=P()|0;O()|0;break w}i=0;break L}i=P()|0;O()|0;break S}i=P()|0;O()|0;wb(m)}ld(o);break w}ld(o);if(d){d=f>>>(l>>>1&1)|0;break M}Ft(E);if(!i){break d}break K}g=Jb(x[e+868>>1]);k=w[e+871|0];q=k&64;f=w[e+872|0];y=f&32;M=(f&31)+1|0;fa=a,ga=TR(g,q>>>6|0,y>>>5|0,M),v[fa+480204>>2]=ga;fa=a,ga=Pd(w[e+873|0],1,32),v[fa+480196>>2]=ga;if(y){v[a+480216>>2]=M;v[a+480220>>2]=M<<2}f=w[e+890|0];if(f){t[e+192|0]=f;t[e+120|0]=64;fa=a,ga=w[Rb(e+192|0,e+120|0)|0]<<2,v[fa+480200>>2]=ga}v[a+480228>>2]=d;v[a+480232>>2]=d;v[a+480208>>2]=v[a+480208>>2]&-3|(k>>>4^-1)&2;oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{d=_b(v[e+572>>2]);if(!d){break ya}v[23220]=0;f=Q(142,b|0,d|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break xa}if(!f){break ya}d=v[e+576>>2];v[23220]=0;U(258,b|0,da|0,_b(d)|0);d=v[23220];v[23220]=0;if((d|0)==1){break xa}if(w[ba|0]<2){break ya}v[23220]=0;U(11,e+192|0,13,da|0);d=v[23220];v[23220]=0;za:{if((d|0)!=1){v[23220]=0;R(263,n|0,e+192|0);d=v[23220];v[23220]=0;if((d|0)==1){break za}vb(e+192|0);break ya}i=P()|0;O()|0;break w}i=P()|0;O()|0;vb(e+192|0);break w}Aa:{if(_b(v[e+544>>2])>>>0<2){break Aa}d=v[e+540>>2];v[23220]=0;f=Q(142,b|0,_b(d)|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break xa}if(!f){break Aa}d=v[e+544>>2];v[23220]=0;X(322,H|0,b|0,_b(d)-1|0,4);d=v[23220];v[23220]=0;if((d|0)==1){break xa}}d=_b(v[e+584>>2]);if(!d){break oa}v[23220]=0;f=Q(142,b|0,d|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break xa}if(!f){break oa}f=v[b+8>>2];d=v[b>>2];v[23220]=0;f=W(143,d|0,f|0,12)|0;d=v[23220];v[23220]=0;if((d|0)==1){break xa}if(!f){break oa}v[23220]=0;Q(175,b|0,6)|0;d=v[23220];v[23220]=0;if((d|0)==1){break xa}v[23220]=0;f=T(261,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break xa}if((f|0)!=1){break oa}v[23220]=0;g=T(269,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break va}if(!g){break oa}f=v[b+8>>2];d=v[b>>2];v[23220]=0;f=W(143,d|0,f|0,g|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break va}if(f){break wa}break oa}i=P()|0;O()|0;break w}h=Mc(e+192|0,H);v[23220]=0;X(322,H|0,b|0,g|0,4);d=v[23220];v[23220]=0;if((d|0)==1){break qa}if(!ze(h)){v[23220]=0;f=W(485,e+24|0,2,13)|0;d=v[23220];v[23220]=0;if((d|0)==1){break ua}v[23220]=0;U(486,e+120|0,h|0,f|0);d=v[23220];v[23220]=0;if((d|0)==1){break ta}v[23220]=0;U(487,e+40|0,e+120|0,H|0);d=v[23220];v[23220]=0;if((d|0)==1){break sa}d=e+40|0;xc(H,d);ub(d);ub(e+120|0);ub(f)}ub(h);break oa}i=P()|0;O()|0;break w}i=P()|0;O()|0;break pa}i=P()|0;O()|0;break ra}i=P()|0;O()|0;ub(e+120|0)}ub(f);break pa}i=P()|0;O()|0}ub(h);break w}Ba:{if(I>>>0<2){break Ba}i=0;if(!_b(v[e+596>>2])){break Ba}while(1){if(x[a+480188>>1]<=i>>>0){break Ba}d=v[e+596>>2];v[23220]=0;f=Q(142,b|0,_b(d)+(i<<2)|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break x}Ca:{if(!f){break Ca}v[23220]=0;f=T(269,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break x}v[23220]=0;f=Q(142,b|0,f|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break x}g=0;d=0;if(!f){break Ca}while(1){Da:{h=v[b+8>>2];f=v[b>>2];v[23220]=0;h=W(143,f|0,h|0,8)|0;f=v[23220];v[23220]=0;Ea:{Fa:{Ga:{if((f|0)!=1){if(!h){break Da}v[23220]=0;R(488,b|0,e+192|0);f=v[23220];v[23220]=0;if((f|0)==1){break Ga}f=_b(v[e+192>>2]);if(!f){break Da}switch((f&536870911)-1|0){case 1:break Ea;case 0:break Fa;default:continue}}i=P()|0;O()|0;break w}i=P()|0;O()|0;break w}g=_b(v[e+196>>2]);continue}d=_b(v[e+196>>2]);continue}break}if(!g|!d){break Ca}v[23220]=0;g=Q(142,b|0,g|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break y}if(!g){break Ca}v[23220]=0;U(366,b|0,((i<<5)+a|0)+480289|0,d|0);d=v[23220];v[23220]=0;if((d|0)==1){break y}}i=i+1|0;continue}}d=x[e+608>>1];v[23220]=0;s=Jb(d);R(212,G|0,C+s&65535);d=v[23220];v[23220]=0;if((d|0)==1){break z}z=k&16;p=C&65535;g=0;Ha:{Ia:{while(1){if((g|0)==(s|0)){fa=e,ga=oj(v[E>>2]),v[fa+120>>2]=ga;g=wf(E);while(1){d=v[e+120>>2];if(!vg(d,g)){i=1;d=_b(v[e+528>>2]);if(!d){break L}v[23220]=0;f=Q(142,b|0,d|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break z}if(!f){break L}C=s+C|0;Ft(E);break K}k=Pp(d);h=Qe(k);Ja:{Ka:{La:{Ma:{d=x[k>>1];if(!d){j=0;break Ma}v[23220]=0;f=Q(300,n|0,d-1&65535)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Ja}j=x[k>>1];if(!f){break Ma}v[23220]=0;j=Q(353,n|0,j-1&65535)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Ja}break La}if(x[h>>1]==((j&65535)+1|0)){break Ka}v[23220]=0;j=Q(352,G|0,1)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Ja}if((j|0)==65535){break Ka}fa=ac(v[n>>2],x[k>>1]),ga=j,u[fa>>1]=ga}d=Xb(v[G>>2],j);me(d,im(He(Be(e+192|0,12,_t(x[h>>1])),v[d+12>>2]-1|0)));s=(s&65535)>>>0>j>>>0?s:j+1|0}Rg(e+120|0);continue}break}i=P()|0;O()|0;break w}Na:{Oa:{if(!D){break Oa}d=v[e+936>>2];v[23220]=0;f=Q(142,b|0,_b(d)+(g<<2)|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Ia}if(!f){break Oa}v[23220]=0;f=T(269,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Ia}v[23220]=0;f=Q(142,b|0,f|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break Ia}if(!f){break Oa}N=Gb(e+56|0);v[23220]=0;V=T(161,e|0)|0;d=v[23220];v[23220]=0;Pa:{Qa:{if((d|0)!=1){if(I){break Qa}v[23220]=0;R(489,b|0,e+192|0);d=v[23220];v[23220]=0;if((d|0)==1){break Na}u[e+104>>1]=w[e+192|0];Y=w[e+193|0]+1|0;f=48;break Pa}i=P()|0;O()|0;break A}v[23220]=0;m=t[e+870|0];R(490,b|0,e+176|0);d=v[23220];v[23220]=0;Ra:{Sa:{if((d|0)!=1){k=Jb(x[e+176>>1]);u[e+104>>1]=k;Y=Jb(x[e+178>>1])+1|0;d=_b(v[e+180>>2]);if(!d){break Ra}h=v[b+8>>2];v[23220]=0;Q(142,b|0,d|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break B}v[23220]=0;R(491,b|0,e+192|0);d=v[23220];v[23220]=0;if((d|0)==1){break B}d=v[e+196>>2];v[23220]=0;f=Q(142,b|0,_b(d)|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break B}if(!f){break Sa}d=v[e+200>>2];v[23220]=0;U(258,b|0,N|0,_b(d)|0);d=v[23220];v[23220]=0;if((d|0)!=1){break Sa}break B}break B}d=_b(v[e+208>>2]);Ta:{if(!d){break Ta}v[23220]=0;f=Q(142,b|0,d|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break B}if(!f){break Ta}v[23220]=0;f=T(269,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break B}v[23220]=0;f=Q(142,b|0,f|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break B}if(!f){break Ta}v[23220]=0;U(177,e+80|0,b|0,B(k,Y)|0);d=v[23220];v[23220]=0;if((d|0)==1){break B}f=e+80|0;d=gc(e+120|0,f);Yc(V,d);wb(d);wb(f)}v[23220]=0;Q(142,b|0,h|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break B}}f=m+(I>>>0<3?48:24)|0}v[23220]=0;k=g+p|0;h=W(213,G|0,k&65535,Y|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break B}Ua:{if(!h){break Ua}d=v[G>>2];v[23220]=0;A=Xb(d,k);R(271,A|0,N|0);d=v[23220];v[23220]=0;if((d|0)==1){break Ha}qg(e+104|0,x[a+480188>>1]);Z=0;o=x[e+104>>1];Va:while(1){if((Y|0)==(Z|0)){break Ua}i=0;d=$c(v[A>>2],v[v[A+48>>2]+12>>2],Z,0);while(1){if((i&65535)>>>0>=o>>>0){Z=Z+1|0;continue Va}Wa:{if(!I){v[23220]=0;R(492,e+192|0,b|0);h=v[23220];v[23220]=0;if((h|0)!=1){m=w[e+192|0];k=e+192|0;h=gd(k);t[d+1|0]=m>>>3&16|w[h|0]>>>4|m>>>1&32;t[d+3|0]=w[h|0]&15;fa=d,ga=w[Qe(k)|0],t[fa+5|0]=ga;h=m&63;j=h?h+f|0:0;break Wa}break B}v[23220]=0;R(342,e+192|0,b|0);h=v[23220];v[23220]=0;Xa:{Ya:{if((h|0)!=1){h=e+192|0;l=gd(h);r=Qe(h);m=zi(h);v[23220]=0;k=T(193,V|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break B}t[d+4|0]=k;k=w[e+192|0];h=k&127;if(!h){break Ya}j=f+h|0;break Xa}break B}j=0;if((k|0)!=128){break Xa}t[d|0]=254}t[d+1|0]=w[l|0]&63;t[d+3|0]=w[r|0];t[d+5|0]=w[m|0]}if(j-1>>>0<=119){t[d|0]=j}F=(j|0)>84&ca|F;r=(q|0)!=0;m=(y|0)!=0;k=(z|0)!=0;l=fb-16|0;fb=l;Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{wb:{h=w[d+3|0];switch(h-4|0){case 42:break $a;case 37:break ab;case 28:break bb;case 27:break cb;case 26:break db;case 25:break eb;case 24:break fb;case 23:break gb;case 22:break hb;case 21:break ib;case 20:break jb;case 18:break kb;case 17:break lb;case 16:break mb;case 14:break nb;case 13:break ob;case 12:break pb;case 11:break qb;case 10:break rb;case 9:break sb;case 8:break tb;case 5:break ub;case 4:break vb;case 0:break wb;default:break _a}}t[d+3|0]=5;k=w[d+5|0];t[l+15|0]=k>>>3;t[l+14|0]=15;h=w[Rb(l+15|0,l+14|0)|0];t[l+13|0]=k<<1&30;t[l+12|0]=15;fa=d,ga=w[Rb(l+13|0,l+12|0)|0]|h<<4,t[fa+5|0]=ga;break Za}t[d+3|0]=0;break Za}if((w[d+5|0]-1&255)>>>0<=19){t[d+3|0]=16;break Za}t[d+3|0]=0;break Za}t[d+3|0]=13;h=w[d+5|0];xb:{if(!k){if(h>>>0>152){break xb}t[d+5|0]=B((h&240)>>>4|0,10)+(h&15);break Za}t[d+5|0]=(h&127)+1>>>1;break Za}t[d+3|0]=0;break Za}t[d+3|0]=11;break Za}t[d+3|0]=0;break Za}h=w[d+5|0];if(!h){t[d+3|0]=14;break Za}if(h>>>0<=240){t[d+3|0]=17;if(h>>>0<=2){t[d+5|0]=112;break Za}fa=d,ga=Yn(+(TR(h,r,m,M)>>>0)/1e4),t[fa+5|0]=ga;break Za}t[d+3|0]=0;break Za}t[d+3|0]=31;t[d+5|0]=w[d+5|0]|128;break Za}t[d+3|0]=19;t[l+11|0]=15;fa=d,ga=w[Rb(d+5|0,l+11|0)|0]|16,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[l+10|0]=15;fa=d,ga=w[Rb(d+5|0,l+10|0)|0]|32,t[fa+5|0]=ga;break Za}t[d+3|0]=5;h=w[d+5|0];t[l+9|0]=(h>>>4|0)+1;t[l+8|0]=15;fa=d,ga=h&15|w[Rb(l+9|0,l+8|0)|0]<<4,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[d+5|0]=w[d+5|0]&15|80;break Za}t[d+3|0]=19;t[l+7|0]=15;fa=d,ga=w[Rb(d+5|0,l+7|0)|0]|96,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[l+6|0]=15;fa=d,ga=w[Rb(d+5|0,l+6|0)|0]|192,t[fa+5|0]=ga;break Za}t[d+3|0]=10;break Za}t[d+3|0]=19;t[l+5|0]=15;fa=d,ga=w[Rb(d+5|0,l+5|0)|0]|160,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[l+4|0]=15;fa=d,ga=w[Rb(d+5|0,l+4|0)|0]|176,t[fa+5|0]=ga;break Za}h=(w[d+5|0]<<24)-16777216>>24;if((h|0)>=0){t[d+5|0]=h;t[d+3|0]=31;break Za}t[d+3|0]=0;break Za}t[d+3|0]=14;break Za}t[d+3|0]=19;t[l+3|0]=15;fa=d,ga=w[Rb(d+5|0,l+3|0)|0]|224,t[fa+5|0]=ga;break Za}h=w[d+5|0];if(h&240){t[d+3|0]=19;t[d+5|0]=h>>>4|208;break Za}if(h&15){t[d+3|0]=19;t[d+5|0]=h|144;break Za}t[d+3|0]=0;break Za}if(!(w[d+5|0]|w[d+4|0])){if(!Oc(w[d|0])){break Za}t[d+5|0]=159;t[d+3|0]=20;break Za}t[d+3|0]=0;break Za}h=w[d+4|0];if(h){t[d+3|0]=44;fa=d,ga=sm(Pc(((w[d+5|0]<<8&65280)>>>0)/(h>>>0)|0,0)),t[fa+5|0]=ga;break Za}t[d+3|0]=0;break Za}h=w[d+5|0];if((h+16&255)>>>0<=32){t[d+3|0]=9;fa=d,ga=vi(((h^128)<<3)-896|0),t[fa+5|0]=ga;break Za}t[d+3|0]=0;break Za}if(h>>>0<=15){Mf(d);break Za}t[d+3|0]=0}fb=l+16|0;d=d+6|0;i=i+1|0;continue}}}wb(V);ub(N)}g=g+1|0;continue}break}break B}i=P()|0;O()|0;break w}break B}Ft(E);f=0;if(!i){break c}}xi($,0);d=1;yb:{if(F&1){break yb}while(1){b=d&65535;if(b>>>0>x[a+480192>>1]){u[a+480192>>1]=0;break yb}c=((b<<2)+a|0)+900380|0;b=v[c>>2];if(b){Fb(Ht(b))}v[c>>2]=0;d=d+1|0;continue}}zb:{if(!ea){break zb}v[23220]=0;c=Q(1,e+192|0,16314)|0;b=v[23220];v[23220]=0;Ab:{if((b|0)!=1){b=v[a+1298464>>2];v[23220]=0;U(360,b|0,2,c|0);b=v[23220];v[23220]=0;if((b|0)==1){break Ab}vb(c);break zb}i=P()|0;O()|0;break f}i=P()|0;O()|0;vb(c);break f}j=21598;Bb:{Cb:{switch(aa-48|0){case 0:j=x[a+480188>>1]>4?17209:17195;break Bb;case 1:j=17177;break Bb;case 2:j=17159;break Bb;case 3:break Cb;default:break Bb}}j=17132}v[23220]=0;R(493,e+80|0,16747);b=v[23220];v[23220]=0;Db:{Eb:{Fb:{if((b|0)!=1){v[23220]=0;U(494,e+120|0,e+80|0,e+919|0);b=v[23220];v[23220]=0;if((b|0)==1){break Fb}b=e+120|0;Db(a+1298344|0,b);vb(b);bc(e+80|0);v[23220]=0;c=Q(1,b|0,12612)|0;b=v[23220];v[23220]=0;if((b|0)==1){break Eb}Db(a+1298356|0,c);vb(c);v[23220]=0;Q(123,a+1298368|0,j|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break Db}v[a+1298404>>2]=13;f=1;break c}i=P()|0;O()|0;break f}i=P()|0;O()|0;bc(e+80|0);break f}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}c=c+1|0;continue}}i=P()|0;O()|0;break f}i=P()|0;O()|0;wb(V)}ub(N);break w}i=P()|0;O()|0;break w}i=P()|0;O()|0;break w}i=P()|0;O()|0}Ft(E);break f}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}A=1;if((f|0)!=7){break m}d=y+108|0;f=lR(d);while(1){if((d|0)!=(f|0)){fa=d,ga=ho(w[d|0]-24|0),t[fa|0]=ga;d=d+1|0;continue}break}g=0}F=1;break l}g=0;Gb:{if(p|(z|0)<0){break Gb}m=y+108|0;j=7;Hb:while(1){if((j|0)==10){break Gb}k=B(j,12);h=B(j,-12)+72|0;d=0;while(1)if((d|0)==12){j=j+1|0;continue Hb}else{f=Hb(m,d+k|0);t[f|0]=h+w[f|0];d=d+1|0;continue}}}}v[23220]=0;R(495,_|0,e+192|0);d=v[23220];v[23220]=0;if((d|0)!=1){Ib:{d=w[e+196|0];if((d-1&255)>>>0<=15){t[y+31|0]=d;F=1}d=w[e+197|0];if((d<<24)-16777216>>24>=0){t[y+30|0]=d}d=0;Jb:{while(1){if((d|0)==(A|0)){if(!o){break j}if((z|0)>=0){break Jb}break j}v[23220]=0;h=B(d+q|0,104)+a|0;R(267,h+484380|0,8);f=v[23220];v[23220]=0;if((f|0)!=1){t[e+120|0]=w[e+198|0];t[e+56|0]=64;fa=h+484410|0,ga=w[Rb(e+120|0,e+56|0)|0]<<2,u[fa>>1]=ga;t[h+484416|0]=w[e+199|0];d=d+1|0;continue}break}break k}m=Uc(e+120|0,8,1,1,0);h=Jb(x[e+194>>1]);i=Jb(x[e+192>>1]);d=v[D>>2];v[23220]=0;j=T(147,d|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){d=Jb(x[e+84>>1]);if(d&16){Eh(m,16);j=j>>>1|0}if(d&32){so(m,3);j=j>>>1|0}if(d&64){Qf(m,2)}j=g?(j>>>0)/((-1<<A^-1)>>>0)|0:j;g=h+i|0;d=0;while(1){if((d|0)==(A|0)){break j}k=B(d+q|0,104)+a|0;f=k+484380|0;v[f>>2]=j;v[23220]=0;W(206,m|0,f|0,D|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break Ib}i=i<<1;g=g<<1;if(h>>>0>=2){v[k+484388>>2]=g;v[k+484384>>2]=i;f=k+484414|0;u[f>>1]=x[f>>1]|2}d=d+1|0;j=j<<1;continue}}}}}i=P()|0;O()|0;wb(D);break f}wb(D);C=C+1|0;s=s+A|0;j=x[a+480192>>1];continue}}i=P()|0;O()|0;break e}i=P()|0;O()|0;break e}i=P()|0;O()|0}lc(K)}wb(_);S(i|0);L()}f=0}d=f;lc(K)}wb(_)}fb=e+976|0;return d|0}function vda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,D=C(0),E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=C(0),ha=0,ia=0,ja=0,ka=0,la=0,ma=0;e=fb-672|0;fb=e;wc(b);a:{b:{c:{if(!Xh(b,e+664|0)){break c}if(!NP(e+664|0)){break c}if((km(b)|0)>=0){break c}if(!c){d=1;break c}zd(a,16777216);v[a+480208>>2]=v[a+480208>>2]|1681e4;Iz(e+272|0,32);g=v[e+284>>2];d=a+1074320|0;v[d>>2]=v[e+280>>2];v[d+4>>2]=g;d=v[e+276>>2];v[a+1074312>>2]=v[e+272>>2];v[a+1074316>>2]=d;zf(a+1074312|0,38);p=Ib(e+648|0);q=Ib(e+632|0);s=Ib(e+616|0);l=Ib(e+600|0);jg(b,4);m=a+480190|0;J=c&1;I=a+1298332|0;r=2500;H=!(c&2);F=a+1298464|0;d:{e:{f:{while(1){c=v[b+8>>2];d=v[b>>2];v[23220]=0;c=W(143,d|0,c|0,4)|0;d=v[23220];v[23220]=0;g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){n:{if(c){v[23220]=0;c=T(647,b|0)|0;d=v[23220];v[23220]=0;o:{if((d|0)==1){break o}j=4;d=0;p:{q:{r:{switch(c+21|0){case 20:v[23220]=0;c=T(269,b|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){d=c&65535;if(x[a+480188>>1]|d-1>>>0>126){continue}u[a+480188>>1]=c;la=a,ma=Ub(512/(d>>>0)|0,16,128),v[la+480228>>2]=ma;continue}c=P()|0;O()|0;break a;case 19:v[23220]=0;K=T(269,b|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break o}if(K>>>0<=1024){continue}break m;case 16:v[23220]=0;c=T(269,b|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){if((c&65535)==4){continue}break m}c=P()|0;O()|0;break a;case 15:v[23220]=0;c=T(269,b|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){v[e+272>>2]=c;v[e+168>>2]=800;la=a,ma=Ee(+y[Eb(e+272|0,e+168|0)>>2]*1.24*1e4),v[la+480204>>2]=ma;continue}c=P()|0;O()|0;break a;case 31:v[23220]=0;c=T(269,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break o}Z=1;r=Pd(c,0,1e4);continue;case 32:case 33:v[23220]=0;c=T(269,b|0)|0;d=v[23220];v[23220]=0;s:{t:{if((d|0)!=1){Z=1;if(!c){continue}v[23220]=0;d=Q(1,e+584|0,12521)|0;c=v[23220];v[23220]=0;if((c|0)==1){break t}c=v[F>>2];v[23220]=0;U(360,c|0,2,d|0);c=v[23220];v[23220]=0;if((c|0)==1){break s}vb(d);continue}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d);break a;case 14:v[23220]=0;Q(175,b|0,4)|0;c=v[23220];v[23220]=0;if((c|0)==1){break o}i=!x[m>>1]|i;continue;case 11:if(!J){break q}if(!rc(v[p>>2],v[p+4>>2])){break q}v[23220]=0;R(648,e+272|0,b|0);c=v[23220];v[23220]=0;if((c|0)!=1){if(v[p>>2]){Bc(p);c=v[p>>2];Xn(p);Fb(c);la=Cb(p),ma=0,v[la>>2]=ma;v[p>>2]=0;v[p+4>>2]=0}c=e+272|0;v[p>>2]=v[c>>2];v[p+4>>2]=v[c+4>>2];d=Cb(c);la=Cb(p),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;ti(c);continue}c=P()|0;O()|0;break a;case 3:case 4:case 10:g=mh(v[l>>2],v[l+4>>2]);d=x[m>>1];if(g>>>0<=d>>>0){continue}if((i|H)&1){break q}if(!Ph(d)){break q}d=d+1|0;u[m>>1]=d;A=Ib(e+568|0);v[23220]=0;i=T(161,e+544|0)|0;g=v[23220];v[23220]=0;u:{v:{w:{if((g|0)!=1){if((c|0)==-17){break w}if((c|0)!=-11){break v}v[23220]=0;c=T(269,b|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break u}v[23220]=0;U(177,e+168|0,b|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break u}c=e+168|0;g=gc(e+272|0,c);Yc(i,g);wb(g);break g}c=P()|0;O()|0;break d}v[23220]=0;R(649,e+272|0,b|0);c=v[23220];v[23220]=0;x:{if((c|0)!=1){c=e+272|0;g=hm(A,c);$b(c);ge(e+512|0,v[g>>2],v[e+572>>2]);c=v[Xd(e+504|0)>>2];v[23220]=0;c=ga(319,e+520|0,v[e+512>>2],v[e+516>>2],c|0,v[e+508>>2])|0;g=v[23220];v[23220]=0;if((g|0)==1){break x}Yc(i,c);break g}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}v[23220]=0;R(650,e+272|0,b|0);c=v[23220];v[23220]=0;y:{if((c|0)!=1){c=e+272|0;g=hm(A,c);$b(c);ge(e+472|0,v[g>>2],v[e+572>>2]);c=v[Xd(e+464|0)>>2];v[23220]=0;c=ga(319,e+480|0,v[e+472>>2],v[e+476>>2],c|0,v[e+468>>2])|0;g=v[23220];v[23220]=0;if((g|0)==1){break y}Yc(i,c);break g}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e;case 9:c=x[m>>1];if(!Ph(c)){continue}u[m>>1]=c+1;continue;case 8:if(!J){break q}if(!rc(v[s>>2],v[s+4>>2])){break q}v[23220]=0;R(651,e+272|0,b|0);c=v[23220];v[23220]=0;if((c|0)!=1){c=e+272|0;MP(s,c);lc(c);continue}c=P()|0;O()|0;break a;case 7:if(!rc(v[l>>2],v[l+4>>2])){break q}v[23220]=0;R(652,e+272|0,b|0);c=v[23220];v[23220]=0;if((c|0)!=1){if(v[l>>2]){Bc(l);c=v[l>>2];Az(l);Fb(c);la=Cb(l),ma=0,v[la>>2]=ma;v[l>>2]=0;v[l+4>>2]=0}c=e+272|0;v[l>>2]=v[c>>2];v[l+4>>2]=v[c+4>>2];d=Cb(c);la=Cb(l),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;qt(c);continue}c=P()|0;O()|0;break a;case 6:if(!J){break q}if(!rc(v[q>>2],v[q+4>>2])){break q}v[23220]=0;R(653,e+272|0,b|0);c=v[23220];v[23220]=0;if((c|0)!=1){if(v[q>>2]){Bc(q);c=v[q>>2];fr(q);Fb(c);la=Cb(q),ma=0,v[la>>2]=ma;v[q>>2]=0;v[q+4>>2]=0}c=e+272|0;v[q>>2]=v[c>>2];v[q+4>>2]=v[c+4>>2];d=Cb(c);la=Cb(q),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Yj(c);continue}c=P()|0;O()|0;break a;case 17:case 18:break p;case 0:case 1:case 2:break q;case 5:break r;default:break m}}v[23220]=0;R(654,e+272|0,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break n}z:{c=v[e+272>>2];d=v[e+276>>2];if(rc(c,d)){break z}v[23220]=0;X(328,I|0,c|0,Wc(c,d)|0,1);c=v[23220];v[23220]=0;if((c|0)!=1){break z}c=P()|0;O()|0;$b(e+272|0);break a}$b(e+272|0);continue}v[23220]=0;j=T(269,b|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break o}}v[23220]=0;Q(175,b|0,j|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){continue}}c=P()|0;O()|0;break a}d=0;if(!x[a+480188>>1]|!K){break m}b=v[l>>2];c=v[l+4>>2];if(rc(b,c)){break m}if(J){if(rc(v[p>>2],v[p+4>>2])){break m}if(rc(v[s>>2],v[s+4>>2])){break m}if(rc(v[q>>2],v[q+4>>2])){break m}}b=mh(b,c);if(b>>>0>=256){v[23220]=0;R(655,l|0,255);b=v[23220];v[23220]=0;if((b|0)==1){break b}b=mh(v[l>>2],v[l+4>>2])}u[a+480192>>1]=b;h=a+480192|0;la=a,ma=x[Re(m,h)>>1],u[la+480190>>1]=ma;if(i&1){v[23220]=0;b=Q(1,e+568|0,16403)|0;c=v[23220];v[23220]=0;if((c|0)==1){break h}c=v[a+1298464>>2];v[23220]=0;U(360,c|0,2,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break i}vb(b)}i=0;A:while(1){if((i|0)!=2){d=1;while(1){f=d&65535;if(f>>>0>x[h>>1]){i=i+1|0;continue A}B:{g=Zl(v[l>>2],f-1|0);if(!w[g|0]|t[g+128|0]<0){break B}if((ot(g)|0)==((i|0)!=1|0)){break B}C:{D:{E:{c=0;F:{if(!ot(g)){break F}if(Jb(w[g+6|0]|w[g+7|0]<<8)){break F}if(Jb(w[g+14|0]|w[g+15|0]<<8)>>>0>20){break F}c=(Jb(w[g+18|0]|w[g+19|0]<<8)|0)==4}G:{H:{if(c){c=w[g+23|0];b=w[g+140|0];v[23220]=0;b=ga(656,g|0,a|0,(b&2)>>>1|0,(B(f,104)+a|0)+484380|0,r&65535)|0;j=v[23220];v[23220]=0;I:{J:{if((j|0)!=1){if(!b){break I}v[23220]=0;b=Q(52,e+400|0,10687)|0;j=v[23220];v[23220]=0;if((j|0)==1){break J}yc(((f<<5)+a|0)+946304|0,b);ub(b);j=v[l>>2];b=d;if(mh(j,v[l+4>>2])>>>0<=c>>>0){break G}la=g,ma=w[g+143|0]+w[Zl(j,c)+143|0]|0,t[la+143|0]=ma;break H}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}b=c+1|0;break G}c=0;K:{if(!ot(g)){break K}if((Jb(w[g+6|0]|w[g+7|0]<<8)|0)!=1){break K}if((Jb(w[g+14|0]|w[g+15|0]<<8)|0)!=2){break K}c=(Jb(w[g+18|0]|w[g+19|0]<<8)|0)==10}b=d;if(!c){break G}nc(e+272|0,g,128);b=Jb(x[e+292>>1]);if(b>>>0>=x[m>>1]){break H}v[23220]=0;c=T(645,e+168|0)|0;j=v[23220];v[23220]=0;if((j|0)==1){break E}j=x[e+308>>1];n=x[a+480190>>1];v[23220]=0;o=B(b,104);b=a+484380|0;j=Jb(j);b=fa(657,e+272|0,(o+b|0)+104|0,(j>>>0<n>>>0?(b+B(j,104)|0)+104|0:c)|0,b+B(f,104)|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break D}if(!b){break H}v[23220]=0;b=Q(52,e+152|0,11227)|0;c=v[23220];v[23220]=0;if((c|0)==1){break C}yc(((f<<5)+a|0)+946304|0,b);ub(b);t[g+139|0]=w[g+139|0]+12}b=d}v[23220]=0;b=b&65535;c=W(241,a|0,f|0,b|0)|0;f=v[23220];v[23220]=0;if((f|0)!=1){if(!c|b>>>0>x[m>>1]){break B}v[23220]=0;X(658,g|0,c|0,(B(b,104)+a|0)+484380|0,a|0);b=v[23220];v[23220]=0;if((b|0)!=1){break B}}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}d=d+1|0;continue}}break}I=eg(e+136|0);A=eg(e+120|0);b=sc(v[s>>2],v[s+4>>2]);_=B(x[a+480188>>1],K);$=fu((b>>>0)/(_>>>0)|0);v[23220]=0;N=a+484344|0;R(212,N|0,$|0);b=v[23220];v[23220]=0;if((b|0)==1){break k}aa=a+484376|0;Bc(Vb(v[a+484360>>2],w[aa|0]));b=x[a+480188>>1];v[23220]=0;F=Q(659,e+104|0,b|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break l}la=e,ma=Ab(v[q>>2]),v[la+48>>2]=ma;ha=a+902204|0;ia=Ab(v[q+4>>2]);ja=a+480208|0;while(1){L:{M:{N:{n=v[e+48>>2];if(!Nb(n,ia)){break N}b=Jb(w[n+6|0]|w[n+7|0]<<8);if((b|0)==1){break L}if((b|0)==65535){break N}g=Jb(w[n|0]|w[n+1|0]<<8);b=v[p>>2];f=v[p+4>>2];c=dg(b,f);if(g>>>0>=c>>>0){break L}d=Jb(w[n+2|0]|w[n+3|0]<<8);if(d>>>0>c>>>0|!d|g>>>0>c-d>>>0){break L}c=b+(dg(b,f)<<5)|0;v[e+272>>2]=b;v[e+276>>2]=c-b>>5;b=v[e+272>>2];cc(e+80|0,b+(Jb(w[n|0]|w[n+1|0]<<8)<<5)|0,Jb(w[n+2|0]|w[n+3|0]<<8));O:{H=Vb(v[a+484360>>2],w[aa|0]);if(rc(v[H>>2],v[H+4>>2])){break O}v[23220]=0;R(480,H|0,65534);b=v[23220];v[23220]=0;if((b|0)!=1){break O}break M}b=v[e+80>>2];ka=le(b,v[e+84>>2]);while(1){if((b|0)==(ka|0)){break L}c=Jb(Jb(w[n+8|0]|w[n+9|0]<<8)+Jb(w[b+16|0]|w[b+17|0]<<8)&65535);t[b+16|0]=c;t[b+17|0]=c>>>8;g=b;b=Od(I);while(1){P:{c=0;if(!b){break P}d=b+14|0;if(!lt(g,d)){c=1;if(!lt(d,g)){break P}b=b+4|0}b=v[b>>2];continue}break}Q:{R:{S:{if(c){v[23220]=0;b=Q(660,I|0,g|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break M}E=x[b>>1];break S}E=0;if(!J){break S}b=w[g+12|0]|w[g+13|0]<<8;v[23220]=0;E=Q(352,N|0,Jb(b)|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break M}if((E|0)==65535){break L}v[23220]=0;b=Q(660,I|0,g|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break M}u[b>>1]=E;if(Jb(w[g+8|0]|w[g+9|0]<<8)>>>0>=$>>>0){break R}if(Jb(w[g+10|0]|w[g+11|0]<<8)>>>0>=K>>>0){break R}m=Jb(w[g+14|0]|w[g+15|0]<<8);c=Yl(Ab(v[s>>2]),B(Jb(w[g+8|0]|w[g+9|0]<<8),_));b=x[a+480188>>1];la=e,ma=Yl(c,B(b,Jb(w[g+10|0]|w[g+11|0]<<8))),v[la+32>>2]=ma;M=0;v[e+16>>2]=0;o=Rh(e- -64|0);T:while(1){U:{d=Jb(w[g+12|0]|w[g+13|0]<<8);c=Xb(v[N>>2],E);if(d>>>0<=M>>>0){break U}j=0;V=$c(v[c>>2],v[v[c+48>>2]+12>>2],M,0);c=0;while(1){if((b&65535)>>>0<=j>>>0){M=M+1|0;continue T}b=Ab(v[s+4>>2]);d=v[e+32>>2];h=Nb(d,b)?d:e+16|0;b=Ab(v[s+4>>2]);if(Nb(v[e+32>>2],b)){KP(e+32|0)}d=B(j,6)+V|0;f=w[h+1|0];b=(f>>>0<85?f+25|0:-1)<<24>>24;r=0;i=v[l>>2];ba=mh(i,v[l+4>>2]);G=w[h+3|0];V:{if(ba>>>0<=G>>>0){break V}r=G+1|0;if(t[Zl(i,G)+142|0]&1|(b|0)<0){break V}b=Jb(w[g+16|0]|w[g+17|0]<<8)+b<<24>>24;b=(b|0)<120?b:120;b=((b|0)>1?b:1)&255}W:{if(!w[d|0]|!(w[h+2|0]?1:G|(w[h|0]|(f|0)!=255))){break W}f=w[d+1|0];if(!f|f>>>0>ba>>>0){break W}if(w[Zl(i,f-1|0)+132|0]!=2){break W}Vn(d)}f=rt(v[F>>2],j);X:{Y:{if(c&1){c=w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24);t[d|0]=c;t[d+1|0]=c>>>8;t[d+2|0]=c>>>16;t[d+3|0]=c>>>24;c=w[o+4|0]|w[o+5|0]<<8;t[d+4|0]=c;t[d+5|0]=c>>>8;Z:{if(w[d+3|0]){break Z}i=w[f+21|0];c=w[rt(v[F>>2],j-1|0)+21|0];if((i|0)==(c|0)){break Z}t[d+3|0]=21;t[f+21|0]=c;t[d+5|0]=c}c=0;i=w[h|0];if(i-24>>>0<2|(i|0)==9|!i&(w[h+2|0]+7&255)>>>0<2){break Y}break X}i=w[h|0]}_:{$:{aa:{ba:{ca:{da:{switch(i|0){case 5:c=w[f+17|0];break ca;case 0:ea:{c=w[h+2|0];if(c>>>0>=201){i=0;fa:{switch(c-242|0){case 11:t[d+4|0]=1;t[d+2|0]=14;t[f+16|0]=0;break $;case 9:if(!w[d|0]){t[d|0]=w[f+17|0]}t[d+4|0]=1;t[d+2|0]=15;break $;case 8:if((m&255)>>>0<2){break $}m=m-1|0;break aa;case 7:if((m&255)==255){m=255;break $}m=m+1|0;break aa;case 6:t[f+17|0]=b;if(w[f+18|0]!=(r&255)){break $}t[d|0]=b;t[d+5|0]=255;t[d+3|0]=4;u[f+32>>1]=0;v[f+8>>2]=0;break $;case 5:t[d+5|0]=242;t[d+3|0]=2;break $;case 4:t[d+5|0]=242;t[d+3|0]=3;break $;case 3:t[d+5|0]=244;t[d+3|0]=2;break $;case 2:t[d+5|0]=244;t[d+3|0]=3;break $;case 1:t[d+5|0]=248;t[d+3|0]=2;break $;case 12:break ea;case 0:break fa;default:break $}}t[d+5|0]=248;t[d+3|0]=3;break $}ga:{if(t[h+1|0]<0){i=0;if(c>>>0<100){break ga}break $}t[f+17|0]=b;t[d|0]=b;t[f+18|0]=r;t[d+1|0]=r;u[f+32>>1]=0;v[f+8>>2]=0;c=w[h+2|0]}b=c&255;if(!b){i=0;break $}la=f,ma=Yn(+(b>>>0)*.64),t[la+19|0]=ma;k=z[f>>2];v[f>>2]=0;i=k!=C(0);break $}t[d+4|0]=0;t[d+2|0]=14;t[f+16|0]=1;break $;case 1:v[f+4>>2]=0;z[f>>2]=C(w[h+2|0])*C(.0333000011742115);break _;case 2:v[f+4>>2]=0;z[f>>2]=C(w[h+2|0])*C(-.0333000011742115);break _;case 12:t[e+272|0]=15;t[e+100|0]=w[h+3|0]>>>3;b=w[Rb(e+272|0,e+100|0)|0];t[e+272|0]=15;t[e+100|0]=w[h+2|0]>>>3;la=f,ma=w[Rb(e+272|0,e+100|0)|0]|b<<4,t[la+24|0]=ma;break _;case 3:v[f+12>>2]=0;b=w[h+2|0];u[f+32>>1]=0;z[f+8>>2]=C(b>>>0)*C(.0333000011742115);break _;case 4:v[f+12>>2]=0;b=w[h+2|0];u[f+32>>1]=0;z[f+8>>2]=C(b>>>0)*C(-.0333000011742115);break _;case 15:if(!w[h+2|0]|(b|0)<0){break _}i=b-w[f+17|0]|0;c=i>>31;c=(c^i<<5)-c|0;v[e+272>>2]=c;t[f+17|0]=b;v[f+8>>2]=0;t[d|0]=b;t[d+3|0]=4;b=vi((c>>>0)/(w[h+2|0]<<1>>>0)|0);t[d+5|0]=b;t[f+27|0]=b;v[e+100>>2]=B(b,(m&255)-1|0);la=f,ma=c-v[nd(e+272|0,e+100|0)>>2]|0,u[la+32>>1]=ma;break _;case 10:case 11:t[d+3|0]=0;t[d+5|0]=0;break _;case 13:t[e+272|0]=15;t[e+100|0]=w[h+3|0]>>>3;b=w[Rb(e+272|0,e+100|0)|0];t[e+272|0]=15;t[e+100|0]=w[h+2|0];la=f,ma=w[Rb(e+272|0,e+100|0)|0]|b<<4,t[la+23|0]=ma;break _;case 18:b=w[h+2|0]+w[f+17|0]&255;b=b?b>>>0<120?b:120:1;t[f+17|0]=b;t[d|0]=b;t[d+5|0]=255;t[d+3|0]=4;break ba;case 23:case 24:case 25:b=Od(A);while(1){ha:{c=0;if(!b){break ha}i=b+13|0;if(!mt(h,i)){c=1;if(!mt(i,h)){break ha}b=b+4|0}b=v[b>>2];continue}break};if(c){t[d+3|0]=31;v[23220]=0;b=Q(661,A|0,h|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break M}t[d+5|0]=w[b|0];break _}b=v[Cb(A)>>2];if(b>>>0>127){break _}v[e+96>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);c=v[ja>>2];v[23220]=0;v[e+12>>2]=v[e+96>>2];c=W(662,e+12|0,le(ha,b&255)|0,c|0)|0;i=v[23220];v[23220]=0;ia:{if((i|0)==1){break ia}if(!c){break _}t[d+3|0]=31;v[23220]=0;c=Q(661,A|0,h|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break ia}b=b|-128;t[c|0]=b;t[d+5|0]=b;ca=(w[h|0]&254)==24|ca;break _}break M;case 16:if(!w[h+2|0]){break _}t[d+3|0]=15;v[e+272>>2]=15;v[e+100>>2]=w[h+3|0]+1;la=d,ma=v[nd(e+272|0,e+100|0)>>2],t[la+5|0]=ma;u[f+30>>1]=B(w[h+2|0],w[h+3|0]+1|0);break _;case 9:t[d+3|0]=16;b=w[h+2|0];m=b?b:4;t[d+5|0]=m;break _;case 19:ja:{ka:{switch(w[h+1|0]){case 0:b=128;break ja;case 4:break ka;default:break _}}b=w[h+3|0]}t[e+95|0]=b;t[e+272|0]=w[h+2|0];t[e+100|0]=100;c=e+272|0;r=e+100|0;i=w[Rb(c,r)|0];v[e+272>>2]=128;v[e+100>>2]=256-(b&255);b=v[nd(c,r)>>2];t[e+272|0]=128;c=w[Rb(c,e+95|0)|0];b=(B(b,i)|0)/128|0;r=b&255;if((r|0)!=w[f+20|0]){t[f+20|0]=b;t[d+3|0]=21;b=Pc(((B(r,w[f+19|0])+50&65535)>>>0)/100|0,0);t[f+21|0]=b;t[d+5|0]=b}if(w[h+1|0]!=4|(x[a+480188>>1]-1|0)<=(j|0)){break _}b=j+1|0;h=rt(v[F>>2],b);c=B(c,i)>>>7|0;if(w[h+20|0]==(c&255)){break _}t[h+20|0]=c;b=B(b,6)+V|0;t[b+3|0]=21;c=Pc(((B(w[f+20|0],w[f+19|0])+50&65535)>>>0)/100|0,0);t[f+21|0]=c;t[b+5|0]=c;break _;case 17:case 20:t[d+3|0]=0;break _;case 7:b=w[h+2|0];t[f+25|0]=0;t[f+26|0]=0;t[f+22|0]=b;break _;case 8:t[f+22|0]=w[f+22|0]+w[h+2|0];break _;case 14:t[f+25|0]=w[h+3|0];t[f+26|0]=w[h+2|0];break _;case 6:break da;default:break _}}t[f+18|0]=r;t[f+17|0]=b;t[d+1|0]=r;c=b}t[d|0]=c;if((b|0)>=0){t[f+18|0]=r;t[d+1|0]=r}if(w[h|0]==5){t[d+4|0]=1;t[d+2|0]=11}c=w[f+22|0];b=w[f+26|0];if(!(b?1:c|w[h+2|0])){break ba}if(b){da=(qi(+x[f+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{da=0}t[d+3|0]=44;la=d,ma=Yn(da+ +(c+w[h+2|0]|0)),t[la+5|0]=ma}u[f+32>>1]=0;break _}t[d+5|0]=m;t[d+3|0]=16}b=Pc(((B(w[f+20|0],w[f+19|0])+50&65535)>>>0)/100|0,0);if(!(!i&w[f+21|0]==(b&255))){t[f+21|0]=b;t[d+5|0]=b;t[d+3|0]=21}if(j&1|t[h+1|0]<=0|(x[a+480188>>1]-1|0)<=(j|0)){break _}b=v[l>>2];if(mh(b,v[l+4>>2])>>>0<=G>>>0){break _}if(w[Zl(b,G)+132|0]!=1){break _}h=j+1|0;b=B(h,6)+V|0;c=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[b|0]=c;t[b+1|0]=c>>>8;t[b+2|0]=c>>>16;t[b+3|0]=c>>>24;c=w[d+4|0]|w[d+5|0]<<8;t[b+4|0]=c;t[b+5|0]=c>>>8;t[b+1|0]=w[b+1|0]+1;b=rt(v[F>>2],h);t[b+19|0]=w[f+19|0];z[b>>2]=z[f>>2];z[b+4>>2]=z[f+4>>2];z[b+8>>2]=z[f+8>>2];z[b+12>>2]=z[f+12>>2];u[b+30>>1]=x[f+30>>1]}la:{if(w[d|0]){t[f+16|0]=0;break la}c=0;if(w[f+16|0]){break X}}ma:{if(!x[f+30>>1]){break ma}b=m&255;u[e+272>>1]=b;c=f+30|0;la=c,ma=x[Re(c,e+272|0)>>1]-b|0,u[la>>1]=ma;if(w[d+3|0]){break ma}t[d+3|0]=15;t[d+5|0]=0}k=z[f>>2];na:{if(k==C(0)){break na}b=m&255;k=C(C(k*C(b>>>0))+z[f+4>>2]);z[f+4>>2]=k;if(w[d+3|0]){break na}oa:{pa:{qa:{ra:{if(b>>>0>=2){h=b-1|0;D=C(h|0);if(!(D<=k)){break ra}t[e+272|0]=15;la=e,ma=Og(C(k/D)),t[la+100|0]=ma;b=w[Rb(e+272|0,e+100|0)|0];z[f+4>>2]=k-C(B(b,h)|0);t[d+3|0]=22;c=b<<4;break oa}if(!(k>=C(1))){break qa}break pa}if(k>=C(1)){break pa}if(!(k<=C(1-b|0))){break qa}t[e+272|0]=15;la=e,ma=Og(C(C(-k)/D)),t[la+100|0]=ma;c=w[Rb(e+272|0,e+100|0)|0];z[f+4>>2]=k+C(B(h,c)|0);t[d+3|0]=22;break oa}if(!(k<=C(-1))){break na}t[e+272|0]=14;la=e,ma=Og(C(-k)),t[la+100|0]=ma;b=w[Rb(e+272|0,e+100|0)|0];z[f+4>>2]=k+C(b>>>0);t[d+3|0]=22;c=b|-16;break oa}t[e+272|0]=15;la=e,ma=Og(k),t[la+100|0]=ma;b=w[Rb(e+272|0,e+100|0)|0];z[f+4>>2]=k-C(b>>>0);t[d+3|0]=22;c=b<<4|15}t[d+5|0]=c}k=z[f+8>>2];sa:{if(k==C(0)){break sa}b=m&255;k=C(C(k*C(b>>>0))+z[f+12>>2]);z[f+12>>2]=k;ta:{if(!w[d+3|0]){ua:{va:{if(b>>>0>=2){c=b-1|0;D=C(c|0);if(!(D<=k)){break va}t[e+272|0]=223;la=e,ma=Og(C(k/D)),t[la+100|0]=ma;b=w[Rb(e+272|0,e+100|0)|0];z[f+12>>2]=k-C(B(b,c)|0);t[d+3|0]=2;t[d+5|0]=b;break sa}if(!(k>=C(1))){break ua}break ta}if(k>=C(1)){break ta}if(!(k<=C(1-b|0))){break ua}t[e+272|0]=223;la=e,ma=Og(C(C(-k)/D)),t[la+100|0]=ma;b=w[Rb(e+272|0,e+100|0)|0];z[f+12>>2]=k+C(B(b,c)|0);t[d+3|0]=3;t[d+5|0]=b;break sa}if(!(k<=C(-1))){break sa}t[e+272|0]=14;la=e,ma=Og(C(-k)),t[la+100|0]=ma;b=w[Rb(e+272|0,e+100|0)|0];z[f+12>>2]=k+C(b>>>0);t[d+3|0]=3;t[d+5|0]=b|240;break sa}if(w[d+2|0]|b>>>0<2){break sa}ea=C(k*C(.25));c=b-1|0;D=C(c|0);if(ea>=D){t[e+272|0]=9;la=e,ma=Og(C(k/D))>>>2|0,t[la+100|0]=ma;b=w[Rb(e+272|0,e+100|0)|0];z[f+12>>2]=k-C(B(b,c)<<2);t[d+2|0]=12;t[d+4|0]=b;break sa}if(!(C(1-b|0)>=ea)){break sa}t[e+272|0]=9;la=e,ma=Og(C(C(-k)/D))>>>2|0,t[la+100|0]=ma;b=w[Rb(e+272|0,e+100|0)|0];z[f+12>>2]=k+C(B(b,c)<<2);t[d+2|0]=13;t[d+4|0]=b;break sa}t[e+272|0]=15;la=e,ma=Og(k),t[la+100|0]=ma;b=w[Rb(e+272|0,e+100|0)|0];z[f+12>>2]=k-C(b>>>0);t[d+3|0]=2;t[d+5|0]=b|240}wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{b=w[d+3|0];switch(b|0){case 4:break wa;case 0:break Ca;default:break Ba}}Da:{b=w[f+23|0];if(!b){b=w[f+24|0];if(b){break Da}if(!x[f+32>>1]){break wa}c=f+32|0;break Aa}t[d+3|0]=5;t[d+5|0]=b;if(!x[f+32>>1]){break wa}break za}t[d+3|0]=8;t[d+5|0]=b;if(x[f+32>>1]){break za}break wa}if(!x[f+32>>1]){break wa}c=f+32|0;if(b){break ya}}t[d+3|0]=4;break xa}c=f+32|0}t[d+2|0]=11}u[e+272>>1]=B(w[f+27|0],(m&255)-1|0);la=f,ma=x[f+32>>1]-x[Tc(c,e+272|0)>>1]|0,u[la+32>>1]=ma}u[f+28>>1]=x[f+28>>1]+B(w[f+25|0],m&255)&1023;c=0;if(j&1){break X}b=w[f+18|0];if(!b){break X}f=v[l>>2];if(mh(f,v[l+4>>2])>>>0<b>>>0){break X}f=Zl(f,b-1|0);if(!(w[f+142|0]&4)){break X}b=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[o|0]=b;t[o+1|0]=b>>>8;t[o+2|0]=b>>>16;t[o+3|0]=b>>>24;b=w[d+4|0]|w[d+5|0]<<8;t[o+4|0]=b;t[o+5|0]=b>>>8;c=1;b=w[e+65|0];if(!b|w[f+132|0]!=1){break X}t[e+65|0]=b+1}j=j+1|0;b=x[a+480188>>1];continue}}break}me(c,uh(He(Be(e+272|0,16,Jb(w[g+14|0]|w[g+15|0]<<8)&255),0)))}b=al(v[H>>2],v[H+4>>2]);la=e,ma=Jb(w[g+4|0]|w[g+5|0]<<8),u[la+272>>1]=ma;u[e+64>>1]=1;c=x[Re(e+272|0,e- -64|0)>>1];v[23220]=0;X(663,H|0,b|0,c|0,E&65535);b=v[23220];v[23220]=0;if((b|0)==1){break Q}b=Jb(w[n+8|0]|w[n+9|0]<<8);b=Jb(Jb(w[g+16|0]|w[g+17|0]<<8)-b&65535);t[g+16|0]=b;t[g+17|0]=b>>>8}b=g+32|0;continue}break}break M}d=ca&1;if(d){v[23220]=0;b=a+906300|0;Y(274,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break M}v[b+16>>2]=1299020115;v[b+20>>2]=1869112133;v[b+24>>2]=655376;v[b+28>>2]=0;v[e+272>>2]=0;g=b+48|0;c=e+272|0;sB(b+32|0,g,c);v[23220]=0;c=Q(52,c|0,9527)|0;f=v[23220];v[23220]=0;if((f|0)==1){break M}lu(g,c);ub(c);v[23220]=0;c=Q(52,e+80|0,9520)|0;g=v[23220];v[23220]=0;if((g|0)==1){break M}pq(b+80|0,c);ub(c);v[23220]=0;b=Q(52,e- -64|0,9512)|0;c=v[23220];v[23220]=0;if((c|0)==1){break M}lu(a+906508|0,b);ub(b)}b=0;while(1){if(x[a+480188>>1]>b>>>0){bB(a,b&65535);c=(b<<5)+a|0;t[c+480288|0]=d;u[c+480284>>1]=b<<8&256;b=b+1|0;continue}break}v[23220]=0;b=Q(1,e+48|0,12071)|0;c=v[23220];v[23220]=0;Ea:{Fa:{Ga:{if((c|0)!=1){Db(a+1298344|0,b);vb(b);v[23220]=0;b=Q(1,e+32|0,12289)|0;c=v[23220];v[23220]=0;if((c|0)==1){break M}Db(a+1298356|0,b);vb(b);if(Z){break Ga}v[23220]=0;b=Q(1,e+16|0,12071)|0;c=v[23220];v[23220]=0;if((c|0)==1){break M}break Fa}break M}if(mh(v[l>>2],v[l+4>>2])>>>0<=128){v[23220]=0;b=Q(1,e+16|0,9269)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break Fa}break M}v[23220]=0;b=Q(1,e+16|0,14772)|0;c=v[23220];v[23220]=0;if((c|0)==1){break Ea}}Db(a+1298368|0,b);vb(b);v[a+1298404>>2]=13;Fz(F);BP(A);AP(I);d=1;break m}}c=P()|0;O()|0;Fz(F);break j}Un(e+48|0);continue}}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}qt(l);lc(s);Yj(q);ti(p);break c}c=P()|0;O()|0;break j}c=P()|0;O()|0}BP(A);AP(I);break a}c=P()|0;O()|0;vb(b);break a}c=P()|0;O()|0;break a}wb(c);v[23220]=0;c=d&65535;d=W(664,a|0,c|0,i|0)|0;g=v[23220];v[23220]=0;Ha:{Ia:{Ja:{Ka:{if((g|0)==1){break Ka}if(d){break Ha}v[23220]=0;d=W(665,a|0,c|0,i|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break Ka}if(d){break Ha}v[23220]=0;d=W(666,a|0,c|0,i|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break Ka}if(d){break Ha}v[23220]=0;d=Q(667,(B(c,104)+a|0)+484380|0,i|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break Ka}if(d){break Ha}v[23220]=0;d=Q(1,e+448|0,16109)|0;g=v[23220];v[23220]=0;if((g|0)==1){break Ja}g=v[F>>2];v[23220]=0;U(360,g|0,2,d|0);g=v[23220];v[23220]=0;if((g|0)==1){break Ia}vb(d);break Ha}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}c=P()|0;O()|0;vb(d);break e}La:{Ma:{Na:{E=B(c,104)+a|0;if(w[E+484414|0]&64){d=x[m>>1];if(Ph(d)){break Na}}d=v[l>>2];if(mh(d,v[l+4>>2])>>>0<=c>>>0){break Ma}if(w[Zl(d,c)+132|0]!=2){break Ma}c=x[m>>1];if(!Ph(c)){break Ma}u[m>>1]=c+1;break Ma}c=d+1|0;u[a+480190>>1]=c;G=B(c&65535,104)+a|0;o=G+484380|0;h=E+484380|0;g=v[h>>2];c=v[h+20>>2];Oa:{if(!Md(g,c)){break Oa}f=x[h+34>>1];if((h|0)==(o|0)|(Cd(f)|0)!=2){break Oa}d=(h|0)==(o|0);if(!(Md(v[o>>2],v[o+20>>2])?d:1)){break Oa}Md(v[h>>2],v[h+20>>2]);if(!d){c=nt(g,ym(f))}f=v[h+20>>2];if(!(f?c:0)){if(!d){nz(c)}break Oa}Pa:{Qa:{switch(ym(x[h+34>>1])-1|0){case 1:d=c;g=f;j=v[h+20>>2];n=v[h>>2];while(1){if(n){u[d>>1]=x[j>>1];u[g>>1]=x[j+2>>1];j=j+4|0;g=g+2|0;d=d+2|0;n=n-1|0;continue}break};break Pa;case 0:break Qa;default:break Pa}}d=c;g=f;j=v[h+20>>2];n=v[h>>2];while(1){if(n){t[d|0]=w[j|0];t[g|0]=w[j+1|0];j=j+2|0;g=g+1|0;d=d+1|0;n=n-1|0;continue}break}}d=Wn(o,h);v[d+20>>2]=c;u[d+34>>1]=x[d+34>>1]&65471;g=Wn(h,h);v[g+20>>2]=f;u[g+34>>1]=x[g+34>>1]&65471;h=a+1074992|0;c=0;while(1){if((c|0)!=256){f=h+B(c,872)|0;j=v[f+104>>2];if(!((j|0)!=(d|0)&(g|0)!=(j|0))){v[f+88>>2]=v[f+88>>2]&-65}c=c+1|0;continue}break}ij(d,a);ij(g,a)}v[23220]=0;c=Q(52,e+432|0,6281)|0;d=v[23220];v[23220]=0;if((d|0)==1){break La}ue(G+484423|0,c);ub(c);v[23220]=0;c=Q(52,e+416|0,6184)|0;d=v[23220];v[23220]=0;if((d|0)==1){break f}ue(E+484423|0,c);ub(c)}wb(i);$b(A);i=0;continue}break}c=P()|0;O()|0;break e}c=P()|0;O()|0}wb(i)}$b(A);break a}fb=e+672|0;return d|0}c=P()|0;O()|0}qt(l);lc(s);Yj(q);ti(p);S(c|0);L()}function Bt(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,T=0,V=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,ea=0,fa=0,ha=0,ia=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ca=0,Da=0,Ea=C(0),Fa=0,Ga=0,Ha=0,Ia=C(0);h=fb-208|0;fb=h;$=Ib(a);s=h+176|0;t[s+26|0]=0;u[s+24>>1]=0;v[s+16>>2]=0;v[s+20>>2]=-1;v[s+8>>2]=-1;v[s+12>>2]=-1;v[s>>2]=0;v[s+4>>2]=0;J=v[d+16>>2];a=w[d+6|0];e=v[b+484360>>2];na=(Fa=a,Ga=w[b+484376|0],Ha=gj(e,v[b+484364>>2])>>>0>a>>>0,Ha?Fa:Ga);a=na&255;G=nj(e,a);v[23220]=0;D=Q(542,h+144|0,b|0)|0;e=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){k=v[D+4>>2];v[23220]=0;H=W(543,h+104|0,b|0,a|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break i}oa=b+484360|0;ca=c&7;l=v[d>>2];a=x[d+4>>1];while(1){e=a&65535;if(Ic(v[G>>2],v[G+4>>2])>>>0<=e>>>0){break g}v[23220]=0;e=Q(300,G|0,e|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break h}if(e){break g}a=a+1|0;l=0;continue}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;v[d>>2]=l;u[d+4>>1]=a;break f}v[d>>2]=l;u[d+4>>1]=a;v[k+52>>2]=l;v[k+48>>2]=l;v[s+16>>2]=l;u[k+74>>1]=a;u[k+72>>1]=a;u[s+24>>1]=a;pa=Xd(h+96|0);qa=lh(h+88|0);j:{if((ca|0)!=7){break j}Pk(Pk(Pk(Pk(Pk(Pk(Pk(Pk(pa,1),2),3),28),38),40),39),41);uN(uN(qa,12),13);if((J|0)!=2){break j}a=v[G>>2];m=Ic(a,v[G+4>>2]);e=x[d+12>>1];if(m>>>0<=e>>>0){break j}m=v[b+484344>>2];f=v[b+484348>>2];a=x[ac(a,e)>>1];if(!ke(m,f,a)){break j}e=Xb(m,a);m=v[d+8>>2];if(y[e+12>>2]<=m>>>0){break j}a=0;n=$c(v[e>>2],v[v[e+48>>2]+12>>2],m,0);e=x[b+480188>>1];m=v[D+8>>2];f=x[b+480192>>1];while(1){if((a|0)==(e|0)){break j}k:{l:{m:{n:{i=w[n|0];switch(i-253|0){case 1:case 2:break l;case 0:break n;default:break m}}if(f){break l}}if(!Oc(i)){break k}if(Us(w[n+2|0],w[n+3|0])){break k}}Fa=Ne(m,a),Ga=-1,v[Fa>>2]=Ga}n=n+6|0;a=a+1|0;continue}}aa=c&1;if(aa){tN(k+223860|0)}N=k+74|0;K=k+48|0;wa=k+223872|0;xa=(J|0)!=3;T=k+80|0;ya=b+901692|0;za=b+902204|0;la=k+44|0;ba=k+20|0;F=b+1074312|0;ea=k+616|0;fa=32768;ra=A[d+8>>3];o(+ra);a=j(1)|0;Aa=j(0)|0;Ca=a;_=b+480188|0;E=b+480180|0;ma=b+484348|0;sa=(J|0)!=2;ha=k+223860|0;ta=b+480192|0;Da=(ca|0)!=7;m=0;o:{p:{q:{r:{s:{t:while(1){e=Ca;while(1){sN(h+24|0,v[E>>2],x[_>>1],k,q&1);if(!(!(A[D+24>>3]>=ra)|xa)){break p}i=w[h+24|0];a=65535;f=v[G>>2];l=Ic(f,v[G+4>>2]);d=x[k+72>>1];if(l>>>0>d>>>0){a=x[ac(f,d)>>1]}u[k+70>>1]=a;g=v[b+484344>>2];l=v[ma>>2];f=a&65535;if(!(ke(g,l,f)|(f|0)==65535|sa)&(d|0)==(e&65535)){break p}u:{v:{while(1){d=a&65535;if(lf(g,l)>>>0>d>>>0){break u}a=x[k+72>>1];w:{x:{if((d|0)!=65535){d=v[G>>2];f=Ic(d,v[G+4>>2]);if(a>>>0<f>>>0){break x}}n=x[G+28>>1];if((a|0)==(n|0)){break u}d=v[G>>2];f=Ic(d,v[G+4>>2]);break w}n=a+1|0}u[k+72>>1]=n;a=65535;p=f;f=n&65535;if(p>>>0>f>>>0){a=x[ac(d,f)>>1]}u[k+74>>1]=n;u[k+70>>1]=a;if(ke(g,l,a&65535)){continue}a=xp(h+24|0,ea);v[23220]=0;a=ga(544,H|0,n&65535,0,a|0,(i|0)!=0|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){if(a){break v}l=v[ma>>2];g=v[b+484344>>2];a=x[k+70>>1];continue}break}b=P()|0;O()|0;break f}if(J>>>0<2){a=x[k+72>>1];v[s+8>>2]=0;u[s+20>>1]=a;if(!J){break u}}v[23220]=0;a=W(545,H|0,N|0,K|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break q}if(!a){break u}A[s>>3]=A[D+24>>3];v[23220]=0;R(546,$|0,s|0);a=v[23220];v[23220]=0;if((a|0)==1){break q}v[s+16>>2]=v[K>>2];u[s+24>>1]=x[N>>1];v[23220]=0;Y(547,D|0);a=v[23220];v[23220]=0;if((a|0)==1){break q}a=x[k+74>>1];u[k+72>>1]=a;Fa=k,Ga=x[ac(v[G>>2],a)>>1],u[Fa+70>>1]=Ga;v[k+52>>2]=v[k+48>>2]}if(x[N>>1]==65535){break o}a=v[b+484344>>2];d=x[k+70>>1];if(!ke(a,v[ma>>2],d)){a=x[k+72>>1];if((a|0)==x[G+28>>1]){if(!J){break o}v[23220]=0;a=W(545,H|0,N|0,K|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break q}if(!a){break o}A[s>>3]=A[D+24>>3];v[23220]=0;R(546,$|0,s|0);a=v[23220];v[23220]=0;if((a|0)==1){break q}v[s+16>>2]=v[K>>2];u[s+24>>1]=x[N>>1];v[23220]=0;Y(547,D|0);a=v[23220];v[23220]=0;if((a|0)==1){break q}v[k+52>>2]=v[k+48>>2];continue}u[N>>1]=a+1;continue}g=v[K>>2];if(g>>>0>=y[Xb(a,d)+12>>2]){v[K>>2]=0;g=0}if(!(x[k+72>>1]!=(e&65535)|sa)&(g|0)==(Aa|0)){break p}a=0;if(!((J|0)==3|y[H+28>>2]<fa>>>0)){v[D+24>>2]=0;v[D+28>>2]=2146435072;v[H+28>>2]=0;fa=fa>>>(fa>>>0>256)|0;g=v[K>>2];a=1}d=x[k+72>>1];f=xp(h+24|0,ea);v[23220]=0;d=ga(544,H|0,d|0,g|0,f|0,(i|0)!=0|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break s}if((a|d)==1){if(J>>>0<2){u[s+20>>1]=x[k+72>>1];v[s+8>>2]=v[k+48>>2];if(!J){break o}}v[23220]=0;a=W(545,H|0,N|0,K|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break r}if(!a){break o}A[s>>3]=A[D+24>>3];v[23220]=0;R(546,$|0,s|0);a=v[23220];v[23220]=0;if((a|0)==1){break r}v[s+16>>2]=v[K>>2];u[s+24>>1]=x[N>>1];v[23220]=0;Y(547,D|0);a=v[23220];v[23220]=0;if((a|0)==1){break r}v[k+52>>2]=v[k+48>>2];continue}u[s+22>>1]=x[k+72>>1];v[s+12>>2]=v[k+48>>2];rN(b,k,0);n=v[k+48>>2];d=Xb(v[b+484344>>2],x[k+70>>1]);if(n>>>0>=y[d+12>>2]){v[K>>2]=0;n=0}if(i){continue}break}a=0;n=$c(v[d>>2],v[v[d+48>>2]+12>>2],n,0);xb(h+24|0,F,77);i=yb(v[v[h+24>>2]>>2],v[h+28>>2]);y:{while(1){if(x[_>>1]>a>>>0){z:{if(!(!Ly(n)&(!i|!(w[((a<<5)+b|0)+480281|0]&4)))){Vn((k+B(a,872)|0)+1404|0);break z}if(Mg(w[n|0])){A:{if(!Nd(w[ha+24|0])){break A}d=w[n+1|0];if(d-251>>>0<5|!d){break A}f=w[n+5|0];q=w[n+3|0];l=Rj(w[n+2|0],w[n+4|0]);e=h+24|0;t[e|0]=d-1;v[e+4>>2]=l&65535;v[23220]=0;d=Q(548,wa|0,e|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break y}Fa=d,Ia=C(C(Rj(q,f)>>>0)/C(999)),z[Fa>>2]=Ia}Vn((k+B(a,872)|0)+1404|0);break z}d=k+B(a,872)|0;e=d+1408|0;f=w[n+4|0]|w[n+5|0]<<8;t[e|0]=f;t[e+1|0]=f>>>8;e=d+1404|0;f=w[n|0]|w[n+1|0]<<8|(w[n+2|0]<<16|w[n+3|0]<<24);t[e|0]=f;t[e+1|0]=f>>>8;t[e+2|0]=f>>>16;t[e+3|0]=f>>>24;B:{C:{D:{E:{switch(w[n+3|0]-16|0){case 0:l=w[n+5|0];break D;case 3:break B;case 4:break C;case 1:break E;default:break z}}xb(h+24|0,F,5);if(!yb(v[v[h+24>>2]>>2],v[h+28>>2])){break z}l=w[n+5|0];if(!l){break z}}pN(b,k,l&255);break z}e=d+1409|0;f=w[e|0];F:{if(!(f|!(v[E>>2]&16777250))){t[e|0]=w[d+1449|0];break F}t[d+1449|0]=f}d=w[n+5|0];e=d&240;if((e|0)!=224){if((e|0)!=96){break z}v[k+24>>2]=v[k+24>>2]+(d&15);break z}if(v[ba>>2]){break z}d=d&15;if(d?0:w[E|0]&2){break z}v[ba>>2]=d+1;break z}d=w[n+5|0];if((d&240)!=224){break z}v[ba>>2]=(d&15)+1}n=n+6|0;a=a+1|0;continue}break}d=Ok(k);v[h+24>>2]=1;a=v[Sc(ba,h+24|0)>>2];u[k+68>>1]=65535;v[k+60>>2]=-1;v[k+64>>2]=-1;V=d-1|0;a=d-a|0;M=B(a,1e4);n=0;while(1){if(x[_>>1]<=n>>>0){if(v[E>>2]==4&v[k+40>>2]==65535){break o}v[k+32>>2]=v[b+480216>>2];a=Xb(v[b+484344>>2],x[k+70>>1]);e=v[a+16>>2];if(oN(e,v[a+20>>2])){v[k+32>>2]=e}e=nN(b,k);a=B(e,d);A[D+24>>3]=A[D+24>>3]+ +(a>>>0)/+y[b+24620>>2];v[k>>2]=a+v[k>>2];G:{H:{if(Da){break H}n=0;ia=(m|0)!=0&(e|0)!=(m|0);while(1){if(x[_>>1]<=n>>>0){break H}r=Ne(v[D+8>>2],n);I:{if(v[r>>2]==-1){break I}p=k+B(n,872)|0;V=p+1404|0;I=v[p+1316>>2];if(!I){if(Ly(V)){break I}}l=p+1409|0;f=1;J:{K:{M=p+1407|0;switch(w[M|0]-4|0){case 0:case 2:break J;default:break K}}f=w[p+1406|0]==11}a=w[l|0];if(w[p+1405|0]){v[p+1276>>2]=0}i=p+616|0;g=a&15;q=0;L:{M:{N:{if(!Oc(w[V|0])){break N}if(!(!f|!w[r+4|0])){Ky(h+24|0,b,i,I,0);q=v[h+28>>2];v[p+624>>2]=v[h+24>>2];v[p+628>>2]=q}t[p+1418|0]=w[p+1415|0];I=p+1308|0;Z=v[I>>2];q=w[p+1419|0];if(q){wp(b,i,q,f,1,1)}q=w[V|0];v[23220]=0;ja(549,b|0,i|0,q|0,f|0,1,0,65535);q=v[23220];v[23220]=0;if((q|0)==1){break M}a=a>>>4|0;mN(v[E>>2],x[_>>1],k,n&65535);ua=Ne(v[D+8>>2],n);t[ua+4|0]=1;r=w[M|0];O:{if(!((w[l|0]&240)!=208|(r-19&255)>>>0>1)){q=g;if(g>>>0<d>>>0){break O}}q=(r|0)==33?a>>>0<d>>>0?a:0:0}va=v[ba>>2];if(!(!(v[E>>2]&16777250)|(!q|va>>>0<2))){q=B(va-1|0,v[k+24>>2]+v[k+40>>2]|0)+q|0}if(!f){v[ua>>2]=0}P:{if((r|0)==9){break P}Q:{if((r|0)!=19){if((r|0)!=20|(a|0)!=8){break Q}break P}if((a|0)==8){break P}}if(w[p+1406|0]!=2){break N}}v[I>>2]=Z}R:{if(!Oc(w[V|0])){xb(h+24|0,F,114);if(!yb(v[v[h+24>>2]>>2],v[h+28>>2])){break R}}S:{T:{U:{V:{a=w[M|0];switch(a-42|0){case 1:break S;case 0:break T;case 2:break U;default:break V}}if((a|0)!=10){break S}a=x[k+70>>1];r=v[k+48>>2];v[23220]=0;da(550,b|0,i|0,n&65535,r|0,a|0);a=v[23220];v[23220]=0;if((a|0)!=1){break R}break G}I=Bia(w[l|0],0,v[p+692>>2],0);r=ib;a=r>>>8|0;Kn(b,i,Pc((r&255)<<24|I>>>8,a));break R}if(!v[p+720>>2]){break S}v[23220]=0;X(551,D|0,n&65535,m|0,-1);a=v[23220];v[23220]=0;if((a|0)==1){break G}kN(i,w[l|0]);q=v[k+40>>2]-1|0;break R}if(w[p+1406|0]!=15){break R}r=v[p+720>>2];if(!r){break R}a=w[p+1408|0];if(a>>>0>9){break R}W:{if(!a){r=v[p+1280>>2];break W}r=v[zb(r+68|0,a-1|0)>>2];v[p+1280>>2]=r}Kn(b,i,r)}X:{Y:{Z:{switch(w[V|0]-253|0){case 0:if(x[ta>>1]){break Y}break;case 1:case 2:break Y;default:break Z}}a=w[M|0];if(!((w[l|0]&240)!=192|(a-19&255)>>>0>1)&d>>>0>g>>>0){break Y}r=0;if((a|0)==33&(g|0)!=0&d>>>0>g+q>>>0){break Y}if((a|0)!=25){break X}}a=w[M|0];r=1}I=p+1304|0;_:{if((a|0)!=13){if(w[p+1406|0]!=1){break _}g=p+1408|0}else{g=l}v[I>>2]=w[g|0]<<2}$:{if(!(!v[p+720>>2]|r)){r=0;aa:{ba:{ca:{if(a>>>0>45){break ca}xb(h+24|0,pa,a);if(yb(v[v[h+24>>2]>>2],v[h+28>>2])){break ba}if(w[M|0]!=19){break ca}r=(w[l|0]-16&255)>>>0<32}a=w[p+1406|0];if(a>>>0<16){break aa}if(r){break $}break L}r=1;a=w[p+1406|0];if(a>>>0>=16){break $}}sk(h+24|0,qa,a);a=yb(v[v[h+24>>2]>>2],v[h+28>>2]);if(r){break $}if(!a){break L}break $}if(!r){break L}}SO(i);Fa=Ne(v[D+8>>2],n),Ga=0,v[Fa>>2]=Ga;break I}b=P()|0;O()|0;break f}if(ia){v[23220]=0;X(551,D|0,n&65535,m|0,-1);a=v[23220];v[23220]=0;if((a|0)==1){break G}}da:{ea:{fa:{ga:{ha:{a=w[M|0];if(a-6>>>0>=2){ia:{switch(a-19|0){case 1:break ga;case 0:break ha;default:break ia}}if(a-35>>>0<2){break ea}if((a|0)==45){break fa}if((a|0)!=11){break da}}if(!w[l|0]&v[E>>2]==1){break da}a=p+1467|0;g=0;while(1){if((d|0)==(g|0)){break da}t[a|0]=!g|w[a|0]&254;Jn(b,i,w[l|0]);g=g+1|0;continue}}l=w[l|0];a=l&15;if(!(v[E>>2]&1048580?1:a)){break da}g=p+1467|0;t[g|0]=w[g|0]|1;l=l&240;if((l|0)!=176){if((l|0)!=160){break da}In(b,i,a,0);break da}Hn(b,i,a,0);break da}ja:{ka:{la:{a=w[l|0];switch(a-158|0){case 1:break ka;case 0:break la;default:break ja}}v[23220]=0;X(551,D|0,n&65535,m|0,-1);a=v[23220];v[23220]=0;if((a|0)==1){break G}v[p+704>>2]=v[p+704>>2]&-129;break da}v[23220]=0;X(551,D|0,n&65535,m|0,-1);a=v[23220];v[23220]=0;if((a|0)==1){break G}a=v[p+704>>2];v[p+704>>2]=a|128;if(v[i+4>>2]){break da}l=v[p+692>>2];if(!l){break da}if(!(Fa=Oc(w[V|0]),Ga=1,Ha=a&2,Ha?Fa:Ga)){break da}v[i>>2]=-1;v[i+4>>2]=l-1;break da}if((a&240)!=112|a>>>0<115){break da}OO(i,a,v[E>>2]);break da}jN(i,w[l|0]);break da}v[23220]=0;a=n&65535;X(551,D|0,a|0,m|0,-1);l=v[23220];v[23220]=0;if((l|0)==1){break G}iN(b,a,k,0)}l=p+1467|0;a=w[l|0]|1;t[l|0]=a;ma:{na:{oa:{pa:{qa:{g=p+1406|0;switch(w[g|0]-3|0){case 11:break na;case 0:case 1:break oa;case 3:break pa;case 2:break qa;default:break ma}}a=w[p+1408|0];xb(h+24|0,F,41);In(b,i,a,yb(v[v[h+24>>2]>>2],v[h+28>>2]));break ma}a=w[p+1408|0];xb(h+24|0,F,41);Hn(b,i,a,yb(v[v[h+24>>2]>>2],v[h+28>>2]));break ma}a=w[p+1408|0];ra:{if(a){break ra}xb(h+24|0,F,41);a=0;if(!yb(v[v[h+24>>2]>>2],v[h+28>>2])){break ra}a=w[p+1450|0];if(!a){break ma}}g=w[g|0]==3?a<<4:a;a=0;while(1){if((a|0)==(d|0)){break ma}t[l|0]=!a|w[l|0]&254;Jn(b,i,g&255);a=a+1|0;continue}}i=w[p+1408|0];if(i>>>0>1){break ma}t[l|0]=a&247|!i<<3}if(w[l|0]&8){break I}if(f){f=Ne(v[D+8>>2],n);a=v[f>>2];v[f>>2]=a+d;v[23220]=0;X(551,D|0,n&65535,e|0,(a+q|0)+1|0);a=v[23220];v[23220]=0;if((a|0)!=1){break I}b=P()|0;O()|0;break f}a=Ne(v[D+8>>2],n);v[a>>2]=v[a>>2]+(d-q|0)}n=n+1|0;continue}}q=hN(b,k,G,0);m=e;continue t}b=P()|0;O()|0;break f}i=k+B(n,872)|0;e=i+1404|0;sa:{if(Ly(e)){break sa}q=i+616|0;ia=i+1409|0;g=w[ia|0];I=i+1407|0;p=w[I|0];ta:{ua:{if(!aa){break ua}l=w[e|0];f=l;r=i+1405|0;Z=w[r|0];if(Z){t[i+1415|0]=0;t[i+1419|0]=Z;Fa=Ne(v[D+8>>2],n),Ga=255,t[Fa+5|0]=Ga;f=w[e|0]}if(Oc(f)){t[i+1415|0]=l;QO(q);f=w[e|0]}va:{if(!(Fa=1,Ga=Oc(f),Ha=w[r|0],Ha?Fa:Ga)){break va}Z=i+1419|0;f=w[Z|0];wa:{if(!f){f=0;break wa}if(x[ta>>1]<f>>>0){break wa}r=v[((f<<2)+b|0)+900380>>2];if(!r|!(t[r+15|0]&1)){break wa}Fp(q,v[r+8>>2],b);f=w[Z|0]}f=Jy(b,l,f);if(!f){break va}f=B(f,104)+b|0;if(!(w[f+484414|0]&32)){break va}Fp(q,x[f+484408>>1],b)}xa:{ya:{za:{f=w[i+1406|0];switch(f-1|0){case 1:break ua;case 2:case 3:break ya;case 0:break za;default:break xa}}Fa=Ne(v[D+8>>2],n),Ga=w[i+1408|0],t[Fa+5|0]=Ga;break ua}e=w[i+1408|0];if(!e){break ua}t[i+1450|0]=e;break ua}if((f|0)!=11){break ua}f=w[i+1408|0];if(!f){break ua}l=h+24|0;Iy(l,b,w[e+3|0],f,0);u[i+1384>>1]=x[h+24>>1];if(w[Qe(l)|0]){break ta}}Aa:{Ba:{Ca:{Da:{Ea:{switch(p-12|0){case 0:gN(b,k,n&65535);break Aa;case 2:e=fN(b,k,n&65535,g);if((e|0)==-1){break Aa}v[k+60>>2]=e;break Aa;case 5:xb(h+24|0,F,5);if(yb(v[v[h+24>>2]>>2],v[h+28>>2])){break Aa}l=B(Gn(b,x[k+70>>1],v[k+48>>2],n&65535,0),1e4);Fa:{if(!aa|!(v[E>>2]&16777250)){break Fa}if(l>>>0>=1e4){t[i+1451|0]=(l>>>0)/1e4;break Fa}l=B(w[i+1451|0],1e4)}Ga:{if(l>>>0>319999){break Ga}l=(l>>>0)/1e4|0;f=B(M,l&15);e=v[la>>2];if((l&240)==16){l=e+f|0;break Ga}f=e-f|0;l=e>>>0<f>>>0?0:f}v[la>>2]=l;e=v[b+8>>2];f=v[e+20>>2];e=v[e+24>>2];xb(h+24|0,F,8);xo(la,B(f,1e4),yb(v[v[h+24>>2]>>2],v[h+28>>2])?255e4:B(e,1e4));break Aa;case 8:Ha:{switch((g&240)-144>>>4|0){case 0:if(g>>>0>145){break Aa}v[i+704>>2]=v[i+704>>2]&-257|((g|0)==145)<<8;break Aa;case 1:t[i+1452|0]=g&15;break Aa;case 2:break Da;case 6:break Ha;default:break Aa}}t[i+1460|0]=g&15;break Aa;case 1:case 3:case 4:case 6:break Aa;case 7:break Ea;default:break Ba}}e=g&240;if((e|0)==240){break Ca}if((e|0)!=96){break Aa}}Hy(b,k,q,g&15);break Aa}t[i+1460|0]=g&15;break Aa}if((p|0)!=28|(g&240)!=160){break Aa}xb(h+24|0,F,58);if(yb(v[v[h+24>>2]>>2],v[h+28>>2])){break Aa}t[i+1452|0]=g&15}if(!aa){break sa}Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{switch(p-2|0){case 0:if(!g){break Ia}xb(h+24|0,F,90);if(!yb(v[v[h+24>>2]>>2],v[h+28>>2])){t[i+1428|0]=g}t[i+1427|0]=g;break ta;case 1:if(!g){break Ia}xb(h+24|0,F,90);if(!yb(v[v[h+24>>2]>>2],v[h+28>>2])){t[i+1427|0]=g}t[i+1428|0]=g;break ta;case 2:if(!g){break Ia}u[i+1384>>1]=g;break ta;case 8:if(!g){break Ia}v[i+1280>>2]=g<<8;break ta;case 4:case 9:if(!g){break Ia}t[i+1425|0]=g;break ta;case 11:Fa=Ne(v[D+8>>2],n),Ga=g,t[Fa+5|0]=Ga;break ta;case 21:e=v[E>>2];g=g<<(!(e&59593760)&g<<24>>24>=0);f=g&255;if(f>>>0<=128){v[T>>2]=f<<1;break ta}if(e&16777250){break ta}v[T>>2]=256;break ta;case 22:xb(h+24|0,F,9);Ra:{if(yb(v[v[h+24>>2]>>2],v[h+28>>2])){e=i+1433|0;if(g){t[e|0]=g;break Ra}g=w[e|0];break Ra}if(g){t[ea+817|0]=g;break Ra}g=w[ea+817|0]}e=g&240;f=g&15;Sa:{if(!(!e|(f|0)!=15)){g=e>>>4<<!(v[E>>2]&59593760);e=v[T>>2]+(g<<1)|0;break Sa}if(!(!f|(e|0)!=240)){g=f<<(v[E>>2]&59593760?1:2);e=v[T>>2]-g|0;break Sa}if(e){g=(g>>>3&30)<<!(v[E>>2]&59593760);e=v[T>>2]+B(a,g)|0;break Sa}g=f<<(v[E>>2]&59593760?1:2);e=v[T>>2]-B(a,g)|0}v[T>>2]=e;ee(T,0,256);break ta;case 19:if(g>>>0>64){break ta}v[i+1364>>2]=g;break ta;case 20:e=i+1432|0;Ta:{if(g){t[e|0]=g;break Ta}g=w[e|0]}l=g&255;p=i+1364|0;e=v[p>>2];r=g&240;f=g&15;Ua:{if(!(!r|(f|0)!=15)){v[h+24>>2]=e+(l>>>4|0);break Ua}if(!(!f|(r|0)!=240)){v[h+24>>2]=e-f;break Ua}if(f){v[h+24>>2]=e-B(a,f);break Ua}v[h+24>>2]=e+B(a,l>>>4|0)}ee(h+24|0,0,64);v[p>>2]=v[h+24>>2];break ta;case 7:Pl(b,q,g,8);break ta;case 29:case 30:break Ja;case 25:break Ka;case 6:break La;case 24:break Ma;case 3:break Na;case 5:break Oa;case 18:break Pa;case 17:break Qa;default:break ta}}if(g>>>0>15){break Pa}e=(g&1)<<14;f=x[_>>1];l=0;while(1){if((f|0)==(l|0)){break Pa}p=k+B(l,872)|0;v[p+704>>2]=(e|v[p+704>>2]&-16385)^16384;l=l+1|0;continue}}if((g&240)!=128){break ta}Pl(b,q,g&15,4);break ta}if(g){t[i+1425|0]=g}g=0}Nk(q,g);break ta}eN(b,q,g);break ta}dN(q,g);break ta}cN(q,g);break ta}Va:{if(g<<24>>24>=0){e=le(ya,w[i+1460|0]);break Va}e=le(za,g&127)}f=w[ia|0];v[23220]=0;ka(552,b|0,k|0,n&65535,0,e|0,f|0);e=v[23220];v[23220]=0;if((e|0)!=1){break ta}b=P()|0;O()|0;break f}g=0}Wa:{Xa:{switch(w[i+1406|0]-2|0){case 0:Pl(b,q,w[i+1408|0],6);break Wa;case 5:xb(h+24|0,F,53);e=w[i+1408|0];if(yb(v[v[h+24>>2]>>2],v[h+28>>2])){t[i+1439|0]=e&15;break Wa}Nk(q,e<<4);break Wa;case 6:break Xa;default:break Wa}}Nk(q,w[i+1408|0])}Ya:{Za:{_a:{$a:{ab:{e=w[I|0];switch(e-5|0){case 1:break Ya;case 3:break _a;case 0:case 2:break $a;default:break ab}}switch(e-26|0){case 1:break Za;case 0:break $a;default:break Ya}}bb:{if(v[E>>2]&16777248){e=d;if(!(w[b+480208|0]&4)){break bb}}e=a}f=w[i+1439|0];xb(h+24|0,F,21);i=i+1435|0;l=w[i|0];e=B(e,f);Fa=i,Ga=(yb(v[v[h+24>>2]>>2],v[h+28>>2])?e<<2:e)+l|0,t[Fa|0]=Ga;break Ya}cb:{if(v[E>>2]&16777248){e=d;if(!(w[b+480208|0]&4)){break cb}}e=a}f=w[i+1442|0];xb(h+24|0,F,21);i=i+1436|0;l=w[i|0];e=B(e,f);Fa=i,Ga=(yb(v[v[h+24>>2]>>2],v[h+28>>2])?e<<2:e)+l|0,t[Fa|0]=Ga;break Ya}e=i+1437|0;t[e|0]=w[e|0]+B(V,w[i+1445|0]);aN(b,q)}xb(h+24|0,F,78);if(!yb(v[v[h+24>>2]>>2],v[h+28>>2])){break sa}e=g&255;if(!e){break sa}$M(q,e)}n=n+1|0;continue}}break}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}t[s+26|0]=1}db:{if((ca|0)!=7){break db}a=0;d=b+480188|0;while(1){if(x[d>>1]<=a>>>0){break db}eb:{if(v[Ne(v[D+8>>2],a)>>2]==-1){break eb}v[23220]=0;X(551,D|0,a&65535,m|0,-1);e=v[23220];v[23220]=0;if((e|0)!=1){break eb}b=P()|0;O()|0;break f}a=a+1|0;continue}}if(w[s+26|0]){u[s+20>>1]=x[k+72>>1];v[s+8>>2]=v[k+48>>2]}A[s>>3]=A[D+24>>3];v[23220]=0;R(546,$|0,s|0);a=v[23220];v[23220]=0;if((a|0)!=1){if(!aa){break a}if(!(J?w[s+26|0]:1)){break c}f=By(h+56|0);if(Nd(w[ha+24|0])){OM(f,ha)}Gy(ha);a=nc(b+1074376|0,k,614);m=0;while(1){if((m|0)==256){hm(a+223848|0,k+223848|0);d=a+223860|0;m=w[d+24|0];e=k+223860|0;fb:{if((Nd(w[e+24|0])|0)==(m|0)){if(!m){break fb}m=fc(d);Os(d,v[m>>2]);v[d>>2]=v[e>>2];v[d+4>>2]=v[e+4>>2];v[d+8>>2]=v[e+8>>2];gb:{if(!v[Cb(d)>>2]){v[d>>2]=m;break gb}v[v[m>>2]+8>>2]=m;m=fc(e);v[e>>2]=m;v[m>>2]=0;Fa=Cb(e),Ga=0,v[Fa>>2]=Ga}d=d+12|0;m=fc(d);Ns(d,v[m>>2]);e=e+12|0;v[d>>2]=v[e>>2];v[d+4>>2]=v[e+4>>2];v[d+8>>2]=v[e+8>>2];hb:{if(!v[Cb(d)>>2]){v[d>>2]=m;break hb}v[v[m>>2]+8>>2]=m;d=fc(e);v[e>>2]=d;v[d>>2]=0;Fa=Cb(e),Ga=0,v[Fa>>2]=Ga}break fb}if(m){Gy(d);break fb}OM(d,e)}}else{d=B(m,872);up((d+a|0)+616|0,(d+k|0)+616|0);m=m+1|0;continue}break}Fy(a);a=0;v[b+1074400>>2]=0;t[b+1074476|0]=1;d=b+1074392|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074428>>2]=v[b+1074424>>2];ib:{jb:{d=v[b+1298300>>2];if(!sd(d)){break jb}v[23220]=0;Y(553,d|0);d=v[23220];v[23220]=0;if((d|0)!=1){break jb}break ib}while(1){if(x[b+480188>>1]<=a>>>0){a=Sz(h+24|0);Fa=h,Ga=oj(v[f+12>>2]),v[Fa+16>>2]=Ga;i=wf(f+12|0);while(1){d=v[h+16>>2];if(!vg(d,i)){kb:{m=250;d=a;lb:{while(1){if(m>>>0>=32){if(v[a>>2]){a=1;break lb}else{m=m-32|0;a=a+4|0;continue}}break}a=(v[d+28>>2]&67108863)!=0}if(!a){break kb}a=0;while(1){if((a|0)==250){break kb}xb(h+8|0,d,a);mb:{if(!yb(v[v[h+8>>2]>>2],v[h+12>>2])){break mb}e=v[(B(a,160)+b|0)+906300>>2];m=v[v[e>>2]+176>>2];v[23220]=0;Y(m|0,e|0);e=v[23220];v[23220]=0;if((e|0)!=1){break mb}break ib}a=a+1|0;continue}}Fa=h,Ga=oj(v[f>>2]),v[Fa+8>>2]=Ga;a=wf(f);while(1){d=v[h+8>>2];if(vg(d,a)){d=pd(d);Fa=(B(w[d|0],160)+b|0)+906444|0,Ia=z[fc(d)>>2],z[Fa>>2]=Ia;Rg(h+8|0);continue}else{vp(f);break b}}}e=pd(d);q=Cb(e);nb:{m=w[e|0];d=v[(B(m,160)+b|0)+906300>>2];if(d){xb(h+8|0,a,m);if(!yb(v[v[h+8>>2]>>2],v[h+12>>2])){v[23220]=0;Q(554,a|0,m|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break nb}m=v[v[d>>2]+172>>2];v[23220]=0;R(m|0,d|0,-1);m=v[23220];v[23220]=0;if((m|0)==1){break nb}}Ea=z[q>>2];e=v[e+4>>2];m=v[v[d>>2]+44>>2];v[23220]=0;Ba(m|0,d|0,e|0,C(Ea));d=v[23220];v[23220]=0;if((d|0)==1){break nb}}Rg(h+16|0);continue}break}break ib}d=B(a,872)+b|0;e=w[d+1075791|0];if(e){t[d+1075794|0]=e}d=Ne(v[D+8>>2],a);if(!((ca|0)==7|w[d+5|0]==255)){t[h+24|0]=64;Fa=(B(a,872)+b|0)+1075680|0,Ga=w[Rb(d+5|0,h+24|0)|0]<<2,v[Fa>>2]=Ga}ob:{e=B(a,872)+b|0;d=v[e+1075096>>2];pb:{if(!d|!(w[d+35|0]&2)){break pb}m=v[b+1298300>>2];if(!sd(m)){break pb}v[23220]=0;l=m;m=a&65535;U(555,l|0,m|0,d+68|0);d=v[23220];v[23220]=0;if((d|0)==1){break ob}d=v[b+1298300>>2];v[23220]=0;U(556,d|0,m|0,1);d=v[23220];v[23220]=0;if((d|0)==1){break ob}}v[e+1075008>>2]=0;a=a+1|0;continue}break}}b=P()|0;O()|0;vp(f);break f}b=P()|0;O()|0}Rs(H)}_M(D)}ti($);S(b|0);L()}if((c|0)==3){break b}v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+1074456>>2]=v[b+480200>>2]}a=na&255;if((a|0)==w[oa+16|0]){break a}xi(oa,a)}if(c&9){a=b+1298264|0;if(v[a>>2]){PN(a);b=v[a>>2];Bj(a);Fb(b);Fa=Cb(a),Ga=0,v[Fa>>2]=Ga;v[a>>2]=0;v[a+4>>2]=0}v[a>>2]=v[H>>2];v[a+4>>2]=v[H+4>>2];b=Cb(H);Fa=Cb(a),Ga=v[b>>2],v[Fa>>2]=Ga;v[b>>2]=0;v[H>>2]=0;v[H+4>>2]=0;a=a+12|0;c=fc(a);zp(a,v[c>>2]);b=H+12|0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];qb:{if(!v[Cb(a)>>2]){v[a>>2]=c;break qb}v[v[c>>2]+8>>2]=c;a=fc(b);v[b>>2]=a;v[a>>2]=0;Fa=Cb(b),Ga=0,v[Fa>>2]=Ga}}Rs(H);_M(D);fb=h+208|0}function LR(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,A=C(0),D=C(0),E=0,F=0,G=0,H=0,I=C(0),J=C(0),K=0,M=C(0),N=C(0),O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=C(0),_=C(0),$=0,aa=C(0),ba=C(0),da=0,ea=0,fa=C(0),ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;U=fb-16|0;fb=U;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;Q=v[a+1420>>2];d=(Q|0)>0?Q:0;while(1){if((d|0)!=(E|0)){v[(B(E,20)+a|0)+1436>>2]=0;E=E+1|0;continue}break}b:{c:{d:{if((Q|0)>3){break d}E=0;if((c|0)<4){break c}c=c-3|0;d=0;while(1){if((c|0)==(d|0)){break d}e:{f:{h=b+d|0;if(w[h|0]!=79){break f}if(Mb(h,92392,4)){break f}g=d+26|0;if((g|0)>=(c|0)){break e}j=d+27|0;i=b+g|0;f=w[i|0];if((j+f|0)>=(c|0)){break e}k=f+27|0;E=0;e=0;while(1)if((e|0)==(f|0)){e=0;while(1){f=22;if((E|0)!=22){e=Sw(e,w[(d+E|0)+b|0]);E=E+1|0;continue}break}while(1){if((f|0)!=26){f=f+1|0;e=Sw(e,0);continue}break}v[a+1420>>2]=Q+1;f=B(Q,20)+a|0;v[f+1432>>2]=e;v[f+1428>>2]=k-26;v[f+1424>>2]=w[h+22|0]|w[h+23|0]<<8|(w[h+24|0]<<16|w[h+25|0]<<24);e=w[(g+w[i|0]|0)+b|0]==255?-1:w[h+6|0]|w[h+7|0]<<8|(w[h+8|0]<<16|w[h+9|0]<<24);v[f+1436>>2]=g;v[f+1440>>2]=e;Q=v[a+1420>>2];if((Q|0)!=4){break f}Q=4;break d}else{k=w[(e+j|0)+b|0]+k|0;e=e+1|0;continue}}d=d+1|0;continue}break}c=d}d=0;g:while(1){i=(d|0)>(Q|0)?d:Q;while(1){if((d|0)==(i|0)){break b}E=0;f=B(d,20)+a|0;n=f+1428|0;h=v[n>>2];k=v[f+1436>>2];j=c-k|0;g=(h|0)<(j|0)?h:j;l=(g|0)>0?g:0;da=f+1432|0;e=v[da>>2];while(1){if((l|0)!=(E|0)){e=Sw(e,w[(k+E|0)+b|0]);E=E+1|0;continue}break}v[n>>2]=h-g;v[da>>2]=e;if((h|0)<=(j|0)){h=e;e=f+1424|0;if((h|0)==v[e>>2]){v[a+1380>>2]=-1;v[a+992>>2]=0;v[a+1420>>2]=-1;b=v[(B(d,20)+a|0)+1440>>2];v[a+1060>>2]=b;v[a+1064>>2]=(b|0)!=-1;E=g+k|0;break c}f=Q-1|0;v[a+1420>>2]=f;f=B(f,20)+a|0;v[e+16>>2]=v[f+1440>>2];h=f+1432|0;g=v[h+4>>2];v[e+8>>2]=v[h>>2];v[e+12>>2]=g;f=f+1424|0;h=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=h;Q=v[a+1420>>2];continue g}else{d=d+1|0;continue}}}}c=E}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!FH(a)){v[f>>2]=0;c=0;break a}qa=U+12|0;da=fb-16|0;fb=da;v[a+1504>>2]=0;v[a+1508>>2]=0;h:{if(v[a+96>>2]){break h}i:{j:{k:{if(v[a+1380>>2]!=-1){break k}c=Le(a);if(v[a+96>>2]){break i}if((c|0)!=79){break j}if((Le(a)|0)!=103){break j}if((Le(a)|0)!=103){break j}if((Le(a)|0)!=83){break j}if(!DH(a)){break i}if(!(t[a+1375|0]&1)){break k}t[a+1376|0]=0;v[a+1384>>2]=0;Zb(a,32);break i}k=Pw(a);break i}Zb(a,30)}if(!k){break h}if(mc(a,1)){Zb(a,35);break h}s=da;l:{m:{if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){c=mc(a,El(v[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=v[a+408>>2]){break h}v[da+12>>2]=c;k=B(c,6)+a|0;if(!w[k+412|0]){h=v[a+112>>2];g=h>>1;break m}h=v[a+116>>2];g=h>>1;c=mc(a,1);j=mc(a,1);if(c|!w[k+412|0]){break m}v[U+4>>2]=h-v[a+112>>2]>>2;c=v[a+112>>2]+h>>2;break l}ca(6286,13164,3152,10695);L()}v[U+4>>2]=0;c=g}v[s+8>>2]=c;n:{if(!(!w[k+412|0]|j)){c=B(h,3);v[U+8>>2]=c-v[a+112>>2]>>2;h=c+v[a+112>>2]>>2;break n}v[U+8>>2]=g}v[da+4>>2]=h;h=1}if(h){E=v[U+4>>2];la=v[U+8>>2];ka=v[da+4>>2];O=fb-2368|0;fb=O;F=v[a+404>>2];oa=B(v[da+12>>2],6)+a|0;G=w[oa+413|0];R=F+B(G,40)|0;V=v[((w[oa+412|0]<<2)+a|0)+104>>2];ha=V>>1;sa=0-ha|0;o:{while(1){c=v[a+4>>2];if((c|0)>(n|0)){c=w[(v[R+4>>2]+B(n,3)|0)+2|0];P=(O+1344|0)+(n<<2)|0;v[P>>2]=0;h=w[(c+R|0)+9|0];if(!x[((h<<1)+a|0)+132>>1]){Zb(a,21);c=0;break o}g=v[a+260>>2];p:{q:{if(!mc(a,1)){break q}c=2;k=v[((n<<2)+a|0)+996>>2];g=g+B(h,1596)|0;r=v[(w[g+1588|0]<<2)+71772>>2];h=El(r)-1|0;ta=k,ua=mc(a,h),u[ta>>1]=ua;ta=k,ua=mc(a,h),u[ta+2>>1]=ua;H=g+82|0;W=g+65|0;S=g+49|0;T=g+33|0;K=g+1|0;o=0;while(1){if(w[g|0]>o>>>0){p=w[o+K|0];q=w[p+S|0];l=-1<<q;X=w[p+T|0];r:{if(!q){i=0;break r}h=v[a+124>>2]+B(w[p+W|0],2096)|0;if(v[a+1396>>2]<=9){Dk(a)}j=v[a+1392>>2];i=u[(h+((j&1023)<<1)|0)+36>>1];s:{if((i|0)>=0){s=j;i=i&65535;j=w[i+v[h+8>>2]|0];v[a+1392>>2]=s>>>j;j=v[a+1396>>2]-j|0;v[a+1396>>2]=(j|0)>0?j:0;i=(j|0)>=0?i:-1;break s}i=Dl(a,h)}if(!w[h+23|0]){break r}i=v[v[h+2088>>2]+(i<<2)>>2]}ea=l^-1;h=c+X|0;while(1){if((c|0)!=(h|0)){l=0;j=u[(H+(p<<4)|0)+((i&ea)<<1)>>1];t:{if((j|0)<0){break t}j=v[a+124>>2]+B(j&65535,2096)|0;if(v[a+1396>>2]<=9){Dk(a)}l=v[a+1392>>2];X=u[(j+((l&1023)<<1)|0)+36>>1];u:{if((X|0)>=0){s=l;X=X&65535;l=w[X+v[j+8>>2]|0];v[a+1392>>2]=s>>>l;l=v[a+1396>>2]-l|0;v[a+1396>>2]=(l|0)>0?l:0;l=(l|0)>=0?X:-1;break u}l=Dl(a,j)}if(!w[j+23|0]){break t}l=v[v[j+2088>>2]+(l<<2)>>2]}i=i>>q;u[k+(c<<1)>>1]=l;c=c+1|0;continue}break}o=o+1|0;c=h;continue}break}if(v[a+1396>>2]==-1){break q}u[O+320>>1]=257;h=g+338|0;o=g+1088|0;c=2;while(1){l=v[g+1592>>2];if((l|0)<=(c|0)){c=0;while(1){if((c|0)>=(l|0)){break p}if(!w[(O+320|0)+c|0]){u[k+(c<<1)>>1]=65535;l=v[g+1592>>2]}c=c+1|0;continue}}else{j=c<<1;l=j+o|0;q=w[l|0];p=q<<1;i=x[p+h>>1];P=w[l+1|0];H=P<<1;W=u[k+p>>1];l=u[H+k>>1]-W|0;p=l>>31;i=(B((l^p)-p|0,x[h+j>>1]-i|0)|0)/(x[h+H>>1]-i|0)|0;l=W+((l|0)<0?0-i|0:i)|0;H=k+j|0;i=x[H>>1];v:{w:{if(i){j=O+320|0;t[j+P|0]=1;t[j+q|0]=1;t[c+j|0]=1;j=i<<16>>16;p=r-l|0;if((j|0)>=((l|0)>(p|0)?p:l)<<1){if((l|0)<(p|0)){break v}l=r+(i^-1)|0;break w}if(j&1){l=l-(j+1>>>1|0)|0;break w}l=(j>>1)+l|0;break w}t[(O+320|0)+c|0]=0}u[H>>1]=l}c=c+1|0;continue}}}v[P>>2]=1}n=n+1|0;continue}break}if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){nc(O+320|0,O+1344|0,c<<2);g=x[R>>1];c=0;while(1){if((c|0)==(g|0)){c=F+B(G,40)|0}else{k=v[R+4>>2]+B(c,3)|0;h=w[k+1|0];l=O+1344|0;k=l+(w[k|0]<<2)|0;if(!(v[(h<<2)+l>>2]?v[k>>2]:0)){v[(O+1344|0)+(h<<2)>>2]=0;v[k>>2]=0}c=c+1|0;continue}break}X=c;i=0;while(1){x:{if(w[X+8|0]>i>>>0){l=0;c=v[a+4>>2];k=(c|0)>0?c:0;c=0;while(1){if((c|0)==(k|0)){break x}if(w[(v[R+4>>2]+B(c,3)|0)+2|0]==(i|0)){h=l+O|0;g=c<<2;y:{if(v[g+(O+1344|0)>>2]){g=0;n=1;break y}g=v[(a+g|0)+800>>2];n=0}t[h|0]=n;v[(O+256|0)+(l<<2)>>2]=g;l=l+1|0}c=c+1|0;continue}}if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){k=(ha|0)>0?ha:0;h=x[R>>1];g=a+800|0;z:while(1){if((h|0)<=0){P=ha<<2;l=0;c=0;while(1){i=v[a+4>>2];if((i|0)<=(c|0)){while(1){if((i|0)>(l|0)){P=w[oa+412|0];R=V>>1;h=R<<2;X=v[a+92>>2];p=V>>3;W=V>>2;k=v[((l<<2)+a|0)+800>>2];c=R<<2;G=k+c|0;A:{if(v[a+80>>2]){j=jn(a,h);break A}j=Fd(h)}h=(j+c|0)-8|0;g=v[((P<<2)+a|0)+1068>>2];i=g;c=k;while(1){if((c|0)!=(G|0)){z[h+4>>2]=C(z[c>>2]*z[i>>2])-C(z[i+4>>2]*z[c+8>>2]);z[h>>2]=C(z[c>>2]*z[i+4>>2])+C(z[c+8>>2]*z[i>>2]);c=c+16|0;i=i+8|0;h=h-8|0;continue}break}c=((R<<2)+k|0)-12|0;while(1){if(h>>>0>=j>>>0){z[h+4>>2]=C(z[c>>2]*z[i+4>>2])-C(z[c+8>>2]*z[i>>2]);z[h>>2]=C(C(-z[c+8>>2])*z[i+4>>2])-C(z[i>>2]*z[c>>2]);c=c-16|0;i=i+8|0;h=h-8|0;continue}break}c=W<<2;o=c+k|0;h=c+j|0;i=(g+(R<<2)|0)-32|0;c=j;n=k;while(1){if(g>>>0<=i>>>0){m=z[c>>2];A=z[h>>2];D=z[h+4>>2];I=z[c+4>>2];z[o+4>>2]=D+I;z[o>>2]=z[h>>2]+z[c>>2];D=C(D-I);m=C(A-m);z[n+4>>2]=C(D*z[i+16>>2])-C(z[i+20>>2]*m);z[n>>2]=C(m*z[i+16>>2])+C(D*z[i+20>>2]);m=z[c+8>>2];A=z[h+8>>2];D=z[h+12>>2];I=z[c+12>>2];z[o+12>>2]=D+I;z[o+8>>2]=z[h+8>>2]+z[c+8>>2];D=C(D-I);m=C(A-m);z[n+12>>2]=C(D*z[i>>2])-C(z[i+4>>2]*m);z[n+8>>2]=C(m*z[i>>2])+C(D*z[i+4>>2]);c=c+16|0;h=h+16|0;n=n+16|0;o=o+16|0;i=i-32|0;continue}break}h=El(V);c=V>>4;n=R-1|0;i=0-p|0;AH(c,k,n,i,g);AH(c,k,n-W|0,i,g);H=V>>5;c=0-c|0;$o(H,k,n,c,g,16);$o(H,k,n-p|0,c,g,16);$o(H,k,n-(p<<1)|0,c,g,16);$o(H,k,n+B(p,-3)|0,c,g,16);c=h-4>>1;o=(c|0)>2?c:2;c=2;while(1){B:{C:{D:{if((c|0)==(o|0)){c=h-7|0;ea=(c|0)<(o|0)?o:c;break D}i=0;p=2<<c;p=(p|0)>0?p:0;r=8<<c;q=V>>c+4;F=V>>c+2;S=0-(F>>1)|0;while(1){if((i|0)==(p|0)){break C}$o(q,k,n-B(i,F)|0,S,g,r);i=i+1|0;continue}}while(1){E:{if((o|0)!=(ea|0)){r=2<<o;S=8<<o;ma=S<<2;i=V>>o+6;Y=V>>o+2;$=0-(Y>>1)|0;h=n;c=g;while(1){if((i|0)<=0){break E}p=r;F=(h<<2)+k|0;q=F+($<<2)|0;T=B(S,12)+c|0;m=z[T>>2];K=(S<<3)+c|0;A=z[K>>2];s=(S<<2)+c|0;D=z[s>>2];I=z[T+4>>2];M=z[K+4>>2];Z=z[s+4>>2];_=z[c+4>>2];fa=z[c>>2];T=0-Y<<2;while(1){if((p|0)>0){K=q-4|0;N=z[K>>2];aa=z[F>>2];ba=z[q>>2];z[F>>2]=aa+ba;s=F-4|0;J=z[s>>2];z[s>>2]=J+z[K>>2];J=C(J-N);N=C(aa-ba);z[K>>2]=C(J*fa)+C(_*N);z[q>>2]=C(N*fa)-C(_*J);K=q-12|0;aa=z[K>>2];s=F-8|0;J=z[s>>2];ia=s;s=q-8|0;ba=z[s>>2];z[ia>>2]=J+ba;ga=F-12|0;N=z[ga>>2];z[ga>>2]=N+z[K>>2];N=C(N-aa);J=C(J-ba);z[K>>2]=C(N*D)+C(Z*J);z[s>>2]=C(J*D)-C(Z*N);K=q-20|0;aa=z[K>>2];s=F-16|0;J=z[s>>2];ia=s;s=q-16|0;ba=z[s>>2];z[ia>>2]=J+ba;ga=F-20|0;N=z[ga>>2];z[ga>>2]=N+z[K>>2];N=C(N-aa);J=C(J-ba);z[K>>2]=C(N*A)+C(M*J);z[s>>2]=C(J*A)-C(M*N);K=q-28|0;aa=z[K>>2];s=F-24|0;J=z[s>>2];ia=s;s=q-24|0;ba=z[s>>2];z[ia>>2]=J+ba;ga=F-28|0;N=z[ga>>2];z[ga>>2]=N+z[K>>2];N=C(N-aa);J=C(J-ba);z[K>>2]=C(N*m)+C(I*J);z[s>>2]=C(J*m)-C(I*N);p=p-1|0;q=q+T|0;F=F+T|0;continue}break}i=i-1|0;h=h-8|0;c=(ma<<2)+c|0;continue}}c=(n<<2)+k|0;i=c-(H<<6)|0;m=z[g+(V>>3<<2)>>2];fa=C(-m);while(1){if(c>>>0>i>>>0){M=z[c>>2];h=c-32|0;Z=z[h>>2];z[c>>2]=M+Z;g=c-4|0;A=z[g>>2];n=g;g=c-36|0;_=z[g>>2];z[n>>2]=A+_;n=c-8|0;D=z[n>>2];s=n;n=c-40|0;J=z[n>>2];z[s>>2]=D+J;p=c-12|0;I=z[p>>2];s=p;p=c-44|0;N=z[p>>2];z[s>>2]=I+N;z[h>>2]=M-Z;z[g>>2]=A-_;g=c-16|0;A=z[g>>2];s=g;g=c-48|0;aa=z[g>>2];z[s>>2]=A+aa;D=C(D-J);I=C(I-N);z[n>>2]=m*C(D+I);z[p>>2]=m*C(I-D);n=c-28|0;D=z[n>>2];p=c-60|0;I=z[p>>2];r=c-24|0;M=z[r>>2];o=c-56|0;Z=z[o>>2];q=c-20|0;_=z[q>>2];s=q;q=c-52|0;J=z[q>>2];z[s>>2]=_+J;z[r>>2]=M+Z;z[n>>2]=D+I;z[g>>2]=_-J;z[q>>2]=-C(A-aa);A=C(D-I);D=C(M-Z);z[o>>2]=m*C(A-D);z[p>>2]=C(D+A)*fa;zH(c);zH(h);c=c+-64|0;continue}break}p=R-4|0;h=j+(p<<2)|0;i=(j+(W<<2)|0)-16|0;c=v[((P<<2)+a|0)+1100>>2];while(1){if(i>>>0>=j>>>0){g=(x[c>>1]<<2)+k|0;z[h+12>>2]=z[g>>2];z[h+8>>2]=z[g+4>>2];z[i+12>>2]=z[g+8>>2];z[i+8>>2]=z[g+12>>2];g=(x[c+2>>1]<<2)+k|0;z[h+4>>2]=z[g>>2];z[h>>2]=z[g+4>>2];z[i+4>>2]=z[g+8>>2];z[i>>2]=z[g+12>>2];c=c+4|0;h=h-16|0;i=i-16|0;continue}break}c=v[((P<<2)+a|0)+1084>>2];i=j;h=i+(R<<2)|0;g=h;while(1){n=g-16|0;if(n>>>0>i>>>0){m=z[i+4>>2];r=g-4|0;A=z[r>>2];D=C(m-A);I=z[c+4>>2];m=C(m+A);A=z[i>>2];o=g-8|0;M=z[o>>2];Z=C(A-M);_=z[c>>2];fa=C(C(I*m)-C(Z*_));z[i+4>>2]=D+fa;A=C(A+M);m=C(C(I*Z)+C(m*_));z[i>>2]=A+m;z[r>>2]=fa-D;z[o>>2]=A-m;m=z[i+8>>2];A=z[n>>2];D=C(m+A);I=z[c+12>>2];m=C(m-A);A=z[i+12>>2];g=g-12|0;M=z[g>>2];Z=C(A+M);_=z[c+8>>2];fa=C(C(I*m)+C(Z*_));z[i+8>>2]=D+fa;A=C(A-M);m=C(C(I*Z)-C(m*_));z[i+12>>2]=A+m;z[n>>2]=D-fa;z[g>>2]=m-A;i=i+16|0;c=c+16|0;g=n;continue}break}i=v[((P<<2)+a|0)+1076>>2]+(R<<2)|0;c=(p<<2)+k|0;g=((V<<2)+k|0)-16|0;while(1){n=h-32|0;if(n>>>0>=j>>>0){m=z[h-8>>2];A=z[i-4>>2];D=z[i-8>>2];I=z[h-4>>2];M=C(C(m*A)-C(D*I));z[k>>2]=M;z[c+12>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G>>2]=m;z[g+12>>2]=m;m=z[h-16>>2];A=z[i-12>>2];D=z[i-16>>2];I=z[h-12>>2];M=C(C(m*A)-C(D*I));z[k+4>>2]=M;z[c+8>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G+4>>2]=m;z[g+8>>2]=m;m=z[h-24>>2];A=z[i-20>>2];D=z[i-24>>2];I=z[h-20>>2];M=C(C(m*A)-C(D*I));z[k+8>>2]=M;z[c+4>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G+8>>2]=m;z[g+4>>2]=m;m=z[n>>2];A=z[i-28>>2];i=i-32|0;D=z[i>>2];I=z[h-28>>2];M=C(C(m*A)-C(D*I));z[k+12>>2]=M;z[c>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G+12>>2]=m;z[g>>2]=m;g=g-16|0;c=c-16|0;G=G+16|0;k=k+16|0;h=n;continue}break}if(!v[a+80>>2]){Fb(j)}v[a+92>>2]=X;break B}o=o+1|0;continue}}c=c+1|0;continue}break}l=l+1|0;i=v[a+4>>2];continue}break}}else{h=c<<2;g=h+a|0;i=v[g+800>>2];F:{if(v[h+(O+320|0)>>2]){Sb(i,0,P);break F}F=v[g+996>>2];G:{h=w[(R+w[(v[R+4>>2]+B(c,3)|0)+2|0]|0)+9|0];if(!x[((h<<1)+a|0)+132>>1]){Zb(a,21);break G}n=V>>1;p=v[a+260>>2]+B(h,1596)|0;H=p+338|0;W=p+838|0;k=B(w[p+1588|0],u[F>>1]);o=1;h=0;while(1){if(v[p+1592>>2]>(o|0)){g=w[o+W|0]<<1;j=u[g+F>>1];if((j|0)>=0){j=B(w[p+1588|0],j&65535);g=x[g+H>>1];if((g|0)!=(h|0)){q=j-k|0;r=g-h|0;G=(q|0)/(r|0)|0;H:{S=(g|0)<(n|0)?g:n;if((S|0)<=(h|0)){break H}s=q;q=q>>31;T=G>>31;T=((s^q)-q|0)-B(r,(T^G)-T|0)|0;K=q|1;q=i+(h<<2)|0;z[q>>2]=z[((k&255)<<2)+71792>>2]*z[q>>2];S=S-1|0;q=0;while(1){if((h|0)==(S|0)){break H}h=h+1|0;X=i+(h<<2)|0;q=q+T|0;ea=(q|0)<(r|0);k=(k+G|0)+(ea?0:K)|0;z[X>>2]=z[((k&255)<<2)+71792>>2]*z[X>>2];q=q-(ea?0:r)|0;continue}}h=g}k=j}o=o+1|0;continue}break}if((h|0)>=(n|0)){break G}g=(k<<2)+71792|0;while(1){if((h|0)==(n|0)){break G}k=i+(h<<2)|0;z[k>>2]=z[g>>2]*z[k>>2];h=h+1|0;continue}}}c=c+1|0;continue}break}CH(a);I:{if(w[a+1377|0]){v[a+1060>>2]=sa;t[a+1377|0]=0;v[a+1064>>2]=1;v[a+1412>>2]=V-ka;break I}c=v[a+1412>>2];if(!c){break I}h=la-E|0;if((h|0)<=(c|0)){v[a+1412>>2]=c-h;v[U+4>>2]=la;E=la;break I}E=c+E|0;v[U+4>>2]=E;v[a+1412>>2]=0}c=v[a+1064>>2];J:{K:{L:{M:{if(v[a+1388>>2]==v[a+1404>>2]){N:{if(!c|!(w[a+1375|0]&4)){break N}c=v[a+1408>>2];h=v[a+1060>>2];if(c>>>0>=h+(ka-E|0)>>>0){break N}h=c-h|0;c=(c>>>0<h>>>0?0:h)+E|0;c=(c|0)<(ka|0)?c:ka;v[qa>>2]=c;v[a+1060>>2]=c+v[a+1060>>2];break K}v[a+1064>>2]=1;c=v[a+1408>>2]+(E-ha|0)|0;break M}if(!c){break L}c=v[a+1060>>2]}v[a+1060>>2]=c+(la-E|0)}if(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0){break J}v[qa>>2]=ka}c=1;break o}ca(6286,13164,3451,5595);L()}h=h-1|0;c=v[R+4>>2]+B(h,3)|0;j=v[g+(w[c+1|0]<<2)>>2];i=v[g+(w[c|0]<<2)>>2];c=0;while(1){if((c|0)==(k|0)){continue z}n=c<<2;l=n+j|0;D=z[l>>2];n=i+n|0;m=z[n>>2];O:{if(m>C(0)){if(D>C(0)){A=C(m-D);break O}A=m;m=C(m+D);break O}if(D>C(0)){A=C(m+D);break O}A=m;m=C(m-D)}z[n>>2]=m;z[l>>2]=A;c=c+1|0;continue}}}ca(6286,13164,3335,5595);L()}W=O+256|0;n=0;q=fb-16|0;fb=q;G=v[a+4>>2];F=v[a+396>>2];o=w[(i+X|0)+24|0];p=F+B(o,24)|0;h=v[p+4>>2];ea=x[((o<<1)+a|0)+268>>1];c=ha<<((ea|0)==2);g=c>>>0>h>>>0?h:c;h=v[p>>2];P=(g-(c>>>0>h>>>0?h:c)>>>0)/y[p+8>>2]|0;k=P<<2;c=B(G,k+4|0);K=v[v[a+124>>2]+B(w[p+13|0],2096)>>2];ga=v[a+92>>2];P:{if(v[a+80>>2]){h=jn(a,c);G=v[a+4>>2];break P}h=Fd(c)}j=(l|0)>0?l:0;H=ha<<2;g=0;c=(G|0)>0?G:0;r=(G<<2)+h|0;while(1){if((c|0)!=(g|0)){v[(g<<2)+h>>2]=r;g=g+1|0;r=k+r|0;continue}break}k=h;c=0;while(1){if((c|0)!=(j|0)){if(!w[c+O|0]){Sb(v[W+(c<<2)>>2],0,H)}c=c+1|0;continue}break}Q:{if(!((l|0)==1|(ea|0)!=2)){c=0;while(1){R:{if((c|0)!=(j|0)){if(w[c+O|0]){break R}}else{c=j}if((c|0)==(l|0)){break Q}r=F+B(o,24)|0;G=(l|0)!=2;F=(l|0)<3;while(1){if((n|0)==8){break Q}S:{if(!G){h=0;o=0;while(1){if((o|0)>=(P|0)){break S}c=v[p>>2]+B(v[p+8>>2],o)|0;v[q+12>>2]=c&1;v[q+8>>2]=c>>1;c=0;if(!n){j=v[a+124>>2]+B(w[p+13|0],2096)|0;if(v[a+1396>>2]<=9){Dk(a)}g=v[a+1392>>2];H=u[(j+((g&1023)<<1)|0)+36>>1];T:{if((H|0)>=0){s=g;H=H&65535;g=w[H+v[j+8>>2]|0];v[a+1392>>2]=s>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;g=(g|0)>=0?H:-1;break T}g=Dl(a,j)}g=w[j+23|0]?v[v[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}v[v[k>>2]+(h<<2)>>2]=v[v[r+16>>2]+(g<<2)>>2]}while(1){if(!((c|0)>=(K|0)|(o|0)>=(P|0))){g=v[p+8>>2];j=u[(v[r+20>>2]+(w[v[v[k>>2]+(h<<2)>>2]+c|0]<<4)|0)+(n<<1)>>1];U:{if((j|0)>=0){if(BH(a,v[a+124>>2]+B(j&65535,2096)|0,W,2,q+12|0,q+8|0,ha,g)){break U}break Q}g=v[p>>2]+(g+B(g,o)|0)|0;v[q+8>>2]=g>>1;v[q+12>>2]=g&1}o=o+1|0;c=c+1|0;continue}break}h=h+1|0;continue}}if(F){break S}h=0;o=0;while(1){if((o|0)>=(P|0)){break S}g=v[p>>2]+B(v[p+8>>2],o)|0;c=(g|0)/(l|0)|0;v[q+12>>2]=g-B(c,l);v[q+8>>2]=c;c=0;if(!n){j=v[a+124>>2]+B(w[p+13|0],2096)|0;if(v[a+1396>>2]<=9){Dk(a)}g=v[a+1392>>2];H=u[(j+((g&1023)<<1)|0)+36>>1];V:{if((H|0)>=0){s=g;H=H&65535;g=w[H+v[j+8>>2]|0];v[a+1392>>2]=s>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;g=(g|0)>=0?H:-1;break V}g=Dl(a,j)}g=w[j+23|0]?v[v[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}v[v[k>>2]+(h<<2)>>2]=v[v[r+16>>2]+(g<<2)>>2]}while(1){if(!((c|0)>=(K|0)|(o|0)>=(P|0))){g=v[p+8>>2];j=u[(v[r+20>>2]+(w[v[v[k>>2]+(h<<2)>>2]+c|0]<<4)|0)+(n<<1)>>1];W:{if((j|0)>=0){if(!BH(a,v[a+124>>2]+B(j&65535,2096)|0,W,l,q+12|0,q+8|0,ha,g)){break Q}break W}g=v[p>>2]+(g+B(g,o)|0)|0;j=(g|0)/(l|0)|0;v[q+8>>2]=j;v[q+12>>2]=g-B(j,l)}o=o+1|0;c=c+1|0;continue}break}h=h+1|0;continue}}n=n+1|0;continue}}c=c+1|0;continue}}ma=F+B(o,24)|0;l=0;while(1){if((l|0)==8){break Q}n=0;S=0;X:while(1){if((n|0)<(P|0)){h=0;c=0;Y:{if(l){break Y}while(1){if((c|0)==(j|0)){break Y}if(!w[c+O|0]){r=v[a+124>>2]+B(w[p+13|0],2096)|0;if(v[a+1396>>2]<=9){Dk(a)}g=v[a+1392>>2];o=u[(r+((g&1023)<<1)|0)+36>>1];Z:{if((o|0)>=0){s=g;o=o&65535;g=w[o+v[r+8>>2]|0];v[a+1392>>2]=s>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;g=(g|0)>=0?o:-1;break Z}g=Dl(a,r)}g=w[r+23|0]?v[v[r+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}v[v[k+(c<<2)>>2]+(S<<2)>>2]=v[v[ma+16>>2]+(g<<2)>>2]}c=c+1|0;continue}}while(1){_:{$:{if((h|0)>=(K|0)){break $}c=0;if((n|0)>=(P|0)){break $}while(1){if((c|0)==(j|0)){break _}aa:{if(w[c+O|0]){break aa}g=c<<2;r=u[(v[ma+20>>2]+(w[v[v[g+k>>2]+(S<<2)>>2]+h|0]<<4)|0)+(l<<1)>>1];if((r|0)<0){break aa}G=v[a+124>>2]+B(r&65535,2096)|0;Y=v[g+W>>2];T=v[p+8>>2];H=v[p>>2]+B(T,n)|0;ba:{ca:{if(ea){F=0;while(1){g=1;if((F|0)>=(T|0)){break ba}$=Y+(H<<2)|0;g=T-F|0;o=0;m=C(0);da:{s=yH(a,G);if((s|0)<0){break da}r=v[G>>2];g=(g|0)>(r|0)?r:g;s=B(r,s);if(w[G+22|0]){r=0;g=(g|0)>0?g:0;o=1;while(1){if((g|0)==(r|0)){break da}ja=$+(r<<2)|0;m=C(m+z[v[G+28>>2]+(r+s<<2)>>2]);z[ja>>2]=z[ja>>2]+m;r=r+1|0;m=C(m+z[G+12>>2]);continue}}r=0;g=(g|0)>0?g:0;o=1;while(1){if((g|0)==(r|0)){break da}ja=$+(r<<2)|0;z[ja>>2]=z[ja>>2]+C(z[v[G+28>>2]+(r+s<<2)>>2]+C(0));r=r+1|0;continue}}if(!o){break ca}g=v[G>>2];H=g+H|0;F=g+F|0;continue}}F=0;r=(T|0)/v[G>>2]|0;s=(r|0)>0?r:0;ja=Y+(H<<2)|0;g=1;while(1){if((F|0)==(s|0)){break ba}o=F+H|0;Y=F<<2;F=F+1|0;ia=Y+ja|0;Y=T-o|0;$=0;m=C(0);ea:{na=yH(a,G);if((na|0)<0){break ea}o=0;$=v[G>>2];Y=(Y|0)>($|0)?$:Y;Y=(Y|0)>0?Y:0;na=B($,na);$=1;while(1){if((o|0)==(Y|0)){break ea}ra=(B(o,r)<<2)+ia|0;A=C(m+z[v[G+28>>2]+(o+na<<2)>>2]);z[ra>>2]=z[ra>>2]+A;m=w[G+22|0]?A:m;o=o+1|0;continue}}if($){continue}break}}g=0}if(!g){break Q}}c=c+1|0;continue}}S=S+1|0;continue X}n=n+1|0;h=h+1|0;continue}}break}l=l+1|0;continue}}if(!v[a+80>>2]){Fb(k)}v[a+92>>2]=ga;fb=q+16|0;i=i+1|0;continue}}ca(6286,13164,3302,5595);L()}fb=O+2368|0}else{c=0}fb=da+16|0;if(!c){fa:{ga:{ha:{c=v[a+100>>2];switch(c-32|0){case 0:break ga;case 3:break ha;default:break fa}}v[a+100>>2]=0;while(1){if(ta=0,ua=(fh(a)|0)!=-1,va=v[a+96>>2],va?ta:ua){continue}break}v[f>>2]=0;c=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break fa}v[a+100>>2]=0;while(1){if(ta=0,ua=(fh(a)|0)!=-1,va=v[a+96>>2],va?ta:ua){continue}break}v[f>>2]=0;c=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;c=1;break a}g=v[U+12>>2];j=v[U+4>>2];h=v[U+8>>2];ia:{ja:{k=v[a+992>>2];if(k){i=k<<1;ka:{if((i|0)==v[a+112>>2]){c=a+1092|0}else{c=0;if((i|0)!=v[a+116>>2]){break ka}c=a+1096|0}c=v[c>>2]}if(!c){break ja}n=(k|0)>0?k:0;while(1){if(v[a+4>>2]>(Q|0)){i=(Q<<2)+a|0;E=0;while(1){if((n|0)!=(E|0)){l=v[i+800>>2]+(j+E<<2)|0;s=l;A=z[l>>2];l=E<<2;z[s>>2]=C(A*z[l+c>>2])+C(z[l+v[i+928>>2]>>2]*z[c+(k+(E^-1)<<2)>>2]);E=E+1|0;continue}break}Q=Q+1|0;continue}break}Q=v[a+992>>2]}v[a+992>>2]=g-h;k=(g|0)<(h|0);i=(k?h:g)-h|0;while(1){if(v[a+4>>2]>(pa|0)){c=(pa<<2)+a|0;E=0;while(1){if((i|0)!=(E|0)){z[v[c+928>>2]+(E<<2)>>2]=z[v[c+800>>2]+(h+E<<2)>>2];E=E+1|0;continue}break}pa=pa+1|0;continue}break}if(!Q){break ja}c=(k?g:h)-j|0;v[a+1416>>2]=c+v[a+1416>>2];break ia}c=0}h=c;v[U+12>>2]=c;c=0;g=v[a+4>>2];k=(g|0)>0?g:0;while(1){if((c|0)!=(k|0)){i=(c<<2)+a|0;v[i+864>>2]=v[i+800>>2]+(j<<2);c=c+1|0;continue}break}if(d){v[d>>2]=g}v[f>>2]=h;v[e>>2]=a+864;c=v[a+32>>2]-b|0}fb=U+16|0;return c}function Oea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=fb-1760|0;fb=d;wc(b);f=fb-16|0;fb=f;g=d+1632|0;eR(f+8|0,g);l=b;p=v[b+8>>2];b=v[f+12>>2];jc(f,v[l>>2],p,v[f+8>>2],b);h=v[f+4>>2];if((h|0)==(b|0)){Yb(l,v[f+12>>2])}fb=f+16|0;b=(b|0)==(h|0);if(!b){dR(g)}a:{if(!b){break a}if(!fR(d+1632|0)){break a}if(!Lb(v[l>>2],v[l+8>>2],Pc(256,0))){break a}b:{if(!c){break b}zd(a,1048576);yg(a);b=fb-16|0;fb=b;e=Qb(b,4191);Mc(d+1376|0,e);vb(e);fb=b+16|0;b=x[d+1640>>1];v[d+160>>2]=b>>>8;v[23220]=0;v[d+16>>2]=b&255;R(387,d+88|0,d+16|0);b=v[23220];v[23220]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((b|0)!=1){v[23220]=0;X(373,d+272|0,d+1376|0,d+160|0,d+88|0);b=v[23220];v[23220]=0;if((b|0)==1){break m}b=d+272|0;Db(a+1298344|0,b);vb(b);e=d+88|0;vb(e);f=d+1376|0;bc(f);g=Qb(b,15158);Db(a+1298356|0,g);vb(g);Ue(e,2,d+1642|0);Ac(f,e);v[23220]=0;U(11,b|0,8,f|0);b=v[23220];v[23220]=0;if((b|0)==1){break i}b=d+272|0;Db(a+1298368|0,b);vb(b);e=d+1376|0;ub(e);v[a+1298404>>2]=8;Uz(e,2,d+1674|0);Ac(b,e);xc(a+1298308|0,b);ub(b);u[a+480188>>1]=x[d+1744>>1];f=w[d+1748|0];v[a+480204>>2]=125e4;v[a+480208>>2]=32792;G=a,H=Pd(f,1,31),v[G+480196>>2]=H;u[a+480192>>1]=x[d+1754>>1];u[a+480190>>1]=x[d+1756>>1];f=Pd(w[d+1749|0],1,32);v[a+480216>>2]=f;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=f<<2;Ku(l,e);f=a+484376|0;Cq(Vb(v[a+484360>>2],w[f|0]),e,x[d+1738>>1],65535,65535);Ve(Vb(v[a+484360>>2],w[f|0]),x[d+1740>>1]);q=Ag(l);Qd(b,l,q?274:0);A=gc(d+1352|0,b);wb(b);v[23220]=0;b=T(144,l|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break k}v[23220]=0;U(177,d+272|0,l|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break k}b=d+272|0;s=gc(d+1328|0,b);wb(b);p=x[a+480188>>1];if(q){u[a+480188>>1]=p+8}z=c&1;if(!z){break j}v[23220]=0;R(212,a+484344|0,x[d+1742>>1]);b=v[23220];v[23220]=0;if((b|0)!=1){break j}g=P()|0;O()|0;break e}g=P()|0;O()|0;break l}g=P()|0;O()|0;vb(d+88|0)}bc(d+1376|0);break c}g=P()|0;O()|0;break d}o=a+484344|0;D=a+480188|0;g=0;while(1){n:{o:{p:{q:{r:{s:{if(x[d+1742>>1]<=r>>>0){b=x[d+1746>>1];if((b-2&65535)>>>0>=4998){break q}if(!(g&1)){break s}h=0;b=Dc(((b>>>1|0)+11025e5>>>0)/(b>>>0)|0,0);break r}v[23220]=0;b=T(181,l|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break f}v[d+160>>2]=b;v[23220]=0;b=T(144,l|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break g}v[23220]=0;U(177,d+88|0,l|0,b+1&-2);b=v[23220];v[23220]=0;if((b|0)==1){break g}b=d+88|0;j=gc(d+272|0,b);wb(b);uc(d+160|0,1024);if(!z){break o}n=v[d+160>>2];if(!n){break o}v[23220]=0;b=W(213,o|0,r&65535,n|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){if(!b){break o}k=0;e=0;if(t[d+1750|0]&1){break p}t:while(1){if((k|0)==(n|0)){break o}e=0;b=Xb(v[o>>2],r);b=Of(v[b>>2],v[v[b+48>>2]+12>>2],k);while(1){if((e|0)==(p|0)){k=k+1|0;continue t}v[23220]=0;R(563,j|0,d+88|0);f=v[23220];v[23220]=0;if((f|0)!=1){g=cR(b+B(e,6)|0,d+88|0)|g;e=e+1|0;continue}break}break}break h}break h}h=2;b=Ee(2646e3/+(B(b,B(v[a+480216>>2],v[a+480196>>2]))>>>0)*1e4)}t[a+480224|0]=h;v[a+480204>>2]=b}h=a+480188|0;b=x[h>>1];v[23220]=0;t[d+272|0]=0;r=W(564,d+1312|0,b|0,d+272|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){j=a+1298320|0;n=a+1298332|0;k=0;u:{v:{w:{x:{y:{z:{while(1){b=v[s+8>>2];e=v[s>>2];v[23220]=0;b=W(143,e|0,b|0,8)|0;e=v[23220];v[23220]=0;A:{if((e|0)!=1){if(b){break A}f=v[r>>2];h=0;g=a+480188|0;while(1){e=x[g>>1];if(e>>>0<=h>>>0){v[d+264>>2]=0;v[d+268>>2]=0;v[d+256>>2]=0;v[d+260>>2]=0;v[d+248>>2]=0;v[d+252>>2]=0;v[d+240>>2]=0;v[d+244>>2]=0;B:{C:{if(!q){break C}e=0;v[23220]=0;R(565,A|0,d+272|0);b=v[23220];v[23220]=0;if((b|0)==1){break B}while(1){if((e|0)==8){e=0;v[23220]=0;j=Q(205,d+224|0,x[d+272>>1])|0;b=v[23220];v[23220]=0;if((b|0)!=1){D:{E:{F:{G:{while(1){if(x[d+272>>1]<=e>>>0){v[23220]=0;n=W(566,d+208|0,x[d+1742>>1],26924)|0;b=v[23220];v[23220]=0;if((b|0)==1){break E}m=a+484376|0;f=0;break F}v[23220]=0;b=T(181,l|0)|0;f=v[23220];v[23220]=0;if((f|0)!=1){v[23220]=0;U(177,d+160|0,l|0,b<<5);b=v[23220];v[23220]=0;if((b|0)==1){break G}f=d+160|0;b=gc(d+88|0,f);Yc(xg(v[j>>2],e),b);wb(b);e=e+1|0;wb(f);continue}break}g=P()|0;O()|0;break D}g=P()|0;O()|0;break D}while(1){if(x[d+1738>>1]<=f>>>0){ld(n);fd(j);break C}H:{g=d+f|0;e=w[g+290|0];if(e>>>0>=x[d+272>>1]){break H}b=x[ac(v[Vb(v[a+484360>>2],w[m|0])>>2],f)>>1];if(b>>>0>=x[d+1742>>1]){break H}I:{h=ac(v[n>>2],b);i=x[h>>1];J:{if((i|0)==65535){u[h>>1]=e;break J}if((e|0)==(i|0)){break J}v[23220]=0;e=Q(567,o|0,b|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break I}if((e|0)==65535){break J}G=ac(v[Vb(v[a+484360>>2],w[m|0])>>2],f),H=e,u[G>>1]=H;b=e}if(!ke(v[o>>2],v[o+4>>2],b)){break H}q=xg(v[j>>2],w[g+290|0]);wc(q);e=v[q>>2];v[23220]=0;e=T(147,e|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break I}z=e>>>5|0;h=0;K:while(1){e=Xb(v[o>>2],b);if(y[e+12>>2]<=h>>>0){break H}g=0;e=$c(v[e>>2],v[v[e+48>>2]+12>>2],h,x[a+480188>>1]-8&65535);while(1){if((g|0)==8){h=h+1|0;continue K}sh(d+88|0);i=x[d+92>>1];t[e+4|0]=i;t[e+5|0]=i>>>8;i=v[d+88>>2];t[e|0]=i;t[e+1|0]=i>>>8;t[e+2|0]=i>>>16;t[e+3|0]=i>>>24;L:{if(h>>>0>=z>>>0){break L}v[23220]=0;Q(568,q|0,d+88|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break I}if(t[d+88|0]>=0){break L}t[e|0]=61;t[e+1|0]=w[(d+256|0)+(g<<1)|0];i=w[d+88|0]&31;t[d+160|0]=i;if(i){hf(d+160|0,15);t[e+3|0]=20;t[e+5|0]=w[d+160|0]|208}t[e+2|0]=1;t[e+4|0]=w[d+89|0]+3>>>2}e=e+6|0;g=g+1|0;continue}}}g=P()|0;O()|0;ld(n);break D}f=f+1|0;continue}}g=P()|0;O()|0}fd(j);break u}g=P()|0;O()|0;break u}f=e<<1;g=f+(d+256|0)|0;b=x[a+480192>>1]+1&65535;h=x[v[a+8>>2]+58>>1];while(1){M:{N:{j=b&65535;if(j>>>0<=h>>>0){if(v[((j<<2)+a|0)+900380>>2]){break N}}else{b=65535}b=b&65535;break M}b=b+1|0;continue}break}u[g>>1]=b;h=f+(d+240|0)|0;f=x[(d+f|0)+274>>1];u[h>>1]=f;O:{if((b|0)!=65535){v[23220]=0;b=W(241,a|0,b|0,f+1&65535)|0;f=v[23220];v[23220]=0;P:{Q:{if((f|0)!=1){if(!b){break O}v[23220]=0;R(276,d+160|0,4436);f=v[23220];v[23220]=0;if((f|0)==1){break Q}v[23220]=0;v[d+16>>2]=e+1;U(569,d+88|0,d+160|0,d+16|0);f=v[23220];v[23220]=0;if((f|0)==1){break P}f=b+492|0;b=d+88|0;yc(f,b);ub(b);Pb(d+160|0);break O}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}g=P()|0;O()|0;Pb(d+160|0);break u}u[g>>1]=0}e=e+1|0;continue}}R:{S:{b=x[d+1750>>1]|x[d+1752>>1]<<16;if(!(b&2)){break S}b=(((b&8?x[a+480188>>1]:p)&65535)+(x[d+1640>>1]>591?k:0)|0)+(b>>>4&1)|0;f=0;T:while(1){e=0;if(x[d+1742>>1]<=f>>>0){break S}while(1){U:{if((b|0)!=(e|0)){g=v[l+8>>2];h=v[l>>2];v[23220]=0;g=W(143,h|0,g|0,4)|0;h=v[23220];v[23220]=0;if((h|0)==1){break R}if(g){break U}}f=f+1|0;continue T}v[23220]=0;R(570,x[d+1640>>1],l|0);g=v[23220];v[23220]=0;if((g|0)==1){break R}e=e+1|0;continue}}}v[23220]=0;j=Q(205,d+192|0,255)|0;b=v[23220];v[23220]=0;if((b|0)!=1){i=a+480208|0;f=0;while(1){V:{b=f;W:{if((b|0)==255){o=Sz(d+88|0);n=Sz(d+160|0);g=0;while(1){X:{Y:{Z:{if((g|0)==256){k=0;break Z}v[23220]=0;R(571,l|0,d+272|0);b=v[23220];v[23220]=0;if((b|0)==1){break Y}v[23220]=0;b=T(144,l|0)|0;e=v[23220];v[23220]=0;_:{$:{aa:{if((e|0)!=1){v[23220]=0;U(177,d+16|0,l|0,b|0);e=v[23220];v[23220]=0;if((e|0)==1){break aa}e=d+16|0;k=gc(d- -64|0,e);wb(e);if(x[d+1756>>1]>g>>>0){e=d+48|0;Ue(e,2,d+272|0);v[23220]=0;R(209,d+16|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){break _}e=d+16|0;yc(((g<<5)+a|0)+946336|0,e);ub(e)}if(!b){break X}if(x[d+1756>>1]>g>>>0){break $}break X}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}v[23220]=0;b=B(g+1|0,104)+a|0;e=b+484380|0;R(267,e|0,32);f=v[23220];v[23220]=0;ba:{ca:{da:{if((f|0)!=1){to(e);v[23220]=0;R(572,k|0,d+16|0);f=v[23220];v[23220]=0;if((f|0)==1){break _}f=v[d+16>>2];v[e>>2]=f;v[b+484404>>2]=v[d+20>>2];if(w[d+24|0]>=2){h=b+484414|0;u[h>>1]=x[h>>1]|1;f=f>>>1|0;v[e>>2]=f}if(w[d+25|0]>=2){h=b+484414|0;u[h>>1]=x[h>>1]|64;v[e>>2]=f>>>1}h=2;switch(w[d+27|0]-1|0){case 0:break ca;case 1:break da;default:break ba}}break _}h=6}e=b+484414|0;u[e>>1]=x[e>>1]|h}v[b+484384>>2]=v[d+28>>2];v[b+484388>>2]=v[d+32>>2];u[b+484410>>1]=x[d+36>>1]>>>7;e=w[d+38|0];ea:{if((e|0)==128){e=b+484414|0;f=x[e>>1]|256;u[e>>1]=f;break ea}u[b+484408>>1]=(e<<24>>24)+128;f=x[b+484414>>1]}h=b+484414|0;u[h>>1]=f|32;t[b+484416|0]=w[d+39|0];e=w[d+26|0];if(e&2){b=d+48|0;xb(b,n,g);dm(b);e=w[d+26|0]}if(e&5){u[h>>1]=x[h>>1]|16384}if(!(e&8)){break X}b=d+48|0;xb(b,o,g);dm(b);e=0;while(1){if((e|0)==8){break X}b=e<<1;fa:{if(x[b+(d+240|0)>>1]!=(g|0)){break fa}b=v[((x[b+(d+256|0)>>1]<<2)+a|0)+900380>>2];if(!b){break fa}t[b+14|0]=0}e=e+1|0;continue}}g=P()|0;O()|0;wb(k);break W}while(1){ga:{ha:{if(x[d+1754>>1]<=k>>>0){if(!(c&2)){break ha}e=a+1298404|0;f=a+1298464|0;g=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{while(1){if(x[a+480190>>1]<=g>>>0){break ha}g=g+1|0;c=B(g,104)+a|0;h=c+484380|0;b=c+484416|0;aq(h,(+(t[b|0]-49|0)+ +t[c+484417|0]*-.0078125)/-12);u[b>>1]=0;b=x[c+484414>>1];if(!(b&16384)){b=Uc(d+272|0,b&1?16:8,b&64?3:1,0,11);v[23220]=0;W(206,b|0,h|0,l|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){continue}g=P()|0;O()|0;break W}v[23220]=0;h=T(144,l|0)|0;b=v[23220];v[23220]=0;qa:{if((b|0)==1){break qa}v[23220]=0;Q(175,l|0,12)|0;b=v[23220];v[23220]=0;if((b|0)==1){break qa}b=Gb(d+272|0);v[23220]=0;U(258,l|0,b|0,h|0);h=v[23220];v[23220]=0;if((h|0)==1){break pa}ue(c+484423|0,b);v[23220]=0;R(372,d- -64|0,16361);c=v[23220];v[23220]=0;if((c|0)==1){break oa}v[d+12>>2]=g;c=v[e>>2];v[23220]=0;U(11,d+48|0,c|0,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break na}v[23220]=0;X(373,d+16|0,d- -64|0,d+12|0,d+48|0);c=v[23220];v[23220]=0;if((c|0)==1){break ma}c=v[f>>2];v[23220]=0;U(360,c|0,2,d+16|0);c=v[23220];v[23220]=0;if((c|0)==1){break la}vb(d+16|0);vb(d+48|0);bc(d- -64|0);ub(b);continue}break}g=P()|0;O()|0;break W}g=P()|0;O()|0;break ia}g=P()|0;O()|0;break ia}g=P()|0;O()|0;break ja}g=P()|0;O()|0;break ka}g=P()|0;O()|0;vb(d+16|0)}vb(d+48|0)}bc(d- -64|0)}ub(b);break W}b=v[xg(v[j>>2],k)>>2];v[23220]=0;b=T(147,b|0)|0;e=v[23220];v[23220]=0;ra:{sa:{if((e|0)!=1){if(!b){k=k+1|0;continue}b=xg(v[j>>2],k);wc(b);v[23220]=0;R(573,b|0,d+272|0);b=v[23220];v[23220]=0;if((b|0)==1){break sa}h=Ib(d+16|0);v[23220]=0;U(574,l|0,h|0,x[d+272>>1]);b=v[23220];v[23220]=0;if((b|0)==1){break ra}k=k+1|0;b=v[((k<<2)+a|0)+900380>>2];if(!b|w[b+34|0]){break ga}v[b+4>>2]=32;e=0;It(b,0);i=b+108|0;m=b+236|0;while(1){if((e|0)==96){break ga}f=w[(d+e|0)+274|0];ta:{if(f>>>0>=x[d+272>>1]){break ta}g=Ne(v[h>>2],f);q=e+12|0;z=ac(m,q);f=w[g|0];p=f+1|0;u[z>>1]=p;if(f>>>0>=x[a+480190>>1]){break ta}f=B(p,104)+a|0;t[f+484418|0]=w[d+370|0]&3;t[f+484419|0]=w[d+371|0];t[f+484420|0]=w[d+372|0];t[f+484421|0]=w[d+373|0];u[f+484412>>1]=w[g+1|0]<<1;t[f+484417|0]=w[g+2|0];f=p-1|0;xb(d- -64|0,o,f);if(yb(v[v[d+64>>2]>>2],v[d+68>>2])){t[b+14|0]=0}xb(d- -64|0,n,f);if(!yb(v[v[d+64>>2]>>2],v[d+68>>2])){break ta}G=Hb(i,q),H=61,t[G|0]=H}e=e+1|0;continue}}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}g=P()|0;O()|0;Wd(h);break W}fd(j);$b(r);wb(s);wb(A);break b}Wd(h);continue}}g=P()|0;O()|0;break W}wb(k);g=g+1|0;continue}}v[23220]=0;R(571,l|0,d+160|0);e=v[23220];v[23220]=0;ua:{va:{wa:{xa:{if((e|0)!=1){v[23220]=0;e=T(144,l|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break xa}v[23220]=0;e=(e|0)==32?428:e;k=e?x[d+1640>>1]>513?e+4|0:e:e;U(177,d+88|0,l|0,k|0);e=v[23220];v[23220]=0;if((e|0)==1){break wa}g=d+88|0;e=gc(d+272|0,g);h=fe(d+16|0,Yc(xg(v[j>>2],b),e));wb(e);f=b+1|0;wb(g);if(b>>>0>=x[d+1754>>1]){break V}v[23220]=0;b=f&65535;g=W(241,a|0,b|0,b|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break va}break ua}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}if(!g){break V}b=d+88|0;Ue(b,2,d+160|0);v[23220]=0;R(209,d+272|0,b|0);b=v[23220];v[23220]=0;ya:{if((b|0)!=1){b=d+272|0;yc(g+492|0,b);ub(b);if(!k){break V}v[23220]=0;R(573,h|0,d+272|0);b=v[23220];v[23220]=0;if((b|0)!=1){k=3;o=0;if(x[d+1640>>1]<513){n=0;break ya}v[23220]=0;n=T(181,h|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break ua}if(x[d+1640>>1]<514){break ya}v[23220]=0;k=T(144,h|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break ya}break ua}break ua}break ua}v[g>>2]=x[d+374>>1];t[g+16|0]=w[(x[d+376>>1]&3)+26926|0];t[g+17|0]=w[(w[d+377|0]&3)+26926|0];t[g+18|0]=w[(x[d+376>>1]>>>12&3)+26930|0];while(1){za:{Aa:{if((o|0)==4){if(!(t[g+60|0]&1|w[g+16|0]==3)){v[g>>2]=32767}um(g,127,1);tm(g,0,1);if(!n){break V}v[23220]=0;R(575,h|0,d+88|0);b=v[23220];v[23220]=0;if((b|0)==1){break ua}if(n&2){um(g,_Q(v[i>>2],+x[d+90>>1]),1);tm(g,w[d+92|0],1)}t[g+25|0]=w[d+89|0]==1;if(!(n&4)){break V}t[g+31|0]=w[d+95|0]+1;b=t[d+96|0];t[g+34|0]=b+1;if((b|0)<0){t[g+30|0]=w[d+103|0]+1}if(!w[d+100|0]){break Aa}k=g+108|0;e=0;while(1){if((e|0)==128){break Aa}b=e+1|0;v[d+64>>2]=b+t[d+100|0];ZQ(d- -64|0);G=Hb(k,e),H=v[d+64>>2],t[G|0]=H;e=b;continue}}if(!(k&1)){break za}v[23220]=0;R(576,h|0,d+88|0);b=v[23220];v[23220]=0;Ba:{if((b|0)!=1){b=Bi(g,w[o+26934|0]);Ca:{if((o|0)!=3){e=w[d+88|0];p=w[b+12|0]&-17;break Ca}e=w[d+88|0];p=w[b+12|0]&-17|e<<4&16}t[b+12|0]=e>>>1&2|(e<<1&4|(p&248|e&1));t[d+64|0]=w[d+89|0];t[d+48|0]=16;e=w[Rb(d- -64|0,d+48|0)|0];v[23220]=0;R(281,b|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){break Ba}e=w[d+90|0];t[b+15|0]=e;t[b+16|0]=e;t[b+13|0]=w[d+91|0];t[b+14|0]=w[d+92|0];e=0;p=v[b>>2];m=ne(p,v[b+4>>2]);while(1){if((e|0)==(m|0)){break za}q=zb(p,e);b=(d+88|0)+(e<<2)|0;u[q>>1]=w[b+8|0]|w[b+9|0]<<8;G=q,H=Pd(w[b+10|0]|w[b+11|0]<<8,0,64),t[G+2|0]=H;e=e+1|0;continue}}break ua}break ua}It(g,0);break V}o=o+1|0;k=k>>>1|0;continue}}g=P()|0;O()|0;wb(h)}fd(j);break u}wb(h);continue}}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}else{b=t[Hb(f,h)|0];Da:{if((b|0)<=(h|0)|(b|0)>=(e|0)){break Da}b=w[((b<<5)+a|0)+480288|0];if(!b){break Da}e=((h<<5)+a|0)+480288|0;j=w[e|0];if(!j){t[e|0]=b;break Da}e=j-1|0;while(1){j=B(e&255,160)+a|0;e=xm(v[j+906328>>2]);if((e|0)!=255){continue}break}b=b-1&255;v[(j+906300|0)+28>>2]=b>>>0<250?b+128|0:0}h=h+1|0;continue}}}g=P()|0;O()|0;break u}v[23220]=0;f=T(144,s|0)|0;b=v[23220];v[23220]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{if((b|0)!=1){v[23220]=0;b=T(144,s|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break Ma}v[23220]=0;U(177,d+272|0,s|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break Ma}e=d+272|0;b=gc(d+88|0,e);wb(e);if((f|0)==4674381){break Ia}if((f|0)==5068115){break Ha}if((f|0)==726487106){break La}if((f|0)==844387158){break Ga}e=0;if((f|0)==1280004692){break Ka}if((f|0)==1314144592){break Ja}if((f|0)!=1397445204){break Fa}v[23220]=0;e=T(181,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break w}e=e>>>0<256?48:e>>>8|0;v[a+480228>>2]=e;v[a+480232>>2]=e>>>1;e=0;while(1){if(x[h>>1]<=e>>>0){break Fa}v[23220]=0;f=Q(577,b|0,d+272|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break z}if(f){u[((e<<5)+a|0)+480286>>1]=x[d+272>>1]>>>10;G=Hb(v[r>>2],e),H=w[d+275|0],t[G|0]=H}e=e+1|0;continue}}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}if(g&1){break Fa}t[a+480224|0]=2;v[23220]=0;C=+na(578,b|0);e=v[23220];v[23220]=0;if((e|0)==1){break Ea}if(!(C>1e-8)){break Fa}G=a,H=Ee(2646e3/(C*+(B(v[a+480216>>2],v[a+480196>>2])>>>0))*1e4),v[G+480204>>2]=H;break Fa}while(1){Na:{if(x[a+480188>>1]<=e>>>0){break Fa}f=v[b>>2];v[23220]=0;f=W(143,f|0,v[d+96>>2],1)|0;i=v[23220];v[23220]=0;if((i|0)==1){break y}if(!f){break Fa}f=Gb(d+272|0);v[23220]=0;U(343,b|0,f|0,-1);i=v[23220];v[23220]=0;if((i|0)!=1){i=d+16|0;Pf(i,3,Ec(f),Bb(f));v[23220]=0;R(209,d+160|0,i|0);i=v[23220];v[23220]=0;if((i|0)==1){break Na}i=d+160|0;mm(((e<<5)+a|0)+480289|0,i);ub(i);ub(f);e=e+1|0;continue}}break}g=P()|0;O()|0;ub(f);break v}while(1){if(x[d+1742>>1]<=e>>>0){break Fa}f=v[b>>2];v[23220]=0;f=W(143,f|0,v[d+96>>2],1)|0;i=v[23220];v[23220]=0;if((i|0)==1){break x}if(!f){break Fa}if(!om(v[o>>2],v[o+4>>2],e&65535)){break Fa}f=Gb(d+272|0);v[23220]=0;U(343,b|0,f|0,-1);i=v[23220];v[23220]=0;Oa:{if((i|0)==1){break Oa}i=v[o>>2];v[23220]=0;R(271,Xb(i,e)|0,f|0);i=v[23220];v[23220]=0;if((i|0)==1){break Oa}ub(f);e=e+1|0;continue}break}g=P()|0;O()|0;ub(f);break v}v[23220]=0;Q(175,b|0,1)|0;e=v[23220];v[23220]=0;if((e|0)==1){break w}v[23220]=0;e=T(189,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break w}v[23220]=0;X(322,n|0,b|0,e|0,2);e=v[23220];v[23220]=0;if((e|0)!=1){break Fa}break w}v[23220]=0;Q(579,b|0,d+16|0)|0;e=v[23220];v[23220]=0;Pa:{if((e|0)!=1){e=Gb(d+272|0);v[23220]=0;U(343,b|0,e|0,-1);f=v[23220];v[23220]=0;if((f|0)==1){break Pa}if(_p(e,12588)){v[23220]=0;U(11,d+160|0,8,e|0);f=v[23220];v[23220]=0;if((f|0)==1){break Pa}f=d+160|0;Db(j,f);vb(f)}ub(e);break Fa}g=P()|0;O()|0;break v}g=P()|0;O()|0;ub(e);break v}v[23220]=0;k=T(144,b|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break w}}wb(b);continue}break}g=P()|0;O()|0;break v}g=P()|0;O()|0;break v}g=P()|0;O()|0;break v}g=P()|0;O()|0;break v}g=P()|0;O()|0}wb(b)}$b(r);break e}g=P()|0;O()|0;break e}while(1){b=v[j>>2];v[23220]=0;b=W(143,b|0,v[d+280>>2],1)|0;f=v[23220];v[23220]=0;Qa:{if((f|0)!=1){if(!b){break o}v[23220]=0;h=T(193,j|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break h}i=0;if((h|0)!=255){break Qa}v[23220]=0;i=T(193,j|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){v[23220]=0;h=T(193,j|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break Qa}}break h}break h}if(h&127){b=Xb(v[o>>2],r);f=$c(v[b>>2],v[v[b+48>>2]+12>>2],e,k&65535);uu(d+88|0);if(h&1){v[23220]=0;b=T(193,j|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break n}t[d+88|0]=b}if(h&2){v[23220]=0;b=T(193,j|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break n}t[d+89|0]=b}if(h&4){v[23220]=0;b=T(193,j|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break n}t[d+90|0]=b}if(h&8){v[23220]=0;b=T(193,j|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break n}t[d+91|0]=b}if(h&16){v[23220]=0;b=T(193,j|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break n}t[d+92|0]=b}if(h&32){v[23220]=0;b=T(193,j|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break n}t[d+93|0]=b}if(h&64){v[23220]=0;b=T(193,j|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break n}t[d+94|0]=b}E=cR(f,d+88|0);v[d+16>>2]=i;v[d+64>>2]=n+(e^-1);F=v[Eb(d+16|0,d- -64|0)>>2];h=0;b=f;while(1){if((h|0)!=(F|0)){b=B(x[D>>1],6)+b|0;m=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[b|0]=m;t[b+1|0]=m>>>8;t[b+2|0]=m>>>16;t[b+3|0]=m>>>24;m=w[f+4|0]|w[f+5|0]<<8;t[b+4|0]=m;t[b+5|0]=m>>>8;h=h+1|0;continue}break}g=g|E}e=(e+i|0)+1|0;while(1){if(e>>>0>=n>>>0){k=k+1|0;e=e-n|0;continue}break}if(p>>>0>(k&65535)>>>0){continue}break}}wb(j);r=r+1|0;continue}break}break h}g=P()|0;O()|0;ub(d+1376|0);break c}g=P()|0;O()|0;wb(j);break e}g=P()|0;O()|0;break e}g=P()|0;O()|0}wb(s)}wb(A)}S(g|0);L()}e=1}fb=d+1760|0;return e|0}function C8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,T=0,U=0,V=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,da=0;n=fb-1152|0;fb=n;wc(b);a:{if(!$q(b,n+1128|0)){break a}if(!nL(n+1128|0)){break a}if(v[n+1136>>2]!=($g(v[b>>2])|0)){break a}if(v[n+1144>>2]!=(Ze(b)|0)){break a}if(!c){d=1;break a}e=n+1072|0;Sb(e,0,56);h=-2;b:{if(!e){break b}v[e+44>>2]=0;v[e+48>>2]=0;v[e+52>>2]=0;v[e+20>>2]=0;v[e+24>>2]=0;v[e+8>>2]=0;k=v[e+32>>2];if(!k){v[e+32>>2]=1062;k=1062}if(!v[e+36>>2]){v[e+36>>2]=1063}k=jb[k|0](v[e+40>>2],1,43784)|0;h=-4;if(!k){break b}v[e+28>>2]=k;v[k+43780>>2]=1;v[k+10992>>2]=0;v[k+10996>>2]=0;v[k>>2]=0;v[k+11008>>2]=15;v[k+11e3>>2]=1;v[k+11004>>2]=0;h=0}if(h){break a}d=v[n+1144>>2];v[n+1068>>2]=d;J=v[n+1148>>2];T=US(n+1056|0,J);c:{d:{while(1){if(!(!d|!J|(f|0)==1)){v[n+16>>2]=1024;f=n+16|0;U=v[Eb(f,n+1068|0)>>2];d=v[cc(n+24|0,n+32|0,U)>>2];v[23220]=0;X(152,f|0,b|0,d|0,v[n+28>>2]);f=v[23220];v[23220]=0;if((f|0)==1){break d}k=n+32|0;f=k;d=U;e=$^-1;while(1){if(d>>>0<4){while(1){if(d){e=v[((w[f|0]^e&255)<<2)+62208>>2]^e>>>8;d=d-1|0;f=f+1|0;continue}break}$=e^-1}else{e=v[((w[f|0]^e&255)<<2)+62208>>2]^e>>>8;e=e>>>8^v[((w[f+1|0]^e&255)<<2)+62208>>2];e=e>>>8^v[((w[f+2|0]^e&255)<<2)+62208>>2];e=e>>>8^v[((w[f+3|0]^e&255)<<2)+62208>>2];d=d-4|0;f=f+4|0;continue}break}v[n+1076>>2]=U;v[n+1072>>2]=k;v[n+1088>>2]=J;v[n+1084>>2]=v[T>>2]+aa;E=fb-16|0;fb=E;f=-2;o=n+1072|0;e:{if(!o){break e}i=v[o+28>>2];if(!i){break e}da=v[o+4>>2];v[i+11e3>>2]=0;f:{if(v[i+43780>>2]<0){break f}if(v[i+11004>>2]){break e}e=v[i+11008>>2];f=0;v[i+11004>>2]=0;d=v[i+10996>>2];if(!d){s=(e|0)>0?11:10;K=i+11012|0;d=v[o+4>>2];h=v[i+10992>>2];while(1){v[E+12>>2]=d;v[E+8>>2]=32768-h;d=0;k=0;r=0;I=0;M=0;N=0;Z=0;_=fb-144|0;fb=_;f=v[E+8>>2];C=h+K|0;V=s&4;Y=V?-1:f+(C+(K^-1)|0)|0;G=Y+1|0;Q=f+C|0;D=v[o>>2];F=v[E+12>>2];A=D+F|0;g:{if(!(G&Y?0:C>>>0>=K>>>0)){v[E+8>>2]=0;v[E+12>>2]=0;l=-3;break g}R=v[i+60>>2];z=v[i+40>>2];f=v[i+36>>2];q=v[i+32>>2];h=v[i+56>>2];g=v[i+4>>2];l=-1;j=D;m=C;p=-1;h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{e=v[i>>2];switch(e|0){case 36:break k;case 39:break n;case 10:break o;case 35:break p;case 17:break q;case 21:break r;case 37:break s;case 34:break t;case 42:break x;case 41:break y;case 53:break z;case 52:break A;case 51:break B;case 38:break C;case 27:break D;case 26:break E;case 25:break F;case 24:break G;case 23:break H;case 18:break I;case 16:break J;case 14:break K;case 11:break L;case 9:break M;case 7:break N;case 6:break O;case 3:break P;case 32:break Q;case 5:break R;case 2:break T;case 1:break U;case 0:break V;default:break j}}v[i+28>>2]=1;h=0;v[i+8>>2]=0;v[i+12>>2]=0;v[i+16>>2]=1;z=0;f=0;q=0;g=0;if(s&1){break U}break S}if((F|0)<=0){v[i>>2]=1;break i}v[i+8>>2]=w[D|0];j=D+1|0}if(j>>>0>=A>>>0){v[i>>2]=2;l=s&2?1:-4;break h}f=w[j|0];v[i+12>>2]=f;j=j+1|0;k=v[i+8>>2];W:{if(!(((f|k<<8)>>>0)%31|f&32)){l=k&15;d=(l|0)!=8;if(!V){break W}f=0;e=36;if((l|0)!=8){break m}break S}e=36;d=1;if(V){break m}}f=0;e=36;l=d;d=256<<(k>>>4);if(l|(d>>>0>32768|d>>>0>G>>>0)){break m}}d=0;break w}if((F|0)<=0){v[i>>2]=5;break i}N=g+8|0;j=D+1|0;h=w[D|0]<<g|h;d=2;break w}if((F|0)<=0){v[i>>2]=32;break i}g=g+8|0;j=D+1|0;e=f;break v}d=1;break w}d=4;break w}d=3;break w}d=7;break w}d=9;break w}d=10;break w}d=11;break w}d=12;break w}d=13;break w}d=14;break w}d=15;break w}d=16;break w}d=17;break w}d=8;break w}d=5;break w}d=6;break w}d=18;break w}e=2;break u}e=1;break u}X:while(1){Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{switch(d|0){case 0:if(g>>>0>2){break Ba}d=1;continue;case 1:break Ca;case 9:break ga;case 10:break ha;case 11:break ia;case 12:break ja;case 13:break ka;case 14:break la;case 15:break ma;case 16:break na;case 17:break oa;case 8:break ta;case 7:break ua;case 6:break va;case 5:break wa;case 4:break ya;case 3:break za;case 2:break Aa;default:break pa}}while(1){if(j>>>0>=A>>>0){v[i>>2]=3;l=s&2?1:-4;break h}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;if(g>>>0<3){continue}break}}d=h&7;v[i+20>>2]=d;k=d>>>1|0;v[i+24>>2]=k;g=g-3|0;h=h>>>3|0;if(d>>>0>=2){break sa}N=g;break qa}g=N&-8;h=h>>>(N&7)|0;f=0;d=0;break ra}if(j>>>0<A>>>0){break xa}v[i>>2]=7;l=s&2?1:-4;break h}while(1){if(j>>>0>=A>>>0){v[i>>2]=6;l=s&2?1:-4;break h}h=w[j|0]<<g|h;d=g>>>0>4294967287;j=j+1|0;g=g+8|0;if(d){continue}break}d=1;break ra}t[(f+i|0)+10528|0]=w[j|0];j=j+1|0;d=2;break ra}while(1){if(j>>>0>=A>>>0){v[i>>2]=51;l=s&2?1:-4;break h}h=w[j|0]<<g|h;d=g>>>0>4294967287;j=j+1|0;g=g+8|0;if(d){continue}break}break _}p=2;e=52;if(m>>>0>=Q>>>0){break k}t[m|0]=q;f=f-1|0;m=m+1|0;break $}p=2;e=9;if(m>>>0>=Q>>>0){break k}d=8;continue}if(j>>>0<A>>>0){d=Q-m|0;e=A-j|0;d=d>>>0<e>>>0?d:e;d=d>>>0<f>>>0?d:f;f=f-d|0;m=nc(m,j,d)+d|0;j=d+j|0;break Z}v[i>>2]=38;l=s&2?1:-4;break h}e=0;Da:{switch(k-1|0){case 0:v[i+44>>2]=288;v[i+48>>2]=32;d=i+3552|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3560|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3568|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3576|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i- -64|0;k=0;while(1){e=144;if((k|0)==144){while(1){k=256;if((e|0)==256){while(1){e=280;if((k|0)==280){while(1){if((e|0)==288){break da}t[d|0]=8;e=e+1|0;d=d+1|0;continue}}else{t[d|0]=7;k=k+1|0;d=d+1|0;continue}}}else{t[d|0]=9;e=e+1|0;d=d+1|0;continue}}}else{t[d|0]=8;k=k+1|0;d=d+1|0;continue}};case 2:break o;default:break Da}}d=0;break fa}while(1){Ea:{Fa:{Ga:{Ha:{Ia:{switch(d|0){case 0:if(f>>>0>3){break Ha}if(!g){g=0;d=3;continue X}if(g>>>0>7){break Fa}d=4;continue X;case 1:t[(f+i|0)+10528|0]=h;g=g-8|0;h=h>>>8|0;break Ea;default:break Ia}}f=f+1|0;break Ga}f=x[i+10528>>1];if((f|0)==(x[i+10530>>1]^65535)){break $}break n}d=0;continue}d=1;continue}d=2;continue}}d=2;continue}p=2;e=53;if(m>>>0>=Q>>>0){break k}t[m|0]=w[(R-q&Y)+K|0];m=m+1|0;R=R+1|0;d=7;break aa}while(1){if(j>>>0>=A>>>0){v[i>>2]=27;l=s&2?1:-4;break h}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;if(z>>>0>g>>>0){continue}break}d=6;break aa}if(j>>>0>=A>>>0){v[i>>2]=26;l=s&2?1:-4;break h}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;d=4;if(g>>>0<15){break aa}d=5;break aa}while(1){if(j>>>0>=A>>>0){v[i>>2]=25;l=s&2?1:-4;break h}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;if(z>>>0>g>>>0){continue}break}d=3;break aa}p=2;e=24;if(m>>>0>=Q>>>0){break k}t[m|0]=f;m=m+1|0;break ba}if(j>>>0>=A>>>0){v[i>>2]=23;l=s&2?1:-4;break h}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;d=0;if(g>>>0<15){break aa}d=1;break aa}while(1){if(j>>>0>=A>>>0){v[i>>2]=18;l=s&2?1:-4;break h}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;if(z>>>0>g>>>0){continue}break}Z=q-16|0;d=3;break ca}if(j>>>0>=A>>>0){v[i>>2]=16;l=s&2?1:-4;break h}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;d=1;if(g>>>0<15){break ca}d=2;break ca}while(1){if(j>>>0>=A>>>0){v[i>>2]=14;l=s&2?1:-4;break h}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;if(g>>>0<3){continue}break}d=1;break ea}d=f+21579|0;while(1){if(j>>>0>=A>>>0){v[i>>2]=11;l=s&2?1:-4;break h}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;M=t[d|0];if(g>>>0<M>>>0){continue}break}e=f;d=1}while(1){Ja:{Ka:{La:{if(!d){if(e>>>0>2){break La}f=e;M=t[e+21579|0];if(M>>>0<=g>>>0){break Ja}d=9;continue X}f=e<<2;v[(f+i|0)+44>>2]=v[f+63744>>2]+((-1<<M^-1)&h);e=e+1|0;g=g-M|0;h=h>>>M|0;break Ka}f=0;Sb(i+7040|0,0,288);d=0;break ea}d=0;continue}d=1;continue}}while(1){Ma:{Na:{Oa:{if(!d){if(y[i+52>>2]<=f>>>0){break Oa}if(g>>>0>2){break Ma}d=10;continue X}t[(w[f+63760|0]+i|0)+7040|0]=h&7;f=f+1|0;g=g-3|0;h=h>>>3|0;break Na}v[i+52>>2]=19;break da}d=0;continue}d=1;continue}}I=v[i+24>>2];d=0}while(1){Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{switch(d|0){case 0:d=0;if((I|0)<0){break ba}F=Sb(_,0,64);e=B(I,3488)+i|0;Sb(e+352|0,0,3200);ba=e- -64|0;H=v[i+24>>2];e=v[((H<<2)+i|0)+44>>2];while(1){if((d|0)!=(e|0)){k=(w[d+ba|0]<<2)+F|0;v[k>>2]=v[k>>2]+1;d=d+1|0;continue}break};v[F+64>>2]=0;v[F+68>>2]=0;l=0;d=1;k=0;while(1){if((d|0)!=16){p=d<<2;d=d+1|0;p=v[p+F>>2];k=p+k<<1;v[(F- -64|0)+(d<<2)>>2]=k;l=l+p|0;continue}break};G=0;p=-1;if((k|0)!=65536&l>>>0>=2){break p}while(1){if(e>>>0>G>>>0){l=w[G+ba|0];Ya:{if(!l){break Ya}d=(F- -64|0)+(l<<2)|0;k=v[d>>2];v[d>>2]=k+1;d=0;e=l;while(1){if(e){d=k&1|d<<1;k=k>>>1|0;e=e-1|0;continue}break}if(l>>>0<=10){e=1<<l;k=l<<9|G;l=B(I,3488)+i|0;while(1){if(d>>>0>1023){break Ya}u[(l+(d<<1)|0)+352>>1]=k;d=d+e|0;continue}}H=B(I,3488)+i|0;k=H+((d&1023)<<1)|0;e=u[k+352>>1];Za:{if(e){k=p;p=e;break Za}u[k+352>>1]=p;k=p-2|0}d=d>>>9|0;while(1){d=d>>>1|0;e=d&1;if(l>>>0>=12){e=(H+(e+(p^-1)<<1)|0)+2400|0;p=u[e>>1];if(!p){u[e>>1]=k;p=k;k=k-2|0}l=l-1|0;continue}break}u[((B(I,3488)+i|0)+(e+(p^-1)<<1)|0)+2400>>1]=G;p=k}G=G+1|0;H=v[i+24>>2];e=v[((H<<2)+i|0)+44>>2];continue}break};d=0;if((H|0)!=2){break Qa}break Ua;case 1:d=u[(((h&1023)<<1)+i|0)+7328>>1];_a:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>g>>>0){break _a}break Ta}e=10;if(g>>>0<11){break _a}while(1){$a:{k=h>>>e|0;l=e+2|0;e=e+1|0;d=u[(((k&1)+(d^-1)<<1)+i|0)+9376>>1];if((d|0)>=0){break $a}if(g>>>0>=l>>>0){continue}}break}if((d|0)>=0){break Ta}}d=11;continue X;case 2:d=10;q=u[(((h&1023)<<1)+i|0)+7328>>1];if((q|0)>=0){break Wa}while(1){e=h>>>d|0;d=d+1|0;q=u[(((e&1)+(q^-1)<<1)+i|0)+9376>>1];if((q|0)<0){continue}break};break Va;default:break Xa}}d=t[Z+17788|0]+((-1<<z^-1)&h)|0;g=g-z|0;h=h>>>z|0;e=f+i|0;Sb(e+10532|0,(q|0)==16?w[e+10531|0]:0,d);d=d+f|0;break Ua}d=q>>9;q=q&511}g=g-d|0;h=h>>>d|0;if(q>>>0>15){break Sa}t[(f+i|0)+10532|0]=q;d=f+1|0}e=v[i+48>>2];f=v[i+44>>2];k=e+f|0;if(k>>>0<=d>>>0){break Ra}if(g>>>0<=14){if((A-j|0)<=1){f=d;d=1;continue}h=w[j|0]<<g|h|w[j+1|0]<<g+8;j=j+2|0;g=g+16|0}f=d}d=2;continue}if(!((q|0)!=16|f)){f=0;q=16;break q}Z=q-16|0;z=t[q+21554|0];if(z>>>0<=g>>>0){break Pa}d=12;continue X}if((d|0)!=(k|0)){f=d;break r}k=i+10532|0;nc(i- -64|0,k,f);nc(i+3552|0,f+k|0,e);H=v[i+24>>2];f=d}I=H-1|0;v[i+24>>2]=I;d=0;continue}d=3;continue}}r=f;d=2}ab:while(1){bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{switch(d|0){case 0:k=i- -64|0;d=u[(k+((h&1023)<<1)|0)+288>>1];ob:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>g>>>0){break ob}break bb}e=10;if(g>>>0<11){break ob}while(1){pb:{l=h>>>e|0;p=e+2|0;e=e+1|0;d=u[(k+((l&1)+(d^-1)<<1)|0)+2336>>1];if((d|0)>=0){break pb}if(g>>>0>=p>>>0){continue}}break}if((d|0)>=0){break bb}}d=13;continue X;case 1:d=10;e=i- -64|0;f=u[(e+((h&1023)<<1)|0)+288>>1];if((f|0)>=0){break mb}while(1){k=h>>>d|0;d=d+1|0;f=u[(e+((k&1)+(f^-1)<<1)|0)+2336>>1];if((f|0)<0){continue}break};break lb;case 2:e=i- -64|0;while(1){d=A-j|0;if(!((Q-m|0)>1&(d|0)>=4)){if(g>>>0>14){break bb}if((d|0)<=1){f=r;d=0;continue ab}h=w[j|0]<<g|h|w[j+1|0]<<g+8;g=g+16|0;j=j+2|0;break bb}if(!(g>>>0>14)){h=(w[j|0]|w[j+1|0]<<8)<<g|h;j=j+2|0;g=g+16|0}l=g;d=10;r=u[(e+((h&1023)<<1)|0)+288>>1];qb:{if((r|0)>=0){d=r>>9;break qb}while(1){f=h>>>d|0;d=d+1|0;r=u[(e+((f&1)+(r^-1)<<1)|0)+2336>>1];if((r|0)<0){continue}break}}g=l-d|0;h=h>>>d|0;if(r&256){f=r;break kb}if(!(g>>>0>14)){h=(w[j|0]|w[j+1|0]<<8)<<g|h;j=j+2|0;g=g+16|0}l=g;d=10;f=u[(e+((h&1023)<<1)|0)+288>>1];rb:{if((f|0)>=0){d=f>>9;break rb}while(1){k=h>>>d|0;d=d+1|0;f=u[(e+((k&1)+(f^-1)<<1)|0)+2336>>1];if((f|0)<0){continue}break}}t[m|0]=r;g=l-d|0;h=h>>>d|0;if(!(f&256)){t[m+1|0]=f;m=m+2|0;continue}break};m=m+1|0;break kb;case 3:g=g-z|0;d=h>>>z|0;f=((-1<<z^-1)&h)+f|0;break jb;case 4:d=u[(((h&1023)<<1)+i|0)+3840>>1];sb:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>g>>>0){break sb}break ib}e=10;if(g>>>0<11){break sb}while(1){tb:{k=h>>>e|0;l=e+2|0;e=e+1|0;d=u[(((k&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)>=0){break tb}if(g>>>0>=l>>>0){continue}}break}if((d|0)>=0){break ib}}d=16;continue X;case 5:e=10;d=u[(((h&1023)<<1)+i|0)+3840>>1];if((d|0)>=0){break hb}while(1){k=h>>>e|0;e=e+1|0;d=u[(((k&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){continue}break};break gb;case 6:g=g-z|0;e=h>>>z|0;q=((-1<<z^-1)&h)+q|0;break fb;default:break nb}}r=-1;d=f;f=d-1|0;if(!d){break eb}d=18;continue X}d=f>>9;f=f&511}g=g-d|0;h=h>>>d|0;if(f>>>0>255){break kb}d=14;continue X}e=256;d=f&511;if((d|0)==256){break Y}e=d-257<<2;f=v[e+63232>>2];z=0;if(d-285>>>0<4294967276){d=h;break jb}z=v[e+63360>>2];if(z>>>0<=g>>>0){break db}d=15;continue X}if(g>>>0>14){h=d;break ib}if((A-j|0)<=1){h=d;d=4;continue}h=w[j|0]<<g|d|w[j+1|0]<<g+8;g=g+16|0;j=j+2|0}d=5;continue}e=d>>9;d=d&511}g=g-e|0;h=h>>>e|0;e=d<<2;q=v[e+63488>>2];z=0;if(d-30>>>0<4294967270){e=h;break fb}z=v[e+63616>>2];if(z>>>0<=g>>>0){break cb}d=17;continue X}R=m-K|0;if(!(!V|(q|0)!=0&R>>>0>=q>>>0)){h=e;break s}d=(R-q&Y)+K|0;if((d>>>0<m>>>0?m:d)+f>>>0>Q>>>0){h=e;d=7;continue}r=f;while(1){if(r>>>0>=3){t[m|0]=w[d|0];t[m+1|0]=w[d+1|0];t[m+2|0]=w[d+2|0];r=r-3|0;d=d+3|0;m=m+3|0;continue}break}if(!r){h=e;r=0;break eb}t[m|0]=w[d|0];if((r|0)!=1){t[m+1|0]=w[d+1|0]}m=m+r|0;h=e}d=2;continue}d=3;continue}d=6;continue}d=1;continue}}if(!f|!g){break Z}if(g>>>0>7){break _}d=5;continue}g=g-8|0;q=h&255;h=h>>>8|0;d=6;continue}e=0;if(!f){break Y}d=7;continue}f=e;if(t[i+20|0]&1){break v}d=0;continue}}h=0;f=g>>>3|0;d=j-D|0;d=d>>>0>j>>>0?0:d;f=j>>>0>D>>>0?d>>>0>f>>>0?f:d:0;if((g&-8)==f<<3){j=j-f|0;k=0;d=0;f=e;g=0;if(!(s&1)){break t}e=0;break u}ca(6800,13142,2797,6810);L()}while(1){ub:{vb:{wb:{xb:{yb:{zb:{switch(e|0){case 0:if(k>>>0>3){f=k;g=d;break t}g=0;if(d){break yb}f=k;e=1;continue;case 1:break zb;default:break xb}}if(j>>>0<A>>>0){break vb}v[i>>2]=42;l=s&2?1:-4;break h}f=k;g=d;if(d>>>0>7){break wb}e=2;continue}while(1){if(j>>>0>=A>>>0){v[i>>2]=41;l=s&2?1:-4;break h}h=w[j|0]<<g|h;e=g>>>0>4294967287;j=j+1|0;d=g+8|0;g=d;if(e){continue}break}k=f}e=h&255;h=h>>>8|0;d=d-8|0;break ub}e=w[j|0];j=j+1|0;k=f;d=g}v[i+16>>2]=v[i+16>>2]<<8|e;k=k+1|0;e=0;continue}}p=0;e=34;break k}e=37;break l}e=21;break l}e=17;break l}e=35;break l}e=10;break l}e=39;break l}f=1}p=-1}v[i>>2]=e;l=p}d=g>>>3|0;e=j-D|0;e=e>>>0>j>>>0?0:e;d=j>>>0>D>>>0?d>>>0<e>>>0?d:e:0;j=j-d|0;g=g-(d<<3)|0;break h}l=s&2?1:-4}v[i+4>>2]=g;v[i+60>>2]=R;v[i+40>>2]=z;v[i+36>>2]=f;v[i+32>>2]=q;v[i+56>>2]=(((g&63)>>>0>=32?0:-1<<g)^-1)&h;v[E+12>>2]=j-D;g=m-C|0;v[E+8>>2]=g;if(!(s&9)|(l|0)<0){break g}j=(g>>>0)%5552|0;f=v[i+28>>2];d=f>>>16|0;h=f&65535;while(1){e=0;if(g){while(1){if((e|7)>>>0<j>>>0){f=w[C|0]+h|0;k=f+w[C+1|0]|0;p=k+w[C+2|0]|0;r=p+w[C+3|0]|0;m=r+w[C+4|0]|0;D=m+w[C+5|0]|0;N=D+w[C+6|0]|0;h=N+w[C+7|0]|0;d=h+(N+(D+(m+(r+(p+(k+(d+f|0)|0)|0)|0)|0)|0)|0)|0;C=C+8|0;e=e+8|0;continue}break}f=j&7;e=j&8184;k=C;while(1){if((e|0)!=(j|0)){e=e+1|0;h=w[k|0]+h|0;d=h+d|0;k=k+1|0;continue}break}g=g-j|0;d=(d>>>0)%65521|0;h=(h>>>0)%65521|0;C=f+C|0;j=5552;continue}else{f=d<<16|h;v[i+28>>2]=f;if(l){break g}l=0;if(!(s&1)){break g}l=(f|0)==v[i+16>>2]?0:-2}break}}fb=_+144|0;v[i+43780>>2]=l;f=v[E+12>>2];v[o>>2]=f+v[o>>2];v[o+4>>2]=v[o+4>>2]-f;v[o+8>>2]=f+v[o+8>>2];v[o+48>>2]=v[i+28>>2];f=v[E+8>>2];v[i+10996>>2]=f;d=v[o+16>>2];e=d>>>0>f>>>0?f:d;nc(v[o+12>>2],v[i+10992>>2]+K|0,e);v[o+12>>2]=e+v[o+12>>2];v[o+16>>2]=v[o+16>>2]-e;v[o+20>>2]=e+v[o+20>>2];k=v[i+10996>>2];v[i+10996>>2]=k-e;h=e+v[i+10992>>2]&32767;v[i+10992>>2]=h;if((l|0)<0){break f}if(!((l|0)!=1|da)){f=-5;break e}if(l){f=0;d=v[o+4>>2];if(!d|!v[o+16>>2]){break e}if((e|0)==(k|0)){continue}break e}break}f=(e|0)==(k|0);break e}e=v[o+16>>2];d=d>>>0<e>>>0?d:e;nc(v[o+12>>2],(v[i+10992>>2]+i|0)+11012|0,d);v[o+12>>2]=d+v[o+12>>2];v[o+16>>2]=v[o+16>>2]-d;v[o+20>>2]=d+v[o+20>>2];e=v[i+10996>>2];v[i+10996>>2]=e-d;v[i+10992>>2]=d+v[i+10992>>2]&32767;if(v[i+43780>>2]){break e}f=(d|0)==(e|0);break e}f=-3}fb=E+16|0;d=v[n+1068>>2]-U|0;v[n+1068>>2]=d;e=J+aa|0;J=v[n+1088>>2];aa=e-J|0;continue}break}b=n+1072|0;Ab:{if(!b){break Ab}d=v[b+28>>2];if(!d){break Ab}jb[v[b+36>>2]](v[b+40>>2],d);v[b+28>>2]=0}d=0;Bb:{Cb:{if(!(v[n+1140>>2]!=($|0)|J|(f|0)!=1)){ge(n+8|0,v[T>>2],v[T+4>>2]);b=Xd(n);f=v[b+4>>2];b=v[b>>2];v[23220]=0;b=ga(499,n+32|0,v[n+8>>2],v[n+12>>2],b|0,f|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break Cb}v[23220]=0;d=W(842,a|0,b|0,c|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break Bb}wb(b)}$b(T);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;wb(b);break c}a=P()|0;O()|0}$b(T);S(a|0);L()}fb=n+1152|0;return d|0}function kfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),y=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=C(0),Q=0,R=C(0),T=0,U=0,X=0,Y=0,$=0,aa=0,ba=0,ca=0,da=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=C(0),ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=C(0);p=fb-11360|0;fb=p;wc(c);a:{while(1){b:{if(!Lb(v[c>>2],v[c+8>>2],4)){break b}e=p+16|0;d=fb-16|0;fb=d;c:{if(!Lb(v[c>>2],v[c+8>>2],3)){f=0;while(1){if((f|0)!=3){rg(e+f|0);f=f+1|0;continue}break}break c}cv(d+8|0,e);md(d,c,v[d+8>>2],v[d+12>>2])}fb=d+16|0;d:{e:{if(!Mb(e,15e3,3)){e=p+4648|0;d=fb-16|0;fb=d;f:{if(!Lb(v[c>>2],v[c+8>>2],7)){f=0;while(1){if((f|0)!=7){rg(e+f|0);f=f+1|0;continue}break}break f}no(d+8|0,e);md(d,c,v[d+8>>2],v[d+12>>2])}fb=d+16|0;H=0;i=3;while(1){if((i|0)==7){break d}e=w[(p+4648|0)+i|0];if(e&128){break e}i=i+1|0;H=e|H<<7;continue}}g:{if(Mb(p+16|0,14173,3)){break g}if(!sR(c,13537)){break g}Yb(c,mg(c)+16|0);continue}if(!Mb(p+16|0,30222,3)){continue}if(!Mb(p+16|0,30226,3)){continue}if(!w[p+16|0]){jg(c,2);continue}if(bP(p+16|0)){break b}}i=0;break a}Yb(c,H);continue}break}wc(c);e=p+11336|0;GA(e,c);ca=v[p+11336>>2];Y=te(e);X=Ib(p+11320|0);c=p+4648|0;Sb(c,0,6668);Vy(c);c=p+4640|0;v[c>>2]=0;v[c+4>>2]=0;c=p+4632|0;v[c>>2]=0;v[c+4>>2]=0;v[p+4624>>2]=0;v[p+4628>>2]=0;H=0;c=0;h:{while(1){d=Dc(ca,da);aa=p+16|0;I=p+4624|0;e=0;n=fb-17168|0;fb=n;v[n+17164>>2]=0;i:{j:{E=p+4648|0;k:{if(w[E+6152|0]!=255|(d|0)<5){break k}if(!bp(E+6152|0,Y)){break k}i=Zw(w[Y+1|0],w[Y+2|0],v[E+6148>>2])+ap(Y)|0;v[n+17164>>2]=i;if((d|0)==(i|0)){i=d;break j}l:{if((d|0)>=(i+4|0)){if(bp(Y,i+Y|0)){break l}}v[n+17164>>2]=0;break k}if(i){break j}}f=Y;J=Sb(E,0,6668)+6148|0;$=n+17164|0;i=0;j=0;D=d-4|0;q=(D|0)>0?D:0;while(1){m:{n:{o:{p:{if((i|0)==(q|0)){i=d;break p}if(!LH(f)){break n}h=Zw(w[f+1|0],w[f+2|0],v[J>>2]);e=h+ap(f)|0;g=4;o=i+4|0;q:{while(1){if(!(g>>>0>2303|h)){if((D|0)<=((g<<1)+i|0)){break q}h=0;m=f+g|0;r:{if(!bp(f,m)){break r}k=g-ap(f)|0;y=ap(m)+k|0;if((d|0)<(y+(g+o|0)|0)){break r}if(!bp(f,m+y|0)){break r}v[J>>2]=k;h=k;e=g}g=g+1|0;continue}break}if(!h|(d|0)<(e+i|0)){break q}y=d-i|0;g=0;A=0;while(1){s:{t:{if((A|0)!=10){k=(A|0)!=0;F=g;g=f+g|0;g=(F+Zw(w[g+1|0],w[g+2|0],h)|0)+ap(g)|0;if((y|0)<(g+4|0)){break s}if(bp(f,f+g|0)){break t}k=0}else{k=1}break s}A=A+1|0;continue}break}if(!k){break q}j=e;break p}if((d|0)!=(e|0)|i){break o}i=0;j=d}v[$>>2]=j;e=i;break m}v[J>>2]=0}f=f+1|0;i=i+1|0;continue}break}i=v[n+17164>>2];if((d|0)>=(e+i|0)?i:0){break j}v[I>>2]=e;A=0;break i}d=e+Y|0;v[E+6152>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[I+4>>2]=e;v[I>>2]=e+i;v[I+8>>2]=w[d+3|0]>191?1:2;qa=I,ra=OH(w[d+1|0],w[d+2|0]),v[qa+12>>2]=ra;v[I+16>>2]=4-(w[d+1|0]>>>1&3);qa=I,ra=Yw(w[d+1|0],w[d+2|0]),v[qa+20>>2]=ra;if(!aa){A=Xw(w[d+1|0]);break i}NH(n+17152|0,d+4|0,i-4|0);if(!(t[d+1|0]&1)){$d(n+17152|0,16)}u:{if(v[I+16>>2]==3){A=0;m=n+17152|0;ja=n+3740|0;e=ja;f=0;g=w[d+1|0];i=B((g>>>3&1)+(g>>>4&1)|0,3)+(w[d+2|0]>>>2&3)|0;j=i-((i|0)!=0)|0;$=d;d=w[d+3|0]>191?1:2;v:{if(g&8){i=$d(m,9);d=d<<1;f=$d(m,d+7|0);break v}i=$d(m,d|8)>>>d|0}g=B(j,40);q=g+64080|0;o=g+64400|0;y=B(j,23)+63888|0;l=-1;h=0;w:{while(1){j=w[$+3|0];k=$d(m,12);u[e+4>>1]=k;g=$d(m,9);u[e+6>>1]=g;if((g&65535)>>>0>288){break w}g=j>>>0>191?f<<4:f;qa=e,ra=$d(m,8),t[qa+10|0]=ra;f=$d(m,w[$+1|0]&8?4:9);t[e+13|0]=22;t[e+14|0]=0;v[e>>2]=y;u[e+8>>1]=f;x:{if($d(m,1)){f=$d(m,2);t[e+11|0]=f;if(!(f&255)){break w}f=$d(m,1);u[e+18>>1]=65287;t[e+12|0]=f;if(w[e+11|0]==2){y:{if(!(f&255)){v[e>>2]=q;t[e+18|0]=8;j=39;f=0;break y}v[e>>2]=o;j=30;f=w[$+1|0]&8?8:6}t[e+14|0]=j;t[e+13|0]=f;g=g&3855}f=$d(m,10);qa=e,ra=$d(m,3),t[qa+21|0]=ra;qa=e,ra=$d(m,3),t[qa+22|0]=ra;qa=e,ra=$d(m,3),t[qa+23|0]=ra;f=f<<5;break x}t[e+11|0]=0;t[e+12|0]=0;f=$d(m,15);qa=e,ra=$d(m,4),t[qa+18|0]=ra;j=$d(m,3);t[e+20|0]=255;t[e+19|0]=j}t[e+17|0]=f&31;t[e+15|0]=f>>>10;t[e+16|0]=f>>>5&31;h=(k&65535)+h|0;z:{if(w[$+1|0]&8){f=$d(m,1);break z}f=x[e+8>>1]>499}t[e+24|0]=f;qa=e,ra=$d(m,1),t[qa+25|0]=ra;f=$d(m,1);t[e+27|0]=g>>>12&15;t[e+26|0]=f;e=e+28|0;f=g<<4;d=d-1|0;if(d){continue}break}l=(v[m+4>>2]+h|0)>(v[m+8>>2]+(i<<3)|0)?-1:i}if(!((l|0)<0|v[n+17156>>2]>v[n+17160>>2])){h=n+17152|0;i=v[h+4>>2];f=v[h+8>>2];d=n+912|0;g=v[E+6144>>2];e=g-l|0;j=(g|0)<(l|0)?g:l;g=nc(d+12|0,(((e|0)>0?e:0)+E|0)+6156|0,j);e=(f-i|0)/8|0;nc(g+j|0,v[h>>2]+(v[h+4>>2]/8|0)|0,e);NH(d,g,e+j|0);A:{i=v[E+6144>>2]>=(l|0);if(!i){break A}ma=E+2304|0;na=n+8620|0;oa=n+3852|0;while(1){if((w[$+1|0]&8?2:1)>>>0<=A>>>0){break A}pa=Sb(oa,0,4608);d=v[I+8>>2];K=B(B(d,A),28)+ja|0;e=0;ka=(d|0)>0?d:0;G=n+912|0;y=G+7548|0;ba=E+6152|0;while(1){if((e|0)!=(ka|0)){o=B(e,28)+K|0;J=x[o+4>>1];D=v[G+4>>2];d=(G+B(e,39)|0)+16156|0;h=y;q=e;j=fb-48|0;fb=j;ia=w[o+25|0];l=B(!w[o+13|0]+(w[o+14|0]!=0)|0,28)+64720|0;B:{if(w[ba+1|0]&8){e=w[o+27|0];g=w[x[o+8>>1]+64816|0];f=g&3;t[j+47|0]=f;t[j+46|0]=f;f=g>>>2|0;t[j+45|0]=f;t[j+44|0]=f;break B}e=(w[ba+3|0]&16)>>>4&(q|0)!=0;g=e?12:0;r=x[o+8>>1]>>>e|0;while(1){if((r|0)>=0){e=3;f=1;while(1){if((e|0)>=0){k=w[(e+g|0)+64832|0];t[(j+44|0)+e|0]=((r|0)/(f|0)|0)%(k|0);e=e-1|0;f=B(f,k);continue}break}g=g+4|0;r=r-f|0;continue}break}l=g+l|0;e=-16}g=d;f=j;m=f+44|0;r=0;while(1){C:{D:{E:{if((r|0)==4){break E}Q=w[l+r|0];if(!Q){break E}if(e&8){nc(f,g,Q);break D}fa=w[m+r|0];if(!fa){Sb(f,0,Q);Sb(g,0,Q);break D}d=(e|0)>=0?-1:-1<<fa^-1;k=0;while(1){if((k|0)==(Q|0)){break D}M=$d(G,fa);t[g+k|0]=(d|0)==(M|0)?-1:M;t[f+k|0]=M;k=k+1|0;continue}}t[f+2|0]=0;t[f|0]=0;t[f+1|0]=0;break C}e=e<<1;r=r+1|0;f=f+Q|0;g=g+Q|0;continue}break}F:{f=w[o+14|0];if(f){e=2-ia|0;m=w[o+23|0]<<e;k=w[o+22|0]<<e;g=w[o+21|0]<<e;d=w[o+13|0];e=0;while(1){if(e>>>0>=f>>>0){break F}M=j+(d+e|0)|0;t[M|0]=g+w[M|0];t[M+1|0]=k+w[M+1|0];t[M+2|0]=m+w[M+2|0];e=e+3|0;continue}}if(!w[o+24|0]){break F}e=0;while(1){if((e|0)==10){break F}d=e+j|0;t[d+11|0]=w[d+11|0]+w[e+64856|0];e=e+1|0;continue}}d=ia+1|0;e=0;s=Uw(C(2048),((((w[ba+3|0]&224)==96)<<1)-w[o+10|0]|0)+258|0);while(1){if(w[o+13|0]+(f&255)>>>0>e>>>0){qa=(e<<2)+h|0,sa=Uw(s,w[e+j|0]<<d),z[qa>>2]=sa;e=e+1|0;f=w[o+14|0];continue}break}fb=j+48|0;k=(G+B(q,2304)|0)+2940|0;ia=D+J|0;s=C(0);e=v[G+4>>2];f=v[G>>2]+((e|0)/8|0)|0;d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24))<<(e&7);l=e|-8;r=f+4|0;T=v[o>>2];U=x[o+6>>1];e=0;while(1){G:{H:{if((U|0)>0){j=e+1|0;e=e+o|0;d=w[e+15|0];fa=(u[(d<<1)+69280>>1]<<1)+64896|0;ga=w[e+18|0];if(d>>>0>=16){M=w[d+69344|0];m=32-M|0;while(1){J=w[T|0]>>>1|0;D=(J|0)>(U|0)?U:J;s=z[h>>2];while(1){e=g>>>27|0;d=5;while(1){e=u[fa+(e<<1)>>1];if((e|0)<0){g=g<<d;f=e&7;e=(g>>>32-f|0)-(e>>3)|0;l=d+l|0;d=f;continue}break}f=e&65535;e=f>>>8|0;l=e+l|0;g=g<<e;d=0;while(1){if((d|0)!=2){F=f&15;I:{if((F|0)==15){l=l+M|0;e=g<<M;while(1){if((l|0)>=0){e=w[r|0]<<l|e;r=r+1|0;l=l-8|0;continue}break}F=(g>>>m|0)+15|0;g=F;J:{if((g|0)<=128){N=z[(g<<2)+69440>>2];break J}ha=g<<3;Q=g;g=g>>>0<1024;ha=g?ha:Q;Q=ha<<1&64;R=C(C((ha&63)-Q|0)/C(Q+(ha&-64)|0));N=C((g?C(16):C(256))*C(C(C(R*C(C(R*C(.2222222238779068))+C(1.3333333730697632)))+C(1))*z[(Q+ha>>6<<2)+69440>>2]))}N=C(C(s*N)*C(e>>31|1));break I}e=g;N=C(s*z[(((e>>>27&16|F)^16)<<2)+69376>>2])}z[k>>2]=N;f=f>>>4|0;k=k+4|0;d=d+1|0;g=(F|0)!=0;l=g+l|0;g=e<<g;continue}break}while(1){if((l|0)>=0){g=w[r|0]<<l|g;r=r+1|0;l=l-8|0;continue}break}D=D-1|0;if(D){continue}break}h=h+4|0;T=T+1|0;U=U-J|0;if((U|0)<=0){break H}e=(ga|0)>0;ga=ga-1|0;if(e){continue}break}break H}while(1){m=w[T|0]>>>1|0;F=(m|0)>(U|0)?U:m;s=z[h>>2];while(1){e=g>>>27|0;d=5;while(1){e=u[fa+(e<<1)>>1];if((e|0)<0){g=g<<d;f=e&7;e=(g>>>32-f|0)-(e>>3)|0;l=d+l|0;d=f;continue}break}d=e&65535;e=d>>>8|0;l=e+l|0;g=g<<e;e=0;while(1){if((e|0)!=2){f=d&15;z[k>>2]=s*z[(((f|g>>>27&16)^16)<<2)+69376>>2];d=d>>>4|0;k=k+4|0;e=e+1|0;f=(f|0)!=0;l=f+l|0;g=g<<f;continue}break}while(1){if((l|0)>=0){g=w[r|0]<<l|g;r=r+1|0;l=l-8|0;continue}break}F=F-1|0;if(F){continue}break}h=h+4|0;T=T+1|0;U=U-m|0;if((U|0)<=0){break H}e=(ga|0)>0;ga=ga-1|0;if(e){continue}break}break H}d=1-U|0;while(1){K:{f=w[o+26|0]?69264:69232;e=w[f+(g>>>28|0)|0];if(!(e&8)){e=w[f+((g<<4>>>32-(e&3))+(e>>>3)|0)|0]}f=e&7;l=f+l|0;if((ia|0)<((l+(r-v[G>>2]<<3)|0)-24|0)){break K}d=d-1|0;if(!d){d=w[T|0];if(d>>>0<2){break K}T=T+1|0;s=z[h>>2];h=h+4|0;d=d>>>1|0}g=g<<f;if(e&128){z[k>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}if(e&64){z[k+4>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}d=d-1|0;if(!d){d=w[T|0];if(d>>>0<2){break K}T=T+1|0;s=z[h>>2];h=h+4|0;d=d>>>1|0}if(e&32){z[k+8>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}if(e&16){z[k+12>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}while(1){if((l|0)>=0){g=w[r|0]<<l|g;r=r+1|0;l=l-8|0;continue}break}k=k+16|0;continue}break}v[G+4>>2]=ia;break G}e=j;continue}break}e=q+1|0;continue}break}e=w[E+6155|0];L:{if(e&16){D=fb-16|0;fb=D;e=G+2940|0;g=e+2304|0;q=v[K>>2];o=w[K+14|0];f=o+w[K+13|0]|0;d=0;m=D+4|0;v[m+8>>2]=-1;v[m>>2]=-1;v[m+4>>2]=-1;while(1){if((d|0)!=(f|0)){y=d+q|0;j=w[y|0];h=0;M:{while(1){if(h>>>0>=j>>>0){break M}k=h<<2;if(z[k+g>>2]==C(0)){h=h+2|0;if(z[(k|4)+g>>2]==C(0)){continue}}break}v[m+((d>>>0)%3<<2)>>2]=d;j=w[y|0]}d=d+1|0;g=(j<<2)+g|0;continue}break}if(w[K+13|0]){g=v[D+4>>2];d=v[D+8>>2];g=(d|0)<(g|0)?g:d;d=v[D+12>>2];d=(d|0)<(g|0)?g:d;v[D+12>>2]=d;v[D+8>>2]=d;v[D+4>>2]=d}m=G+16195|0;j=o?3:1;g=f-j|0;h=0;while(1){if((h|0)!=(j|0)){f=g+h|0;d=f-j|0;if((d|0)<=v[(D+4|0)+(h<<2)>>2]){d=w[ba+1|0]<<28>>31&3}else{d=w[d+m|0]}t[f+m|0]=d;h=h+1|0;continue}break}q=v[K>>2];o=D+4|0;y=u[K+36>>1]&1;g=0;k=w[ba+1|0]&8?7:64;while(1){j=g+q|0;d=w[j|0];if(d){f=w[ba+3|0]&32;N:{O:{if(v[o+((g>>>0)%3<<2)>>2]>=(g|0)){break O}h=w[g+m|0];if(h>>>0>=k>>>0){break O}N=f?C(1.4142135381698608):C(1);P:{if(w[ba+1|0]&8){f=h<<3;s=z[f+69972>>2];R=z[f+69968>>2];break P}R=Uw(C(1),h+1>>>1<<y);f=h&1;s=f?C(1):R;R=f?R:C(1)}R=C(N*R);s=C(N*s);h=0;while(1){if((d|0)!=(h|0)){f=(h<<2)+e|0;N=z[f>>2];z[f+2304>>2]=N*s;z[f>>2]=N*R;h=h+1|0;continue}break}break N}if(!f){break N}KH(e,d)}g=g+1|0;e=(w[j|0]<<2)+e|0;continue}break}fb=D+16|0;break L}if((e&224)!=96){break L}KH(G+2940|0,576)}k=G+7708|0;e=0;while(1){if((e|0)!=(ka|0)){d=w[E+6153|0];q=(w[K+12|0]!=0)<<1<<((B((d>>>3&1)+(d>>>4&1)|0,3)+(w[E+6154|0]>>>2&3)|0)==2);j=(G+B(e,2304)|0)+2940|0;g=j;if(w[K+14|0]){r=v[K>>2]+w[K+13|0]|0;h=((G+B(e,2304)|0)+B(q,72)|0)+2940|0;d=h;f=k;while(1){o=w[r|0];if(o){y=o<<1;l=0;while(1){if((l|0)!=(o|0)){z[f>>2]=z[d>>2];z[f+4>>2]=z[(o<<2)+d>>2];z[f+8>>2]=z[(y<<2)+d>>2];d=d+4|0;l=l+1|0;f=f+12|0;continue}break}r=r+3|0;d=(y<<2)+d|0;continue}break}nc(h,k,f-k|0);f=q-1|0}else{f=31}while(1){d=0;if((f|0)>0){while(1){if((d|0)!=8){y=d<<2;h=y+g|0;la=z[h+72>>2];F=h;N=z[y+70032>>2];R=z[y+70064>>2];h=(17-d<<2)+g|0;s=z[h>>2];z[F+72>>2]=C(la*N)-C(R*s);z[h>>2]=C(la*R)+C(s*N);d=d+1|0;continue}break}g=g+72|0;f=f-1|0;continue}break}d=j;f=B(e,1152)+E|0;g=w[K+11|0];if(q){JH(d,f,70096,q);f=B(q,36)+f|0;d=B(q,72)+d|0}Q:{if((g|0)==2){h=32-q|0;m=fb-80|0;fb=m;q=m|8;o=m|4;while(1){if((h|0)>0){y=nc(m,d,72);g=v[f+20>>2];v[d+16>>2]=v[f+16>>2];v[d+20>>2]=g;g=v[f+12>>2];v[d+8>>2]=v[f+8>>2];v[d+12>>2]=g;g=v[f+4>>2];v[d>>2]=v[f>>2];v[d+4>>2]=g;g=f+24|0;Tw(y,d+24|0,g);Tw(o,d+48|0,g);Tw(q,f,g);d=d+72|0;f=f+36|0;h=h-1|0;continue}break}fb=m+80|0;break Q}JH(d,f,B((g|0)==3,72)+70096|0,32-q|0)}h=0;f=j+72|0;while(1){d=1;if(h>>>0<=31){while(1){if(d>>>0<=17){g=(d<<2)+f|0;z[g>>2]=-z[g>>2];d=d+2|0;continue}break}f=f+144|0;h=h+2|0;continue}break}K=K+28|0;e=e+1|0;continue}break}MH(ma,pa,18,v[I+8>>2],aa,na);A=A+1|0;aa=B(v[I+8>>2],1152)+aa|0;continue}}g=n+912|0;d=v[g+8>>2]>>>3|0;e=v[g+4>>2]+7>>>3|0;j=d-e|0;f=(j|0)<511?j:511;if((j|0)>0){Zi(E+6156|0,(g+(j>>>0>511?d-511|0:e)|0)+12|0,f)}v[E+6144>>2]=f;break u}Vy(E);break i}q=n+17152|0;f=0;g=0;h=0;A=0;e=d;R:{S:{T:{d=w[d+3|0];i=d>>>6|0;switch(i-1|0){case 2:break R;case 0:break T;default:break S}}g=(d>>>2&12)+4|0;break R}g=32}k=w[e+1|0];U:{if((k&6)==6){i=71500;d=32;break U}if(!(k&8)){i=71503;d=30;break U}d=w[e+2|0];j=d>>>2&3;d=Yw(k,d)>>>((i|0)!=3)|0;d=d?d:192;if(d>>>0<=55){i=71524;d=(j|0)==2?12:8;break U}i=71512;d=d>>>0>95?(j|0)!=1?30:27:27}t[n+768|0]=d;t[n+769|0]=(d|0)>(g|0)?g:d;d=i;j=71408;while(1){g=w[n+768|0];if(g>>>0<=f>>>0){f=0;while(1){j=g<<1&510;if(j>>>0>f>>>0){i=f+n|0;V:{if(!w[i+770|0]){d=6;break V}d=2;if((w[e+1|0]&6)==6){break V}d=$d(q,2);g=w[n+768|0]}t[i+834|0]=d;f=f+1|0;continue}break}g=n+770|0;o=n+834|0;e=n;f=0;while(1){if((f|0)!=(j|0)){d=w[g|0];i=d?19>>>w[f+o|0]&3|4:0;g=g+1|0;y=B(d,3)-6|0;s=C(0);d=4;while(1){if(d){if(d&i){k=$d(q,6);h=(k|0)/3|0;s=C(z[(y+(B(h,-3)+k|0)<<2)+71536>>2]*C(2097152>>>h|0))}z[e>>2]=s;d=d>>>1|0;e=e+4|0;continue}break}f=f+1|0;continue}break}f=w[n+769|0];e=w[n+768|0];e=e>>>0<f>>>0?f:e;while(1){if((e|0)!=(f|0)){t[((f<<1)+n|0)+771|0]=0;f=f+1|0;continue}break}}else{if((f|0)==(A|0)){j=w[d|0]+71408|0;A=w[d+2|0]+f|0;h=w[d+1|0];d=d+3|0}k=f<<1;g=w[$d(q,h)+j|0];t[(k+n|0)+770|0]=g;i=w[n+769|0];if(i>>>0>f>>>0){g=w[$d(q,h)+j|0];i=w[n+769|0]}t[((k|1)+n|0)+770|0]=i?g:0;f=f+1|0;continue}break}i=0;d=Sb(n+3852|0,0,4608);q=E+2304|0;o=n+8620|0;A=0;W:{while(1){if((A|0)==3){break W}y=d+(i<<2)|0;D=n+17152|0;j=0;J=v[I+16>>2]|1;m=(J|0)>0?J:0;l=576;while(1){if((j|0)!=4){f=y+(B(j,J)<<2)|0;g=0;while(1){if(w[n+768|0]<<1>>>0>g>>>0){X:{k=w[(g+n|0)+770|0];if(!k){break X}if(k>>>0<=16){h=(-1<<k-1)+1|0;e=0;while(1){if((e|0)==(m|0)){break X}qa=(e<<2)+f|0,sa=C($d(D,k)+h|0),z[qa>>2]=sa;e=e+1|0;continue}}h=2<<k-17;k=h>>>1|0;$=h|1;e=0;h=$d(D,(h-(h>>>3|0)|0)+3|0);while(1){if((e|0)==(m|0)){break X}F=h;h=(h>>>0)/($>>>0)|0;z[(e<<2)+f>>2]=F-(k+B($,h)|0)|0;e=e+1|0;continue}}g=g+1|0;f=(l<<2)+f|0;l=18-l|0;continue}break}j=j+1|0;continue}break}i=(J<<2)+i|0;if((i|0)==12){j=(A<<2)+n|0;e=d;i=w[n+769|0];f=d+B(i,72)|0;nc(f+2304|0,f,B(w[n+768|0]-i|0,72));g=0;while(1){if(w[n+768|0]>g>>>0){f=0;while(1){if((f|0)!=12){i=(f<<2)+e|0;z[i>>2]=z[j>>2]*z[i>>2];i=i+2304|0;z[i>>2]=z[j+12>>2]*z[i>>2];f=f+1|0;continue}break}j=j+24|0;e=e+72|0;g=g+1|0;continue}break}MH(q,d,12,v[I+8>>2],aa,o);Sb(d,0,4608);aa=B(v[I+8>>2],768)+aa|0;i=0}A=A+1|0;if(v[n+17156>>2]<=v[n+17160>>2]){continue}break}Vy(E);A=0;break i}i=1}A=B(Xw(w[E+6153|0]),i)}fb=n+17168|0;e=v[p+4624>>2];if((e|0)<0|!e&(A|0)!=0|!(e|A)){break h}Y:{if(e){e=v[p+4636>>2];if((e|0)!=(H|0)?H:0){break h}d=v[p+4632>>2];if((d|0)!=(c|0)?c:0){break h}if(d-3>>>0<4294967294|(e|0)<=0){break Y}v[p+12>>2]=0;qa=p,ra=Dc(ca,da),v[qa+8>>2]=ra;c=v[uj(p+4624|0,p+12|0,p+8|0)>>2];v[p+12>>2]=0;qa=p,ra=Dc(ca,da),v[qa+8>>2]=ra;Y=c+Y|0;c=ca;f=v[uj(p+4624|0,p+12|0,p+8|0)>>2];ca=c-f|0;da=da-((f>>31)+(c>>>0<f>>>0)|0)|0;Z:{if(!A){break Z}v[23220]=0;c=p+16|0;W(536,X|0,c|0,c+(B(d,A)<<1)|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break Z}H=V(91480)|0;if((O()|0)==(ea(91480)|0)){_(H|0)|0;v[23220]=0;Z(17);f=v[23220];v[23220]=0;H=e;c=d;if((f|0)!=1){break h}H=P()|0;O()|0}ld(X);Jc(p+11336|0);S(H|0);L()}H=e;c=d}if((Ic(v[X>>2],v[X+4>>2])>>>0)/(c>>>0)>>>0>268435456){break h}if(!!ca&(da|0)>=0|(da|0)>0){continue}break h}break}H=e;c=d}i=0;_:{if(!H|!c){break _}d=v[X>>2];e=v[X+4>>2];if(rc(d,e)){break _}if((Ic(d,e)>>>0)/(c>>>0)>>>0>268435456){break _}Xs(a,b);e=B(b,104)+a|0;d=e+484380|0;qa=d,ra=(Ic(v[X>>2],v[X+4>>2])>>>0)/(c>>>0)|0,v[qa>>2]=ra;a=e+484414|0;b=x[a>>1];u[a>>1]=(c|0)==2?b|65:b&65470|1;wg(d);a=e+484400|0;i=Md(v[d>>2],v[a>>2]);if(!i){break _}Ln(Ab(v[X>>2]),Ab(v[X+4>>2]),v[a>>2]);i=Md(v[d>>2],v[d+20>>2])}ld(X);Jc(p+11336|0)}fb=p+11360|0;return i|0}function iA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),A=0,E=0,F=0,G=0,I=C(0),J=0,K=0,M=0,N=0,O=C(0);r=fb-1520|0;fb=r;e=r+8|0;M=Sb(e,0,1512),N=-1,v[M+1420>>2]=N;t[r+56|0]=1;v[r+48>>2]=a+b;v[r+40>>2]=a;l=fb-1024|0;fb=l;t[e+1377|0]=1;a:{if(!Tr(e)){break a}b=w[e+1375|0];if(!(b&2)){Zb(e,34);break a}if(b&4){Zb(e,34);break a}if(b&1){Zb(e,34);break a}if(v[e+1116>>2]!=1){Zb(e,34);break a}b=w[e+1120|0];if((b|0)!=30){b:{if((b|0)!=64){break b}if(!Qw(e,l+1018|0,6)|w[l+1018|0]!=102|(w[l+1019|0]!=105|w[l+1020|0]!=115)){break b}if(w[l+1021|0]!=104|w[l+1022|0]!=101|w[l+1023|0]!=97){break b}if((Le(e)|0)!=100){break b}if(Le(e)){break b}Zb(e,38);break a}Zb(e,34);break a}if((Le(e)|0)!=1){Zb(e,34);break a}if(!Qw(e,l+1018|0,6)){Zb(e,10);break a}if(!Ow(l+1018|0)){Zb(e,34);break a}if(Xi(e)){Zb(e,34);break a}b=Le(e);v[e+4>>2]=b;if(!b){Zb(e,34);break a}if(b>>>0>=17){Zb(e,5);break a}b=Xi(e);v[e>>2]=b;if(!b){Zb(e,34);break a}Xi(e);Xi(e);Xi(e);b=Le(e);j=b>>>4|0;v[e+116>>2]=1<<j;g=b&15;v[e+112>>2]=1<<g;if(g-14>>>0<=4294967287){Zb(e,20);break a}if((b<<24)+536870912>>24>=0){Zb(e,20);break a}c:{if(g>>>0>j>>>0){Zb(e,20);break c}if(!(Le(e)&1)){Zb(e,34);break c}if(!Tr(e)){break a}if(!Pw(e)){break a}if(!Rw(e)){break a}if((fh(e)|0)==3){while(1){if((f|0)!=6){M=(l+1018|0)+f|0,N=fh(e),t[M|0]=N;f=f+1|0;continue}break}if(!Ow(l+1018|0)){Zb(e,20);break c}b=Nw(e);f=_d(e,b+1|0);v[e+20>>2]=f;if(f){f=0;g=(b|0)>0?b:0;while(1){if((f|0)!=(g|0)){j=fh(e);t[v[e+20>>2]+f|0]=j;f=f+1|0;continue}break}t[b+v[e+20>>2]|0]=0;b=Nw(e);v[e+28>>2]=0;v[e+24>>2]=b;d:{if((b|0)<=0){break d}b=_d(e,b<<2);v[e+28>>2]=b;if(b){break d}Zb(e,3);break c}while(1){e:{f:{if(v[e+24>>2]>(h|0)){b=Nw(e);f=_d(e,b+1|0);g=h<<2;v[g+v[e+28>>2]>>2]=f;if(!v[g+v[e+28>>2]>>2]){break f}f=0;j=(b|0)>0?b:0;while(1){if((f|0)==(j|0)){break e}i=fh(e);t[v[g+v[e+28>>2]>>2]+f|0]=i;f=f+1|0;continue}}if(!(fh(e)&1)){Zb(e,20);break c}xH(e,w[e+1376|0]);t[e+1376|0]=0;while(1){b=Rw(e);xH(e,b);t[e+1376|0]=0;if(b){continue}break}f=0;if(!Pw(e)){break a}if(!FH(e)){if(v[e+100>>2]!=21){break a}v[e+100>>2]=20;break a}b=0;while(1){if((b|0)!=256){j=b<<24;g=0;while(1){if((g|0)!=8){j=j>>31&79764919^j<<1;g=g+1|0;continue}break}v[(b<<2)+461760>>2]=j;b=b+1|0;continue}break}if((fh(e)|0)==5){while(1){if((f|0)!=6){M=(l+1018|0)+f|0,N=fh(e),t[M|0]=N;f=f+1|0;continue}break}if(!Ow(l+1018|0)){Zb(e,20);break c}b=mc(e,8)+1|0;v[e+120>>2]=b;b=_d(e,B(b,2096));v[e+124>>2]=b;if(!b){Zb(e,3);break c}Sb(b,0,B(v[e+120>>2],2096));g:{h:{while(1){i:{if(v[e+120>>2]>(E|0)){b=v[e+124>>2];if((mc(e,8)&255)!=66){Zb(e,20);break c}if((mc(e,8)&255)!=67){Zb(e,20);break c}if((mc(e,8)&255)!=86){Zb(e,20);break c}g=b+B(E,2096)|0;M=g,N=mc(e,8)&255|mc(e,8)<<8,v[M>>2]=N;M=g,N=mc(e,8)&255|(mc(e,8)<<8&65280|mc(e,8)<<16),v[M+4>>2]=N;k=g+4|0;f=0;m=mc(e,1);if(!m){f=mc(e,1)}t[g+23|0]=f;h=v[k>>2];if(v[g>>2]){b=h;break i}b=0;if(!h){break i}Zb(e,20);break c}b=mc(e,6)+1&255;f=0;j:{while(1){if((b|0)==(f|0)){break j}f=f+1|0;if(!mc(e,16)){continue}break}Zb(e,20);break c}b=mc(e,6)+1|0;v[e+128>>2]=b;b=_d(e,B(b,1596));v[e+260>>2]=b;k:{if(b){E=0;k=0;l:while(1){if(v[e+128>>2]<=(k|0)){break k}b=mc(e,16);u[((k<<1)+e|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){Zb(e,20);break c}if(!b){b=v[e+260>>2]+B(k,1596)|0;M=b,N=mc(e,8),t[M|0]=N;M=b,N=mc(e,16),u[M+2>>1]=N;M=b,N=mc(e,16),u[M+4>>1]=N;M=b,N=mc(e,6),t[M+6|0]=N;M=b,N=mc(e,8),t[M+7|0]=N;j=mc(e,4)+1|0;t[b+8|0]=j;h=b+9|0;f=0;while(1){if((j&255)>>>0>f>>>0){M=f+h|0,N=mc(e,8),t[M|0]=N;f=f+1|0;j=w[b+8|0];continue}break}Zb(e,4);break c}f=v[e+260>>2]+B(k,1596)|0;b=mc(e,5);t[f|0]=b;m=f+1|0;j=0;g=-1;while(1)if((b&255)>>>0<=j>>>0){h=g+1|0;g=f+82|0;i=f+65|0;o=f+49|0;n=f+33|0;b=0;while(1){if((b|0)!=(h|0)){M=b+n|0,N=mc(e,3)+1|0,t[M|0]=N;q=b+o|0;p=mc(e,2);t[q|0]=p;j=0;m:{if(!(p&255)){break m}p=mc(e,8);t[b+i|0]=p;if(v[e+120>>2]>(p&255)){break m}Zb(e,20);break c}n:{while(1){if(1<<w[q|0]<=(j|0)){break n}p=mc(e,8)-1|0;u[(g+(b<<4)|0)+(j<<1)>>1]=p;j=j+1|0;if(v[e+120>>2]>p<<16>>16){continue}break}Zb(e,20);break c}b=b+1|0;continue}break}g=2;M=f,N=mc(e,2)+1|0,t[M+1588|0]=N;b=mc(e,4);v[f+1592>>2]=2;h=0;u[f+338>>1]=0;t[f+1589|0]=b;u[f+340>>1]=1<<b;b=f+338|0;i=0;while(1){if(w[f|0]>i>>>0){o=n+w[i+m|0]|0;j=0;while(1){if(w[o|0]>j>>>0){g=mc(e,w[f+1589|0]);u[b+(v[f+1592>>2]<<1)>>1]=g;g=v[f+1592>>2]+1|0;v[f+1592>>2]=g;j=j+1|0;continue}break}i=i+1|0;continue}break}while(1){if((g|0)>(h|0)){g=x[b+(h<<1)>>1];j=(l+16|0)+(h<<2)|0;u[j+2>>1]=h;u[j>>1]=g;h=h+1|0;g=v[f+1592>>2];continue}break}wH(l+16|0,g,1064);j=0;g=v[f+1592>>2];h=g-1|0;h=(h|0)>0?h:0;o:{while(1){if((h|0)==(j|0)){h=f+838|0;j=0;break o}i=l+16|0;n=x[i+(j<<2)>>1];j=j+1|0;if((n|0)!=x[i+(j<<2)>>1]){continue}break}Zb(e,20);break c}while(1){if((g|0)>(j|0)){t[h+j|0]=w[((l+16|0)+(j<<2)|0)+2|0];j=j+1|0;g=v[f+1592>>2];continue}break}q=f+1088|0;j=2;while(1){if((g|0)>(j|0)){v[l+12>>2]=0;v[l+8>>2]=0;g=0;p=(j|0)>0?j:0;i=b+(j<<1)|0;m=65536;n=-1;while(1){if((g|0)!=(p|0)){o=b+(g<<1)|0;h=x[o>>1];if(!((n|0)>=(h|0)|x[i>>1]<=h>>>0)){v[l+12>>2]=g;h=x[o>>1];n=h}if(!((h|0)>=(m|0)|x[i>>1]>=h>>>0)){v[l+8>>2]=g;m=x[o>>1]}g=g+1|0;continue}break}h=q+(j<<1)|0;t[h|0]=v[l+12>>2];t[h+1|0]=v[l+8>>2];j=j+1|0;g=v[f+1592>>2];continue}break}E=(g|0)>(E|0)?g:E;k=k+1|0;continue l}else{b=mc(e,4);t[j+m|0]=b;b=b&255;g=(b|0)>(g|0)?b:g;j=j+1|0;b=w[f|0];continue}}}Zb(e,3);break c}b=mc(e,6)+1|0;v[e+264>>2]=b;b=_d(e,B(b,24));v[e+396>>2]=b;if(!b){Zb(e,3);break c}k=0;Sb(b,0,B(v[e+264>>2],24));p:{q:{r:{s:{while(1){if(v[e+264>>2]>(k|0)){b=v[e+396>>2];h=mc(e,16);u[((k<<1)+e|0)+268>>1]=h;if((h&65535)>>>0>=3){Zb(e,20);break c}g=b+B(k,24)|0;M=g,N=mc(e,24),v[M>>2]=N;b=mc(e,24);v[g+4>>2]=b;if(b>>>0<y[g>>2]){Zb(e,20);break c}M=g,N=mc(e,24)+1|0,v[M+8>>2]=N;M=g,N=mc(e,6)+1|0,t[M+12|0]=N;b=mc(e,8);t[g+13|0]=b;if(v[e+120>>2]<=(b&255)){break r}f=0;while(1){b=w[g+12|0];if(b>>>0>f>>>0){h=(l+16|0)+f|0;b=mc(e,3);if(mc(e,1)){i=mc(e,5)}else{i=0}t[h|0]=b+(i<<3);f=f+1|0;continue}break}b=_d(e,b<<4);v[g+20>>2]=b;if(!b){break q}h=0;while(1){if(w[g+12|0]>h>>>0){b=w[(l+16|0)+h|0];f=0;while(1){if((f|0)!=8){t:{if(b>>>f&1){j=mc(e,8);m=f<<1;i=h<<4;u[m+(i+v[g+20>>2]|0)>>1]=j;if(v[e+120>>2]>u[m+(i+v[g+20>>2]|0)>>1]){break t}Zb(e,20);break c}u[(v[g+20>>2]+(h<<4)|0)+(f<<1)>>1]=65535}f=f+1|0;continue}break}h=h+1|0;continue}break}h=_d(e,v[(v[e+124>>2]+B(w[g+13|0],2096)|0)+4>>2]<<2);v[g+16>>2]=h;if(!h){Zb(e,3);break c}b=0;Sb(h,0,v[(v[e+124>>2]+B(w[g+13|0],2096)|0)+4>>2]<<2);while(1){h=v[e+124>>2]+B(w[g+13|0],2096)|0;if(v[h+4>>2]>(b|0)){f=v[h>>2];j=_d(e,f);h=b<<2;v[h+v[g+16>>2]>>2]=j;j=b;if(!v[h+v[g+16>>2]>>2]){break s}while(1){if((f|0)>0){f=f-1|0;t[f+v[h+v[g+16>>2]>>2]|0]=(j|0)%w[g+12|0];j=(j|0)/w[g+12|0]|0;continue}break}b=b+1|0;continue}break}k=k+1|0;continue}break}b=mc(e,6)+1|0;v[e+400>>2]=b;b=_d(e,B(b,40));v[e+404>>2]=b;if(!b){Zb(e,3);break c}Sb(b,0,B(v[e+400>>2],40));i=0;while(1){if(v[e+400>>2]>(i|0)){b=v[e+404>>2];if(mc(e,16)){Zb(e,20);break c}h=b+B(i,40)|0;b=_d(e,B(v[e+4>>2],3));v[h+4>>2]=b;if(!b){Zb(e,3);break c}if(mc(e,1)){b=mc(e,4)+1|0}else{b=1}t[h+8|0]=b;u:{if(mc(e,1)){b=mc(e,8)+1|0;u[h>>1]=b;f=0;g=v[e+4>>2];if((g|0)<(b&65535)){Zb(e,20);break c}while(1){if((b&65535)>>>0<=f>>>0){break u}g=mc(e,El(g-1|0));b=B(f,3);t[b+v[h+4>>2]|0]=g;g=mc(e,El(v[e+4>>2]-1|0));t[(b+v[h+4>>2]|0)+1|0]=g;g=v[e+4>>2];b=b+v[h+4>>2]|0;j=w[b|0];if((g|0)<=(j|0)){Zb(e,20);break c}b=w[b+1|0];if((b|0)>=(g|0)){Zb(e,20);break c}if((b|0)!=(j|0)){f=f+1|0;b=x[h>>1];continue}break}Zb(e,20);break c}u[h>>1]=0}if(mc(e,2)){Zb(e,20);break c}g=0;b=0;f=0;v:{if(w[h+8|0]>=2){while(1){if(v[e+4>>2]<=(b|0)){break v}f=mc(e,4);j=B(b,3);t[(j+v[h+4>>2]|0)+2|0]=f;b=b+1|0;if(w[(j+v[h+4>>2]|0)+2|0]<w[h+8|0]){continue}break}Zb(e,20);break c}while(1){if(v[e+4>>2]<=(f|0)){break v}t[(v[h+4>>2]+B(f,3)|0)+2|0]=0;f=f+1|0;continue}}w:{while(1){if(w[h+8|0]<=g>>>0){break w}mc(e,8);b=g+h|0;M=b,N=mc(e,8),t[M+9|0]=N;f=mc(e,8);t[b+24|0]=f;if(v[e+128>>2]<=w[b+9|0]){Zb(e,20);break c}g=g+1|0;if(v[e+264>>2]>(f&255)){continue}break}Zb(e,20);break c}i=i+1|0;continue}break}f=mc(e,6)+1|0;v[e+408>>2]=f;h=e+412|0;j=0;x:{while(1){if((f|0)<=(j|0)){break x}b=h+B(j,6)|0;M=b,N=mc(e,1),t[M|0]=N;M=b,N=mc(e,16),u[M+2>>1]=N;M=b,N=mc(e,16),u[M+4>>1]=N;f=mc(e,8);t[b+1|0]=f;if(x[b+2>>1]){Zb(e,20);break c}if(x[b+4>>1]){Zb(e,20);break c}if(v[e+400>>2]>(f&255)){j=j+1|0;f=v[e+408>>2];continue}break}Zb(e,20);break c}CH(e);v[e+992>>2]=0;h=E<<1;f=0;while(1){if(v[e+4>>2]>(f|0)){b=(f<<2)+e|0;M=b,N=_d(e,v[e+116>>2]<<2),v[M+800>>2]=N;M=b,N=_d(e,v[e+116>>2]<<1&2147483646),v[M+928>>2]=N;g=_d(e,h);v[b+996>>2]=g;j=v[b+800>>2];if(g?!j|!v[b+928>>2]:1){Zb(e,3);break c}Sb(j,0,v[e+116>>2]<<2);f=f+1|0;continue}break}f=0;if(!vH(e,0,v[e+112>>2])){break a}if(!vH(e,1,v[e+116>>2])){break a}v[e+104>>2]=v[e+112>>2];h=v[e+116>>2];v[e+108>>2]=h;b=v[e+264>>2];i=(b|0)>0?b:0;b=(h|0)/2|0;g=0;while(1){if((f|0)!=(i|0)){j=v[e+396>>2]+B(f,24)|0;k=v[j+4>>2];n=b>>>0>k>>>0?k:b;k=v[j>>2];j=(n-(b>>>0>k>>>0?k:b)>>>0)/y[j+8>>2]|0;g=(g|0)<(j|0)?j:g;f=f+1|0;continue}break}b=h<<1&2147483646;h=B(v[e+4>>2],(g<<2)+4|0);b=b>>>0>h>>>0?b:h;v[e+12>>2]=b;y:{if(!v[e+80>>2]){break y}h=v[e+92>>2];if((h|0)!=v[e+84>>2]){break p}if(h>>>0>=(b+v[e+88>>2]|0)+1512>>>0){break y}Zb(e,3);break c}if(v[e+1380>>2]==-1){v[e+52>>2]=w[e+48|0]?0:v[e+32>>2]-v[e+36>>2]|0;f=1;break a}v[e+52>>2]=0;f=1;break a}Zb(e,3);break c}Zb(e,20);break c}Zb(e,3);break c}ca(7262,13164,4196,8800);L()}z:{if(f&255){j=jn(e,b);break z}j=_d(e,b);v[g+8>>2]=j}if(!j){Zb(e,3);break c}i=0;A:{if(!m){f=0;while(1){b=v[k>>2];if((f|0)>=(b|0)){break A}B:{C:{if(w[g+23|0]){if(!mc(e,1)){break C}}b=mc(e,5)+1|0;t[f+j|0]=b;if((b&255)!=32){i=i+1|0;break B}Zb(e,20);break c}t[f+j|0]=255}f=f+1|0;continue}}h=mc(e,5);f=0;while(1){b=v[k>>2];if((f|0)>=(b|0)){break A}m=mc(e,El(b-f|0));h=h+1|0;if((h|0)>=32){Zb(e,20);break c}b=f+m|0;if((b|0)>v[k>>2]){Zb(e,20);break c}else{Sb(f+j|0,h,m);f=b;continue}}}D:{E:{F:{if(w[g+23|0]){if(b>>2>(i|0)){break F}if(v[e+16>>2]<(b|0)){v[e+16>>2]=b;b=v[k>>2]}b=_d(e,b);v[g+8>>2]=b;if(!b){Zb(e,3);break c}nc(b,j,v[k>>2]);Wi(e,j,v[k>>2]);j=v[g+8>>2];t[g+23|0]=0;b=v[k>>2]}h=0;i=(b|0)>0?b:0;f=0;while(1){if((f|0)!=(i|0)){h=((w[f+j|0]-11&255)>>>0<244)+h|0;f=f+1|0;continue}break}v[g+2092>>2]=h;b=_d(e,b<<2);v[g+32>>2]=b;if(b){m=g+2092|0;f=0;break E}Zb(e,3);break c}v[g+2092>>2]=i;m=g+2092|0;G:{if(!i){f=0;h=0;break G}b=_d(e,i);v[g+8>>2]=b;if(!b){Zb(e,3);break c}b=jn(e,v[m>>2]<<2);v[g+32>>2]=b;if(!b){Zb(e,3);break c}f=jn(e,v[m>>2]<<2);if(!f){break D}b=v[k>>2];h=v[m>>2]}b=(h<<3)+b|0;if(b>>>0<=y[e+16>>2]){break E}v[e+16>>2]=b}n=v[k>>2];b=0;h=fb-128|0;fb=h;o=Sb(h,0,128);h=(n|0)>0?n:0;while(1){H:{I:{if((b|0)!=(h|0)){if(w[b+j|0]==255){break I}h=b}if((h|0)==(n|0)){b=1;if(!v[g+2092>>2]){break H}ca(15677,13164,1103,7506);L()}b=h+j|0;i=w[b|0];if(i>>>0<32){tH(g,0,h,0,i,f);q=1;i=w[b|0]+1|0;b=1;J:{while(1){if((b|0)==(i|0)){K:while(1){L:{b=1;h=h+1|0;if((n|0)<=(h|0)){break H}F=h+j|0;i=w[F|0];if((i|0)==255){continue}b=i;if(b>>>0>=32){break L}while(1){if((b|0)<=0){b=0;break H}G=o+(b<<2)|0;p=v[G>>2];if(!p){b=b-1|0;continue}break}v[G>>2]=0;tH(g,Cl(p),h,q,i,f);q=q+1|0;i=w[F|0];if((i|0)==(b|0)){continue}while(1){if((b|0)>=(i|0)){continue K}F=o+(i<<2)|0;if(v[F>>2]){break J}v[F>>2]=p+(1<<32-i);i=i-1|0;continue}}break}}else{v[o+(b<<2)>>2]=1<<32-b;b=b+1|0;continue}break}ca(15203,13164,1118,7506);L()}ca(15721,13164,1133,7506);L()}ca(15210,13164,1104,7506);L()}b=b+1|0;continue}break}fb=o+128|0;if(!b){if(w[g+23|0]){Wi(e,f,0)}Zb(e,20);break c}b=v[m>>2];if(b){b=_d(e,(b<<2)+4|0);v[g+2084>>2]=b;if(!b){Zb(e,3);break c}b=_d(e,(v[m>>2]<<2)+4|0);v[g+2088>>2]=b;if(!b){Zb(e,3);break c}v[g+2088>>2]=b+4;v[b>>2]=-1;b=0;i=0;M:{N:{O:{if(w[g+23|0]){while(1){i=v[g+2092>>2];if((i|0)<=(b|0)){break O}h=b<<2;M=h+v[g+2084>>2]|0,N=Cl(v[h+v[g+32>>2]>>2]),v[M>>2]=N;b=b+1|0;continue}}while(1){if(v[g+4>>2]>(b|0)){if(sH(w[g+23|0],w[b+j|0])){M=v[g+2084>>2]+(i<<2)|0,N=Cl(v[v[g+32>>2]+(b<<2)>>2]),v[M>>2]=N;i=i+1|0}b=b+1|0;continue}break}if(v[g+2092>>2]!=(i|0)){break N}}wH(v[g+2084>>2],i,1065);v[v[g+2084>>2]+(v[g+2092>>2]<<2)>>2]=-1;h=0;b=v[g+(w[g+23|0]?2092:4)>>2];p=(b|0)>0?b:0;P:{while(1){if((h|0)!=(p|0)){b=h;i=w[g+23|0];b=i?v[(b<<2)+f>>2]:b;F=w[b+j|0];Q:{if(!sH(i,F)){break Q}G=h<<2;n=Cl(v[G+v[g+32>>2]>>2]);b=v[g+2092>>2];i=0;while(1){if((b|0)>=2){o=b>>>1|0;J=o+i|0;q=n>>>0<y[v[g+2084>>2]+(J<<2)>>2];b=q?o:b-o|0;i=q?i:J;continue}break}b=i<<2;if((n|0)!=v[b+v[g+2084>>2]>>2]){break P}if(w[g+23|0]){v[b+v[g+2088>>2]>>2]=v[f+G>>2];t[v[g+8>>2]+i|0]=F;break Q}v[b+v[g+2088>>2]>>2]=h}h=h+1|0;continue}break}break M}ca(12205,13164,1230,9943);L()}ca(7447,13164,1200,9943);L()}}if(w[g+23|0]){Wi(e,f,v[m>>2]<<2);Wi(e,v[g+32>>2],v[m>>2]<<2);Wi(e,j,v[k>>2]);v[g+32>>2]=0}i=g;b=0;f=0;while(1){if((b|0)!=1024){u[(i+(b<<1)|0)+36>>1]=65535;b=b+1|0;continue}break}b=v[i+(w[i+23|0]?2092:4)>>2];b=(b|0)<32767?b:32767;h=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){R:{if(w[v[i+8>>2]+f|0]>10){break R}S:{if(w[i+23|0]){b=Cl(v[v[i+2084>>2]+(f<<2)>>2]);break S}b=v[v[i+32>>2]+(f<<2)>>2]}while(1){if(b>>>0>1023){break R}u[(i+(b<<1)|0)+36>>1]=f;b=(1<<w[v[i+8>>2]+f|0])+b|0;continue}}f=f+1|0;continue}break}b=mc(e,4);t[i+21|0]=b;b=b&255;if(b>>>0>=3){Zb(e,20);break c}if(b){M=i,O=uH(mc(e,32)),z[M+12>>2]=O;M=i,O=uH(mc(e,32)),z[M+16>>2]=O;M=i,N=mc(e,4)+1|0,t[M+20|0]=N;M=i,N=mc(e,1),t[M+22|0]=N;f=v[i>>2];h=v[k>>2];T:{if(w[i+21|0]==1){A=H(tx(+C(C(ip(+C(h|0)))/C(f|0))));U:{if(D(A)<2147483648){b=~~A;break U}b=-2147483648}A=+(f|0);K=H(Mj(+C(C(b|0)+C(1)),A));V:{if(D(K)<2147483648){f=~~K;break V}f=-2147483648}b=((f|0)<=(h|0))+b|0;s=C(b|0);if(Mj(+C(s+C(1)),A)<=+(h|0)){f=-1}else{A=H(Mj(+s,A));W:{if(D(A)<2147483648){f=~~A;break W}f=-2147483648}f=(f|0)>(h|0)?-1:b}if((f|0)>=0){break T}Zb(e,20);break c}f=B(f,h)}v[i+24>>2]=f;if(!f){Zb(e,20);break c}n=jn(e,f<<1);if(!n){break h}f=0;while(1){j=v[i+24>>2];if((j|0)>(f|0)){b=mc(e,w[i+20|0]);if((b|0)==-1){Wi(e,n,v[i+24>>2]<<1);Zb(e,20);break c}else{u[n+(f<<1)>>1]=b;f=f+1|0;continue}}break}X:{Y:{if(w[i+21|0]==1){o=w[i+23|0];Z:{if(o){f=v[m>>2];if(f){break Z}break X}f=v[k>>2]}b=_d(e,B(v[i>>2],f)<<2);v[i+28>>2]=b;if(!b){Wi(e,n,v[i+24>>2]<<1);Zb(e,3);break c}h=0;b=v[(o?m:k)>>2];m=(b|0)>0?b:0;q=i+2088|0;s=C(0);while(1){if((h|0)==(m|0)){break Y}g=h;g=o?v[v[q>>2]+(g<<2)>>2]:g;j=v[i>>2];f=0;b=1;while(1){if((f|0)<(j|0)){I=C(s+C(C(C(x[n+(((g>>>0)/(b>>>0)>>>0)%y[i+24>>2]<<1)>>1])*z[i+16>>2])+z[i+12>>2]));z[v[i+28>>2]+(B(h,j)+f<<2)>>2]=I;s=w[i+22|0]?I:s;f=f+1|0;j=v[i>>2];if((f|0)>=(j|0)){continue}k=v[i+24>>2];Bia(k,0,b,0);if(ib){Wi(e,n,k<<1);Zb(e,20);break c}else{b=B(b,k);continue}}break}h=h+1|0;continue}}b=_d(e,j<<2);v[i+28>>2]=b;if(!b){break g}f=0;s=C(0);while(1){j=v[i+24>>2];if((j|0)<=(f|0)){break X}I=C(s+C(C(C(x[n+(f<<1)>>1])*z[i+16>>2])+z[i+12>>2]));z[v[i+28>>2]+(f<<2)>>2]=I;s=w[i+22|0]?I:s;f=f+1|0;continue}}t[i+21|0]=2;j=v[i+24>>2]}Wi(e,n,j<<1)}E=E+1|0;continue}break}Zb(e,3);break c}Zb(e,3);break c}Wi(e,n,v[i+24>>2]<<1);Zb(e,3);break c}Zb(e,20);break c}Zb(e,3);break c}t[b+v[v[e+28>>2]+(h<<2)>>2]|0]=0;h=h+1|0;continue}}Zb(e,3);break c}Zb(e,20)}f=0}fb=l+1024|0;_:{$:{if(!f){v[d>>2]=v[r+104>>2]?1:v[r+108>>2];break $}b=_d(r+8|0,1512);if(b){M=c,N=v[nc(b,r+8|0,1512)+32>>2]-a|0,v[M>>2]=N;v[d>>2]=0;break _}}GH(r+8|0);b=0}fb=r+1520|0;return b}function qG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0;s=fb-48|0;fb=s;a:{if(c>>>0<=2){c=c<<2;I=v[c+78604>>2];J=v[c+78592>>2];while(1){c=v[b+4>>2];b:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=jd(b)}if(wk(c)){continue}break}o=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}o=(c|0)==45?-1:1;c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=jd(b)}e:{f:{while(1){if(t[g+4913|0]==(c|32)){g:{if(g>>>0>6){break g}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=jd(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){v[b+4>>2]=v[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}i=fb-16|0;fb=i;l=(p(C(C(o|0)*C(N))),j(2));b=l&2147483647;h:{if(b-8388608>>>0<=2130706431){r=b<<25;c=(b>>>7|0)+1065353216|0;break h}r=l<<25;c=l>>>7|2147418112;if(b>>>0>=2139095040){break h}r=0;c=0;if(!b){break h}c=b;b=E(b);vf(i,c,0,0,0,b+81|0);k=v[i>>2];h=v[i+4>>2];r=v[i+8>>2];c=v[i+12>>2]^65536|16265-b<<16}v[s>>2]=k;v[s+4>>2]=h;v[s+8>>2]=r;v[s+12>>2]=l&-2147483648|c;fb=i+16|0;k=v[s+8>>2];h=v[s+12>>2];i=v[s>>2];l=v[s+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(t[g+9939|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=jd(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=v[b+4>>2];o:{if((g|0)!=v[b+104>>2]){v[b+4>>2]=g+1;g=w[g|0];break o}g=jd(b)}if((g&-33)==88){g=d;c=0;f=fb-432|0;fb=f;p:{q:{d=v[b+4>>2];if((d|0)!=v[b+104>>2]){v[b+4>>2]=d+1;c=w[d|0];break q}d=0;break p}d=1}while(1){r:{s:{t:{u:{v:{w:{x:{y:{if(!d){c=jd(b);break y}if((c|0)!=48){l=1073676288;if((c|0)==46){break w}break v}d=v[b+4>>2];if((d|0)==v[b+104>>2]){break x}n=1;v[b+4>>2]=d+1;c=w[d|0]}d=1;continue}n=1;break s}c=v[b+4>>2];z:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break z}c=jd(b)}if((c|0)==48){break u}F=1}break t}while(1){c=r;r=c-1|0;u=u-!c|0;F=1;c=v[b+4>>2];A:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break A}c=jd(b)}if((c|0)==48){continue}break}n=1}while(1){e=c|32;B:{C:{M=c-48|0;if(M>>>0<10){break C}if(!((c|0)==46|e-97>>>0<6)){d=c;break r}d=46;if((c|0)!=46){break C}if(F){break r}F=1;r=k;u=h;break B}c=(c|0)>57?e-87|0:M;D:{if((h|0)<=0&k>>>0<=7|(h|0)<0){x=c+(x<<4)|0;break D}if(!h&k>>>0<=28){Ig(f+48|0,c);Ad(f+32|0,G,H,i,l,0,0,0,1073414144);G=v[f+32>>2];H=v[f+36>>2];i=v[f+40>>2];l=v[f+44>>2];Ad(f+16|0,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2],G,H,i,l);tg(f,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2],m,q,A,D);A=v[f+8>>2];D=v[f+12>>2];m=v[f>>2];q=v[f+4>>2];break D}if(!c|z){break D}Ad(f+80|0,G,H,i,l,0,0,0,1073610752);tg(f- -64|0,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2],m,q,A,D);A=v[f+72>>2];D=v[f+76>>2];z=1;m=v[f+64>>2];q=v[f+68>>2]}c=k+1|0;h=c?h:h+1|0;k=c;n=1}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0]}else{c=jd(b)}continue}}d=0;continue}break}E:{if(!n){c=v[b+116>>2];F:{G:{if((c|0)>0|(c|0)>=0){c=v[b+4>>2];v[b+4>>2]=c-1;if(!g){break G}v[b+4>>2]=c-2;if(!F){break F}v[b+4>>2]=c-3;break F}if(g){break F}}ai(b,0,0)}Ti(f+96|0,+(o|0)*0);m=v[f+96>>2];q=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2];break E}if((h|0)<=0&k>>>0<=7|(h|0)<0){i=k;l=h;while(1){x=x<<4;c=i+1|0;l=c?l:l+1|0;i=c;if((c|0)!=8|l){continue}break}}H:{I:{J:{if((d&-33)==80){i=pG(b,g);c=ib;l=c;if(i|(c|0)!=-2147483648){break H}if(g){c=v[b+116>>2];if((c|0)>0|(c|0)>=0){break J}break I}m=0;q=0;ai(b,0,0);c=0;b=0;break E}i=0;l=0;if(v[b+116>>2]<0){break H}}v[b+4>>2]=v[b+4>>2]-1}i=0;l=0}if(!x){Ti(f+112|0,+(o|0)*0);m=v[f+112>>2];q=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break E}b=F?r:k;h=(F?u:h)<<2|b>>>30;b=i+(b<<2)|0;d=h+l|0;d=b>>>0<i>>>0?d+1|0:d;k=b-32|0;h=d-(b>>>0<32)|0;b=h;if(k>>>0>0-I>>>0&(b|0)>=0|(b|0)>0){v[115696]=68;Ig(f+160|0,o);Ad(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);Ad(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);m=v[f+128>>2];q=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break E}b=I-226|0;c=b>>31;if((h|0)>=(c|0)&b>>>0<=k>>>0|(c|0)<(h|0)){if((x|0)>=0){while(1){tg(f+416|0,m,q,A,D,0,0,0,-1073807360);c=NS(m,q,A,D,1073610752);b=(c|0)<0;tg(f+400|0,m,q,A,D,b?m:v[f+416>>2],b?q:v[f+420>>2],b?A:v[f+424>>2],b?D:v[f+428>>2]);b=k;k=b-1|0;h=h-!b|0;A=v[f+408>>2];D=v[f+412>>2];m=v[f+400>>2];q=v[f+404>>2];x=x<<1|(c|0)>=0;if((x|0)>=0){continue}break}}d=h-((I>>31)+(k>>>0<I>>>0)|0)|0;b=(k-I|0)+32|0;d=b>>>0<32?d+1|0:d;c=b>>>0<J>>>0&(d|0)<=0|(d|0)<0?(b|0)>0?b:0:J;K:{if((c|0)>=113){Ig(f+384|0,o);r=v[f+392>>2];u=v[f+396>>2];G=v[f+384>>2];H=v[f+388>>2];h=0;b=0;break K}Ti(f+352|0,Cj(1,144-c|0));Ig(f+336|0,o);G=v[f+336>>2];H=v[f+340>>2];r=v[f+344>>2];u=v[f+348>>2];sG(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],G,H,r,u);K=v[f+376>>2];L=v[f+380>>2];h=v[f+372>>2];b=v[f+368>>2]}c=!(x&1)&((gm(m,q,A,D,0,0,0,0)|0)!=0&(c|0)<32);Wm(f+320|0,c+x|0);Ad(f+304|0,G,H,r,u,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);d=b;tg(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,h,K,L);b=c;Ad(f+288|0,G,H,r,u,b?0:m,b?0:q,b?0:A,b?0:D);tg(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);Nx(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],d,h,K,L);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];h=v[f+252>>2];if(!gm(b,c,d,h,0,0,0,0)){v[115696]=68}rG(f+224|0,b,c,d,h,k);m=v[f+224>>2];q=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break E}v[115696]=68;Ig(f+208|0,o);Ad(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);Ad(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);m=v[f+176>>2];q=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2]}v[s+16>>2]=m;v[s+20>>2]=q;v[s+24>>2]=b;v[s+28>>2]=c;fb=f+432|0;k=v[s+24>>2];h=v[s+28>>2];i=v[s+16>>2];l=v[s+20>>2];break a}if(v[b+116>>2]<0){break n}v[b+4>>2]=v[b+4>>2]-1}g=b;f=o;x=d;d=0;o=0;e=fb-8976|0;fb=e;K=I+J|0;L=0-K|0;L:{M:{while(1){if((c|0)!=48){N:{if((c|0)!=46){break L}b=v[g+4>>2];if((b|0)==v[g+104>>2]){break N}v[g+4>>2]=b+1;c=w[b|0];break M}}else{b=v[g+4>>2];if((b|0)!=v[g+104>>2]){d=1;v[g+4>>2]=b+1;c=w[b|0]}else{d=1;c=jd(g)}continue}break}c=jd(g)}n=1;if((c|0)!=48){break L}while(1){b=k;k=b-1|0;h=h-!b|0;b=v[g+4>>2];O:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break O}c=jd(g)}if((c|0)==48){continue}break}d=1}v[e+784>>2]=0;P:{Q:{b=(c|0)==46;m=c-48|0;R:{S:{T:{U:{if(b|m>>>0<=9){while(1){V:{if(b&1){if(!n){k=i;h=l;n=1;break V}b=!d;break U}b=i+1|0;l=b?l:l+1|0;i=b;if((o|0)<=2044){F=(c|0)==48?F:i;b=(e+784|0)+(o<<2)|0;if(z){m=(B(v[b>>2],10)+c|0)-48|0}v[b>>2]=m;d=1;c=z+1|0;b=(c|0)==9;z=b?0:c;o=b+o|0;break V}if((c|0)==48){break V}v[e+8960>>2]=v[e+8960>>2]|1;F=18396}b=v[g+4>>2];W:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break W}c=jd(g)}b=(c|0)==46;m=c-48|0;if(b|m>>>0<10){continue}break}}k=n?k:i;h=n?h:l;if(!(!d|(c&-33)!=69)){m=pG(g,x);b=ib;q=b;X:{if(m|(b|0)!=-2147483648){break X}if(!x){break R}m=0;q=0;if(v[g+116>>2]<0){break X}v[g+4>>2]=v[g+4>>2]-1}if(!d){break S}h=h+q|0;b=k+m|0;h=b>>>0<m>>>0?h+1|0:h;k=b;break Q}b=!d;if((c|0)<0){break T}}if(v[g+116>>2]<0){break T}v[g+4>>2]=v[g+4>>2]-1}if(!b){break Q}}v[115696]=28}i=0;l=0;ai(g,0,0);c=0;b=0;break P}b=v[e+784>>2];if(!b){Ti(e,+(f|0)*0);i=v[e>>2];l=v[e+4>>2];c=v[e+12>>2];b=v[e+8>>2];break P}if(!((k|0)!=(i|0)|(h|0)!=(l|0)|(i>>>0>9&(l|0)>=0|(l|0)>0)|(b>>>J|0?(J|0)<=30:0))){Ig(e+48|0,f);Wm(e+32|0,b);Ad(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);i=v[e+16>>2];l=v[e+20>>2];c=v[e+28>>2];b=v[e+24>>2];break P}if(k>>>0>(I|0)/-2>>>0&(h|0)>=0|(h|0)>0){v[115696]=68;Ig(e+96|0,f);Ad(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);Ad(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);i=v[e+64>>2];l=v[e+68>>2];c=v[e+76>>2];b=v[e+72>>2];break P}b=I-226|0;c=k>>>0<b>>>0;b=b>>31;if(c&(h|0)<=(b|0)|(b|0)>(h|0)){v[115696]=68;Ig(e+144|0,f);Ad(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);Ad(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);i=v[e+112>>2];l=v[e+116>>2];c=v[e+124>>2];b=v[e+120>>2];break P}if(z){if((z|0)<=8){b=(e+784|0)+(o<<2)|0;g=v[b>>2];while(1){g=B(g,10);z=z+1|0;if((z|0)!=9){continue}break}v[b>>2]=g}o=o+1|0}Y:{n=k;if((F|0)>(k|0)|(F|0)>8|(k|0)>17){break Y}if((n|0)==9){Ig(e+192|0,f);Wm(e+176|0,v[e+784>>2]);Ad(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);i=v[e+160>>2];l=v[e+164>>2];c=v[e+172>>2];b=v[e+168>>2];break P}if((n|0)<=8){Ig(e+272|0,f);Wm(e+256|0,v[e+784>>2]);Ad(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);Ig(e+224|0,v[(0-n<<2)+78592>>2]);EP(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);i=v[e+208>>2];l=v[e+212>>2];c=v[e+220>>2];b=v[e+216>>2];break P}b=(J+B(n,-3)|0)+27|0;c=v[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break Y}Ig(e+352|0,f);Wm(e+336|0,c);Ad(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);Ig(e+304|0,v[(n<<2)+78520>>2]);Ad(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);i=v[e+288>>2];l=v[e+292>>2];c=v[e+300>>2];b=v[e+296>>2];break P}while(1){c=o;o=c-1|0;if(!v[(e+784|0)+(o<<2)>>2]){continue}break}b=(n|0)%9|0;Z:{if(!b){z=0;b=0;break Z}z=0;d=(n|0)<0?b+9|0:b;_:{if(!c){b=0;c=0;break _}k=v[(0-d<<2)+78592>>2];l=1e9/(k|0)|0;m=0;g=0;b=0;while(1){h=m;i=(e+784|0)+(g<<2)|0;o=v[i>>2];m=(o>>>0)/(k>>>0)|0;h=h+m|0;v[i>>2]=h;h=!h&(b|0)==(g|0);b=h?b+1&2047:b;n=h?n-9|0:n;m=B(l,o-B(k,m)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!m){break _}v[(e+784|0)+(c<<2)>>2]=m;c=c+1|0}n=(n-d|0)+9|0}while(1){o=(e+784|0)+(b<<2)|0;g=(n|0)<36;$:{while(1){aa:{if(g){break aa}if((n|0)!=36){break $}if(y[o>>2]<=10384592){break aa}n=36;break $}d=c+2047|0;m=0;while(1){i=d&2047;x=(e+784|0)+(i<<2)|0;d=v[x>>2];l=d>>>3|0;h=d<<29;k=h+m|0;d=l;d=h>>>0>k>>>0?d+1|0:d;h=d;if(!h&k>>>0<1000000001){m=0}else{m=Eia(k,h,1e9,0);d=Bia(m,ib,-1e9,-1)+k|0;k=d}v[x>>2]=k;c=(i|0)!=(c-1&2047)?c:(b|0)==(i|0)?c:k?c:i;d=i-1|0;if((b|0)!=(i|0)){continue}break}z=z-29|0;if(!m){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=e+784|0;k=d+((c+2046&2047)<<2)|0;c=c-1&2047;v[k>>2]=v[k>>2]|v[d+(c<<2)>>2]}n=n+9|0;v[(e+784|0)+(b<<2)>>2]=m;continue}break}ba:{ca:while(1){k=c+1&2047;l=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(n|0)>45?9:1;da:{while(1){d=b;g=0;ea:{while(1){fa:{b=d+g&2047;if((b|0)==(c|0)){break fa}b=v[(e+784|0)+(b<<2)>>2];i=v[(g<<2)+78544>>2];if(b>>>0<i>>>0){break fa}if(b>>>0>i>>>0){break ea}g=g+1|0;if((g|0)!=4){continue}}break}if((n|0)!=36){break ea}k=0;h=0;g=0;i=0;l=0;while(1){b=d+g&2047;if((b|0)==(c|0)){c=c+1&2047;v[((c<<2)+e|0)+780>>2]=0}Wm(e+768|0,v[(e+784|0)+(b<<2)>>2]);Ad(e+752|0,k,h,i,l,0,0,1342177280,1075633366);tg(e+736|0,v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2],v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2]);i=v[e+744>>2];l=v[e+748>>2];k=v[e+736>>2];h=v[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}Ig(e+720|0,f);Ad(e+704|0,k,h,i,l,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);i=v[e+712>>2];l=v[e+716>>2];k=0;h=0;m=v[e+704>>2];q=v[e+708>>2];x=z+113|0;o=x-I|0;n=(o|0)<(J|0);b=n?(o|0)>0?o:0:J;if((b|0)<=112){break da}break ba}z=h+z|0;b=c;if((d|0)==(b|0)){continue}break}o=1e9>>>h|0;m=-1<<h^-1;g=0;b=d;while(1){i=g;g=(e+784|0)+(d<<2)|0;x=v[g>>2];i=i+(x>>>h|0)|0;v[g>>2]=i;i=!i&(b|0)==(d|0);b=i?b+1&2047:b;n=i?n-9|0:n;g=B(o,m&x);d=d+1&2047;if((d|0)!=(c|0)){continue}break}if(!g){continue}if((b|0)!=(k|0)){v[(e+784|0)+(c<<2)>>2]=g;c=k;continue ca}v[l>>2]=v[l>>2]|1;continue}break}break}Ti(e+656|0,Cj(1,225-b|0));sG(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],m,q,i,l);G=v[e+696>>2];H=v[e+700>>2];A=v[e+688>>2];D=v[e+692>>2];Ti(e+640|0,Cj(1,113-b|0));$O(e+672|0,m,q,i,l,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);k=v[e+672>>2];h=v[e+676>>2];r=v[e+680>>2];u=v[e+684>>2];Nx(e+624|0,m,q,i,l,k,h,r,u);tg(e+608|0,A,D,G,H,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);i=v[e+616>>2];l=v[e+620>>2];m=v[e+608>>2];q=v[e+612>>2]}g=d+4&2047;ga:{if((g|0)==(c|0)){break ga}g=v[(e+784|0)+(g<<2)>>2];ha:{if(g>>>0<=499999999){if(!g&(d+5&2047)==(c|0)){break ha}Ti(e+496|0,+(f|0)*.25);tg(e+480|0,k,h,r,u,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);r=v[e+488>>2];u=v[e+492>>2];k=v[e+480>>2];h=v[e+484>>2];break ha}if((g|0)!=5e8){Ti(e+592|0,+(f|0)*.75);tg(e+576|0,k,h,r,u,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);r=v[e+584>>2];u=v[e+588>>2];k=v[e+576>>2];h=v[e+580>>2];break ha}O=+(f|0);if((d+5&2047)==(c|0)){Ti(e+528|0,O*.5);tg(e+512|0,k,h,r,u,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);r=v[e+520>>2];u=v[e+524>>2];k=v[e+512>>2];h=v[e+516>>2];break ha}Ti(e+560|0,O*.75);tg(e+544|0,k,h,r,u,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);r=v[e+552>>2];u=v[e+556>>2];k=v[e+544>>2];h=v[e+548>>2]}if((b|0)>111){break ga}$O(e+464|0,k,h,r,u,0,0,0,1073676288);if(gm(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break ga}tg(e+448|0,k,h,r,u,0,0,0,1073676288);r=v[e+456>>2];u=v[e+460>>2];k=v[e+448>>2];h=v[e+452>>2]}tg(e+432|0,m,q,i,l,k,h,r,u);Nx(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],A,D,G,H);i=v[e+424>>2];l=v[e+428>>2];m=v[e+416>>2];q=v[e+420>>2];ia:{if((-2-K|0)>=(x&2147483647)){break ia}v[e+408>>2]=i;v[e+412>>2]=l&2147483647;v[e+400>>2]=m;v[e+404>>2]=q;Ad(e+384|0,m,q,i,l,0,0,0,1073610752);d=NS(v[e+400>>2],v[e+404>>2],v[e+408>>2],v[e+412>>2],1081081856);c=(d|0)<0;i=c?i:v[e+392>>2];l=c?l:v[e+396>>2];m=c?m:v[e+384>>2];q=c?q:v[e+388>>2];z=((d|0)>=0)+z|0;if((gm(k,h,r,u,0,0,0,0)|0)!=0&(c?n:n&(b|0)!=(o|0))?0:(L|0)>=(z+110|0)){break ia}v[115696]=68}rG(e+368|0,m,q,i,l,z);i=v[e+368>>2];l=v[e+372>>2];c=v[e+380>>2];b=v[e+376>>2]}v[s+40>>2]=b;v[s+44>>2]=c;v[s+32>>2]=i;v[s+36>>2]=l;fb=e+8976|0;k=v[s+40>>2];h=v[s+44>>2];i=v[s+32>>2];l=v[s+36>>2];break a;case 3:break j;default:break m}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}break i}ja:{c=v[b+4>>2];ka:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ka}c=jd(b)}if((c|0)==40){g=1;break ja}h=2147450880;if(v[b+116>>2]<0){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];la:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break la}c=jd(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}h=2147450880;if((c|0)==41){break a}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}ma:{if(d){if(g){break ma}break a}break i}while(1){g=g-1|0;if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(g){continue}break}break a}v[115696]=28;ai(b,0,0)}h=0}v[a>>2]=i;v[a+4>>2]=l;v[a+8>>2]=k;v[a+12>>2]=h;fb=s+48|0}function hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;d=fb-384|0;fb=d;wc(b);a:{if(!go(b,d+368|0)){break a}if(!IQ(d+368|0)){break a}q=fe(d+344|0,b);o=Ib(d+328|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if(!c){v[23220]=0;R(601,d+40|0,q|0);b=v[23220];v[23220]=0;if((b|0)==1){break z}break B}v[23220]=0;R(602,d+40|0,q|0);b=v[23220];v[23220]=0;if((b|0)==1){break A}}b=d+40|0;wt(o,b);Vd(b);v[23220]=0;U(603,b|0,o|0,1413891155);b=v[23220];v[23220]=0;C:{D:{if((b|0)!=1){v[23220]=0;e=Q(604,d+40|0,14102)|0;b=v[23220];v[23220]=0;if((b|0)==1){break D}wb(d+40|0);if(!c){break b}if(!(e^1)){break C}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;wb(d+40|0);break c}v[23220]=0;R(236,a|0,4194304);b=v[23220];v[23220]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[23220]=0;U(603,d+304|0,o|0,1280592212);b=v[23220];v[23220]=0;if((b|0)==1){break e}v[23220]=0;b=T(147,v[d+304>>2])|0;e=v[23220];v[23220]=0;if((e|0)==1){break g}v[23220]=0;U(398,d+304|0,a+1298308|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break g}Bc(Vb(v[a+484360>>2],w[a+484376|0]));m=Ib(d+288|0);t[d+287|0]=0;v[23220]=0;U(605,d+272|0,o|0,1196314451);b=v[23220];v[23220]=0;if((b|0)==1){break i}z=d,A=Ab(v[d+272>>2]),v[z+264>>2]=A;h=d+252|0;j=Ab(v[d+276>>2]);k=a+484360|0;E:{F:{while(1){b=v[d+264>>2];if(!Nb(b,j)){break F}l=fe(d+40|0,b);v[23220]=0;e=Q(606,l|0,d+24|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break E}b=1;if(!(!e|w[d+33|0]!=1)){z=a,A=Pd(w[d+34|0],x[a+480188>>1],127),u[z+480188>>1]=A;v[23220]=0;i=T(607,d+208|0)|0;b=v[23220];v[23220]=0;G:{H:{I:{J:{K:{if((b|0)!=1){b=d+192|0;_e(b,d+24|0,9,1);v[23220]=0;R(209,d+160|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break K}b=d+8|0;cc(b,h,10);e=b;b=d+160|0;gl(e,b);ub(b);b=Vb(v[k>>2],w[k+16|0]);if(rc(v[b>>2],v[b+4>>2])){break H}v[23220]=0;b=T(262,k|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break J}if((b|0)!=255){break I}b=2;break G}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=Vb(v[k>>2],w[k+16|0])}v[23220]=0;U(5,d+160|0,5,h|0);e=v[23220];v[23220]=0;if((e|0)==1){break n}v[23220]=0;R(263,b|0,d+160|0);b=v[23220];v[23220]=0;if((b|0)==1){break o}vb(d+160|0);v[23220]=0;R(602,d+192|0,l|0);b=v[23220];v[23220]=0;if((b|0)==1){break p}z=d,A=Ab(v[d+192>>2]),v[z+184>>2]=A;r=Ab(v[d+196>>2]);L:{M:{while(1){b=v[d+184>>2];if(!Nb(b,r)){b=0;if(x[d+244>>1]==65535|x[d+246>>1]==65535){break L}b=w[k+16|0];e=v[k>>2];v[23220]=0;Y(608,Vb(e,b)|0);b=v[23220];v[23220]=0;if((b|0)!=1){v[23220]=0;R(609,m|0,i|0);e=v[23220];v[23220]=0;b=0;if((e|0)!=1){break L}}b=P()|0;O()|0;break m}ko(d+160|0,b);wi(d+8|0,v[b>>2],v[b+4>>2]);e=1;N:{f=v[d+8>>2];O:{if((f|0)!=1212960847){b=0;if((f|0)!=1312903248){break O}while(1){if(x[a+480188>>1]<=b>>>0){break O}v[23220]=0;f=W(143,v[d+160>>2],v[d+168>>2],2)|0;g=v[23220];v[23220]=0;if((g|0)!=1){if(!f){break O}v[23220]=0;R(250,d+136|0,d+160|0);f=v[23220];v[23220]=0;P:{Q:{R:{S:{if((f|0)!=1){switch(w[d+136|0]){case 4:break Q;case 2:break R;case 0:break S;default:break P}}break q}f=gd(d+136|0);z=Hb(v[i>>2],b),A=w[f|0]^128,t[z|0]=A;f=d+144|0;xb(f,v[d+232>>2],b);sg(f,0);break P}z=Hb(v[i>>2],b),A=128,t[z|0]=A;f=d+144|0;xb(f,v[d+232>>2],b);sg(f,1);break P}z=Hb(v[i>>2],b),A=128,t[z|0]=A;f=d+144|0;xb(f,v[d+232>>2],b);sg(f,0)}b=b+1|0;continue}break}break q}if(y[d+12>>2]<9){break O}b=0;v[23220]=0;Q(175,d+160|0,2)|0;e=v[23220];v[23220]=0;f=65535;if((e|0)==1){break N}while(1){T:{v[23220]=0;e=W(143,v[d+160>>2],v[d+168>>2],1)|0;g=v[23220];v[23220]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{if((g|0)!=1){if(!e){break T}v[23220]=0;g=T(193,d+160|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break q}e=0;switch(g|0){case 0:break T;case 14:break V;case 13:break W;case 12:break X;case 8:break Y;case 7:break Z;case 4:break _;case 1:break $;default:break O}}break q}e=Vb(v[k>>2],w[k+16|0]);if(x[d+244>>1]==65535){z=d,A=al(v[e>>2],v[e+4>>2]),u[z+244>>1]=A}e=al(v[e>>2],v[e+4>>2]);v[23220]=0;u[d+246>>1]=e;e=Q(610,d+160|0,d+287|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break q}aa:{ba:{switch(e-254|0){case 1:e=65535;break aa;case 0:break ba;default:break aa}}e=65534}g=w[k+16|0];n=v[k>>2];v[23220]=0;R(480,Vb(n,g)|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){break q}f=(f&65535)==65535?b:f;break U}v[23220]=0;e=T(181,d+160|0)|0;g=v[23220];v[23220]=0;ca:{da:{if((g|0)!=1){if(e>>>0>=(f&65535)>>>0){break da}e=x[d+248>>1];break ca}break q}e=e-f|0;u[d+248>>1]=e}Ve(Vb(v[k>>2],w[k+16|0]),e&65535);break U}v[23220]=0;e=T(193,d+160|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break q}t[d+251|0]=e;break U}v[23220]=0;e=T(193,d+160|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break q}t[d+250|0]=e;break U}v[23220]=0;g=Q(579,d+160|0,d+144|0)|0;n=v[23220];v[23220]=0;if((n|0)!=1){if(w[d+144|0]|!g|(w[d+146|0]|w[d+145|0]!=255)){break O}if(w[d+147|0]|w[d+148|0]!=1){break O}if(!w[d+149|0]){break U}break O}break q}v[23220]=0;R(492,d+152|0,d+160|0);e=v[23220];v[23220]=0;ea:{fa:{ga:{ha:{if((e|0)!=1){n=gd(d+152|0);e=v[i>>2];p=Wc(e,v[d+212>>2]);g=w[d+152|0];if(p>>>0<=g>>>0){break U}switch(w[Qe(d+152|0)|0]){case 4:break fa;case 2:break ga;case 0:break ha;default:break ea}}break q}z=Hb(e,g),A=w[n|0]^128,t[z|0]=A;e=d+144|0;xb(e,v[d+232>>2],w[d+152|0]);sg(e,0);break ea}z=Hb(e,g),A=128,t[z|0]=A;e=d+144|0;xb(e,v[d+232>>2],w[d+152|0]);sg(e,1);break ea}z=Hb(e,g),A=128,t[z|0]=A;e=d+144|0;xb(e,v[d+232>>2],w[d+152|0]);sg(e,0)}ia:{if(s){break ia}s=0;e=v[m+4>>2];if(!Lp(v[m>>2],e)){break U}g=e-56|0;e=w[d+152|0];if(w[Hb(v[g>>2],e)|0]!=w[Hb(v[i>>2],e)|0]){break ia}xb(d+144|0,v[g+24>>2],e);e=yb(v[v[d+144>>2]>>2],v[d+148>>2]);xb(d+136|0,v[d+232>>2],w[d+152|0]);if((yb(v[v[d+136>>2]>>2],v[d+140>>2])|0)==(e|0)){break U}}s=1;break U}v[23220]=0;R(250,d+144|0,d+160|0);e=v[23220];v[23220]=0;if((e|0)==1){break q}e=v[d+220>>2];n=Wc(e,v[d+224>>2]);g=w[d+144|0];if(n>>>0<=g>>>0){break U}n=gd(d+144|0);z=Hb(e,g),A=(w[n|0]>>>2|0)+1|0,t[z|0]=A}b=b+1|0;continue}break}e=1}wb(d+160|0);if(!e){break M}jm(d+184|0);continue}break}break q}b=1}Vd(d+192|0)}vt(i)}wb(l);if(!b){rh(d+264|0);continue}break}e=0;if((b|0)!=2){break w}}e=0;xi(k,0);b=v[m>>2];if(rc(b,v[m+4>>2])){break w}if(!(c&2)){break x}v[23220]=0;U(605,d+160|0,o|0,1347244868);b=v[23220];v[23220]=0;if((b|0)!=1){z=d,A=Ab(v[d+160>>2]),v[z+8>>2]=A;e=a+480190|0;f=d+53|0;i=d+57|0;l=Ab(v[d+164>>2]);g=w[d+287|0];while(1){b=v[d+8>>2];if(!Nb(b,l)){fd(d+160|0);b=v[m>>2];break x}ja:{ka:{la:{if(!g){v[23220]=0;h=Q(611,b|0,d+40|0)|0;j=v[23220];v[23220]=0;if((j|0)==1){break ja}if(!h){break ka}h=x[d+92>>1];j=h+1|0;u[d+144>>1]=j;if(h>>>0>3998){break la}z=a,A=x[Re(e,d+144|0)>>1],u[z+480190>>1]=A;v[23220]=0;R(612,d+40|0,(B(j&65535,104)+a|0)+484380|0);h=v[23220];v[23220]=0;if((h|0)==1){break ja}h=d+24|0;HQ(h,f);v[23220]=0;R(209,d+192|0,h|0);h=v[23220];v[23220]=0;if((h|0)==1){break y}h=d+192|0;yc(((x[d+144>>1]<<5)+a|0)+946304|0,h);ub(h);break la}v[23220]=0;h=Q(613,b|0,d+40|0)|0;j=v[23220];v[23220]=0;if((j|0)==1){break y}if(!h){break ka}h=x[d+96>>1];j=h+1|0;u[d+144>>1]=j;if(h>>>0>3998){break la}z=a,A=x[Re(e,d+144|0)>>1],u[z+480190>>1]=A;v[23220]=0;R(614,d+40|0,(B(j&65535,104)+a|0)+484380|0);h=v[23220];v[23220]=0;if((h|0)==1){break y}h=d+24|0;HQ(h,i);v[23220]=0;R(209,d+192|0,h|0);h=v[23220];v[23220]=0;if((h|0)==1){break y}h=d+192|0;yc(((x[d+144>>1]<<5)+a|0)+946304|0,h);ub(h)}h=x[d+144>>1];if((h-1&65535)>>>0>3998){break ka}j=Uc(d+40|0,8,1,0,2);v[23220]=0;W(206,j|0,(B(h,104)+a|0)+484380|0,b|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break ka}break y}rh(d+8|0);continue}break}break y}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;fd(d+160|0);break j}b=Oz(b,0);v[a+480196>>2]=w[b+43|0];v[a+480204>>2]=B(w[b+42|0],1e4);Ve(Vb(v[a+484360>>2],w[a+484376|0]),x[b+40>>1]);b=0;while(1){if(x[a+480188>>1]>b>>>0){e=(b<<5)+a|0;f=e+480280|0;Pe(f);i=Oz(v[m>>2],0);z=e+480286|0,A=w[Hb(v[i+12>>2],b)|0],u[z>>1]=A;z=e+480284|0,A=w[Hb(v[i>>2],b)|0],u[z>>1]=A;xb(d+40|0,v[i+24>>2],b);z=f,A=v[f>>2]&-257|(yb(v[v[d+40>>2]>>2],v[d+44>>2])?256:0),v[z>>2]=A;b=b+1|0;continue}break}v[23220]=0;b=Q(1,d+192|0,(w[d+287|0]?17075:16948)|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break r}Db(a+1298344|0,b);vb(b);v[23220]=0;b=Q(1,d+24|0,10098)|0;e=v[23220];v[23220]=0;if((e|0)==1){break s}Db(a+1298356|0,b);vb(b);v[a+1298404>>2]=5;e=1;if(!(c&1)|!x[a+480188>>1]){break w}v[23220]=0;U(605,d+8|0,o|0,1146045008);b=v[23220];v[23220]=0;if((b|0)==1){break t}b=v[d+12>>2];c=v[d+8>>2];v[23220]=0;l=a+484344|0;R(212,l|0,Bf(c,b)&65535);b=v[23220];v[23220]=0;if((b|0)==1){break v}z=d,A=Ab(v[d+8>>2]),v[z+144>>2]=A;n=Ab(v[d+12>>2]);while(1){g=v[d+144>>2];if(!Nb(g,n)){ma:{na:{b=v[m>>2];e=v[m+4>>2];if(Lp(b,e)>>>0<2){break na}f=0;while(1){if(Lp(b,e)>>>0<=f>>>0){break na}h=v[l>>2];j=v[l+4>>2];i=nj(v[k>>2],f&255);n=v[i>>2];c=Oz(b,f);g=x[c+36>>1];if(ke(h,j,x[ac(n,g)>>1])){v[23220]=0;e=Q(353,i|0,g|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break ma}oa:{if(!s){break oa}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break oa}xb(d+40|0,v[c+24>>2],b);g=yb(v[v[d+40>>2]>>2],v[d+44>>2]);i=Xb(v[l>>2],e);pa:{if(g){me(i,uh(io(He(Be(d+40|0,20,145),0),b&65535)));break pa}me(i,uh(io(He(Be(d+40|0,9,w[Hb(v[c>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}b=d+40|0;me(Xb(v[l>>2],e),uh(He(Be(b,16,w[c+43|0]),0)));me(Xb(v[l>>2],e),uh(He(Be(b,17,w[c+42|0]),0)));e=v[m+4>>2];b=v[m>>2]}f=f+1|0;continue}}fd(d+8|0);e=1;break w}b=P()|0;O()|0;break u}b=v[g>>2];v[23220]=0;b=T(147,b|0)|0;c=v[23220];v[23220]=0;qa:{ra:{sa:{ta:{ua:{va:{wa:{if((c|0)==1){break wa}v[23220]=0;c=T(144,g|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break wa}if((b|0)!=(c|0)){break qa}b=v[g>>2];v[23220]=0;b=Q(615,b|0,8)|0;c=v[23220];v[23220]=0;if((c|0)==1){break wa}if(!b){break qa}v[23220]=0;j=Q(610,g|0,d+287|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break ra}v[23220]=0;r=T(181,g|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break sa}v[23220]=0;b=W(213,l|0,j|0,r|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break sa}if(!b){break qa}h=0;while(1){if((h|0)==(r|0)){break qa}b=Xb(v[l>>2],j);c=Of(v[b>>2],v[v[b+48>>2]+12>>2],h);v[23220]=0;b=T(181,g|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break va}xa:{if(b>>>0>=3){v[23220]=0;U(177,d+160|0,g|0,b-2|0);b=v[23220];v[23220]=0;if((b|0)==1){break ta}b=d+160|0;i=gc(d+40|0,b);wb(b);while(1){b=v[i>>2];v[23220]=0;b=W(143,b|0,v[d+48>>2],3)|0;e=v[23220];v[23220]=0;if((e|0)==1){break xa}if(b){v[23220]=0;R(250,d+160|0,i|0);b=v[23220];v[23220]=0;ya:{za:{Aa:{Ba:{if((b|0)!=1){u[d+136>>1]=x[a+480188>>1]-1;z=d,A=w[gd(d+160|0)|0],u[z+264>>1]=A;e=x[Tc(d+136|0,d+264|0)>>1];f=c+B(e,6)|0;b=t[d+160|0];if((b|0)>=0){break ya}v[23220]=0;b=T(193,i|0)|0;p=v[23220];v[23220]=0;if((p|0)==1){break ua}if(w[d+287|0]){break Aa}if((b|0)!=255){break Ba}b=254;break za}break ua}if(b>>>0>128){break za}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break za}b=b>>>0<85?b+36|0:b}t[f|0]=b;b=w[d+160|0]}if(b&64){v[23220]=0;b=T(193,i|0)|0;p=v[23220];v[23220]=0;if((p|0)==1){break ua}t[f+1|0]=b+1;b=w[d+160|0]}if(b&32){v[23220]=0;b=T(193,i|0)|0;p=v[23220];v[23220]=0;if((p|0)==1){break ua}t[d+136|0]=b;t[f+2|0]=1;t[d+264|0]=127;z=f,A=w[Rb(d+136|0,d+264|0)|0]+1>>>1|0,t[z+4|0]=A;b=w[d+160|0]}if(!(b&16)){continue}v[23220]=0;R(250,d+136|0,i|0);b=v[23220];v[23220]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{if((b|0)!=1){b=w[gd(d+136|0)|0];t[f+5|0]=b;switch(w[d+136|0]-1|0){case 72:break Da;case 71:break Ea;case 70:break Fa;case 61:break Ga;case 60:break Ha;case 53:break Ia;case 52:break Ja;case 51:break Ka;case 50:break Ma;case 43:break Na;case 42:break Oa;case 41:break Pa;case 40:break Qa;case 31:break Ra;case 30:break Sa;case 23:break Ta;case 22:break Ua;case 21:break Va;case 20:break Wa;case 18:break Xa;case 17:break Ya;case 15:break Za;case 16:break _a;case 14:break $a;case 13:break ab;case 12:break bb;case 11:break cb;case 10:break db;case 3:break eb;case 2:break fb;case 1:break gb;case 0:break hb;default:break Ca}}break ua}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[f+5|0]=b<<4|15;continue}t[f+5|0]=b<<3|15;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[f+5|0]=b<<4;continue}t[f+5|0]=b<<3&240;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[f+5|0]=b|240;continue}t[f+5|0]=b>>>1|240;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[f+5|0]=b&15;continue}if(b>>>0<=1){t[f+5|0]=b|240;continue}t[f+5|0]=b>>>1&15;continue}t[(c+B(e,6)|0)+3|0]=2;z=f,A=tt(b,w[d+287|0])|240,t[z+5|0]=A;continue}t[(c+B(e,6)|0)+3|0]=2;z=f,A=tt(b,w[d+287|0]),t[z+5|0]=A;continue}t[(c+B(e,6)|0)+3|0]=3;z=f,A=tt(b,w[d+287|0])|240,t[z+5|0]=A;continue}t[(c+B(e,6)|0)+3|0]=3;z=f,A=tt(b,w[d+287|0]),t[z+5|0]=A;continue}t[(c+B(e,6)|0)+3|0]=4;if(w[d+287|0]){continue}t[f+5|0]=(b&252)>>>2;continue}t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&1|16;continue}t[(c+B(e,6)|0)+3|0]=6;t[f+5|0]=b&240;continue}t[(c+B(e,6)|0)+3|0]=6;t[f+5|0]=(b&240)>>>4;continue}t[(c+B(e,6)|0)+3|0]=20;continue}t[(c+B(e,6)|0)+3|0]=5;continue}t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&15|48;continue}t[(c+B(e,6)|0)+3|0]=7;t[f+5|0]=b|240;continue}t[(c+B(e,6)|0)+3|0]=7;continue}t[(c+B(e,6)|0)+3|0]=8;continue}t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&15|64;continue}t[(c+B(e,6)|0)+3|0]=10;v[23220]=0;b=T(193,i|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){break La}break ua}t[(c+B(e,6)|0)+3|0]=15;continue}t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&15|192;continue}t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&15|208;continue}t[(c+B(e,6)|0)+3|0]=12;b=(b&254)>>>1|0}t[f+5|0]=b;v[23220]=0;Q(175,i|0,1)|0;b=v[23220];v[23220]=0;if((b|0)!=1){continue}break ua}t[(c+B(e,6)|0)+3|0]=14;t[f+5|0]=0;continue}t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&15|176;continue}t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&15|224;continue}t[(c+B(e,6)|0)+3|0]=16;continue}t[(c+B(e,6)|0)+3|0]=17;continue}t[(c+B(e,6)|0)+3|0]=1;continue}t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&15|32;continue}t[(c+B(e,6)|0)+3|0]=20;t[f+5|0]=b&15|128;continue}t[(c+B(e,6)|0)+3|0]=0;continue}break}wb(i)}h=h+1|0;continue}break}break ua}b=P()|0;O()|0;break u}b=P()|0;O()|0;break u}b=P()|0;O()|0;wb(i);break u}b=P()|0;O()|0;break u}b=P()|0;O()|0;break u}b=P()|0;O()|0;break u}rh(d+144|0);continue}}fd(d+272|0);FQ(m);wb(d+304|0);break b}b=P()|0;O()|0}fd(d+8|0);break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;wb(d+160|0);break m}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(d+160|0);break l}b=P()|0;O()|0;break l}Vd(d+192|0)}vt(i)}wb(l)}fd(d+272|0);break h}b=P()|0;O()|0}FQ(m);break f}b=P()|0;O()|0}wb(d+304|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0}Vd(o);wb(q);S(b|0);L()}Vd(o);wb(q)}fb=d+384|0;return e|0}function jga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=fb-480|0;fb=d;wc(b);g=d+472|0;e=ru(b,g);if(!e){kS(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!e){break k}if(!lS(d+472|0)){break k}if(!c){A=1;break k}F=fe(d+448|0,b);v[23220]=0;R(448,d+432|0,F|0);b=v[23220];v[23220]=0;l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if((b|0)!=1){v[23220]=0;U(449,d+408|0,d+432|0,20041);b=v[23220];v[23220]=0;if((b|0)==1){break u}v[23220]=0;e=T(165,v[d+408>>2])|0;b=v[23220];v[23220]=0;if((b|0)==1){break m}if(!e){break l}v[23220]=0;e=Q(450,d+408|0,d+312|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break m}if(!e){break l}v[23220]=0;R(236,a|0,16384);b=v[23220];v[23220]=0;if((b|0)==1){break m}v[a+480208>>2]=8;v[23220]=0;e=W(254,a+1074312|0,9,1)|0;b=v[23220];v[23220]=0;if((b|0)==1){break m}v[23220]=0;e=W(254,e|0,114,1)|0;b=v[23220];v[23220]=0;if((b|0)==1){break m}v[23220]=0;e=Q(255,e|0,21)|0;b=v[23220];v[23220]=0;if((b|0)==1){break m}v[23220]=0;Q(255,e|0,30)|0;b=v[23220];v[23220]=0;if((b|0)==1){break m}v[23220]=0;e=Q(1,d+296|0,8267)|0;b=v[23220];v[23220]=0;if((b|0)==1){break r}Db(a+1298344|0,e);vb(e);v[23220]=0;e=Q(1,d+280|0,10683)|0;b=v[23220];v[23220]=0;if((b|0)==1){break q}Db(a+1298356|0,e);vb(e);v[23220]=0;j=Q(1,d+264|0,17445)|0;b=v[23220];v[23220]=0;if((b|0)==1){break p}e=15084;b=w[d+476|0];switch(b-16|0){case 1:break n;case 0:break t;default:break s}}f=P()|0;O()|0;break a}f=P()|0;O()|0;break b}e=15065;break n}if(!b){break o}e=21598;break n}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}e=13237}v[23220]=0;g=Q(1,d+248|0,e|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break e}v[23220]=0;U(2,d+208|0,j|0,g|0);b=v[23220];v[23220]=0;if((b|0)==1){break f}e=d+208|0;Db(a+1298368|0,e);vb(e);vb(g);vb(j);v[a+1298404>>2]=5;b=d+96|0;Ue(b,3,d+312|0);v[23220]=0;R(209,e|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break g}b=d+208|0;xc(a+1298308|0,b);ub(b);b=d+232|0;rj(b,3,d+344|0);v[23220]=0;R(209,d+96|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break h}v[23220]=0;U(11,d+208|0,5,d+96|0);b=v[23220];v[23220]=0;if((b|0)==1){break i}b=d+208|0;Db(a+1298320|0,b);vb(b);ub(d+96|0);v[a+480200>>2]=w[d+368|0]+1;G=a,H=Pd(w[d+369|0],1,255),v[G+480196>>2]=H;G=a,H=B(Pd(w[d+370|0],4,255),1e4),v[G+480204>>2]=H;g=a+484376|0;e=w[g|0];b=v[a+484360>>2];v[23220]=0;da(333,Vb(b,e)|0,d+408|0,x[d+364>>1],65535,65535);b=v[23220];v[23220]=0;if((b|0)==1){break m}Ve(Vb(v[a+484360>>2],w[g|0]),x[d+366>>1]);u[a+480188>>1]=0;b=0;while(1){if((b|0)==32){v[23220]=0;U(449,d+208|0,d+432|0,17741);b=v[23220];v[23220]=0;if((b|0)!=1){b=d+208|0;g=Yc(d+408|0,b);wb(b);b=v[g>>2];v[23220]=0;e=T(147,b|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break m}v[23220]=0;X(322,a+1298332|0,g|0,e|0,0);b=v[23220];v[23220]=0;if((b|0)==1){break m}v[23220]=0;U(449,d+208|0,d+432|0,21321);b=v[23220];v[23220]=0;if((b|0)!=1){b=d+208|0;i=Yc(g,b);wb(b);b=v[i>>2];v[23220]=0;e=T(165,b|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break m}v:{w:{if(e){v[23220]=0;U(449,d+208|0,d+432|0,16723);b=v[23220];v[23220]=0;if((b|0)==1){break v}v[23220]=0;h=T(193,i|0)|0;b=v[23220];v[23220]=0;x:{if((b|0)!=1){j=c&2;g=a+480190|0;while(1){if(h>>>0<=(o&255)>>>0){break x}v[23220]=0;l=T(193,i|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break w}if(!l){break x}e=v[i+8>>2];b=v[i>>2];v[23220]=0;e=W(143,b|0,e|0,56)|0;b=v[23220];v[23220]=0;if((b|0)==1){break w}if(!e){break x}if(l>>>0>x[g>>1]){u[a+480190>>1]=l}v[23220]=0;p=B(l,104)+a|0;r=p+484380|0;R(267,r|0,0);b=v[23220];v[23220]=0;if((b|0)==1){break w}dB(r);v[23220]=0;U(303,i|0,((l<<5)+a|0)+946304|0,32);b=v[23220];v[23220]=0;if((b|0)==1){break w}v[23220]=0;R(306,i|0,p+484423|0);b=v[23220];v[23220]=0;if((b|0)==1){break w}y:{if(w[d+476|0]<=15){v[23220]=0;f=T(181,i|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break y}break w}v[23220]=0;f=T(144,i|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break w}}v[p+484404>>2]=f<<1;v[23220]=0;e=T(144,i|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break w}v[r>>2]=e;v[23220]=0;e=T(144,i|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break w}A=p+484384|0;v[A>>2]=e;v[23220]=0;e=T(144,i|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break w}D=p+484388|0;v[D>>2]=e;if(e){b=p+484414|0;u[b>>1]=x[b>>1]|2;v[D>>2]=e+v[A>>2]}v[23220]=0;e=T(193,i|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break w}if(w[d+476|0]<=15){u[p+484410>>1]=e}v[23220]=0;E=T(193,i|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break w}l=p+484414|0;e=x[l>>1];b=8;if(E&1){e=e|1;u[l>>1]=e;v[r>>2]=v[r>>2]>>>1;v[A>>2]=v[A>>2]>>>1;v[D>>2]=v[D>>2]>>>1;b=16}u[l>>1]=e&65531|E<<1&4;b=Uc(d+96|0,b,1,0,((E&12)!=0)<<3);z:{if(!j){break z}v[23220]=0;W(206,b|0,r|0,d+208|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break z}break w}o=o+1|0;continue}}break w}wb(d+208|0)}v[23220]=0;U(449,d+208|0,d+432|0,18761);b=v[23220];v[23220]=0;A:{if((b|0)!=1){b=d+208|0;k=Yc(i,b);wb(b);b=v[k>>2];v[23220]=0;e=T(165,b|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break m}if(!e){break A}q=Ib(d+96|0);s=Ib(d+232|0);y=Ib(d+192|0);v[23220]=0;U(449,d+168|0,d+432|0,17750);b=v[23220];v[23220]=0;B:{if((b|0)==1){break B}b=v[d+180>>2];e=d- -64|0;v[e>>2]=v[d+176>>2];v[e+4>>2]=b;v[d+72>>2]=v[d+184>>2];v[23220]=0;b=v[d+172>>2];v[d+56>>2]=v[d+168>>2];v[d+60>>2]=b;R(451,d+56|0,q|0);b=v[23220];v[23220]=0;if((b|0)==1){break B}v[23220]=0;U(449,d+144|0,d+432|0,17744);b=v[23220];v[23220]=0;if((b|0)==1){break B}b=v[d+156>>2];v[d+40>>2]=v[d+152>>2];v[d+44>>2]=b;v[d+48>>2]=v[d+160>>2];v[23220]=0;b=v[d+148>>2];v[d+32>>2]=v[d+144>>2];v[d+36>>2]=b;R(451,d+32|0,s|0);b=v[23220];v[23220]=0;if((b|0)==1){break B}v[23220]=0;U(449,d+120|0,d+432|0,17734);b=v[23220];v[23220]=0;if((b|0)==1){break B}b=v[d+132>>2];v[d+16>>2]=v[d+128>>2];v[d+20>>2]=b;v[d+24>>2]=v[d+136>>2];v[23220]=0;b=v[d+124>>2];v[d+8>>2]=v[d+120>>2];v[d+12>>2]=b;R(451,d+8|0,y|0);b=v[23220];v[23220]=0;if((b|0)==1){break B}v[23220]=0;r=T(193,k|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break B}p=d+208|1;A=a+480190|0;while(1){if(r>>>0<=(n&255)>>>0){ao(y);ao(s);ao(q);break A}v[23220]=0;R(250,d+80|0,k|0);b=v[23220];v[23220]=0;C:{if((b|0)!=1){C=gd(d+80|0);D:{E:{if(!w[d+80|0]){break E}g=v[k+8>>2];e=v[k>>2];b=w[C|0];v[23220]=0;e=W(143,e|0,g|0,B(b,14)+32|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break B}if(!e){break E}v[23220]=0;m=W(241,a|0,w[d+80|0],0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break B}if(m){break D}}b=w[C|0];v[23220]=0;Q(175,k|0,B(b,14)+32|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break C}break B}v[23220]=0;U(303,k|0,m+492|0,32);b=v[23220];v[23220]=0;if((b|0)==1){break B}D=m+88|0;E=m+68|0;l=m+48|0;h=m+236|0;b=0;o=0;while(1){if(w[C|0]<=(o&255)>>>0){break C}v[23220]=0;R(452,k|0,d+208|0);e=v[23220];v[23220]=0;if((e|0)==1){break B}e=w[d+208|0];F:{if(!e|e>>>0>x[A>>1]){break F}if(w[p|0]>=129){t[p|0]=128}while(1){e=b&255;j=w[d+209|0];if(e>>>0>j>>>0){e=v[q+4>>2];b=v[q>>2];v[23220]=0;X(453,l|0,w[d+211|0],b|0,e|0);b=v[23220];v[23220]=0;if((b|0)==1){break B}e=v[s+4>>2];b=v[s>>2];v[23220]=0;X(453,E|0,w[d+213|0],b|0,e|0);b=v[23220];v[23220]=0;if((b|0)==1){break B}e=v[y+4>>2];b=v[y>>2];v[23220]=0;X(453,D|0,w[d+221|0],b|0,e|0);b=v[23220];v[23220]=0;if((b|0)==1){break B}v[m>>2]=x[d+214>>1]+1>>>1;e=w[d+208|0];G:{if(w[d+211|0]&64){u[(B(e,104)+a|0)+484410>>1]=w[d+210|0];break G}b=(B(e,104)+a|0)+484414|0;u[b>>1]=x[b>>1]|32768}u[d+118>>1]=w[d+212|0]<<1;u[d+116>>1]=254;z=B(e,104)+a|0;G=z+484408|0,H=x[Tc(d+118|0,d+116|0)>>1],u[G>>1]=H;t[z+484418|0]=w[(w[d+219|0]&3)+26660|0];e=z+484419|0;i=w[d+218|0];t[e|0]=i;g=w[d+217|0]+3>>>2|0;t[z+484420|0]=g;t[z+484421|0]=w[d+216|0];b=j+1|0;if(i){g=sm(Pc(((g<<8|i>>>1)>>>0)/(i>>>0)|0,0))}else{g=255}t[e|0]=g;if(!(w[d+213|0]&64)){break F}e=z+484414|0;u[e>>1]=x[e>>1]|32}else{G=ac(h,e),H=w[d+208|0],u[G>>1]=H;b=b+1|0;continue}break}}o=o+1|0;continue}}break B}n=n+1|0;continue}}f=P()|0;O()|0;ao(y);ao(s);ao(q);break c}f=P()|0;O()|0;break c}A=1;s=Ib(d+232|0);H:{if(!(c&1)){break H}v[23220]=0;U(449,d+208|0,d+432|0,21076);b=v[23220];v[23220]=0;I:{J:{K:{L:{M:{N:{if((b|0)!=1){j=Yc(k,d+208|0);b=v[j>>2];v[23220]=0;c=T(165,b|0)|0;b=v[23220];v[23220]=0;O:{P:{Q:{if((b|0)!=1){wb(d+208|0);if(!c){break O}v[23220]=0;e=T(181,j|0)|0;c=v[23220];v[23220]=0;b=1;if((c|0)==1){break Q}v[23220]=0;g=e+1|0;R(454,s|0,g|0);c=v[23220];v[23220]=0;if((c|0)==1){break Q}while(1){if((b|0)==(g|0)){break O}v[23220]=0;e=T(181,j|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break P}v[23220]=0;U(177,d+96|0,j|0,e|0);c=v[23220];v[23220]=0;if((c|0)==1){break P}c=d+96|0;e=gc(d+208|0,c);Yc(xg(v[s>>2],b),e);wb(e);b=b+1|0;wb(c);continue}}f=P()|0;O()|0;wb(d+208|0);break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}v[23220]=0;U(449,d+208|0,d+432|0,16720);b=v[23220];v[23220]=0;if((b|0)==1){break K}m=Yc(j,d+208|0);b=v[m>>2];v[23220]=0;c=T(165,b|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break L}wb(d+208|0);if(!c){break N}v[23220]=0;i=T(193,m|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break J}n=0;R:{S:{T:while(1){U:{if(i>>>0<=(n&65535)>>>0){v[23220]=0;Q(142,m|0,1)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break U}break J}o=32;V:{if(w[d+476|0]<16){break V}v[23220]=0;R(455,m|0,d+208|0);b=v[23220];v[23220]=0;if((b|0)==1){break R}o=w[d+208|0];if(o>>>0<=x[a+480188>>1]|o>>>0>32){break V}u[a+480188>>1]=o}b=0;while(1){g=b&65535;if(g>>>0>=o>>>0){n=n+1|0;continue T}v[23220]=0;e=T(181,m|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break S}if(!(!e|g>>>0>31|g>>>0<x[a+480188>>1])){u[a+480188>>1]=b+1}b=b+1|0;continue}}break}v[23220]=0;y=a+484344|0;R(212,y|0,i|0);b=v[23220];v[23220]=0;if((b|0)==1){break J}D=d+208|2;q=0;while(1){if((i|0)==(q|0)){break N}z=Gb(d+96|0);W:{if(w[d+476|0]<16){p=32;j=64;break W}v[23220]=0;R(455,m|0,d+208|0);b=v[23220];v[23220]=0;if((b|0)==1){break M}c=w[d+209|0];p=w[d+208|0];b=d+80|0;_e(b,D,16,3);v[23220]=0;R(209,d+192|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break M}b=d+192|0;xc(z,b);ub(b);j=c+1|0}v[23220]=0;c=W(213,y|0,q&65535,j|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break M}X:{if(!c){v[23220]=0;Q(175,m|0,p<<1)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break X}break M}b=v[y>>2];v[23220]=0;R(271,Xb(b,q)|0,z|0);b=v[23220];v[23220]=0;if((b|0)==1){break M}E=j-1|0;r=0;while(1){C=r&65535;if(C>>>0>=p>>>0){break X}v[23220]=0;c=T(181,m|0)|0;b=v[23220];v[23220]=0;Y:{if((b|0)!=1){if(!c){break Y}b=v[s>>2];if(Bf(b,v[s+4>>2])>>>0<=c>>>0|C>>>0>=x[a+480188>>1]){break Y}k=xg(b,c);wc(k);c=0;Z:while(1){e=c;if(j>>>0<=e>>>0){break Y}c=v[k+8>>2];b=v[k>>2];v[23220]=0;c=W(143,b|0,c|0,1)|0;b=v[23220];v[23220]=0;_:{$:{aa:{ba:{ca:{if((b|0)!=1){if(!c){break Y}b=Xb(v[y>>2],q);b=$c(v[b>>2],v[v[b+48>>2]+12>>2],e,C);v[23220]=0;g=T(193,k|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break M}f=g>>>2|0;switch((g&3)-1|0){case 2:break $;case 1:break aa;case 0:break ba;default:break ca}}break M}c=(e+f|0)+1|0;continue}c=0;if(!e){continue}c=Xb(v[y>>2],q);h=$c(v[c>>2],v[v[c+48>>2]+12>>2],e-1|0,C);while(1){c=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[b|0]=c;t[b+1|0]=c>>>8;t[b+2|0]=c>>>16;t[b+3|0]=c>>>24;c=w[h+4|0]|w[h+5|0]<<8;t[b+4|0]=c;t[b+5|0]=c>>>8;c=e+1|0;if((e|0)==(E|0)){continue Z}b=B(x[a+480188>>1],6)+b|0;g=f&255;e=c;f=f-1|0;if(g){continue}break}continue}if(e>>>0<=f>>>0){break _}c=Xb(v[y>>2],q);g=$c(v[c>>2],v[v[c+48>>2]+12>>2],f,C);c=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=c;t[b+1|0]=c>>>8;t[b+2|0]=c>>>16;t[b+3|0]=c>>>24;c=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=c;t[b+5|0]=c>>>8;break _}if(f&1){v[23220]=0;g=T(193,k|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break M}t[b|0]=g>>>0>120?-1:g}if(f&2){v[23220]=0;g=T(193,k|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break M}t[b+1|0]=g}o=0;c=0;da:{if(f&4){v[23220]=0;c=T(193,k|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break da}}n=0;if(f&8){v[23220]=0;h=T(193,k|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break da}o=h&15;n=h>>>4|0}l=0;h=0;if(f&16){v[23220]=0;h=T(193,k|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break da}}if(f&32){v[23220]=0;l=T(193,k|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break da}}f=fb-16|0;fb=f;t[f+14|0]=n;t[f+15|0]=o;t[f+13|0]=h;t[f+12|0]=l;if((n-1&255)>>>0<=5){t[f+14|0]=n+15}iS(f+15|0,f+13|0);iS(f+14|0,f+12|0);ea:{fa:{n=w[f+15|0];ga:{if((n|0)==10){l=w[f+12|0];h=w[f+13|0]&15;t[f+13|0]=h?-1:l;g=w[f+14|0];n=(g|0)==10?0:g;t[f+14|0]=n;g=l|h<<8;break ga}if(w[f+14|0]!=10){break fa}g=w[f+12|0]&15;t[f+12|0]=g?-1:0;g=g<<8}if(g-256>>>0>4294967038){break fa}if(yi(n)>>>0>=yi(10)>>>0){break fa}t[b+5|0]=g;t[b+2|0]=15;t[b+3|0]=10;t[b+4|0]=g>>>8;break ea}if(c){t[b+2|0]=1;t[b+4|0]=c+2>>>2}yu(f+15|0,f+13|0,f+14|0,f+12|0);h=w[f+15|0];ha:{if(!h){break ha}g=w[f+14|0];if(!g){t[f+14|0]=h;t[f+12|0]=w[f+13|0];t[f+15|0]=0;break ha}if(!((h|0)==20|(g|0)!=(h|0))){t[f+15|0]=0;break ha}if(!c){lo(f+8|0,f+15|0,f+13|0,f+14|0,f+12|0);t[b+2|0]=w[f+15|0];t[b+4|0]=w[f+13|0];break ha}if(yi(h)>>>0<=yi(g)>>>0){break ha}Wg(f+15|0,f+14|0);Wg(f+13|0,f+12|0)}t[b+3|0]=w[f+14|0];t[b+5|0]=w[f+12|0]}fb=f+16|0;break _}break M}c=e+1|0;continue}}break M}r=r+1|0;continue}}ub(z);q=q+1|0;continue}}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}v[23220]=0;U(449,d+208|0,d+432|0,20048);b=v[23220];v[23220]=0;ia:{ja:{if((b|0)!=1){g=Yc(m,d+208|0);b=v[g>>2];v[23220]=0;c=T(165,b|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break ja}wb(d+208|0);if(!c){break H}e=a+484348|0;while(1){if(!lf(v[a+484344>>2],v[e>>2])){break H}c=v[g+8>>2];b=v[g>>2];v[23220]=0;c=W(143,b|0,c|0,16)|0;b=v[23220];v[23220]=0;if((b|0)==1){break ia}if(!c){break H}v[23220]=0;R(456,g|0,d+208|0);b=v[23220];v[23220]=0;if((b|0)!=1){b=v[a+484344>>2];v[23220]=0;R(457,Xb(b,0)|0,d+208|0);b=v[23220];v[23220]=0;if((b|0)!=1){continue}}break}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;wb(d+208|0);break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;ub(z);break I}f=P()|0;O()|0;wb(d+208|0);break I}f=P()|0;O()|0;break I}f=P()|0;O()|0}fd(s);break c}fd(s);break l}f=P()|0;O()|0;wb(d+208|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}h=(b<<5)+a|0;j=h+480280|0;Pe(j);g=t[(b+d|0)+371|0];e=g<<1&254;u[h+480284>>1]=(e|0)==254?256:e;ka:{if((g|0)<0){v[j>>2]=v[j>>2]|1024;break ka}u[a+480188>>1]=b+1}v[23220]=0;R(458,d+408|0,h+480289|0);e=v[23220];v[23220]=0;if((e|0)==1){break j}b=b+1|0;continue}}f=P()|0;O()|0;break c}wb(d+408|0);Vd(d+432|0);wb(F)}fb=d+480|0;return A|0}f=P()|0;O()|0;break c}f=P()|0;O()|0;ub(d+96|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(g);break d}f=P()|0;O()|0}vb(j)}wb(d+408|0)}Vd(d+432|0)}wb(F);S(f|0);L()}function Lha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=fb-240|0;fb=d;wc(b);e=fb-16|0;fb=e;i=d+216|0;Zt(e+8|0,i);g=v[e+12>>2];jc(e,v[b>>2],v[b+8>>2],v[e+8>>2],g);j=v[e+4>>2];if((j|0)==(g|0)){Yb(b,v[e+12>>2])}fb=e+16|0;e=(g|0)==(j|0);if(!e){uT(i)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!e){break n}if(!vT(d+216|0)){break n}if(!c){f=1;break n}zd(a,1024);yg(a);v[a+480208>>2]=v[a+480208>>2]|12;zf(a+1074312|0,21);e=Jb(x[d+232>>1]);if(e){v[a+480204>>2]=B(e,1e4)}e=Jb(x[d+230>>1]);if(e){v[a+480196>>2]=e}if(!w[d+226|0]){th(a,1)}nu(b,a+1298308|0,_b(v[d+220>>2])-14|0);b=fe(d+112|0,b);v[23220]=0;R(331,d+200|0,b|0);e=v[23220];v[23220]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((e|0)!=1){wb(b);v[23220]=0;U(332,d+112|0,d+200|0,1395544366);b=v[23220];v[23220]=0;if((b|0)==1){break s}v[23220]=0;b=T(265,v[d+112>>2])|0;e=v[23220];v[23220]=0;if((e|0)==1){break y}if(!b){break r}v[23220]=0;b=T(261,d+112|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break y}v[23220]=0;e=T(261,d+112|0)|0;f=v[23220];v[23220]=0;A:{if((f|0)==1){break A}v[23220]=0;Q(175,d+112|0,4)|0;f=v[23220];v[23220]=0;if((f|0)==1){break A}f=a+484376|0;g=w[f|0];i=v[a+484360>>2];v[23220]=0;da(333,Vb(i,g)|0,d+112|0,b|0,65535,65535);b=v[23220];v[23220]=0;if((b|0)!=1){break z}}break y}a=P()|0;O()|0;wb(b);break a}Ve(Vb(v[a+484360>>2],w[f|0]),e);b=d+112|0;wb(b);v[23220]=0;U(332,b|0,d+200|0,1346458708);b=v[23220];v[23220]=0;if((b|0)==1){break x}v[23220]=0;e=T(265,v[d+112>>2])|0;b=v[23220];v[23220]=0;if((b|0)==1){break w}f=0;b=0;if(!e){break t}v[23220]=0;e=T(261,d+112|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break w}u[a+480188>>1]=e;if((e-33&65535)>>>0<65504){break t}v[23220]=0;b=T(261,d+112|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break w}v[23220]=0;R(212,a+484344|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break w}b=0;v[23220]=0;m=T(269,d+112|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break w}switch(m-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}a=P()|0;O()|0;wb(d+112|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;wb(d+112|0);break b}if(m){break t}}b=1}wb(d+112|0);if(!b){break o}v[23220]=0;U(332,d+176|0,d+200|0,1398157625);b=v[23220];v[23220]=0;if((b|0)==1){break d}v[23220]=0;b=T(265,v[d+176>>2])|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}if(!b){break q}v[23220]=0;Q(175,d+176|0,2)|0;b=v[23220];v[23220]=0;if((b|0)==1){break c}v[23220]=0;b=T(269,d+176|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}G=a,H=Ee((+(b>>>0)*2.3283064365386963e-10+ +(y[a+480204>>2]/1e4>>>0))*1e4),v[G+480204>>2]=H;b=0;v[23220]=0;Q(334,d+176|0,d+112|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}f=x[a+480188>>1];while(1){if((b|0)!=32&(b|0)!=(f|0)){G=d,H=Jb(x[(d+112|0)+(b<<1)>>1]),v[G+48>>2]=H;v[d+32>>2]=180;e=v[nd(d+48|0,d+32|0)>>2]-90|0;g=e>>31;G=((b<<5)+a|0)+480284|0,H=Dc(Cia(e<<7|45,g<<7|e>>>25,90,0),ib)+128|0,u[G>>1]=H;b=b+1|0;continue}else{B:{v[23220]=0;Q(175,d+176|0,16)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break B}break c}}break}v[23220]=0;b=W(143,v[d+176>>2],v[d+184>>2],2)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}C:{if(b){v[23220]=0;b=T(261,d+176|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break C}u[d+48>>1]=b;u[d+32>>1]=256;G=a,H=x[Tc(d+48|0,d+32|0)>>1],v[G+480200>>2]=H}v[23220]=0;Q(175,d+176|0,128)|0;b=v[23220];v[23220]=0;if((b|0)==1){break c}v[23220]=0;b=Q(334,d+176|0,d+48|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){if(!b){break q}e=x[a+480188>>1];b=0;while(1)if((b|0)!=32&(b|0)!=(e|0)){G=d,H=Jb(x[(d+48|0)+(b<<1)>>1]),v[G+32>>2]=H;v[d+16>>2]=128;G=((b<<5)+a|0)+480286|0,H=v[nd(d+32|0,d+16|0)>>2]/2&255,u[G>>1]=H;b=b+1|0;continue}else{v[a+480228>>2]=v[a+480228>>2]<<1;break q}}break c}break c}a=P()|0;O()|0;break b}wb(d+112|0);break p}wb(d+176|0);v[23220]=0;U(332,d+112|0,d+200|0,1413830740);b=v[23220];v[23220]=0;D:{E:{if((b|0)!=1){v[23220]=0;b=T(265,v[d+112>>2])|0;e=v[23220];v[23220]=0;if((e|0)==1){break e}if(!b){break D}v[23220]=0;R(335,d+112|0,d+48|0);b=v[23220];v[23220]=0;if((b|0)==1){break e}if((Jb(x[d+58>>1])|0)!=65535){break E}v[23220]=0;Q(175,d+112|0,1)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break E}break e}a=P()|0;O()|0;break b}v[23220]=0;b=T(189,d+112|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break e}v[23220]=0;X(322,a+1298332|0,d+112|0,b|0,2);b=v[23220];v[23220]=0;if((b|0)==1){break e}}wb(d+112|0);v[23220]=0;U(332,d+48|0,d+200|0,1229869908);b=v[23220];v[23220]=0;if((b|0)==1){break h}v[23220]=0;b=T(265,v[d+48>>2])|0;e=v[23220];v[23220]=0;if((e|0)==1){break l}if(b){F:{v[23220]=0;b=T(261,d+48|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break i}G:{H:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break H}v[23220]=0;e=W(143,v[d+48>>2],v[d+56>>2],B(f,(b>>>14&2)+50|0)|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break g}if(!e){break H}u[a+480190>>1]=f;g=a+480190|0;i=d+130|0;j=(b|0)>=0;b=1;I:{J:{K:{L:{while(1){if(f>>>0<(b&65535)>>>0){v[23220]=0;b=T(261,d+48|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){break I}break g}M:{if(j){o=b}else{v[23220]=0;e=T(261,d+48|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break M}o=e+1|0}u[d+16>>1]=o;v[23220]=0;R(336,d+48|0,d+112|0);e=v[23220];v[23220]=0;if((e|0)==1){break L}e=x[d+16>>1];if((e-4e3&65535)>>>0>=61537){G=a,H=x[Re(g,d+16|0)>>1],u[G+480190>>1]=H;l=x[d+234>>1]|x[d+236>>1]<<16;v[23220]=0;X(337,d+112|0,(B(e,104)+a|0)+484380|0,_b(l)|0,m|0);e=v[23220];v[23220]=0;if((e|0)==1){break K}e=d+32|0;dl(e,2,i);v[23220]=0;R(209,d+176|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){break J}e=d+176|0;yc(((x[d+16>>1]<<5)+a|0)+946304|0,e);ub(e)}b=b+1|0;continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}if((b|0)!=4){break G}u[d+112>>1]=x[a+480190>>1];u[d+176>>1]=255;b=d+176|0;G=a,H=x[Tc(d+112|0,b)>>1],u[G+480192>>1]=H;v[23220]=0;U(332,b|0,d+200|0,1229278806);b=v[23220];v[23220]=0;if((b|0)==1){break j}i=a+480192|0;N:{O:while(1){v[23220]=0;b=W(143,v[d+48>>2],v[d+56>>2],15)|0;e=v[23220];v[23220]=0;if((e|0)==1){break N}if(b){v[23220]=0;R(338,d+48|0,d+32|0);b=v[23220];v[23220]=0;if((b|0)==1){break k}b=Jb(x[d+32>>1]);if(b>>>0>=x[i>>1]){continue}e=B(b,104)+a|0;t[e+484524|0]=w[d+40|0];f=w[d+39|0];t[e+484523|0]=255;t[e+484525|0]=f;v[23220]=0;b=b+1&65535;e=W(241,a|0,b|0,b|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break k}if(!e){continue}G=d,H=Jb(w[d+37|0]|w[d+38|0]<<8),u[G+112>>1]=H;u[d+16>>1]=4095;G=e,H=x[Tc(d+112|0,d+16|0)>>1],v[G>>2]=H;b=w[d+35|0];if((b|0)==255){continue}v[23220]=0;b=Q(142,d+176|0,B(b,34)+2|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break k}if(!b){continue}v[23220]=0;R(339,d+176|0,d+112|0);b=v[23220];v[23220]=0;if((b|0)==1){break k}t[e+60|0]=w[e+60|0]|1;b=x[d+112>>1];v[d+20>>2]=16;v[d+24>>2]=240;G=d,H=Jb(b),v[G+16>>2]=H;b=rB(d+16|0);v[23220]=0;R(281,e+48|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break k}g=v[e+52>>2];f=v[e+48>>2];b=0;while(1){j=ne(f,g);if(j>>>0<=b>>>0){b=w[d+36|0];if((b|0)!=255){t[e- -64|0]=b;t[e+63|0]=b;t[e+60|0]=w[e+60|0]|4}if(rc(f,g)){continue O}b=j-1|0;t[e+62|0]=b;t[e+61|0]=b;t[e+60|0]=w[e+60|0]|2;continue O}else{t[d+16|0]=64;j=(d+112|0)+(b<<1)|0;t[d+12|0]=w[j+2|0];l=Rb(d+16|0,d+12|0);h=zb(f,b);t[h+2|0]=w[l|0];u[h>>1]=w[j+3|0];b=b+1|0;continue}}}break}wb(d+176|0);break F}break k}wb(d+48|0);break p}}}wb(d+48|0);v[23220]=0;U(340,d+176|0,d+200|0,1145131092);b=v[23220];v[23220]=0;if((b|0)==1){break m}G=d,H=Ab(v[d+176>>2]),v[G+16>>2]=H;j=a+484344|0;C=c&1;r=d+48|4;D=Ab(v[d+180>>2]);s=(m|0)!=841887798;z=a+480188|0;E=(m|0)!=841887796;while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{g=v[d+16>>2];if(!Nb(g,D)){fd(d+176|0);v[23220]=0;U(332,d+112|0,d+200|0,1346458702);b=v[23220];v[23220]=0;if((b|0)!=1){break ba}a=P()|0;O()|0;break b}v[23220]=0;Q(175,g|0,4)|0;b=v[23220];v[23220]=0;if((b|0)!=1){v[23220]=0;f=T(261,g|0)|0;b=v[23220];v[23220]=0;ca:{if((b|0)!=1){v[23220]=0;l=T(261,g|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break R}l=s?l:(l>>>0)/y[a+480196>>2]|0;if(!C|f>>>0>255){break P}v[23220]=0;b=W(213,j|0,f|0,l|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break R}if(b){break ca}break P}a=P()|0;O()|0;break Q}if(!s){i=0;v[23220]=0;Q(175,g|0,4)|0;b=v[23220];v[23220]=0;if((b|0)==1){break R}while(1){A=i&65535;if(A>>>0>=x[z>>1]){break P}v[23220]=0;b=T(261,g|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break aa}v[23220]=0;U(177,d+48|0,g|0,b+(b&1)&65535);b=v[23220];v[23220]=0;if((b|0)==1){break S}b=d+48|0;e=gc(d+112|0,b);wb(b);v[d+48>>2]=0;v[d+52>>2]=0;n=0;da:{while(1){b=v[e>>2];v[23220]=0;b=W(143,b|0,v[d+120>>2],6)|0;h=v[23220];v[23220]=0;if((h|0)==1){break da}h=v[d+48>>2];if(b&h>>>0<l>>>0){b=Xb(v[j>>2],f);b=$c(v[b>>2],v[v[b+48>>2]+12>>2],h,A);v[23220]=0;R(341,d+32|0,e|0);h=v[23220];v[23220]=0;ea:{fa:{if((h|0)!=1){h=d+32|0;k=gd(h);F=Qe(h);o=zi(h);p=fc(h);q=t[d+32|0];if((q-1&255)>>>0>95){break fa}t[b|0]=q+13;if(!v[d+52>>2]){break ea}t[b+3|0]=19;v[d+12>>2]=15;G=b,H=w[nd(r,d+12|0)|0]|208,t[G+5|0]=H;break ea}break T}if((q|0)>=0){break ea}if(v[d+52>>2]){t[b+3|0]=19;v[d+12>>2]=15;G=b,H=w[nd(r,d+12|0)|0]|192,t[G+5|0]=H;break ea}t[b|0]=254}if(w[k|0]){t[b+2|0]=1;t[d+12|0]=64;G=b,H=w[Rb(k,d+12|0)|0],t[G+4|0]=H}k=w[F|0];if(k){t[b+1|0]=k}k=w[o|0];if(k|w[p|0]){t[b+3|0]=k;t[b+5|0]=w[p|0];Mf(b)}k=d+48|0;b=w[h+5|0];if(b&128){v[23220]=0;h=T(193,e|0)|0;p=v[23220];v[23220]=0;if((p|0)==1){break T}b=h|b<<8&32512}n=b+n|0;jB(k,n,v[a+480196>>2]);continue}break}wb(e);i=i+1|0;continue}break}break T}i=0;b=Xb(v[j>>2],f);b=$c(v[b>>2],v[v[b+48>>2]+12>>2],0,0);ga:while(1){f=0;if((i|0)==(l|0)){break P}while(1){if(x[z>>1]<=(f&65535)>>>0){i=i+1|0;continue ga}v[23220]=0;R(342,d+112|0,g|0);e=v[23220];v[23220]=0;if((e|0)==1){break $}ha:{if(!E){e=v[d+112>>2];v[d+48>>2]=e;h=d+48|0;n=gd(h);k=Qe(h);h=zi(h);if(e<<24>>24>0){t[b|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+12}e=w[n|0];if(e>>>0>=4){t[b+2|0]=1;t[b+4|0]=(e>>>2|0)-1;e=w[n|0]}t[b+1|0]=e<<4&48|w[k|0]>>>4;t[b+3|0]=w[k|0]&15;t[b+5|0]=w[h|0];break ha}e=v[d+112>>2];v[d+8>>2]=e;v[d+4>>2]=e;Yt(d+4|0,b);G=b,H=w[b+1|0]|w[Hb(d+112|0,0)|0]&48,t[G+1|0]=H}Mf(b);e=w[b+3|0];ia:{if(e>>>0>11){break ia}e=1<<e;ja:{if(!(e&2240)){if(!(e&12)){break ia}if(!w[b+5|0]){break ja}break ia}e=w[b+5|0];h=e&240;if(h){t[b+5|0]=h;break ia}if(e){break ia}}t[b+3|0]=0}b=b+6|0;f=f+1|0;continue}}}a=P()|0;O()|0;break Q}v[23220]=0;b=T(265,v[d+112>>2])|0;e=v[23220];v[23220]=0;ka:{la:{ma:{na:{oa:{if((e|0)!=1){if(b){e=Gb(d+48|0);b=0;pa:{while(1){qa:{v[23220]=0;f=W(143,v[d+112>>2],v[d+120>>2],1)|0;g=v[23220];v[23220]=0;if((g|0)==1){break qa}if(!f){break pa}if(lf(v[j>>2],v[j+4>>2])>>>0<=b>>>0){break pa}v[23220]=0;U(343,d+112|0,e|0,32);f=v[23220];v[23220]=0;if((f|0)==1){break qa}f=v[j>>2];v[23220]=0;R(271,Xb(f,b)|0,e|0);f=v[23220];v[23220]=0;if((f|0)==1){break qa}b=b+1|0;continue}break}a=P()|0;O()|0;ub(e);break oa}ub(e)}b=d+112|0;wb(b);v[23220]=0;U(332,b|0,d+200|0,1414679374);b=v[23220];v[23220]=0;if((b|0)==1){break na}v[23220]=0;b=T(265,v[d+112>>2])|0;e=v[23220];v[23220]=0;if((e|0)==1){break V}if(!b){break ka}e=Gb(d+48|0);f=a+480188|0;b=0;while(1){v[23220]=0;g=W(143,v[d+112>>2],v[d+120>>2],1)|0;i=v[23220];v[23220]=0;if((i|0)==1){break ma}if(!(g&x[f>>1]>b>>>0)){break la}v[23220]=0;U(343,d+112|0,e|0,32);g=v[23220];v[23220]=0;if((g|0)==1){break ma}mm(((b<<5)+a|0)+480289|0,e);b=b+1|0;continue}}a=P()|0;O()|0}wb(d+112|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;ub(e);break U}ub(e)}b=d+112|0;wb(b);v[23220]=0;U(340,b|0,d+200|0,1145129300);b=v[23220];v[23220]=0;if((b|0)==1){break W}G=d,H=Ab(v[d+112>>2]),v[G+48>>2]=H;e=c&2;f=Ab(v[d+116>>2]);g=a+480190|0;ra:{sa:{ta:{ua:{va:{wa:{while(1){b=v[d+48>>2];if(!Nb(b,f)){fd(d+112|0);b=Gb(d+48|0);if((m|0)!=841887798){break va}v[23220]=0;c=Q(1,d+112|0,9461)|0;e=v[23220];v[23220]=0;if((e|0)==1){break wa}Db(b,c);vb(c);break ua}v[23220]=0;c=T(261,b|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break X}xa:{if(!(!e|c>>>0>=x[g>>1])){c=B(c,104)+a|0;i=x[c+484518>>1];i=Uc(d+176|0,i&1?16:8,i&64?2:1,1,0);v[23220]=0;W(206,i|0,c+484484|0,b|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break xa}}rh(d+48|0);continue}break}break X}a=P()|0;O()|0;break Y}v[23220]=0;U(332,d+112|0,d+200|0,1447383635);c=v[23220];v[23220]=0;ya:{za:{Aa:{Ba:{Ca:{if((c|0)!=1){v[23220]=0;c=T(265,v[d+112>>2])|0;e=v[23220];v[23220]=0;if((e|0)==1){break ta}if(!c){break za}v[23220]=0;c=T(269,d+112|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break Ca}v[23220]=0;R(256,d+32|0,4253);e=v[23220];v[23220]=0;if((e|0)==1){break Ba}v[d+16>>2]=c>>>4;v[23220]=0;v[d+12>>2]=c&15;X(344,d+176|0,d+32|0,d+16|0,d+12|0);c=v[23220];v[23220]=0;if((c|0)==1){break Aa}c=d+176|0;Db(b,c);vb(c);bc(d+32|0);break ya}a=P()|0;O()|0;break Y}a=P()|0;O()|0;break Z}a=P()|0;O()|0;break Z}a=P()|0;O()|0;bc(d+32|0);break Z}v[23220]=0;c=Q(1,d+176|0,8496)|0;e=v[23220];v[23220]=0;if((e|0)==1){break _}Db(b,c);vb(c)}wb(d+112|0)}v[23220]=0;c=Q(1,d+32|0,8496)|0;e=v[23220];v[23220]=0;if((e|0)==1){break sa}Db(a+1298344|0,c);vb(c);v[23220]=0;c=Q(1,d+16|0,10094)|0;e=v[23220];v[23220]=0;if((e|0)==1){break ra}Db(a+1298356|0,c);vb(c);Db(a+1298368|0,b);v[a+1298404>>2]=13;vb(b);f=1;break o}a=P()|0;O()|0;break Z}a=P()|0;O()|0;break Y}a=P()|0;O()|0;break Y}a=P()|0;O()|0;break Q}a=P()|0;O()|0;break Q}a=P()|0;O()|0}wb(d+112|0)}vb(b);break b}a=P()|0;O()|0;fd(d+112|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0}wb(d+112|0);break b}a=P()|0;O()|0;wb(e);break Q}a=P()|0;O()|0;break Q}a=P()|0;O()|0}fd(d+176|0);break b}rh(d+16|0);continue}}f=0}Vd(d+200|0)}fb=d+240|0;return f|0}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;wb(d+176|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break b}a=P()|0;O()|0}wb(d+48|0);break b}a=P()|0;O()|0;wb(d+112|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;wb(d+176|0)}Vd(d+200|0)}S(a|0);L()}function EU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=fb-448|0;fb=d;wc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(!Xh(b,d+440|0)){break F}if(!AB(d+440|0)){break F}if(!c){p=1;break F}q=fe(d+416|0,b);v[23220]=0;R(251,d+400|0,q|0);b=v[23220];v[23220]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((b|0)!=1){v[23220]=0;U(252,d+224|0,d+400|0,1229866575);b=v[23220];v[23220]=0;if((b|0)==1){break da}v[23220]=0;p=Q(253,d+224|0,d+384|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break fa}wb(d+224|0);if(!p){break G}v[23220]=0;R(236,a|0,524288);b=v[23220];v[23220]=0;ga:{if((b|0)==1){break ga}yg(a);v[a+480208>>2]=12;G=a,H=Pd(Jb(x[d+392>>1]),1,127),u[G+480188>>1]=H;G=d,H=Jb(x[d+384>>1]),u[G+224>>1]=H;u[d+328>>1]=255;G=a,H=x[Tc(d+224|0,d+328|0)>>1],u[G+480192>>1]=H;G=d,H=Jb(x[d+386>>1]),u[G+224>>1]=H;u[d+328>>1]=3999;G=a,H=x[Tc(d+224|0,d+328|0)>>1],u[G+480190>>1]=H;v[23220]=0;b=W(254,a+1074312|0,6,1)|0;f=v[23220];v[23220]=0;if((f|0)==1){break ga}v[23220]=0;b=Q(255,b|0,21)|0;f=v[23220];v[23220]=0;if((f|0)==1){break ga}v[23220]=0;Q(255,b|0,13)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break ea}}b=P()|0;O()|0;break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;wb(d+224|0);break b}v[23220]=0;b=Q(1,d+368|0,9253)|0;f=v[23220];v[23220]=0;if((f|0)==1){break c}Db(a+1298344|0,b);vb(b);v[23220]=0;b=Q(1,d+352|0,10278)|0;f=v[23220];v[23220]=0;if((f|0)==1){break d}Db(a+1298356|0,b);vb(b);v[23220]=0;R(256,d+328|0,4297);b=v[23220];v[23220]=0;if((b|0)==1){break e}v[23220]=0;R(257,d+304|0,d+440|4);b=v[23220];v[23220]=0;if((b|0)==1){break g}v[23220]=0;R(257,d+280|0,d+440|5);b=v[23220];v[23220]=0;if((b|0)==1){break i}v[23220]=0;X(98,d+224|0,d+328|0,d+304|0,d+280|0);b=v[23220];v[23220]=0;if((b|0)==1){break j}b=d+224|0;Db(a+1298368|0,b);vb(b);vb(d+280|0);vb(d+304|0);b=d+328|0;bc(b);v[a+1298404>>2]=13;v[23220]=0;U(252,b|0,d+400|0,1312902469);b=v[23220];v[23220]=0;if((b|0)==1){break k}v[23220]=0;b=T(147,v[d+328>>2])|0;f=v[23220];v[23220]=0;if((f|0)==1){break m}v[23220]=0;h=a+1298308|0;U(258,d+328|0,h|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break m}v[23220]=0;U(252,d+304|0,d+400|0,1397706311);b=v[23220];v[23220]=0;if((b|0)==1){break n}Bc(Vb(v[a+484360>>2],w[a+484376|0]));g=Jb(x[d+388>>1]);f=a+484360|0;ha:{ia:{while(1){if(g>>>0<=(e&65535)>>>0){break ha}v[23220]=0;b=W(143,v[d+304>>2],v[d+312>>2],46)|0;i=v[23220];v[23220]=0;ja:{if((i|0)!=1){if(!b){break ha}v[23220]=0;R(259,d+304|0,d+224|0);b=v[23220];v[23220]=0;if((b|0)!=1){if(!ze(h)){break ja}v[23220]=0;Q(260,h|0,d+224|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break ja}}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}v[23220]=0;i=T(261,d+304|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break ca}b=Vb(v[f>>2],w[f+16|0]);if(!rc(v[b>>2],v[b+4>>2])){v[23220]=0;b=T(262,f|0)|0;j=v[23220];v[23220]=0;if((j|0)==1){break ca}if((b|0)==255){break ha}b=Vb(v[f>>2],w[f+16|0])}v[23220]=0;U(5,d+280|0,13,d+224|0);j=v[23220];v[23220]=0;if((j|0)!=1){v[23220]=0;R(263,b|0,d+280|0);b=v[23220];v[23220]=0;if((b|0)==1){break ia}vb(d+280|0);b=w[f+16|0];j=v[f>>2];v[23220]=0;U(264,Vb(j,b)|0,d+304|0,i|0);b=v[23220];v[23220]=0;if((b|0)==1){break ca}e=e+1|0;continue}break}b=P()|0;O()|0;break o}b=P()|0;O()|0;vb(d+280|0);break o}xi(f,0);v[23220]=0;U(252,d+280|0,d+400|0,1229869908);b=v[23220];v[23220]=0;if((b|0)==1){break ba}v[23220]=0;b=T(265,v[d+280>>2])|0;f=v[23220];v[23220]=0;if((f|0)==1){break p}ka:{if(!b){break ka}h=a+480192|0;b=1;la:{while(1){f=b&65535;if(f>>>0>x[h>>1]){v[23220]=0;U(252,d+200|0,d+400|0,1447382614);b=v[23220];v[23220]=0;if((b|0)!=1){break la}break p}v[23220]=0;R(266,d+280|0,d+224|0);e=v[23220];v[23220]=0;if((e|0)==1){break p}e=x[d+254>>1];v[23220]=0;f=W(241,a|0,f|0,Jb(e)|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break p}ma:{na:{if(!f){break na}if(Jb(x[d+254>>1])>>>0>3999){break na}e=d+112|0;mu(e,2,d+224|0);v[23220]=0;R(209,d+136|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){break ma}e=d+136|0;yc(f+492|0,e);ub(e);g=d+112|0;mu(g,2,d+224|0);v[23220]=0;R(209,e|0,g|0);e=v[23220];v[23220]=0;if((e|0)==1){break p}e=d+136|0;yc(((Jb(x[d+254>>1])<<5)+a|0)+946304|0,e);ub(e);v[f>>2]=0;G=f,H=Jb(x[d+270>>1])+128&65535,v[G+8>>2]=H;uc(f+8|0,256);t[f+15|0]=w[f+15|0]|1;f=x[d+254>>1];v[23220]=0;f=B(Jb(f),104)+a|0;R(267,f+484380|0,0);e=v[23220];v[23220]=0;if((e|0)==1){break p}G=d,H=Jb(x[d+256>>1]),u[G+136>>1]=H;u[d+112>>1]=64;G=f+484410|0,H=x[Tc(d+136|0,d+112|0)>>1]<<2,u[G>>1]=H;G=f+484404|0,H=_b(x[d+258>>1]|x[d+260>>1]<<16),v[G>>2]=H;e=_b(x[d+266>>1]|x[d+268>>1]<<16);if(!e){break na}g=Jb(x[d+272>>1]);if(!(g&3)){break na}l=e;e=_b(x[d+262>>1]|x[d+264>>1]<<16);v[f+484388>>2]=l+e;v[f+484384>>2]=e;f=f+484414|0;e=x[f>>1];u[f>>1]=e|2;if(!(g&2)){break na}u[f>>1]=e|6}b=b+1|0;continue}break}break p}b=v[d+212>>2];v[d+32>>2]=v[d+208>>2];v[d+36>>2]=b;v[d+40>>2]=v[d+216>>2];v[23220]=0;b=v[d+204>>2];v[d+24>>2]=v[d+200>>2];v[d+28>>2]=b;X(268,d+24|0,0,a|0,0);b=v[23220];v[23220]=0;if((b|0)==1){break p}v[23220]=0;U(252,d+176|0,d+400|0,1346719318);b=v[23220];v[23220]=0;if((b|0)==1){break p}b=v[d+188>>2];v[d+8>>2]=v[d+184>>2];v[d+12>>2]=b;v[d+16>>2]=v[d+192>>2];v[23220]=0;b=v[d+180>>2];v[d>>2]=v[d+176>>2];v[d+4>>2]=b;X(268,d|0,1,a|0,w[d+444|0]>2|0);b=v[23220];v[23220]=0;if((b|0)==1){break p}e=x[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(e|0)){break ka}f=v[((b<<2)+a|0)+900380>>2];if(!(!f|t[f+60|0]&1)){v[f>>2]=32767}b=b+1|0;continue}}wb(d+280|0);v[23220]=0;U(252,d+224|0,d+400|0,1346458708);b=v[23220];v[23220]=0;if((b|0)==1){break q}v[23220]=0;b=T(165,v[d+224>>2])|0;f=v[23220];v[23220]=0;if((f|0)==1){break s}if(!(!(c&1)|b^1)){v[23220]=0;U(252,d+280|0,d+400|0,1347305805);b=v[23220];v[23220]=0;if((b|0)==1){break t}v[23220]=0;Q(175,d+280|0,1)|0;b=v[23220];v[23220]=0;if((b|0)==1){break v}b=x[d+390>>1];v[23220]=0;m=a+484344|0;R(212,m|0,Jb(b)|0);b=v[23220];v[23220]=0;if((b|0)==1){break v}b=d+112|0;s=b|5;y=b|3;z=b|4;A=b|2;C=b|1;h=Ib(d+160|0);D=a+480188|0;f=0;b=0;while(1){if(Jb(x[d+390>>1])>>>0<=f>>>0){ld(h);f=b;wb(d+280|0);if(!(c&4)){break $}e=0;if(!E){break aa}h=x[a+480188>>1];b=0;e=1;while(1){if((b|0)==(h|0)){break aa}g=(b<<5)+a|0;t[g+480288|0]=1;g=g+480280|0;v[g>>2]=v[g>>2]|67108864;b=b+1|0;continue}}v[23220]=0;g=T(261,d+224|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break x}v[23220]=0;e=T(269,d+224|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break y}v[23220]=0;U(177,d+112|0,d+224|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){break z}i=d+112|0;e=gc(d+136|0,i);wb(i);v[23220]=0;i=W(213,m|0,f&65535,g|0)|0;j=v[23220];v[23220]=0;if((j|0)==1){break B}oa:{if(i){o=Gb(d+96|0);v[23220]=0;R(270,d+280|0,o|0);i=v[23220];v[23220]=0;if((i|0)==1){break oa}i=v[m>>2];v[23220]=0;R(271,Xb(i,f)|0,o|0);i=v[23220];v[23220]=0;if((i|0)==1){break oa}n=0;i=Xb(v[m>>2],f);r=Of(v[i>>2],v[v[i+48>>2]+12>>2],0);Bc(h);F=(g>>>0>1?g:1)-1|0;pa:while(1){g=v[e>>2];v[23220]=0;g=W(143,g|0,v[d+144>>2],1)|0;i=v[23220];v[23220]=0;if((i|0)==1){break C}qa:{if(!g){break qa}v[23220]=0;j=T(193,e|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break C}if(!j){G=d,H=Ab(v[h>>2]),v[G+88>>2]=H;i=Ab(v[h+4>>2]);while(1){g=v[d+88>>2];if(Nb(g,i)){me(Xb(v[m>>2],f),He(Be(d+112|0,w[g|0],w[g+1|0]),n));Oe(d+88|0);continue}else{Bc(h);if((n|0)==(F|0)){break qa}g=Xb(v[m>>2],f);n=n+1|0;r=Of(v[g>>2],v[v[g+48>>2]+12>>2],n);continue pa}}}sh(d+112|0);i=x[D>>1];v[23220]=0;g=T(193,e|0)|0;k=v[23220];v[23220]=0;ra:{sa:{if((k|0)!=1){i=i>>>0<j>>>0;j=B(j-1|0,6)+r|0;ta:{if(!(g&1)){break ta}v[23220]=0;k=T(193,e|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break C}l=i?d+112|0:j;if((k|0)!=31){if((k-1&255)>>>0>252){break ta}k=(B(k>>>4|0,12)+(k&15)|0)+13|0}else{k=255}t[l|0]=k}if(!(g&2)){break ra}v[23220]=0;k=T(193,e|0)|0;l=v[23220];v[23220]=0;if((l|0)!=1){break sa}}break C}t[(i?C:j+1|0)|0]=k}if(!(g&60)){continue}t[d+87|0]=0;t[d+86|0]=0;t[d+85|0]=0;t[d+84|0]=0;if(g&4){v[23220]=0;k=T(193,e|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break C}t[d+86|0]=k}if(g&8){v[23220]=0;k=T(193,e|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break C}t[d+84|0]=k}if(g&16){v[23220]=0;k=T(193,e|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break C}t[d+87|0]=k}if(g&32){v[23220]=0;g=T(193,e|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break C}t[d+85|0]=g}wB(d+87|0,d+85|0);wB(d+86|0,d+84|0);g=w[d+86|0];if(!(w[d+87|0]==13|g?(g|0)!=13:0)){Wg(d+87|0,d+86|0);Wg(d+85|0,d+84|0)}lo(d+88|0,d+87|0,d+85|0,d+86|0,d+84|0);if(vB(w[d+88|0],w[d+89|0])){g=v[dc(d+80|0,Ab(v[h>>2]))>>2];v[23220]=0;U(272,h|0,g|0,d+88|0);g=v[23220];v[23220]=0;if((g|0)==1){break C}}t[(i?A:j+2|0)|0]=w[d+87|0];t[(i?z:j+4|0)|0]=w[d+85|0];g=w[d+86|0];t[(i?y:j+3|0)|0]=g;t[(i?s:j+5|0)|0]=w[d+84|0];if((g|0)==43){E=1;continue}if((g|0)!=31){continue}b=1;continue}break}ub(o)}wb(e);f=f+1|0;continue}break}break C}f=0;e=0;if(c&4){break aa}break H}b=P()|0;O()|0;break b}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}v[d+160>>2]=-1778364416;v[d+164>>2]=-16756736;v[23220]=0;U(252,d+280|0,d+400|0,1146310725);b=v[23220];v[23220]=0;if((b|0)==1){break E}v[23220]=0;b=T(265,v[d+280>>2])|0;h=v[23220];v[23220]=0;if((h|0)==1){break D}if(b){v[23220]=0;i=T(261,d+280|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break D}b=0;h=e;while(1){ua:{if((b|0)==(i|0)){v[23220]=0;R(273,d+280|0,d+160|0);b=v[23220];v[23220]=0;if((b|0)!=1){break ua}break D}v[23220]=0;g=T(193,d+280|0)|0;j=v[23220];v[23220]=0;va:{wa:{if((j|0)!=1){if(x[a+480188>>1]<=b>>>0){break va}if(!e){break wa}j=((b<<5)+a|0)+480280|0;v[j>>2]=v[j>>2]&-67108865|((g|0)!=0)<<26;break va}break D}if(g){break va}h=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;continue}break}e=h&1}wb(d+280|0);if(!e){break $}v[23220]=0;b=a+906300|0;Y(274,b|0);e=v[23220];v[23220]=0;if((e|0)==1){break _}v[b+16>>2]=810369604;v[b+20>>2]=1869112133;v[b+24>>2]=655376;v[b+28>>2]=0;v[d+280>>2]=0;h=b+48|0;sB(b+32|0,h,d+280|0);v[23220]=0;e=Q(52,d+136|0,9527)|0;g=v[23220];v[23220]=0;if((g|0)==1){break Z}lu(h,e);ub(e);v[23220]=0;e=Q(52,d+112|0,9491)|0;h=v[23220];v[23220]=0;if((h|0)==1){break Y}pq(b+80|0,e);ub(e);v[23220]=0;R(275,b+4|0,8);e=v[23220];v[23220]=0;if((e|0)==1){break _}rU(d+280|0,w[d+161|0],w[d+163|0],w[d+165|0],w[d+167|0]);e=v[d+284>>2];b=v[b+4>>2];h=v[d+280>>2];t[b|0]=h;t[b+1|0]=h>>>8;t[b+2|0]=h>>>16;t[b+3|0]=h>>>24;t[b+4|0]=e;t[b+5|0]=e>>>8;t[b+6|0]=e>>>16;t[b+7|0]=e>>>24}if(!f){break H}f=a+902204|0;b=0;while(1){if((b|0)==32){break H}v[d+88>>2]=B(b,127)>>>5;v[23220]=0;R(276,d+160|0,4054);e=v[23220];v[23220]=0;if((e|0)==1){break X}v[23220]=0;R(277,d+96|0,d+88|0);e=v[23220];v[23220]=0;if((e|0)==1){break W}v[23220]=0;U(278,d+280|0,d+160|0,d+96|0);e=v[23220];v[23220]=0;if((e|0)==1){break V}e=d+280|0;re(d+72|0,e);Te(le(f,b),v[d+72>>2],v[d+76>>2]);ub(e);ub(d+96|0);e=d+160|0;Pb(e);v[23220]=0;R(276,e|0,4036);e=v[23220];v[23220]=0;if((e|0)==1){break T}v[23220]=0;R(277,d+96|0,d+88|0);e=v[23220];v[23220]=0;if((e|0)==1){break S}v[23220]=0;U(278,d+280|0,d+160|0,d+96|0);e=v[23220];v[23220]=0;if((e|0)==1){break R}e=d+280|0;re(d- -64|0,e);Te(le(f,b+32|0),v[d+64>>2],v[d+68>>2]);ub(e);ub(d+96|0);e=d+160|0;Pb(e);v[23220]=0;R(276,e|0,4027);e=v[23220];v[23220]=0;if((e|0)==1){break P}v[23220]=0;R(277,d+96|0,d+88|0);e=v[23220];v[23220]=0;if((e|0)==1){break O}v[23220]=0;U(278,d+280|0,d+160|0,d+96|0);e=v[23220];v[23220]=0;if((e|0)==1){break N}e=d+280|0;re(d+56|0,e);Te(le(f,b- -64|0),v[d+56>>2],v[d+60>>2]);ub(e);ub(d+96|0);e=d+160|0;Pb(e);v[23220]=0;R(276,e|0,4e3);e=v[23220];v[23220]=0;if((e|0)==1){break L}v[23220]=0;R(277,d+96|0,d+88|0);e=v[23220];v[23220]=0;if((e|0)==1){break K}v[23220]=0;U(278,d+280|0,d+160|0,d+96|0);e=v[23220];v[23220]=0;if((e|0)==1){break J}e=d+280|0;re(d+48|0,e);Te(le(f,b+96|0),v[d+48>>2],v[d+52>>2]);b=b+1|0;ub(e);ub(d+96|0);Pb(d+160|0);continue}}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break U}b=P()|0;O()|0;ub(d+96|0)}Pb(d+160|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break Q}b=P()|0;O()|0;ub(d+96|0)}Pb(d+160|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break M}b=P()|0;O()|0;ub(d+96|0)}Pb(d+160|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break I}b=P()|0;O()|0;ub(d+96|0)}Pb(d+160|0);break r}v[23220]=0;U(252,d+280|0,d+400|0,1397575756);b=v[23220];v[23220]=0;xa:{if((b|0)!=1){v[23220]=0;b=T(165,v[d+280>>2])|0;f=v[23220];v[23220]=0;if((f|0)!=1){ya:{if(!(c&2)|b^1){break xa}f=a+480190|0;b=1;while(1){e=b&65535;if(e>>>0>x[f>>1]){break xa}v[23220]=0;c=T(269,d+280|0)|0;h=v[23220];v[23220]=0;za:{if((h|0)!=1){v[23220]=0;h=T(269,d+280|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break ya}if(!(c&7)){break za}e=(B(e,104)+a|0)+484380|0;v[e>>2]=h;c=Uc(d+160|0,c&4?32:c&2?16:8,1,1,0);v[23220]=0;W(206,c|0,e|0,d+280|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break za}break ya}break ya}b=b+1|0;continue}}}b=P()|0;O()|0;wb(d+280|0);break r}b=P()|0;O()|0;break r}wb(d+280|0);wb(d+224|0);wb(d+304|0);wb(d+328|0)}Vd(d+400|0);wb(q)}fb=d+448|0;return p|0}b=P()|0;O()|0;break r}b=P()|0;O()|0;wb(d+280|0);break r}b=P()|0;O()|0;ub(o);break A}b=P()|0;O()|0}wb(e);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0}ld(h);break u}b=P()|0;O()|0}wb(d+280|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0}wb(d+224|0);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;wb(d+280|0)}wb(d+304|0);break l}b=P()|0;O()|0;break l}b=P()|0;O()|0}wb(d+328|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(d+280|0);break h}b=P()|0;O()|0}vb(d+304|0);break f}b=P()|0;O()|0}bc(d+328|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}Vd(d+400|0)}wb(q);S(b|0);L()}function Eda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0;e=fb-496|0;fb=e;wc(b);k=fb-16|0;fb=k;f=e+288|0;YP(k+8|0,f);n=b;m=v[b+8>>2];b=v[k+12>>2];jc(k,v[n>>2],m,v[k+8>>2],b);m=v[k+4>>2];if((m|0)==(b|0)){Yb(n,v[k+12>>2])}fb=k+16|0;b=(b|0)==(m|0);if(!b){XP(f)}a:{if(!b){break a}if(!ZP(e+288|0)){break a}if(!c){d=1;break a}zd(a,134217728);b=e+8|0;og(b,3936);v[23220]=0;U(638,e+120|0,b|0,x[e+292>>1]);b=v[23220];v[23220]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=e+120|0;Db(a+1298344|0,b);vb(b);bc(e+8|0);b=Qb(b,8945);Db(a+1298356|0,b);vb(b);v[a+480188>>2]=4;v[a+1298404>>2]=13;V=a,X=Jb(x[e+424>>1]),v[V+480196>>2]=X;b=x[e+428>>1];v[a+480260>>2]=56;v[a+480264>>2]=13696;V=a,X=WP(Jb(b)),v[V+480204>>2]=X;kq(Vb(v[a+484360>>2],w[a+484376|0]),e+296|0,w[e+294|0]);A=a+480190|0;i=a+480188|0;p=Ib(e+272|0);s=Ib(e+256|0);h:{i:{j:{k:{while(1){if(Jb(x[e+488>>1])>>>0<=(l&65535)>>>0){break k}v[23220]=0;b=T(261,n|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break g}u[e+232>>1]=b;if((b-4e3&65535)>>>0<=61536){break c}d=Jb(x[e+490>>1]);if((Jb(x[e+292>>1])|0)==2){v[23220]=0;b=T(269,n|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break h}d=b-2|0}v[23220]=0;U(177,e+8|0,n|0,d|0);b=v[23220];v[23220]=0;if((b|0)==1){break i}b=e+8|0;k=gc(e+120|0,b);wb(b);C=x[Re(A,e+232|0)>>1];u[a+480190>>1]=C;v[23220]=0;m=B(x[e+232>>1],104)+a|0;f=m+484380|0;R(267,f|0,1);b=v[23220];v[23220]=0;l:{m:{n:{if((b|0)==1){break n}if(Jb(x[e+292>>1])>>>0>1){break m}v[23220]=0;R(639,k|0,m+484423|0);b=v[23220];v[23220]=0;if((b|0)==1){break n}v[23220]=0;Q(175,k|0,1)|0;b=v[23220];v[23220]=0;if((b|0)==1){break n}v[23220]=0;U(316,k|0,((x[e+232>>1]<<5)+a|0)+946304|0,30);b=v[23220];v[23220]=0;if((b|0)!=1){break l}}f=P()|0;O()|0;break f}b=Gb(e+8|0);v[23220]=0;U(343,k|0,b|0,257);d=v[23220];v[23220]=0;o:{p:{if((d|0)==1){break p}ue(m+484423|0,b);v[23220]=0;Q(175,k|0,1)|0;d=v[23220];v[23220]=0;if((d|0)==1){break p}v[23220]=0;U(343,k|0,b|0,31);d=v[23220];v[23220]=0;if((d|0)==1){break p}yc(((x[e+232>>1]<<5)+a|0)+946304|0,b);if(!(t[e+128|0]&1)){break o}v[23220]=0;Q(175,k|0,1)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break o}}f=P()|0;O()|0;ub(b);break f}ub(b)}v[23220]=0;R(640,k|0,e+8|0);b=v[23220];v[23220]=0;q:{if((b|0)==1){break q}h=fb-16|0;fb=h;d=_b(w[e+8|0]|w[e+9|0]<<8|(w[e+10|0]<<16|w[e+11|0]<<24));v[f>>2]=d;t[h+15|0]=w[e+12|0];t[h+14|0]=64;V=f,X=w[Rb(h+15|0,h+14|0)|0]<<2,u[V+30>>1]=X;g=_b(w[e+14|0]|w[e+15|0]<<8|(w[e+16|0]<<16|w[e+17|0]<<24));v[f+4>>2]=g;b=_b(w[e+14|0]|w[e+15|0]<<8|(w[e+16|0]<<16|w[e+17|0]<<24))+_b(w[e+18|0]|w[e+19|0]<<8|(w[e+20|0]<<16|w[e+21|0]<<24))|0;v[f+8>>2]=b;if(d>>>0<=g>>>0){g=d-1|0;v[f+4>>2]=g}if(b>>>0>d>>>0){v[f+8>>2]=d;b=d}r:{if(b>>>0<g>>>0){v[f+4>>2]=0;v[f+8>>2]=0;break r}if(b>>>0<=g>>>0){break r}u[f+34>>1]=x[f+34>>1]|2;V=zb(f+68|0,0),X=g,v[V>>2]=X}fb=h+16|0;s:{t:{switch(Jb(x[e+292>>1])|0){case 2:t[m+484417|0]=w[e+26|0]<<3;break;case 0:break s;default:break t}}v[23220]=0;R(201,s|0,C|0);b=v[23220];v[23220]=0;if((b|0)==1){break q}v[23220]=0;R(641,p|0,C|0);b=v[23220];v[23220]=0;if((b|0)==1){break q}f=Dd(v[p>>2],x[e+232>>1]-1|0);Bc(f);v[23220]=0;b=T(261,n|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break j}d=v[n+8>>2];h=v[n>>2];v[23220]=0;d=W(143,h|0,d|0,b<<3)|0;h=v[23220];v[23220]=0;if((h|0)==1){break j}if(d){v[23220]=0;R(642,f|0,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break j}d=0;v[e+248>>2]=0;if(!(!(w[m+484414|0]&2)|b)){b=v[m+484384>>2];v[e+240>>2]=b;d=v[m+484388>>2];v[23220]=0;v[e+244>>2]=d-b;R(643,f|0,e+240|0);b=v[23220];v[23220]=0;if((b|0)!=1){break s}f=P()|0;O()|0;break f}while(1){if(b>>>0<=(d&65535)>>>0){break s}v[23220]=0;m=T(269,n|0)|0;h=v[23220];v[23220]=0;u:{if((h|0)==1){break u}v[23220]=0;v[e+240>>2]=m;m=T(269,n|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break u}v[23220]=0;v[e+244>>2]=m;R(643,f|0,e+240|0);m=v[23220];v[23220]=0;if((m|0)==1){break u}d=d+1|0;continue}break}f=P()|0;O()|0;break f}wb(k);break c}wb(k);l=l+1|0;continue}break}f=P()|0;O()|0;break f}v:{w:{x:{y:{if(Jb(x[e+292>>1])){z=w[e+295|0];u[e+238>>1]=4;D=128;break y}v[23220]=0;D=T(261,n|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){f=P()|0;O()|0;break e}b=x[e+292>>1];z=w[e+295|0];u[e+238>>1]=4;if(!Jb(b)){break x}}d=v[n+8>>2];f=0;while(1){z:{if((f&65535)>>>0>=D>>>0){break z}v[23220]=0;b=T(261,n|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break w}if((b|0)==65535){break z}v[23220]=0;z=T(261,n|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break w}v[23220]=0;b=T(261,n|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break w}u[e+238>>1]=b;if(b>>>0>127){break c}V=i,X=x[Re(i,e+238|0)>>1],u[V>>1]=X;v[23220]=0;Q(175,n|0,B(b,z)<<2)|0;b=v[23220];v[23220]=0;if((b|0)==1){break w}f=f+1|0;continue}break}v[23220]=0;Q(142,n|0,d|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break v}}b=x[i>>1];v[23220]=0;E=Q(644,e+240|0,b|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){J=a+484344|0;N=c&1;F=Jb(x[e+426>>1]);b=0;k=0;while(1){A:{B:{C:{D:{if((b&65535)>>>0>=D>>>0){break D}E:{if(!Jb(x[e+292>>1])){d=x[e+238>>1];f=b;break E}v[23220]=0;f=T(261,n|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break A}if((f|0)==65535){break D}v[23220]=0;z=T(261,n|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break A}v[23220]=0;d=T(261,n|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break A}u[e+238>>1]=d}m=v[n+8>>2];h=v[n>>2];v[23220]=0;g=d&65535;G=z&65535;d=G<<2;m=W(143,h|0,m|0,B(g,d)|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break A}if(!m){break D}if(!N){break C}v[23220]=0;K=f&65535;f=W(213,J|0,K|0,G|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break A}if(!f){break C}r=0;F:while(1){if((r|0)==(G|0)){break B}f=0;d=Xb(v[J>>2],K);i=Of(v[d>>2],v[v[d+48>>2]+12>>2],r);H=0;m=0;G:{H:{I:{switch((F&3)-1|0){case 0:m=!(r&3);break H;case 1:m=!(r&1);break H;case 2:break I;default:break G}}m=(r&3)!=3}}while(1){if(x[e+238>>1]<=f>>>0){r=r+1|0;continue F}d=v[E>>2];v[23220]=0;R(342,e+232|0,n|0);h=v[23220];v[23220]=0;if((h|0)==1){break A}h=B(f,9)+d|0;d=e+232|0;g=gd(d);q=Qe(d);l=i+B(f,6)|0;t[l+1|0]=w[e+232|0];j=w[g|0];t[l|0]=j;g=w[zi(d)|0];t[l+5|0]=g;o=l+5|0;if(j){t[l|0]=j+25;t[h+8|0]=0;t[h|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[h+3|0]=0;t[h+4|0]=0;t[h+5|0]=0;t[h+6|0]=0;t[h+7|0]=0;g=w[o|0]}j=g&255;q=w[q|0];J:{if(q>>>0>=240){d=j|(q&15)<<8;if(d){V=o,X=Yn(+(WP(d)>>>0)/1e4),t[V|0]=X;t[l+3|0]=17;break J}t[l+3|0]=0;break J}I=j>>>4|0;M=j<<4;d=I|M;K:{switch(q|0){case 0:d=i+B(f,6)|0;if(g&255){t[d+3|0]=1;break J}t[d+3|0]=0;break J;case 1:t[(i+B(f,6)|0)+3|0]=2;break J;case 2:t[(i+B(f,6)|0)+3|0]=3;break J;case 3:t[e+228|0]=15;V=h,X=w[Rb(o,e+228|0)|0]|16,t[V|0]=X;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(i+B(f,6)|0)+3|0]=0;break J;case 4:t[e+228|0]=15;V=h,X=w[Rb(o,e+228|0)|0]|32,t[V|0]=X;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(i+B(f,6)|0)+3|0]=0;break J;case 5:t[h+7|0]=0;t[h+2|0]=0;t[h+1|0]=g;t[h|0]=0;t[(i+B(f,6)|0)+3|0]=0;break J;case 6:t[h+7|0]=0;t[h+2|0]=g;t[h|0]=0;t[h+1|0]=0;t[(i+B(f,6)|0)+3|0]=0;break J;case 7:t[(i+B(f,6)|0)+3|0]=23;k=0;break J;case 8:t[(i+B(f,6)|0)+3|0]=0;k=d;break J;case 9:t[(i+B(f,6)|0)+3|0]=19;t[e+228|0]=15;V=o,X=w[Rb(o,e+228|0)|0]|16,t[V|0]=X;break J;case 10:t[(i+B(f,6)|0)+3|0]=19;t[e+228|0]=15;V=o,X=w[Rb(o,e+228|0)|0]|32,t[V|0]=X;break J;case 11:t[h+3|0]=d;t[(i+B(f,6)|0)+3|0]=0;break J;case 12:d=i+B(f,6)|0;t[d+4|0]=g;t[d+2|0]=1;t[h+3|0]=0;t[d+3|0]=0;break J;case 13:q=i+B(f,6)|0;L:{M:{if(j&240){t[(i+B(f,6)|0)+2|0]=4;d=(g&240)>>>4|0;break M}if(!(j&15)){break L}t[(i+B(f,6)|0)+2|0]=3;d=g&15}t[q+4|0]=d}t[h+3|0]=0;t[(i+B(f,6)|0)+3|0]=0;break J;case 14:t[(i+B(f,6)|0)+3|0]=19;t[o|0]=!(g&255);break J;case 15:t[(i+B(f,6)|0)+3|0]=16;t[o|0]=(g&240)>>>4;F=g&15;break J;case 16:t[h+5|0]=0;t[h+4|0]=g;t[(i+B(f,6)|0)+3|0]=0;break J;case 17:t[h+6|0]=j&15?g:0;t[(i+B(f,6)|0)+3|0]=0;break J;case 18:t[(i+B(f,6)|0)+3|0]=14;break J;case 19:t[h+8|0]=0;t[h+7|0]=g;t[h+2|0]=0;t[h|0]=0;t[h+1|0]=0;t[(i+B(f,6)|0)+3|0]=0;break J;case 20:t[(i+B(f,6)|0)+3|0]=12;break J;case 22:d=w[l+1|0];N:{if(!d){break N}j=v[p>>2];if(rd(j,v[p+4>>2])>>>0<d>>>0){break N}g=g-1|0;t[o|0]=g;v[23220]=0;T(645,e+120|0)|0;q=v[23220];v[23220]=0;if((q|0)==1){break A}v[e+228>>2]=9;d=Dd(j,d-1|0);V=e,X=rd(v[d>>2],v[d+4>>2]),v[V+116>>2]=X;if(y[Eb(e+228|0,e+116|0)>>2]<=(g&255)>>>0){break N}d=i+B(f,6)|0;t[d+2|0]=15;t[d+4|0]=w[o|0]}t[(i+B(f,6)|0)+3|0]=0;break J;case 23:d=w[l+1|0];O:{if(!d){break O}j=v[p>>2];if(rd(j,v[p+4>>2])>>>0<d>>>0){break O}g=g-1|0;t[o|0]=g;d=Dd(j,d-1|0);j=v[d>>2];q=rd(j,v[d+4>>2]);d=g&255;if(q>>>0<=d>>>0){break O}d=Dd(j,d);g=x[d+8>>1];P:{if(g){break P}g=0;j=x[a+480190>>1];if(!Ph(j)){break P}g=j+1|0;u[A>>1]=g;u[d+8>>1]=g}t[l+1|0]=g}t[(i+B(f,6)|0)+3|0]=0;break J;case 24:d=w[l+1|0];Q:{if(!d){break Q}j=v[p>>2];if(rd(j,v[p+4>>2])>>>0<d>>>0){break Q}g=g-1|0;t[o|0]=g;v[23220]=0;T(645,e+8|0)|0;q=v[23220];v[23220]=0;if((q|0)==1){break A}v[e+228>>2]=9;d=Dd(j,d-1|0);V=e,X=rd(v[d>>2],v[d+4>>2]),v[V+116>>2]=X;if(y[Eb(e+228|0,e+116|0)>>2]>(g&255)>>>0){d=i+B(f,6)|0;t[d+2|0]=15;t[d+4|0]=w[o|0]}d=ac(v[s>>2],w[l+1|0]-1|0);g=x[d>>1];R:{if(g){break R}g=0;j=x[a+480190>>1];if(!Ph(j)){break R}g=j+1|0;u[A>>1]=g;u[d>>1]=g}t[l+1|0]=g}t[(i+B(f,6)|0)+3|0]=0;break J;case 25:d=w[l+1|0];S:{if(!d){break S}j=v[p>>2];if(rd(j,v[p+4>>2])>>>0<d>>>0){break S}g=g-1|0;t[o|0]=g;d=Dd(j,d-1|0);j=v[d>>2];q=rd(j,v[d+4>>2]);d=g&255;if(q>>>0<=d>>>0){break S}d=Dd(j,d);g=x[d+10>>1];T:{if(g){break T}g=0;j=x[a+480190>>1];if(!Ph(j)){break T}g=j+1|0;u[A>>1]=g;u[d+10>>1]=g}t[l+1|0]=g}t[(i+B(f,6)|0)+3|0]=0;break J;case 29:t[(i+B(f,6)|0)+3|0]=11;t[o|0]=d;if(j&15){t[o|0]=M|15;break J}if((g&255)>>>0<16){break J}t[o|0]=I|240;break J;case 32:if(j&240){t[h+3|0]=I;t[(i+B(f,6)|0)+3|0]=0;break J}t[(i+B(f,6)|0)+3|0]=19;t[o|0]=g&15|192;break J;case 33:t[(i+B(f,6)|0)+3|0]=19;t[e+228|0]=15;V=o,X=w[Rb(o,e+228|0)|0]|208,t[V|0]=X;break J;case 34:t[(i+B(f,6)|0)+3|0]=19;t[e+228|0]=15;V=o,X=w[Rb(o,e+228|0)|0]|144,t[V|0]=X;break J;case 73:t[(i+B(f,6)|0)+3|0]=10;break J;case 78:if((g&112|128)==224){t[(i+B(f,6)|0)+3|0]=19;break J}t[(i+B(f,6)|0)+3|0]=0;break J;case 79:d=i+B(f,6)|0;if((g&255)>>>0<=31){t[d+3|0]=16;F=0;break J}t[d+3|0]=17;break J;default:break K}}t[(i+B(f,6)|0)+3|0]=0}j=0;g=w[h+3|0];if(!(w[l+2|0]|!g)){U:{if(g>>>0>=16){t[l+2|0]=5;g=g>>>4|0;break U}t[l+2|0]=6}t[l+4|0]=g;j=1}V:{if(w[l+3|0]){break V}d=w[h+1|0];W:{if(d){t[l+3|0]=2;break W}d=w[h+2|0];if(d){t[l+3|0]=3;break W}d=w[h|0];if(d){t[l+3|0]=19;break W}d=w[h+7|0];if(d){t[l+3|0]=4;t[h+8|0]=d;break W}d=w[h+4|0];if(d){t[l+3|0]=5;t[h+5|0]=d;break W}d=w[h+3|0];if(!(!d|j)){t[l+3|0]=11;t[o|0]=d;if(d&15){d=d|-16;break W}if(!(d&240)){break V}d=d|15;break W}d=w[h+6|0];if(d){t[l+3|0]=8;break W}if(m){t[l+3|0]=20;m=0;d=97;break W}m=0;if(H){break V}d=k&255;if(!d){break V}t[l+3|0]=24;t[o|0]=k;if(k&15){d=k|-16}else{if(!(d&240)){H=1;break V}d=k|15}H=1}t[o|0]=d}f=f+1|0;continue}}}v[a+480228>>2]=256/x[a+480188>>1];j=1;th(a,1);if(Jb(x[e+292>>1])){X:{while(1){b=v[n+8>>2];d=v[n>>2];v[23220]=0;b=W(143,d|0,b|0,2)|0;d=v[23220];v[23220]=0;if((d|0)==1){break A}if(!b){break X}v[23220]=0;b=T(261,n|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break A}if((b|0)==65535){break X}v[23220]=0;Q(175,n|0,2)|0;b=v[23220];v[23220]=0;if((b|0)==1){break A}v[23220]=0;b=T(269,n|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){v[23220]=0;Q(175,n|0,b|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){continue}}break}break A}v[23220]=0;Q(175,n|0,34)|0;b=v[23220];v[23220]=0;if((b|0)==1){break A}}Y:{if(!(c&2)){break Y}while(1){b=j&65535;if(b>>>0>C>>>0){break Y}Z:{d=(B(b,104)+a|0)+484380|0;if(!v[d>>2]){break Z}c=Uc(e+232|0,8,1,0,0);v[23220]=0;W(206,c|0,d|0,n|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break A}c=v[p>>2];if(rd(c,v[p+4>>2])>>>0<b>>>0){break Z}g=b-1|0;m=Dd(c,g);c=0;b=0;i=fb-112|0;fb=i;_:{h=v[d>>2];if(!Md(h,v[d+20>>2])){break _}o=v[m>>2];k=rd(o,v[m+4>>2]);if(k>>>0<2){break _}f=Wn(i+8|0,d);v[f+20>>2]=0;v[f>>2]=0;$:{while(1){if((c|0)==(k|0)){break $}aa:{l=Dd(o,c);r=v[l>>2];if(r>>>0>=h>>>0){break aa}l=v[l+4>>2];if(l>>>0>h-r>>>0|268435456-l>>>0<b>>>0){break aa}b=b+l|0;v[f>>2]=b;c=c+1|0;continue}break}k=c}if(!wg(f)){break _}l=f+68|0;b=0;c=0;while(1){if((c|0)==(k|0)){am(d);b=Wn(d,f);v[b+4>>2]=0;v[b+8>>2]=v[b>>2];u[b+34>>1]=x[b+34>>1]|2;break _}o=v[f+20>>2]+b|0;r=v[d+20>>2];h=Dd(v[m>>2],c);nc(o,r+v[h>>2]|0,v[h+4>>2]);v[h>>2]=b;if(c-10>>>0>=4294967287){V=zb(l,c-1|0),X=b,v[V>>2]=X}c=c+1|0;b=v[h+4>>2]+b|0;continue}}fb=i+112|0;b=x[ac(v[s>>2],g)>>1];if(b){Kz(d,(B(b,104)+a|0)+484380|0,0,v[d>>2],0)}b=Dd(v[p>>2],g);V=e,X=Ab(v[b>>2]),v[V+232>>2]=X;c=Ab(v[b+4>>2]);while(1){b=v[e+232>>2];if(!Nb(b,c)){break Z}k=x[b+8>>1];if(k){Kz(d,(B(k,104)+a|0)+484380|0,v[b>>2],v[b+4>>2],1)}k=x[b+10>>1];if(k){Kz(d,(B(k,104)+a|0)+484380|0,v[b>>2],v[b+4>>2],0)}Sp(e+232|0);continue}}j=j+1|0;continue}}Jp(E);d=1;break b}v[23220]=0;Q(175,n|0,B(d,x[e+238>>1])|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break B}break A}b=b+1|0;continue}break}f=P()|0;O()|0;Jp(E);break e}f=P()|0;O()|0;break e}f=P()|0;O()|0;break e}f=P()|0;O()|0;break e}f=P()|0;O()|0;break f}f=P()|0;O()|0;break e}f=P()|0;O()|0;break e}f=P()|0;O()|0;bc(e+8|0);break d}f=P()|0;O()|0;break e}wb(k)}ld(s);SP(p)}S(f|0);L()}d=0}ld(s);SP(p)}fb=e+496|0;return d|0}function Lca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;d=fb-592|0;fb=d;wc(b);a:{if(!NA(b,d+512|0)){break a}if(!iP(d+512|0)){break a}if(!Lb(v[b>>2],v[b+8>>2],Pc(hP(d+512|0),ib))){break a}b:{if(!c){break b}zd(a,4);yg(a);t[a+1074368|0]=4;k=Gb(d+496|0);c:{d:{e:{f:{l=d+550|0;g:{if(!(Mb(l,17741,20)|v[d+572>>2]!=276)){if(x[d+570>>1]<260){break g}e=PA(d+529|0,0,20)?1154:34;break e}if(!Mb(l,17720,20)){e=1;break e}g=d- -64|0;rj(g,3,l);v[23220]=0;R(209,d+104|0,g|0);g=v[23220];v[23220]=0;h:{i:{if((g|0)!=1){v[23220]=0;U(11,d+208|0,5,d+104|0);g=v[23220];v[23220]=0;if((g|0)==1){break i}g=d+208|0;Db(k,g);vb(g);ub(d+104|0);if(Mb(l,17558,8)){break h}e=1048;break e}f=P()|0;O()|0;break c}f=P()|0;O()|0;ub(d+104|0);break c}if(!Mb(l,17458,12)){e=16;if(!Mb(l+12|0,17762,8)){break e}t[a+1074368|0]=5;break e}if(Mb(l,11631,20)){break f}}e=48;break e}if(!Mb(l,27088,15)){v[23220]=0;g=Q(255,a+1074312|0,54)|0;e=v[23220];v[23220]=0;C=1;if((e|0)==1){break d}v[23220]=0;Q(255,g|0,51)|0;g=v[23220];v[23220]=0;e=16;if((g|0)==1){break d}break e}j:{if(Mb(l,27104,14)){if(Mb(l,27119,14)){break j}}v[23220]=0;g=Q(255,a+1074312|0,57)|0;e=v[23220];v[23220]=0;if((e|0)==1){break d}v[23220]=0;Q(255,g|0,51)|0;g=v[23220];v[23220]=0;e=16;if((g|0)!=1){break e}break d}e=Mb(l,17546,11)?16:256}g=d+104|0;s=d+529|0;rj(g,3,s);v[23220]=0;R(209,d+208|0,g|0);g=v[23220];v[23220]=0;k:{l:{m:{n:{o:{p:{q:{if((g|0)!=1){g=d+208|0;xc(a+1298308|0,g);ub(g);v[a+480260>>2]=1;v[a+480264>>2]=31999;Ve(Vb(v[a+484360>>2],w[a+484376|0]),x[d+578>>1]);u[a+480188>>1]=x[d+580>>1];u[d+208>>1]=x[d+584>>1];u[d+104>>1]=255;E=a,F=x[Tc(g,d+104|0)>>1],u[E+480192>>1]=F;g=x[d+588>>1];if(g){v[a+480196>>2]=g}g=x[d+590>>1];if(g){g=B(g,1e4);g=g>>>0<1e7?g:1e7;v[a+480204>>2]=g>>>0>32e4?g:32e4}g=x[d+586>>1];v[a+480208>>2]=g<<4&16|g<<3&32768;f=w[a+484376|0];n=v[a+484360>>2];v[23220]=0;da(333,Vb(n,f)|0,b|0,x[d+576>>1],65535,65535);f=v[23220];v[23220]=0;if((f|0)==1){break d}f=g>>>12&1?(e|0)==34?146:e:e;if(!(x[d+576>>1]|f&1024)){g=w[a+484376|0];e=v[a+484360>>2];v[23220]=0;Y(699,Vb(e,g)|0);g=v[23220];v[23220]=0;if((g|0)==1){break d}}v[23220]=0;Q(142,b|0,v[d+572>>2]+60|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break d}if(x[d+570>>1]>=260){v[23220]=0;U(700,b|0,d+512|0,a|0);g=v[23220];v[23220]=0;if((g|0)==1){break d}}t[d+495|0]=0;z=c&2;D=d+122|0;o=d+241|0;n=Ib(d+480|0);p=1;g=-1;while(1){e=p&65535;if(e>>>0>x[a+480192>>1]){if(!(!(f&2)|q&255)){f=PA(s,0,20)?f|16:f}if(x[d+570>>1]>259){break o}if(c&3){v[23220]=0;U(700,b|0,d+512|0,a|0);c=v[23220];v[23220]=0;if((c|0)==1){break n}}if(!z){break o}o=a+480190|0;e=1;while(1){c=e&65535;if(c>>>0>x[o>>1]){break o}i=v[n>>2];v[23220]=0;W(206,zb(i,c-1|0)|0,(B(c,104)+a|0)+484380|0,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){e=e+1|0;continue}break}f=P()|0;O()|0;break k}v[23220]=0;i=T(144,b|0)|0;h=v[23220];v[23220]=0;r:{s:{if((h|0)!=1){jg(b,4);v[23220]=0;U(701,b|0,d+208|0,(i?i:263)|0);i=v[23220];v[23220]=0;if((i|0)==1){break p}t:{if((f|0)==1){i=v[d+208>>2];if((i|0)!=263){f=16;if((i|0)!=245){break t}v[a+1074308>>2]=16777381;v[23220]=0;f=Q(1,d+192|0,13333)|0;i=v[23220];v[23220]=0;if((i|0)!=1){Db(k,f);vb(f);f=17;break t}f=P()|0;O()|0;break k}v[a+1074308>>2]=16777395;v[23220]=0;f=Q(1,d+176|0,13248)|0;i=v[23220];v[23220]=0;if((i|0)!=1){Db(k,f);vb(f);f=17;break t}f=P()|0;O()|0;break k}if(w[d+235|0]|w[d+236|0]<<8){break t}i=v[d+208>>2];if(!(!(f&2)|(w[d+237|0]|w[d+238|0]<<8|(w[d+239|0]<<16|w[d+240|0]<<24))|(i|0)!=263)){f=f|16;break t}if(!(!(f&256)|(i|0)==29)){f=f&-257;break t}if(!(f&160)){break t}f=(i|0)==33?f:0}v[23220]=0;i=W(241,a|0,e|0,0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break p}if(!i){break r}i=((e<<2)+a|0)+900380|0;e=v[i>>2];v[23220]=0;R(702,d+208|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){break p}e=w[d+234|0];u:{if((g|0)==-1){g=e;break u}if(!(f&32)|(e|0)==(g|0)){break u}f=f&-161|128}e=w[d+235|0]|w[d+236|0]<<8;if(!e){break r}v[23220]=0;h=w[d+455|0];j=w[d+451|0]|w[d+452|0]<<8;m=w[d+450|0];r=w[d+449|0];U(703,d+160|0,a|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){break q}f=h|(j|(m|r))?f&-4:f;i=v[i>>2]+236|0;e=12;h=v[d+160>>2];j=Ic(h,v[d+164>>2]);v:{while(1){w:{if((e|0)==108){if(x[d+570>>1]>259){Bc(n)}e=0;v[23220]=0;i=Q(704,d+144|0,w[d+235|0]|w[d+236|0]<<8)|0;h=v[23220];v[23220]=0;if((h|0)!=1){break w}f=P()|0;O()|0;break v}m=ac(i,e);if(j>>>0>x[m>>1]){E=m,F=x[ac(h,x[ac(i,e)>>1])>>1],u[E>>1]=F}e=e+1|0;continue}break}x:{y:{z:{A:{while(1){h=w[d+235|0]|w[d+236|0]<<8;if(e>>>0>=h>>>0){e=0;if(x[d+570>>1]<=259){break s}B:{while(1){if(e>>>0>=h>>>0){break s}j=w[zb(v[n>>2],e)+3|0];h=v[zb(v[i>>2],e)>>2];v[23220]=0;U(177,d- -64|0,b|0,((j|0)==10?(h+1>>>1|0)+16|0:h)|0);h=v[23220];v[23220]=0;if((h|0)!=1){j=d- -64|0;h=gc(d+104|0,j);wb(j);j=v[d+160>>2];if(!(!z|Ic(j,v[d+164>>2])>>>0<=e>>>0)){m=x[ac(j,e)>>1];j=zb(v[n>>2],e);j=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);v[23220]=0;v[d+56>>2]=j;v[d>>2]=j;j=fa(705,(B(m,104)+a|0)+484380|0,d|0,h|0,d+495|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break B}A=j^1|A}wb(h);e=e+1|0;h=w[d+235|0]|w[d+236|0]<<8;continue}break}f=P()|0;O()|0;break x}f=P()|0;O()|0;wb(h);break x}v[23220]=0;R(706,b|0,d+104|0);h=v[23220];v[23220]=0;if((h|0)==1){break y}h=d- -64|0;j=w[d+118|0];C:{if(!(j&48|w[d+121|0]!=173)){Uc(h,8,1,0,10);break C}Uc(h,j&16?16:8,j&32?3:1,0,2)}v[23220]=0;R(707,n|0,h|0);h=v[23220];v[23220]=0;if((h|0)!=1){E=zb(v[i>>2],e),F=v[d+104>>2],v[E>>2]=F;m=w[d+121|0];h=v[d+160>>2];if(Ic(h,v[d+164>>2])>>>0>e>>>0){j=x[ac(h,e)>>1];v[23220]=0;h=(B(j,104)+a|0)+484380|0;R(708,d+104|0,h|0);r=v[23220];v[23220]=0;if((r|0)==1){break A}t[h+38|0]=w[o+202|0];t[h+39|0]=w[o+203|0];t[h+40|0]=w[o+204|0];t[h+41|0]=w[o+205|0];h=d+88|0;dl(h,3,D);v[23220]=0;R(209,d- -64|0,h|0);h=v[23220];v[23220]=0;if((h|0)==1){break z}h=d- -64|0;yc(((j<<5)+a|0)+946304|0,h);ub(h);f=(w[d+118|0]&3)==3?(f&2)>>>1|0?f|4:f:f}q=m|q;e=e+1|0;continue}break}f=P()|0;O()|0;break x}f=P()|0;O()|0;break x}f=P()|0;O()|0;break x}f=P()|0;O()|0}lc(i)}ld(d+160|0);break k}f=P()|0;O()|0;break k}lc(i);ld(d+160|0)}p=p+1|0;continue}}f=P()|0;O()|0;break c}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}D:{if(!(A&1)){break D}v[23220]=0;c=Q(1,d+104|0,16573)|0;e=v[23220];v[23220]=0;E:{if((e|0)!=1){e=v[a+1298464>>2];v[23220]=0;U(360,e|0,2,c|0);e=v[23220];v[23220]=0;if((e|0)==1){break E}vb(c);break D}f=P()|0;O()|0;break k}f=P()|0;O()|0;vb(c);break k}v[23220]=0;c=Q(355,b|0,5519)|0;e=v[23220];v[23220]=0;if((e|0)==1){break n}if(c){v[23220]=0;c=T(144,b|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break n}v[23220]=0;X(322,a+1298332|0,b|0,c|0,0);c=v[23220];v[23220]=0;if((c|0)==1){break n}f=f|16}v[23220]=0;o=Q(355,b|0,14064)|0;c=v[23220];v[23220]=0;if((c|0)==1){break l}if(o){v[23220]=0;c=T(144,b|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break l}v[23220]=0;e=a+901404|0;U(709,b|0,e|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break l}OA(e);f=f|16}v[23220]=0;c=Q(355,b|0,13830)|0;e=v[23220];v[23220]=0;if((e|0)==1){break l}if(!c){break m}v[23220]=0;c=T(144,b|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){u[d+208>>1]=c>>>5;E=d,F=lf(v[a+484344>>2],v[a+484348>>2]),u[E+64>>1]=F;c=x[Tc(d+208|0,d- -64|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break m}v[23220]=0;R(526,b|0,d+208|0);i=v[23220];v[23220]=0;F:{if((i|0)==1){break F}i=v[a+484344>>2];v[23220]=0;R(527,Xb(i,e)|0,d+208|0);i=v[23220];v[23220]=0;if((i|0)==1){break F}e=e+1|0;continue}break}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[23220]=0;c=Q(355,b|0,13835)|0;e=v[23220];v[23220]=0;if((e|0)==1){break l}G:{if(!c){break G}v[23220]=0;c=T(144,b|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){u[d+208>>1]=(c>>>0)/20;u[d+64>>1]=x[a+480188>>1];c=x[Tc(d+208|0,d- -64|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break G}v[23220]=0;U(366,b|0,((e<<5)+a|0)+480289|0,20);i=v[23220];v[23220]=0;if((i|0)!=1){e=e+1|0;continue}break}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}c=v[b+8>>2];e=v[b>>2];v[23220]=0;c=W(143,e|0,c|0,8)|0;e=v[23220];v[23220]=0;if((e|0)==1){break l}H:{I:{J:{K:{if(c){c=v[b+8>>2];v[23220]=0;Q(367,a|0,b|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break K}f=(c|0)==v[b+8>>2]?f:f|16}L:{if(!(f&16)){break L}if(f&4){v[a+1074308>>2]=17367040;v[23220]=0;c=Q(1,d+208|0,14671)|0;e=v[23220];v[23220]=0;if((e|0)!=1){Db(k,c);vb(c);break L}f=P()|0;O()|0;break k}if(!(f&2)){break L}v[a+1074308>>2]=18219008;v[23220]=0;c=Q(1,d+208|0,14828)|0;e=v[23220];v[23220]=0;if((e|0)==1){break J}Db(k,c);vb(c)}M:{N:{O:{P:{Q:{R:{S:{if(!Mb(l,17558,8)){v[23220]=0;c=Q(710,d- -64|0,l+8|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break S}v[23220]=0;U(11,d+160|0,1,c|0);e=v[23220];v[23220]=0;if((e|0)==1){break R}v[23220]=0;e=T(711,d+160|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break Q}v[a+1074308>>2]=e;vb(d+160|0);t[a+1074368|0]=y[a+1074308>>2]<19007257?4:5;ub(c);f=24}if(!(!v[a+1074308>>2]|f&8)){t[a+1074368|0]=0;Ut(a+1074312|0)}c=f&32;T:{if(!c){break T}t[a+1074368|0]=5;if(!o){Vp(a+901404|0)}if(x[d+570>>1]<260){break T}v[23220]=0;W(254,a+1074312|0,4,1)|0;e=v[23220];v[23220]=0;if((e|0)==1){break l}}if(!ah(v[k+4>>2],w[k+11|0])){break M}if(!(f&256)|q&255|g+1>>>0>1){break N}v[23220]=0;c=Q(1,d+160|0,8279)|0;g=v[23220];v[23220]=0;if((g|0)==1){break O}Db(k,c);vb(c);break M}f=P()|0;O()|0;break k}f=P()|0;O()|0;break P}f=P()|0;O()|0;vb(d+160|0)}ub(c);break k}f=P()|0;O()|0;break k}if(c){v[23220]=0;c=Q(1,d+160|0,12043)|0;g=v[23220];v[23220]=0;if((g|0)!=1){Db(k,c);vb(c);break M}f=P()|0;O()|0;break k}v[23220]=0;c=Q(1,d+160|0,9711)|0;g=v[23220];v[23220]=0;if((g|0)==1){break I}Db(k,c);vb(c)}t[d+55|0]=0;U:{if(x[a+480192>>1]){v[23220]=0;c=Q(376,a|0,b|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break U}t[d+55|0]=c}v[23220]=0;X(377,a|0,b|0,1,d+55|0);b=v[23220];v[23220]=0;if((b|0)==1){break U}e=v[a+1074308>>2];V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if(w[d+55|0]){if(e>>>0>18284543){break ha}v[a+1074308>>2]=18284544;break ha}if(e>>>0<18284544){break ga}}v[23220]=0;b=Q(1,d+40|0,17558)|0;c=v[23220];v[23220]=0;if((c|0)==1){break fa}c=v[a+1074308>>2];v[23220]=0;R(712,d+24|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break ea}v[23220]=0;U(2,d+88|0,b|0,d+24|0);c=v[23220];v[23220]=0;if((c|0)==1){break da}c=d+88|0;Db(k,c);vb(c);vb(d+24|0);vb(b);e=v[a+1074308>>2]}ia:{if(e-1>>>0>19005952){break ia}b=v[a+484344>>2];f=v[a+484348>>2];if(!ke(b,f,254)){b=w[a+484376|0];c=v[a+484360>>2];v[23220]=0;Y(713,Vb(c,b)|0);b=v[23220];v[23220]=0;if((b|0)==1){break U}f=v[a+484348>>2];b=v[a+484344>>2]}if(ke(b,f,255)){break ia}$z(Vb(v[a+484360>>2],w[a+484376|0]),255,65535)}v[23220]=0;R(714,d+24|0,4063);b=v[23220];v[23220]=0;if((b|0)==1){break ba}b=x[d+570>>1];v[d+20>>2]=b>>>8;v[23220]=0;v[d+4>>2]=b&255;R(387,d+8|0,d+4|0);b=v[23220];v[23220]=0;if((b|0)==1){break aa}v[23220]=0;X(373,d+88|0,d+24|0,d+20|0,d+8|0);b=v[23220];v[23220]=0;if((b|0)==1){break $}c=d+88|0;b=Db(a+1298344|0,c);vb(c);vb(d+8|0);bc(d+24|0);Db(a+1298368|0,k);v[a+1298404>>2]=C?8:v[a+1074308>>2]?8:5;if(!w[d+495|0]){break W}Db(a+1298380|0,b);v[23220]=0;c=Q(1,d+88|0,15251)|0;g=v[23220];v[23220]=0;if((g|0)==1){break Z}Db(b,c);vb(c);v[23220]=0;b=Q(1,d+24|0,10062)|0;c=v[23220];v[23220]=0;if((c|0)==1){break Y}Db(a+1298356|0,b);vb(b);v[23220]=0;b=Q(1,d+8|0,10063)|0;c=v[23220];v[23220]=0;if((c|0)==1){break X}Db(a+1298392|0,b);break V}f=P()|0;O()|0;break k}f=P()|0;O()|0;break ca}f=P()|0;O()|0;vb(d+24|0)}vb(b);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break _}f=P()|0;O()|0;vb(d+8|0)}bc(d+24|0);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[23220]=0;b=Q(1,d+88|0,10063)|0;c=v[23220];v[23220]=0;if((c|0)==1){break H}Db(a+1298356|0,b)}vb(b);lc(n);vb(k);break b}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0}lc(n);break c}f=P()|0;O()|0}vb(k);S(f|0);L()}e=1}fb=d+592|0;return e|0}function Pda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=fb-336|0;fb=e;wc(b);a:{b:{c:{if(!xt(b,e+240|0)){break c}if(!rQ(e+240|0)){break c}if(!Lb(v[b>>2],v[b+8>>2],Pc(qQ(e+240|0),ib))){break c}if(!c){n=1;break c}zd(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;j=Gb(e+224|0);d=x[e+280>>1];k=(d|0)==20479?x[e+294>>1]:d-16464|0;d:{e:{f:{g:{h:{i:{switch(d>>>12|0){case 0:if((d|0)!=520){break d}v[23220]=0;d=Q(1,e+208|0,12283)|0;f=v[23220];v[23220]=0;if((f|0)!=1){Db(j,d);break e}b=P()|0;O()|0;break a;case 1:j:{if((d|0)!=4896){break j}d=x[e+302>>1];if(d){break j}if(!(x[e+278>>1]&65455|(w[e+292|0]|w[e+272|0]&15))){k:{if(t[e+291|0]<0){v[a+1074308>>2]=18219008;v[23220]=0;d=Q(1,e+208|0,14741)|0;f=v[23220];v[23220]=0;if((f|0)!=1){break k}b=P()|0;O()|0;break a}v[a+1074308>>2]=16777216;v[23220]=0;d=Q(1,e+208|0,13333)|0;f=v[23220];v[23220]=0;if((f|0)==1){break h}}Db(j,d);vb(d);v[23220]=0;g=1;W(254,a+1074312|0,81,1)|0;d=v[23220];v[23220]=0;f=1;if((d|0)!=1){break d}break b}if(w[e+292|0]|d|(x[e+278>>1]|w[e+293|0])){break j}v[23220]=0;d=Q(1,e+208|0,9447)|0;f=v[23220];v[23220]=0;if((f|0)!=1){Db(j,d);break e}b=P()|0;O()|0;break a}v[23220]=0;d=Q(1,e+208|0,8481)|0;g=v[23220];v[23220]=0;i=1;if((g|0)!=1){Db(j,d);vb(d);break f}b=P()|0;O()|0;break a;case 2:v[23220]=0;d=Q(1,e+208|0,6734)|0;g=v[23220];v[23220]=0;f=1;if((g|0)!=1){Db(j,d);vb(d);break f}b=P()|0;O()|0;break a;case 3:l:{m:{n:{o:{if(d>>>0<=12820){v[23220]=0;f=Q(1,e+208|0,8528)|0;g=v[23220];v[23220]=0;if((g|0)!=1){Db(j,f);vb(f);break o}b=P()|0;O()|0;break a}v[23220]=0;R(385,e+208|0,3976);f=v[23220];v[23220]=0;if((f|0)==1){break n}v[23220]=0;v[e+192>>2]=x[e+280>>1]-12820;U(386,e+48|0,e+208|0,e+192|0);f=v[23220];v[23220]=0;if((f|0)==1){break m}f=e+48|0;Db(j,f);vb(f);bc(e+208|0)}f=x[e+280>>1];if(f>>>0<12807){break g}g=v[e+296>>2];if(g){break l}break g}b=P()|0;O()|0;break a}b=P()|0;O()|0;bc(e+208|0);break a}f=JC(f,g);g=jq(e+48|0);v[g+44>>2]=f;v[23220]=0;R(388,a+1298408|0,g|0);f=v[23220];v[23220]=0;if((f|0)!=1){break g}b=P()|0;O()|0;break a;case 4:p:{q:{if((d|0)==16640){v[23220]=0;f=Q(1,e+208|0,8327)|0;g=v[23220];v[23220]=0;if((g|0)!=1){Db(j,f);vb(f);g=81;break q}b=P()|0;O()|0;break a}v[23220]=0;U(389,e+48|0,d|0,x[e+294>>1]);f=v[23220];v[23220]=0;r:{if((f|0)!=1){f=e+48|0;Db(j,f);vb(f);v[a+480260>>2]=1;if((k|0)<4201){break r}v[23220]=0;W(254,a+1074312|0,7,1)|0;f=v[23220];v[23220]=0;g=38;if((f|0)==1){break b}break q}b=P()|0;O()|0;break a}g=38;if((k|0)<2386){break p}}v[23220]=0;W(254,a+1074312|0,g|0,1)|0;f=v[23220];v[23220]=0;if((f|0)==1){break b}}h=(d|0)!=16640;f=1;g=0;break d;case 5:d=d&4095;v[a+1074308>>2]=d<<16|(d>>>0>296?x[e+294>>1]:0)&65535;v[23220]=0;d=Q(1,e+208|0,17558)|0;f=v[23220];v[23220]=0;s:{t:{u:{if((f|0)!=1){f=v[a+1074308>>2];v[23220]=0;R(127,e+192|0,f|0);f=v[23220];v[23220]=0;if((f|0)==1){break u}v[23220]=0;U(2,e+48|0,d|0,e+192|0);f=v[23220];v[23220]=0;if((f|0)==1){break t}f=e+48|0;Db(j,f);vb(f);vb(e+192|0);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break s}b=P()|0;O()|0;vb(e+192|0)}vb(d);break a;case 6:v[23220]=0;d=Q(1,e+208|0,8327)|0;h=v[23220];v[23220]=0;if((h|0)!=1){Db(j,d);vb(d);v[23220]=0;W(254,a+1074312|0,81,1)|0;d=v[23220];v[23220]=0;h=0;if((d|0)==1){break b}break d}b=P()|0;O()|0;break a;case 7:v[23220]=0;d=Q(1,e+208|0,8339)|0;f=v[23220];v[23220]=0;if((f|0)!=1){Db(j,d);break e}b=P()|0;O()|0;break a;default:break i}}if((d|0)!=51712){break d}v[23220]=0;d=Q(1,e+208|0,9246)|0;f=v[23220];v[23220]=0;if((f|0)!=1){Db(j,d);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}v[23220]=0;f=W(254,a+1074312|0,7,1)|0;g=v[23220];v[23220]=0;if((g|0)==1){break b}v[23220]=0;f=W(254,f|0,23,1)|0;g=v[23220];v[23220]=0;if((g|0)==1){break b}v[23220]=0;f=W(254,f|0,38,1)|0;g=v[23220];v[23220]=0;if((g|0)==1){break b}v[23220]=0;W(254,f|0,107,1)|0;f=v[23220];v[23220]=0;if((f|0)==1){break b}f=1;v[a+480260>>2]=1;g=0;if(d>>>0>12820){break d}}v[23220]=0;Y(630,e+192|0);d=v[23220];v[23220]=0;v:{w:{x:{if((d|0)!=1){d=x[e+280>>1];v[e+160>>2]=d>>>8&15;v[23220]=0;v[e+136>>2]=d&255;R(387,e+176|0,e+136|0);d=v[23220];v[23220]=0;if((d|0)==1){break x}g=0;v[23220]=0;da(631,e+48|0,e+192|0,j|0,e+160|0,e+176|0);d=v[23220];v[23220]=0;if((d|0)==1){break w}d=e+48|0;Db(j,d);vb(d);vb(e+176|0);bc(e+192|0);break d}b=P()|0;O()|0;break a}b=P()|0;O()|0;break v}b=P()|0;O()|0;vb(e+176|0)}bc(e+192|0);break a}vb(d);f=0}v[23220]=0;d=Q(1,e+192|0,15069)|0;l=v[23220];v[23220]=0;y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{if((l|0)!=1){Db(a+1298344|0,d);vb(d);v[23220]=0;d=Q(1,e+176|0,10435)|0;l=v[23220];v[23220]=0;if((l|0)==1){break H}Db(a+1298356|0,d);vb(d);p=Db(a+1298368|0,j);v[a+1298404>>2]=v[a+1074308>>2]?8:5;if(f){v[23220]=0;d=Q(255,a+1074312|0,77)|0;f=v[23220];v[23220]=0;if((f|0)==1){break b}v[23220]=0;d=Q(255,d|0,78)|0;f=v[23220];v[23220]=0;if((f|0)==1){break b}v[23220]=0;d=Q(255,d|0,79)|0;f=v[23220];v[23220]=0;if((f|0)==1){break b}v[23220]=0;d=Q(255,d|0,80)|0;f=v[23220];v[23220]=0;if((f|0)==1){break b}v[23220]=0;d=Q(255,d|0,82)|0;f=v[23220];v[23220]=0;if((f|0)==1){break b}v[23220]=0;d=Q(255,d|0,96)|0;f=v[23220];v[23220]=0;if((f|0)==1){break b}v[23220]=0;Q(255,d|0,113)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}}d=x[e+280>>1];f=d&61440;if(f>>>0>=4097){g=(f|0)!=12288|d>>>0>12819|g}v[23220]=0;d=a+901404|0;Y(632,d|0);f=v[23220];v[23220]=0;if((f|0)==1){break b}if(!g){Vp(d)}d=e+160|0;$k(d,1,e+240|0);v[23220]=0;R(209,e+48|0,d|0);d=v[23220];v[23220]=0;if((d|0)==1){break C}d=e+48|0;xc(a+1298308|0,d);ub(d);d=x[e+278>>1];if(d&16){v[a+480208>>2]=v[a+480208>>2]|65536}if(d&1){v[a+480208>>2]=v[a+480208>>2]|131072}l=x[e+280>>1];if(!(d&64?0:(l|0)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}d=w[e+289|0];v[a+480196>>2]=d;if(!d){break G}if((d|0)!=255){break F}if(i){break G}d=w[e+290|0];g=d>>>0<33;f=B(d,1e4);i=0;d=32e4;break D}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}v[a+480196>>2]=6;d=w[e+290|0];g=d>>>0<33;f=B(d,1e4);break E}d=w[e+290|0];g=d>>>0<33;f=B(d,1e4)}d=32e4;if(!i){break D}d=125e4}v[a+480204>>2]=g?d:f;t[e+48|0]=w[e+288|0];t[e+160|0]=64;d=w[Rb(e+48|0,e+160|0)|0];v[a+480200>>2]=d<<2;if(!(d|l>>>0>4895)){v[a+480200>>2]=256}g=w[e+291|0];I:{if(!(x[e+282>>1]!=1|g>>>0>7)){v[e+48>>2]=(g<<4)+16;v[e+160>>2]=127;f=v[nd(e+48|0,e+160|0)>>2];break I}f=32;if((g|16)==18){break I}d=g&127;f=48;if(!d){break I}v[e+48>>2]=d;v[e+160>>2]=16;f=v[Ke(e+48|0,e+160|0)>>2]}v[a+480228>>2]=f;d=0;l=v[a+1074308>>2]!=0|g<<24>>24<0;if(!l){H=a,I=Pc(Eia(f<<3|5,f>>>29|0,11,0),ib),v[H+480228>>2]=I}u[a+480188>>1]=4;v[a+480232>>2]=h?(k|0)<3299?64:36:36;f=lh(e+152|0);while(1){if((d|0)==32){if(!x[a+480188>>1]){u[a+480188>>1]=1}d=w[a+484376|0];g=v[a+484360>>2];v[23220]=0;da(333,Vb(g,d)|0,b|0,x[e+272>>1],255,254);d=v[23220];v[23220]=0;if((d|0)!=1){l=Ib(e+160|0);v[23220]=0;W(204,b|0,l|0,x[e+274>>1])|0;d=v[23220];v[23220]=0;if((d|0)!=1){q=Ib(e+136|0);v[23220]=0;W(204,b|0,q|0,x[e+276>>1])|0;d=v[23220];v[23220]=0;J:{if((d|0)!=1){if(w[e+293|0]!=252){break B}d=0;v[23220]=0;R(633,b|0,e+48|0);g=v[23220];v[23220]=0;if((g|0)==1){break J}while(1){if((d|0)==32){break B}g=w[(e+48|0)+d|0];K:{if(!(g&32)){break K}if(i){sk(e+32|0,f,d);if(yb(v[v[e+32>>2]>>2],v[e+36>>2])){break K}}u[((d<<5)+a|0)+480284>>1]=(((g&15)<<8|8)>>>0)/15}d=d+1|0;continue}}break A}break A}b=P()|0;O()|0;break z}b=P()|0;O()|0;break a}g=(d<<5)+a|0;k=g+480280|0;Pe(k);h=w[(d+e|0)+304|0];q=h&127;L:{if((h|0)!=255){h=h<<24>>24;u[a+480188>>1]=d+1;if(l){u[g+480284>>1]=h&8?204:51}if((h|0)>=0){break L}}v[k>>2]=1024}if((q-16&255)>>>0<=13){u[g+480284>>1]=128;g=e+48|0;sk(g,f,d);dm(g)}d=d+1|0;continue}}b=P()|0;O()|0;break a}u[e+48>>1]=x[e+274>>1];u[e+32>>1]=3999;g=x[Tc(e+48|0,e+32|0)>>1];u[a+480190>>1]=g;k=c&2;r=e+96|0;d=0;f=0;h=0;M:{N:{O:{while(1){if((g&65535)>>>0<=d>>>0){if(!i){break N}if(!(!(f&1)|h&65535)&x[e+280>>1]!=4864){break O}v[23220]=0;d=h&65535;f=W(254,a+1074312|0,79,d>>>0>1|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break A}v[23220]=0;d=d>>>0<2;f=W(254,f|0,107,d|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break A}v[23220]=0;W(254,f|0,38,d|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break A}v[23220]=0;d=h&65535;Q(120,p|0,(d>>>0>1?17119:17126)|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break A}if(d>>>0<2){break N}v[a+480228>>2]=48;break N}g=ac(v[l>>2],d);g=w[g|0]|w[g+1|0]<<8;v[23220]=0;g=Q(142,b|0,g<<4)|0;n=v[23220];v[23220]=0;if((n|0)==1){break M}P:{Q:{if(!g){break Q}v[23220]=0;g=Q(634,b|0,e+48|0)|0;n=v[23220];v[23220]=0;if((n|0)==1){break M}if(!g){break Q}v[23220]=0;g=d+1|0;n=(B(g,104)+a|0)+484380|0;U(635,e+48|0,n|0,i|0);m=v[23220];v[23220]=0;if((m|0)==1){break M}m=e+16|0;$k(m,1,r);v[23220]=0;R(209,e+32|0,m|0);m=v[23220];v[23220]=0;if((m|0)==1){break P}m=((g<<5)+a|0)+946304|0;g=e+32|0;yc(m,g);ub(g);if(w[e+48|0]>1){break Q}R:{if(!k|!v[e+64>>2]){break R}g=oQ(e+48|0);v[23220]=0;g=Q(142,b|0,g|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break A}if(!g){break R}f=e+32|0;nQ(f,w[e+78|0],w[e+79|0],x[e+282>>1]==1);v[23220]=0;W(206,f|0,n|0,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break A}f=1}h=x[e+88>>1]|h}d=d+1|0;g=x[a+480190>>1];continue}break}break A}v[23220]=0;d=Q(1,e+48|0,9711)|0;f=v[23220];v[23220]=0;if((f|0)==1){break A}Db(p,d);vb(d)}n=1;if(!(c&1)){break y}c=x[e+280>>1];u[e+32>>1]=x[e+276>>1];u[e+16>>1]=255;m=x[Tc(e+32|0,e+16|0)>>1];v[23220]=0;g=a+484344|0;R(212,g|0,m|0);d=v[23220];v[23220]=0;if((d|0)==1){break M}s=c>>>0<4896;c=e+32|0;C=c|5;D=c|3;y=c|4;E=c|2;F=c|1;G=a+480188|0;h=0;p=0;r=0;while(1){if((h|0)==(m|0)){if(!s){break y}a=x[a+480188>>1];if((a|0)>(p+r|0)|(a|0)<=(p-r|0)){break y}d=lf(v[g>>2],v[g+4>>2])-1&65535;b=0;S:{if(lf(v[g>>2],v[g+4>>2])>>>0<=d>>>0){break S}while(1){c=b&65535;if(c>>>0>d>>>0){break S}a=Nf(v[g>>2],c);f=v[a>>2];if(Nb(f,v[a+4>>2])){a=Ab(f);f=Ab(v[Nf(v[g>>2],c)+4>>2]);c=fb-16|0;fb=c;v[c+8>>2]=a;while(1){if(Nb(a,f)){if(w[a+3|0]==31){t[a+3|0]=20;t[a+5|0]=w[a+5|0]|128}a=v[gk(c+8|0)>>2];continue}break}fb=c+16|0}b=b+1|0;continue}}break y}v[23220]=0;c=W(213,g|0,h&65535,64)|0;d=v[23220];v[23220]=0;if((d|0)==1){break M}T:{if(!c){break T}c=ac(v[q>>2],h);c=w[c|0]|w[c+1|0]<<8;if(!c){break T}v[23220]=0;c=Q(142,b|0,c<<4)|0;d=v[23220];v[23220]=0;if((d|0)==1){break M}if(!c){break T}v[23220]=0;Q(175,b|0,2)|0;c=v[23220];v[23220]=0;if((c|0)==1){break M}d=0;c=Xb(v[g>>2],h);z=Of(v[c>>2],v[v[c+48>>2]+12>>2],0);while(1){if(d>>>0>63){break T}c=d;v[23220]=0;k=T(193,b|0)|0;d=v[23220];v[23220]=0;U:{if((d|0)!=1){if(k){break U}d=64;if(c>>>0>62){continue}d=Xb(v[g>>2],h);f=v[d>>2];i=v[v[d+48>>2]+12>>2];d=c+1|0;z=Of(f,i,d);continue}break A}f=k&31;d=B(f,6)+z|0;o=Rh(e+32|0);i=f>>>0<x[G>>1];A=i?d:o;if(k&32){v[23220]=0;R(250,e+16|0,b|0);f=v[23220];v[23220]=0;V:{W:{X:{if((f|0)!=1){o=gd(e+16|0);f=w[e+16|0];if(f>>>0>239){break X}f=mQ((B(f>>>4|0,12)+(f&15)|0)+13|0);break W}break A}Y:{switch(f-254|0){case 0:break W;case 1:break Y;default:break V}}f=0}t[A|0]=f}t[(i?d+1|0:F)|0]=w[o|0]}Z:{if(!(k&64)){break Z}v[23220]=0;o=T(193,b|0)|0;f=v[23220];v[23220]=0;_:{if((f|0)!=1){f=i?d+2|0:E;o=o<<24>>24;t[e+16|0]=o;if((o|0)>-64){break _}t[f|0]=2;t[(i?d+4|0:y)|0]=w[e+16|0]^128;break Z}break A}t[f|0]=1;t[e+15|0]=64;H=i?d+4|0:y,I=w[Rb(e+16|0,e+15|0)|0],t[H|0]=I}$:{if(!(k&128)){break $}v[23220]=0;R(250,e+16|0,b|0);f=v[23220];v[23220]=0;aa:{ba:{if((f|0)!=1){f=i?d+3|0:D;t[f|0]=w[e+16|0];d=i?d+5|0:C;H=d,I=w[gd(e+16|0)|0],t[H|0]=I;LA(A,0);i=w[f|0];if((i|0)==10){break aa}if((i|0)==31){break ba}if((i|0)!=20){break $}f=w[d|0];if((f&240)!=160|x[e+280>>1]>4895){break $}t[d|0]=f&15^136;break $}break A}d=w[d|0];if(d>>>0>15){s=0;break $}if(d>>>0<=7){r=r+1|0;break $}p=((d|0)!=8)+p|0;break $}if(w[d|0]|x[e+280>>1]>4865){break $}t[f|0]=37}d=c;continue}}h=h+1|0;continue}}}b=P()|0;O()|0;ld(q)}ld(l);break a}ld(q);ld(l);vb(j)}fb=e+336|0;return n|0}b=P()|0;O()|0}vb(j);S(b|0);L()}function Fd(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=fb-16|0;fb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(a>>>0<=244){f=v[115702];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=f>>>c|0;if(b&3){c=c+((b^-1)&1)|0;a=c<<3;b=a+462848|0;d=v[a+462856>>2];a=v[d+8>>2];l:{if((b|0)==(a|0)){m=462808,n=Fia(-2,c)&f,v[m>>2]=n;break l}v[a+12>>2]=b;v[b+8>>2]=a}a=c<<3;v[d+4>>2]=a|3;a=a+d|0;v[a+4>>2]=v[a+4>>2]|1;a=d+8|0;break a}k=v[115704];if(k>>>0>=h>>>0){break k}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;d=(c|a)+(b>>>a|0)|0;a=d<<3;b=a+462848|0;g=v[a+462856>>2];a=v[g+8>>2];m:{if((b|0)==(a|0)){f=Fia(-2,d)&f;v[115702]=f;break m}v[a+12>>2]=b;v[b+8>>2]=a}v[g+4>>2]=h|3;c=g+h|0;a=d<<3;d=a-h|0;v[c+4>>2]=d|1;v[a+g>>2]=d;if(k){a=k>>>3|0;b=(a<<3)+462848|0;e=v[115707];a=1<<a;n:{if(!(a&f)){v[115702]=a|f;a=b;break n}a=v[b+8>>2]}v[b+8>>2]=e;v[a+12>>2]=e;v[e+12>>2]=b;v[e+8>>2]=a}v[115707]=c;v[115704]=d;a=g+8|0;break a}j=v[115703];if(!j){break k}b=(0-j&j)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+463112>>2];d=(v[b+4>>2]&-8)-h|0;c=b;while(1){o:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break o}}c=(v[a+4>>2]&-8)-h|0;e=c>>>0<d>>>0;d=e?c:d;b=e?a:b;c=a;continue}break}i=v[b+24>>2];e=v[b+12>>2];if((e|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=e;v[e+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){g=c;e=a;c=a+20|0;a=v[c>>2];if(a){continue}c=e+16|0;a=v[e+16>>2];if(a){continue}break}v[g>>2]=0;break b}h=-1;if(a>>>0>4294967231){break k}a=a+11|0;h=a&-8;j=v[115703];if(!j){break k}d=0-h|0;f=0;p:{if(h>>>0<256){break p}f=31;if(h>>>0>16777215){break p}a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;f=(a<<1|h>>>a+21&1)+28|0}c=v[(f<<2)+463112>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=h<<((f|0)==31?0:25-(f>>>1|0)|0);while(1){t:{g=(v[c+4>>2]&-8)-h|0;if(g>>>0>=d>>>0){break t}e=c;d=g;if(d){break t}d=0;a=c;break r}g=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|e)){e=0;a=2<<f;a=(0-a|a)&j;if(!a){break k}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+463112>>2]}if(!a){break q}}while(1){b=(v[a+4>>2]&-8)-h|0;c=b>>>0<d>>>0;d=c?b:d;e=c?a:e;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!e|v[115704]-h>>>0<=d>>>0){break k}f=v[e+24>>2];b=v[e+12>>2];if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=e+20|0;a=v[c>>2];if(!a){a=v[e+16>>2];if(!a){break i}c=e+16|0}while(1){g=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[g>>2]=0;break c}c=v[115704];if(c>>>0>=h>>>0){d=v[115707];b=c-h|0;u:{if(b>>>0>=16){v[115704]=b;a=d+h|0;v[115707]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=h|3;break u}v[115707]=0;v[115704]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}i=v[115705];if(i>>>0>h>>>0){b=i-h|0;v[115705]=b;c=v[115708];a=c+h|0;v[115708]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;if(v[115820]){c=v[115822]}else{v[115823]=-1;v[115824]=-1;v[115821]=4096;v[115822]=4096;v[115820]=l+12&-16^1431655768;v[115825]=0;v[115813]=0;c=4096}g=j+c|0;e=0-c|0;c=g&e;if(c>>>0<=h>>>0){break a}d=v[115812];if(d){b=v[115810];f=b+c|0;if(d>>>0<f>>>0|b>>>0>=f>>>0){break a}}if(w[463252]&4){break f}v:{w:{d=v[115708];if(d){a=463256;while(1){b=v[a>>2];if(b>>>0<=d>>>0&d>>>0<b+v[a+4>>2]>>>0){break w}a=v[a+8>>2];if(a){continue}break}}b=_o(0);if((b|0)==-1){break g}f=c;d=v[115821];a=d-1|0;if(a&b){f=(c-b|0)+(a+b&0-d)|0}if(f>>>0<=h>>>0|f>>>0>2147483646){break g}d=v[115812];if(d){a=v[115810];e=a+f|0;if(d>>>0<e>>>0|a>>>0>=e>>>0){break g}}a=_o(f);if((b|0)!=(a|0)){break v}break e}f=e&g-i;if(f>>>0>2147483646){break g}b=_o(f);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|h+48>>>0<=f>>>0)){b=v[115822];b=b+(j-f|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((_o(b)|0)!=-1){f=b+f|0;b=a;break e}_o(0-f|0);break g}b=a;if((a|0)!=-1){break e}break g}e=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[115813]=v[115813]|4}if(c>>>0>2147483646){break d}b=v[23139];c=c+3&-4;a=b+c|0;x:{y:{if(!c|a>>>0>b>>>0){if(Hw()>>>0>=a>>>0){break y}if(xa(a|0)|0){break y}a=v[23139]}else{a=b}v[115696]=48;b=-1;break x}v[23139]=a}if(Hw()>>>0<a>>>0){if(!(xa(a|0)|0)){break d}}v[23139]=a;if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break d}f=a-b|0;if(f>>>0<=h+40>>>0){break d}}a=v[115810]+f|0;v[115810]=a;if(a>>>0>y[115811]){v[115811]=a}z:{A:{B:{g=v[115708];if(g){a=463256;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break B}a=v[a+8>>2];if(a){continue}break}break A}a=v[115706];if(!(a>>>0<=b>>>0?a:0)){v[115706]=b}a=0;v[115815]=f;v[115814]=b;v[115710]=-1;v[115711]=v[115820];v[115817]=0;while(1){d=a<<3;c=d+462848|0;v[d+462856>>2]=c;v[d+462860>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[115705]=c;a=a+b|0;v[115708]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[115709]=v[115824];break z}if(w[a+12|0]&8|d>>>0>g>>>0|b>>>0<=g>>>0){break A}v[a+4>>2]=c+f;a=g+8&7?-8-g&7:0;c=a+g|0;v[115708]=c;b=v[115705]+f|0;a=b-a|0;v[115705]=a;v[c+4>>2]=a|1;v[(b+g|0)+4>>2]=40;v[115709]=v[115824];break z}if(y[115706]>b>>>0){v[115706]=b}d=b+f|0;c=463256;C:{while(1){if((d|0)!=v[c>>2]){a=463256;c=v[c+8>>2];if(c){continue}break C}break}a=463256;if(w[c+12|0]&8){break C}v[c>>2]=b;v[c+4>>2]=v[c+4>>2]+f;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=h|3;e=d+(d+8&7?-8-d&7:0)|0;i=h+j|0;c=e-i|0;D:{if((e|0)==(g|0)){v[115708]=i;a=v[115705]+c|0;v[115705]=a;v[i+4>>2]=a|1;break D}if(v[115707]==(e|0)){v[115707]=i;a=v[115704]+c|0;v[115704]=a;v[i+4>>2]=a|1;v[a+i>>2]=a;break D}a=v[e+4>>2];if((a&3)==1){f=a&-8;E:{if(a>>>0<=255){d=v[e+8>>2];a=a>>>3|0;b=v[e+12>>2];if((b|0)==(d|0)){m=462808,n=v[115702]&Fia(-2,a),v[m>>2]=n;break E}v[d+12>>2]=b;v[b+8>>2]=d;break E}h=v[e+24>>2];b=v[e+12>>2];F:{if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break F}G:{a=e+20|0;d=v[a>>2];if(d){break G}a=e+16|0;d=v[a>>2];if(d){break G}b=0;break F}while(1){g=a;b=d;a=b+20|0;d=v[a>>2];if(d){continue}a=b+16|0;d=v[b+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break E}d=v[e+28>>2];a=(d<<2)+463112|0;H:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break H}m=462812,n=v[115703]&Fia(-2,d),v[m>>2]=n;break E}v[h+(v[h+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break E}}v[b+24>>2]=h;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break E}v[b+20>>2]=a;v[a+24>>2]=b}c=c+f|0;e=e+f|0;a=v[e+4>>2]}v[e+4>>2]=a&-2;v[i+4>>2]=c|1;v[c+i>>2]=c;if(c>>>0<=255){a=c>>>3|0;b=(a<<3)+462848|0;c=v[115702];a=1<<a;I:{if(!(c&a)){v[115702]=a|c;a=b;break I}a=v[b+8>>2]}v[b+8>>2]=i;v[a+12>>2]=i;v[i+12>>2]=b;v[i+8>>2]=a;break D}a=31;if(c>>>0<=16777215){a=c>>>8|0;e=a+1048320>>>16&8;a=a<<e;d=a+520192>>>16&4;a=a<<d;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(d|e))|0;a=(a<<1|c>>>a+21&1)+28|0}v[i+28>>2]=a;v[i+16>>2]=0;v[i+20>>2]=0;e=(a<<2)+463112|0;J:{d=v[115703];b=1<<a;K:{if(!(d&b)){v[115703]=b|d;v[e>>2]=i;v[i+24>>2]=e;break K}a=c<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[e>>2];while(1){d=b;if((v[b+4>>2]&-8)==(c|0)){break J}b=a>>>29|0;a=a<<1;e=d+(b&4)|0;b=v[e+16>>2];if(b){continue}break}v[e+16>>2]=i;v[i+24>>2]=d}v[i+12>>2]=i;v[i+8>>2]=i;break D}a=v[d+8>>2];v[a+12>>2]=i;v[d+8>>2]=i;v[i+24>>2]=0;v[i+12>>2]=d;v[i+8>>2]=a}a=j+8|0;break a}while(1){L:{c=v[a>>2];if(c>>>0<=g>>>0){e=c+v[a+4>>2]|0;if(e>>>0>g>>>0){break L}}a=v[a+8>>2];continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[115705]=c;a=a+b|0;v[115708]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[115709]=v[115824];a=(e+(e-39&7?39-e&7:0)|0)-47|0;c=a>>>0<g+16>>>0?g:a;v[c+4>>2]=27;a=v[115817];v[c+16>>2]=v[115816];v[c+20>>2]=a;a=v[115815];v[c+8>>2]=v[115814];v[c+12>>2]=a;v[115816]=c+8;v[115815]=f;v[115814]=b;v[115817]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<e>>>0){continue}break}if((c|0)==(g|0)){break z}v[c+4>>2]=v[c+4>>2]&-2;e=c-g|0;v[g+4>>2]=e|1;v[c>>2]=e;if(e>>>0<=255){a=e>>>3|0;b=(a<<3)+462848|0;c=v[115702];a=1<<a;M:{if(!(c&a)){v[115702]=a|c;a=b;break M}a=v[b+8>>2]}v[b+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=b;v[g+8>>2]=a;break z}a=31;if(e>>>0<=16777215){a=e>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|e>>>a+21&1)+28|0}v[g+28>>2]=a;v[g+16>>2]=0;v[g+20>>2]=0;d=(a<<2)+463112|0;N:{c=v[115703];b=1<<a;O:{if(!(c&b)){v[115703]=b|c;v[d>>2]=g;v[g+24>>2]=d;break O}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[d>>2];while(1){c=b;if((e|0)==(v[b+4>>2]&-8)){break N}b=a>>>29|0;a=a<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=g;v[g+24>>2]=c}v[g+12>>2]=g;v[g+8>>2]=g;break z}a=v[c+8>>2];v[a+12>>2]=g;v[c+8>>2]=g;v[g+24>>2]=0;v[g+12>>2]=c;v[g+8>>2]=a}a=v[115705];if(a>>>0<=h>>>0){break d}b=a-h|0;v[115705]=b;c=v[115708];a=c+h|0;v[115708]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;v[115696]=48;break a}P:{if(!f){break P}c=v[e+28>>2];a=(c<<2)+463112|0;Q:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break Q}j=Fia(-2,c)&j;v[115703]=j;break P}v[f+(v[f+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break P}}v[b+24>>2]=f;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break P}v[b+20>>2]=a;v[a+24>>2]=b}R:{if(d>>>0<=15){a=d+h|0;v[e+4>>2]=a|3;a=a+e|0;v[a+4>>2]=v[a+4>>2]|1;break R}v[e+4>>2]=h|3;f=e+h|0;v[f+4>>2]=d|1;v[d+f>>2]=d;if(d>>>0<=255){a=d>>>3|0;b=(a<<3)+462848|0;c=v[115702];a=1<<a;S:{if(!(c&a)){v[115702]=a|c;a=b;break S}a=v[b+8>>2]}v[b+8>>2]=f;v[a+12>>2]=f;v[f+12>>2]=b;v[f+8>>2]=a;break R}a=31;if(d>>>0<=16777215){a=d>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|d>>>a+21&1)+28|0}v[f+28>>2]=a;v[f+16>>2]=0;v[f+20>>2]=0;b=(a<<2)+463112|0;T:{c=1<<a;U:{if(!(c&j)){v[115703]=c|j;v[b>>2]=f;break U}a=d<<((a|0)==31?0:25-(a>>>1|0)|0);h=v[b>>2];while(1){b=h;if((v[b+4>>2]&-8)==(d|0)){break T}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=v[c+16>>2];if(h){continue}break}v[c+16>>2]=f}v[f+24>>2]=b;v[f+12>>2]=f;v[f+8>>2]=f;break R}a=v[b+8>>2];v[a+12>>2]=f;v[b+8>>2]=f;v[f+24>>2]=0;v[f+12>>2]=b;v[f+8>>2]=a}a=e+8|0;break a}V:{if(!i){break V}c=v[b+28>>2];a=(c<<2)+463112|0;W:{if(v[a>>2]==(b|0)){v[a>>2]=e;if(e){break W}m=462812,n=Fia(-2,c)&j,v[m>>2]=n;break V}v[i+(v[i+16>>2]==(b|0)?16:20)>>2]=e;if(!e){break V}}v[e+24>>2]=i;a=v[b+16>>2];if(a){v[e+16>>2]=a;v[a+24>>2]=e}a=v[b+20>>2];if(!a){break V}v[e+20>>2]=a;v[a+24>>2]=e}X:{if(d>>>0<=15){a=d+h|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break X}v[b+4>>2]=h|3;e=b+h|0;v[e+4>>2]=d|1;v[d+e>>2]=d;if(k){a=k>>>3|0;c=(a<<3)+462848|0;g=v[115707];a=1<<a;Y:{if(!(a&f)){v[115702]=a|f;a=c;break Y}a=v[c+8>>2]}v[c+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=a}v[115707]=e;v[115704]=d}a=b+8|0}fb=l+16|0;return a|0}function k5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;a:{b:{c:{d:{e:{if(je(b,21598)){Gb(a);break e}if(je(b,9854)){b=fb-128|0;fb=b;f=Gb(a);v[23220]=0;Y(121,b+96|0);a=v[23220];v[23220]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[23220]=0;v[b+64>>2]=0;R(1020,b+80|0,b- -64|0);a=v[23220];v[23220]=0;if((a|0)==1){break p}v[23220]=0;a=Q(772,f|0,b+80|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break o}ub(b+80|0);v[23220]=0;a=Q(908,a|0,16715)|0;c=v[23220];v[23220]=0;q:{if((c|0)==1){break q}v[23220]=0;v[b+64>>2]=6;R(1020,b+80|0,b- -64|0);c=v[23220];v[23220]=0;if((c|0)==1){break n}v[23220]=0;a=Q(772,a|0,b+80|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break m}ub(b+80|0);v[23220]=0;a=Q(908,a|0,16715)|0;c=v[23220];v[23220]=0;if((c|0)==1){break q}v[23220]=0;v[b+64>>2]=3;R(1020,b+80|0,b- -64|0);c=v[23220];v[23220]=0;if((c|0)==1){break l}v[23220]=0;a=Q(772,a|0,b+80|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break k}c=b+80|0;ub(c);v[23220]=0;c=Q(52,c|0,21598)|0;d=v[23220];v[23220]=0;if((d|0)==1){break j}d=Bb(c);ub(c);if(!d){break i}v[23220]=0;Q(908,a|0,21598)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;ub(b+80|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;ub(b+80|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;ub(b+80|0);break h}a=P()|0;O()|0;break h}c=Ib(b- -64|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=v[b+108>>2];if(d){v[23220]=0;v[b+16>>2]=d;R(1020,b+32|0,b+16|0);d=v[23220];v[23220]=0;if((d|0)==1){break D}v[23220]=0;U(934,b+48|0,8935,b+32|0);d=v[23220];v[23220]=0;if((d|0)==1){break C}v[23220]=0;R(170,c|0,b+48|0);d=v[23220];v[23220]=0;if((d|0)==1){break B}ub(b+48|0);ub(b+32|0)}if(!Nd(w[b+112|0])){break x}v[23220]=0;d=Q(52,b+48|0,12744)|0;e=v[23220];v[23220]=0;if((e|0)==1){break z}v[23220]=0;R(170,c|0,d|0);e=v[23220];v[23220]=0;if((e|0)==1){break y}ub(d);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;ub(b+48|0)}ub(b+32|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;ub(d);break r}if(!Nd(w[b+113|0])){break w}v[23220]=0;d=Q(52,b+48|0,12515)|0;e=v[23220];v[23220]=0;if((e|0)==1){break v}v[23220]=0;R(170,c|0,d|0);e=v[23220];v[23220]=0;if((e|0)==1){break u}ub(d)}if(Nd(w[b+114|0])){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;ub(d);break r}v[23220]=0;d=Q(52,b+32|0,11040)|0;e=v[23220];v[23220]=0;E:{if((e|0)!=1){v[23220]=0;R(170,c|0,d|0);e=v[23220];v[23220]=0;if((e|0)==1){break E}ub(d);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;ub(d);break r}if(rc(v[c>>2],v[c+4>>2])){break f}v[23220]=0;a=Q(908,a|0,16745)|0;d=v[23220];v[23220]=0;if((d|0)!=1){v[23220]=0;d=Q(52,b|0,16715)|0;e=v[23220];v[23220]=0;F:{G:{H:{if((e|0)!=1){v[23220]=0;U(1021,b+16|0,c|0,d|0);e=v[23220];v[23220]=0;if((e|0)==1){break H}v[23220]=0;Q(772,a|0,b+16|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break G}ub(b+16|0);ub(d);break f}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;ub(b+16|0)}ub(d);break r}a=P()|0;O()|0}De(c)}of(b+96|0)}ub(f);break a}De(c);of(b+96|0);fb=b+128|0;break e}if(je(b,8119)){v[g>>2]=0;hp(a,g);break e}if(je(b,8097)){v[g>>2]=6;hp(a,g);break e}if(je(b,10760)){v[g>>2]=3;hp(a,g);break e}if(je(b,10557)){Qb(a,21598);break e}if(je(b,11377)){b=Qb(g,21598);c=Bb(b);v[23220]=0;Q(52,a|0,(c?15750:15420)|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break d}ub(b);break e}if(je(b,7330)){b=fb-48|0;fb=b;PD(b+16|0);v[23220]=0;Y(138,b|0);c=v[23220];v[23220]=0;I:{J:{K:{L:{if((c|0)!=1){v[23220]=0;U(139,b+32|0,b+16|0,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break L}v[23220]=0;R(981,a|0,b+32|0);a=v[23220];v[23220]=0;if((a|0)==1){break K}vb(b+32|0);vb(b);vb(b+16|0);fb=b+48|0;break e}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;vb(b+32|0)}vb(b)}vb(b+16|0);break a}if(je(b,9870)){b=fb-16|0;fb=b;e=fb-16|0;fb=e;v[e+8>>2]=101;c=fb-112|0;fb=c;f=Ib(c+96|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{d=v[e+8>>2];if(d&1){v[23220]=0;R(127,c- -64|0,19923968);d=v[23220];v[23220]=0;if((d|0)==1){break $}v[23220]=0;R(111,f|0,c- -64|0);d=v[23220];v[23220]=0;if((d|0)==1){break _}vb(c- -64|0);d=v[e+8>>2]}if(!(d&4)){break Y}v[23220]=0;d=ha(128)|0;h=v[23220];v[23220]=0;if((h|0)==1){break X}if(!d){break Z}break Y}d=P()|0;O()|0;break N}d=P()|0;O()|0;vb(c- -64|0);break N}v[23220]=0;Y(129,c- -64|0);d=v[23220];v[23220]=0;aa:{if((d|0)!=1){v[23220]=0;R(111,f|0,c- -64|0);d=v[23220];v[23220]=0;if((d|0)==1){break aa}vb(c- -64|0);break Y}d=P()|0;O()|0;break N}d=P()|0;O()|0;vb(c- -64|0);break N}ba:{d=v[e+8>>2];if(!(d&32)){break ba}v[23220]=0;Y(121,c- -64|0);d=v[23220];v[23220]=0;ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((d|0)!=1){v[23220]=0;R(130,c+48|0,c- -64|0);d=v[23220];v[23220]=0;if((d|0)==1){break da}d=ah(v[c+52>>2],w[c+59|0]);vb(c+48|0);if(!d){v[23220]=0;Y(131,c+32|0);d=v[23220];v[23220]=0;if((d|0)==1){break ua}v[23220]=0;R(130,c+16|0,c- -64|0);d=v[23220];v[23220]=0;if((d|0)==1){break ta}v[23220]=0;U(132,c+48|0,c+32|0,c+16|0);d=v[23220];v[23220]=0;if((d|0)==1){break sa}v[23220]=0;R(111,f|0,c+48|0);d=v[23220];v[23220]=0;if((d|0)==1){break ra}vb(c+48|0);vb(c+16|0);bc(c+32|0)}d=Go(c- -64|0);if(!ah(v[d+4>>2],w[d+11|0])){v[23220]=0;Y(133,c+32|0);h=v[23220];v[23220]=0;if((h|0)==1){break oa}v[23220]=0;U(134,c+48|0,c+32|0,d|0);d=v[23220];v[23220]=0;if((d|0)==1){break na}v[23220]=0;R(111,f|0,c+48|0);d=v[23220];v[23220]=0;if((d|0)==1){break ma}vb(c+48|0);bc(c+32|0)}v[23220]=0;R(135,c+48|0,c- -64|0);d=v[23220];v[23220]=0;if((d|0)==1){break ka}d=ah(v[c+52>>2],w[c+59|0]);vb(c+48|0);if(!d){v[23220]=0;Y(131,c+32|0);d=v[23220];v[23220]=0;if((d|0)==1){break ja}v[23220]=0;R(135,c+16|0,c- -64|0);d=v[23220];v[23220]=0;if((d|0)==1){break ia}v[23220]=0;U(132,c+48|0,c+32|0,c+16|0);d=v[23220];v[23220]=0;if((d|0)==1){break ha}v[23220]=0;R(111,f|0,c+48|0);d=v[23220];v[23220]=0;if((d|0)==1){break ga}vb(c+48|0);vb(c+16|0);bc(c+32|0)}of(c- -64|0);d=v[e+8>>2];break ba}d=P()|0;O()|0;break N}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break pa}d=P()|0;O()|0;break qa}d=P()|0;O()|0;vb(c+48|0)}vb(c+16|0)}bc(c+32|0);break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break la}d=P()|0;O()|0;vb(c+48|0)}bc(c+32|0);break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break ea}d=P()|0;O()|0;break fa}d=P()|0;O()|0;vb(c+48|0)}vb(c+16|0)}bc(c+32|0);break ca}d=P()|0;O()|0}of(c- -64|0);break N}va:{if(!(d&64)){break va}v[23220]=0;d=ha(128)|0;h=v[23220];v[23220]=0;if((h|0)==1){break X}if(d){break va}d=c- -64|0;Gb(d);v[23220]=0;R(111,f|0,d|0);d=v[23220];v[23220]=0;if((d|0)==1){break O}vb(c- -64|0)}if(w[e+8|0]&128){v[23220]=0;Y(136,c- -64|0);d=v[23220];v[23220]=0;if((d|0)==1){break W}v[23220]=0;R(111,f|0,c- -64|0);d=v[23220];v[23220]=0;if((d|0)==1){break V}vb(c- -64|0)}v[23220]=0;h=Q(1,c- -64|0,21598)|0;d=v[23220];v[23220]=0;if((d|0)==1){break U}v[23220]=0;U(137,c|0,f|0,h|0);d=v[23220];v[23220]=0;if((d|0)==1){break T}v[23220]=0;Y(138,c+48|0);d=v[23220];v[23220]=0;if((d|0)==1){break S}v[23220]=0;U(139,b|0,c|0,c+48|0);d=v[23220];v[23220]=0;if((d|0)==1){break R}vb(c+48|0);vb(c);vb(h);rl(f);fb=c+112|0;break M}d=P()|0;O()|0;break N}d=P()|0;O()|0;break N}d=P()|0;O()|0;vb(c- -64|0);break N}d=P()|0;O()|0;break N}d=P()|0;O()|0;break P}d=P()|0;O()|0;break Q}d=P()|0;O()|0;vb(c+48|0)}vb(c)}vb(h);break N}d=P()|0;O()|0;vb(c- -64|0)}rl(f);S(d|0);L()}fb=e+16|0;v[23220]=0;R(981,a|0,b|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(b);fb=b+16|0;break e}break b}if(je(b,10486)){b=fb-48|0;fb=b;dr(b);v[23220]=0;R(130,b+32|0,b|0);c=v[23220];v[23220]=0;wa:{xa:{if((c|0)!=1){v[23220]=0;R(981,a|0,b+32|0);a=v[23220];v[23220]=0;if((a|0)==1){break xa}vb(b+32|0);of(b);fb=b+48|0;break e}a=P()|0;O()|0;break wa}a=P()|0;O()|0;vb(b+32|0)}of(b);break a}if(je(b,11340)){b=fb-32|0;fb=b;dr(b);v[23220]=0;R(981,a|0,Go(b)|0);a=v[23220];v[23220]=0;if((a|0)!=1){of(b);fb=b+32|0;break e}a=P()|0;O()|0;of(b);break a}if(je(b,9883)){b=fb-48|0;fb=b;dr(b+16|0);c=v[b+28>>2];ya:{if(c){v[23220]=0;v[b+12>>2]=c;R(1020,a|0,b+12|0);a=v[23220];v[23220]=0;if((a|0)!=1){break ya}a=P()|0;O()|0;of(b+16|0);break a}Gb(a)}of(b+16|0);fb=b+48|0;break e}if(je(b,12734)){dr(g);b=w[g+16|0];v[23220]=0;Q(52,a|0,(Nd(b)?15420:15750)|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){of(g);break e}a=P()|0;O()|0;of(g);break a}if(je(b,9899)){dr(g);b=w[g+17|0];v[23220]=0;Q(52,a|0,(Nd(b)?15420:15750)|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){of(g);break e}a=P()|0;O()|0;of(g);break a}if(je(b,12187)){dr(g);b=w[g+18|0];v[23220]=0;Q(52,a|0,(Nd(b)?15420:15750)|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){of(g);break e}a=P()|0;O()|0;of(g);break a}if(je(b,12489)){b=fb-16|0;fb=b;c=fb-32|0;fb=c;d=Gb(b);v[23220]=0;Y(121,c|0);f=v[23220];v[23220]=0;za:{Aa:{Ba:{if((f|0)!=1){v[23220]=0;R(122,d|0,Go(c)|0);f=v[23220];v[23220]=0;if((f|0)==1){break Ba}of(c);fb=c+32|0;break za}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;of(c)}vb(d);break a}v[23220]=0;R(981,a|0,b|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(b);fb=b+16|0;break e}break b}if(je(b,8240)){b=fb-16|0;fb=b;c=fb-48|0;fb=c;d=Gb(b);v[23220]=0;R(124,c+16|0,4096);f=v[23220];v[23220]=0;Ca:{Da:{Ea:{Fa:{Ga:{if((f|0)!=1){v[c+12>>2]=15;v[c+8>>2]=0;v[23220]=0;v[c+4>>2]=0;da(125,c+32|0,c+16|0,c+12|0,c+8|0,c+4|0);f=v[23220];v[23220]=0;if((f|0)==1){break Ga}v[23220]=0;Q(85,d|0,c+32|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break Fa}vb(c+32|0);bc(c+16|0);fb=c+48|0;break Ca}a=P()|0;O()|0;break Da}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;vb(c+32|0)}bc(c+16|0)}vb(d);S(a|0);L()}v[23220]=0;R(981,a|0,b|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(b);fb=b+16|0;break e}break b}if(je(b,6783)){b=fb-16|0;fb=b;Im(b,0,19544);v[23220]=0;R(981,a|0,b|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(b);fb=b+16|0;break e}break b}if(je(b,6416)){b=fb-48|0;fb=b;c=Qb(b+16|0,17605);v[23220]=0;R(1022,b|0,2);d=v[23220];v[23220]=0;Ha:{Ia:{Ja:{Ka:{if((d|0)!=1){v[23220]=0;U(2,b+32|0,c|0,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break Ka}v[23220]=0;R(981,a|0,b+32|0);a=v[23220];v[23220]=0;if((a|0)==1){break Ja}vb(b+32|0);vb(b);vb(c);fb=b+48|0;break e}a=P()|0;O()|0;break Ha}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;vb(b+32|0)}vb(b)}vb(c);break a}if(je(b,11363)){b=fb-16|0;fb=b;Im(b,0,17944);v[23220]=0;R(981,a|0,b|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(b);fb=b+16|0;break e}break b}if(je(b,10493)){b=fb-16|0;fb=b;ar(b,0);v[23220]=0;R(981,a|0,b|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(b);fb=b+16|0;break e}break b}if(je(b,10468)){b=fb-16|0;fb=b;ar(b,2);v[23220]=0;R(981,a|0,b|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(b);fb=b+16|0;break e}break b}if(je(b,10453)){b=fb-16|0;fb=b;ar(b,3);v[23220]=0;R(981,a|0,b|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(b);fb=b+16|0;break e}break b}Gb(a)}fb=g+32|0;break c}a=P()|0;O()|0;ub(b);break a}return}a=P()|0;O()|0;vb(b)}S(a|0);L()}function n9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;g=fb-48|0;fb=g;b=v[a+1074308>>2];if(!(b>>>0>18285125|(b|0)==18284544)){zf(a+1074312|0,0)}k=a+1074308|0;b=g+32|0;j=a+1074312|0;xb(b,j,0);c=yb(v[v[g+32>>2]>>2],v[g+36>>2]);d=a+480180|0;e=v[d>>2];xb(b,j,0);p=c&(e&16777248)!=0;D=yb(v[v[g+32>>2]>>2],v[g+36>>2]);E=v[d>>2];a:{b=v[a+1074308>>2];if(b>>>0>18874367){break a}e=!p;f=a+480192|0;c=1;while(1){b:{b=c&65535;if(b>>>0<=x[f>>1]){b=v[((b<<2)+a|0)+900380>>2];if(!b){break b}v[g+32>>2]=B(w[b+20|0],100)>>>6;v[g+16>>2]=100;G=b,H=v[Eb(g+32|0,g+16|0)>>2],t[G+20|0]=H;if(!(e|y[k>>2]<18350080)){break b}i=t[b+26|0];t[b+26|0]=((i>>31|1)+i|0)/2;if(!(e|y[k>>2]<18285314)){break b}QA(Bi(b,2),v[d>>2]);i=v[a+1074308>>2];c:{if(i>>>0<18284544){break c}if(i>>>0>18285135){break b}if(!w[b+34|0]){break c}if(!jj(w[b+31|0])){break c}Kb(j,2,1);if(y[k>>2]>18285135){break b}}if(!(w[b+24|0]|(w[b+23|0]|(w[b+19|0]|w[b+20|0])))){break b}Kb(j,1,1)}d:{if(!(v[a+480180>>2]&16777248)|y[k>>2]>18285313&p){break d}c=x[a+480190>>1]+1&65535;d=1;while(1){if((d|0)==(c|0)){break d}b=B(d,104)+a|0;e=b+484419|0;if(!(w[e|0]|!(w[b+484421|0]|w[b+484420|0]))){t[e|0]=255}d=d+1|0;continue}}c=a+901404|0;f=sz(c);while(1){if((c|0)!=(f|0)){b=c;i=Rn(b);while(1){if((b|0)!=(i|0)){d=w[b|0];e:{f:{if((d-97&255)>>>0<=5){e=d-32|0;break f}if(!(d-88>>>0<2|d-120>>>0<2)){e=99;if((d|0)==75|(d|0)==107){break f}break e}e=122}t[b|0]=e}b=b+1|0;continue}break}c=c+32|0;continue}break}b=v[a+1074308>>2];break a}c=c+1|0;continue}}g:{h:{i:{if((b|0)==18874368|b>>>0>18874895){break i}if(!(v[a+480180>>2]&16777252)){break h}f=x[a+480192>>1]+1&65535;c=0;d=1;while(1){if((d|0)==(f|0)){if(!c){break i}Kb(j,3,1);b=v[k>>2]}else{e=v[((d<<2)+a|0)+900380>>2];if(!(!e|!w[e+31|0])){t[e+33|0]=13;c=1}d=d+1|0;continue}break}}if((b|0)==19005440|b>>>0>19006225){break g}}if(!(v[a+480180>>2]&16777248)){break g}xb(g+32|0,j,0);if(!yb(v[v[g+32>>2]>>2],v[g+36>>2])){xb(g+16|0,j,1);if(!yb(v[v[g+16>>2]>>2],v[g+20>>2])){break g}}c=x[a+480192>>1]+1&65535;d=1;while(1){if((d|0)==(c|0)){break g}b=v[((d<<2)+a|0)+900380>>2];if(!(!b|!w[b+19|0]|!(t[b+80|0]&1))){t[b+19|0]=0}d=d+1|0;continue}}j:{k:{l:{m:{n:{if(y[k>>2]>19007232){break n}b=a+906300|0;d=0;while(1){if((d|0)==250){break n}c=g+16|0;e=(b+B(d,160)|0)+80|0;UL(c,e);v[23220]=0;X(225,g+32|0,0,8,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break m}ub(g+16|0);c=g+32|0;pq(e,c);d=d+1|0;ub(c);continue}}o:{p:{q:{if(v[a+480180>>2]!=4){break q}c=v[k>>2];if(c>>>0<19007257){break o}if(c>>>0>19071235){break p}if(w[a+1074368|0]!=4){break q}ly(a,5)}c=v[k>>2]}if(c>>>0>19202054){break l}b=19202048;if((c|0)==19202048){break k}}f=x[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(f|0)){break l}e=v[((b<<2)+a|0)+900380>>2];r:{if(!e|!w[e+20|0]|!w[e+31|0]){break r}d=e+236|0;i=$p(d);while(1){if((d|0)!=(i|0)){m=x[d>>1];d=d+2|0;if(!m){continue}break r}break}t[e+20|0]=0}b=b+1|0;continue}}a=P()|0;O()|0;ub(g+16|0);S(a|0);L()}b=c;if(b>>>0>19267583){break j}}e=!p;f=x[a+480192>>1]+1&65535;d=1;while(1){if((d|0)==(f|0)){break j}c=v[((d<<2)+a|0)+900380>>2];s:{if(!c){break s}b=t[c+26|0];t[c+26|0]=((b>>31|1)+b|0)/2;b=v[k>>2];if(!(e|b>>>0<18350080)){break s}t[c+19|0]=w[c+19|0]+3>>>2}d=d+1|0;continue}}t:{if(b>>>0>19398673){break t}c=x[a+480192>>1];d=1;while(1){e=d&65535;if(e>>>0>c>>>0){break t}e=v[((e<<2)+a|0)+900380>>2];if(!e|w[e+65|0]==255){d=d+1|0;continue}else{Kb(j,94,1);b=v[k>>2]}break}}u:{if(b>>>0>19399427){break u}c=x[a+480192>>1];d=1;while(1){e=d&65535;if(e>>>0>c>>>0){break u}e=v[((e<<2)+a|0)+900380>>2];if(!e|w[e+36|0]>1){d=d+1|0;continue}else{Kb(j,101,1);b=v[k>>2]}break}}v:{if(b>>>0>19923027){break v}c=x[a+480190>>1];d=1;while(1){b=d&65535;if(b>>>0>c>>>0){break v}b=B(b,104)+a|0;if(!Md(v[b+484380>>2],v[b+484400>>2])|!(w[b+484414|0]&20)){d=d+1|0;continue}else{Kb(j,116,1)}break}}b=fb-16|0;fb=b;u[g+12>>1]=0;v[g+8>>2]=a;xb(b+8|0,a+1074312|0,0);G=g,H=yb(v[v[b+8>>2]>>2],v[b+12>>2]),t[G+14|0]=H;fb=b+16|0;b=v[g+12>>2];v[g>>2]=v[g+8>>2];v[g+4>>2]=b;e=fb-16|0;fb=e;m=a+484344|0;d=v[m+4>>2];f=v[m>>2];c=v[g+4>>2];b=e;i=v[g>>2];v[b>>2]=i;v[b+4>>2]=c;v[b+8>>2]=i;v[b+12>>2]=c;A=lf(f,d)-1&65535;d=fb-32|0;fb=d;r=v[b>>2];s=v[b+4>>2];w:{if(lf(v[m>>2],v[m+4>>2])>>>0<=A>>>0){break w}while(1){c=C&65535;if(c>>>0>A>>>0){break w}b=Nf(v[m>>2],c);f=v[b>>2];if(Nb(f,v[b+4>>2])){b=Ab(f);F=Ab(v[Nf(v[m>>2],c)+4>>2]);v[d+24>>2]=r;v[d+28>>2]=s;v[d+8>>2]=r;v[d+12>>2]=s;i=d+8|0;q=fb-16|0;fb=q;v[q+8>>2]=b;while(1){if(Nb(b,F)){n=fb-16|0;fb=n;z=x[i+4>>1];c=z+1|0;u[i+4>>1]=c;l=v[i>>2];u[i+4>>1]=x[l+480188>>1]>(c&65535)>>>0?c:0;x:{if(Mg(w[b|0])){break x}f=v[l+1074308>>2];y:{l=v[l+480180>>2];z:{A:{if((l|0)==2){if(f>>>0>18415615){break A}if(w[b+3|0]!=23){break z}hf(b+5|0,64);break z}if(l&16777248){B:{C:{if(f>>>0>=18285314){if(w[i+6|0]){break C}c=0;h=0;if(f>>>0>18874367){break B}}D:{switch(w[b+3|0]-20|0){case 3:hf(b+5|0,128);break C;case 0:break D;default:break C}}c=w[b+5|0];if((c|0)!=208){if((c|0)!=192){break C}t[b|0]=254;t[b+3|0]=0;break C}t[b+3|0]=0}E:{F:{if(f>>>0>=18350080){if(w[i+6|0]){break F}c=0;h=0;if(f>>>0>18874367){break B}}h=w[b+3|0];o=h-6&255;c=0;if(o>>>0>23){break E}c=8388643>>>o&1;break E}c=0;h=0;if(f>>>0>18874367){break B}h=w[b+3|0];c=0}h=(h|0)==24|(h|0)==22}G:{if(!(h?1:c)){break G}h=w[b+5|0];c=h&15;if(!c|(c|0)==15){break G}h=h&240;if(!h|(h|0)==240){break G}t[b+5|0]=w[b+3|0]==24?h:c}H:{if((f|0)==19005440|f>>>0>19005699){break H}c=x[v[i>>2]+480192>>1];if(w[i+6|0]|(!c|c>>>0>=w[b+1|0])){break H}t[b+4|0]=0;t[b+2|0]=1}if(w[b+3|0]!=18|w[b+5|0]!=17){break A}if(f>>>0>19468801){break y}xb(n+8|0,v[i>>2]+1074312|0,22);if(!yb(v[v[n+8>>2]>>2],v[n+12>>2])|v[v[i>>2]+480208>>2]&4){break A}t[b+5|0]=0;break A}if((l|0)!=4){break A}I:{if((!w[i+6|0]|f>>>0<18285314)&f>>>0<18874368){break I}if(f>>>0>19137025){break y}if(w[b+3|0]!=23|w[b+5|0]<65){break I}t[b+3|0]=0}J:{K:{L:{if(!(w[i+6|0]|f>>>0>18874367?f>>>0>=18415616:0)){c=w[b+2|0];if(w[b+3|0]!=10|(c|0)!=11){break L}t[b+3|0]=0;c=11;break L}if(f>>>0>18874639){break K}c=w[b+2|0]}if((c|0)!=11|w[b+3|0]!=4){break J}c=w[b+4|0];if(!(c|w[i+6|0])){break J}h=w[b+5|0];if(!h){break J}t[b+2|0]=0;G=b,H=_t(h+(c<<4)|0),t[G+5|0]=H;break J}if(f>>>0>19007240){break y}}if(w[b+5|0]|w[b+3|0]!=16){break A}t[b+3|0]=0}if(f>>>0>18874367){break y}}c=w[b+3|0];o=w[b+5|0]&240;M:{N:{if((c|0)!=28|(o|0)!=96){h=0}else{if(!w[i+6|0]|(l|0)!=4){break N}h=f>>>0<18350080}if(!(h|(c|0)==20&(o|0)==96)){break M}}c=B(z,-6)+b|0;while(1){if(b>>>0>c>>>0){if(!((w[c+3|0]|8)!=28|(w[c+5|0]&240)!=96)){t[c+3|0]=0}c=c+6|0;continue}break}c=w[b+3|0]}if((c|0)!=20|(w[b+5|0]&240)!=224){break y}c=B(z,-6)+b|0;while(1){if(b>>>0<=c>>>0){break y}if(!(w[c+3|0]!=20|(w[c+5|0]&240)!=224)){t[c+3|0]=0}c=c+6|0;continue}}c=b+2|0;h=w[b+2|0];O:{if((h|0)==8){if((f|0)==19333120|f>>>0>19333174){break x}l=w[b+4|0];f=w[b+3|0];if(!(!l|(f|0)!=7)){t[b+3|0]=11;break x}P:{switch(f-5|0){default:if((f|0)!=26){break x}break;case 1:break x;case 2:break O;case 0:break P}}h=w[b+5|0];if(!(h&15)){t[b+3|0]=5;t[b+5|0]=h|l&15;break O}Q:{switch(f-5|0){case 1:break x;case 0:case 2:break O;default:break Q}}if((f|0)==26){break O}break x}R:{if(!((l|0)==16777216|(h|0)!=15)){if(w[b+3|0]){break R}t[b+3|0]=10;t[b+5|0]=w[b+4|0]<<3;break O}if((h|0)!=15){break x}}if(w[b+3|0]!=10|f>>>0>19922963){break x}c=w[b+5|0]?c:w[b+4|0]?b+3|0:c}t[c|0]=0}fb=n+16|0;b=v[gk(q+8|0)>>2];continue}break}b=v[i+4>>2];v[d+16>>2]=v[i>>2];v[d+20>>2]=b;fb=q+16|0}C=C+1|0;continue}}v[g+32>>2]=r;v[g+36>>2]=s;fb=d+32|0;fb=e+16|0;S:{b=y[a+1074308>>2]<19267584;if(b&p){d=42032;while(1){if((d|0)==42376){break S}b=v[k>>2];c=v[d+4>>2];Kb(j,v[d>>2],b>>>0>=c>>>0|(b|0)==(c&-65536));d=d+8|0;continue}}if(!(b&((E|0)==4&D))){break S}d=42384;while(1){if((d|0)==42624){break S}Kb(j,v[d>>2],y[k>>2]>=y[d+4>>2]);d=d+8|0;continue}}T:{U:{b=v[a+480180>>2];if(b&16777248){d=42624;while(1){if((d|0)==42680){break U}b=v[k>>2];c=v[d+4>>2];e=c&-65536;if(!(b>>>0>=e>>>0&(b>>>0<=e>>>0|b>>>0>=c>>>0))){zf(j,v[d>>2])}d=d+8|0;continue}}d=42752;c=42688;V:{switch(b-2|0){case 2:while(1){if((c|0)==42752){break U}if(y[k>>2]<y[c+4>>2]){zf(j,v[c>>2])}c=c+8|0;continue};case 0:break V;default:break T}}while(1){if((d|0)==42840){break U}if(y[k>>2]<y[d+4>>2]){zf(j,v[d>>2])}d=d+8|0;continue}}b=v[a+480180>>2]}W:{if((b|0)==4){d=v[k>>2];if(d>>>0>18415615){break W}Kb(j,98,1)}d=v[k>>2]}c=8;if(d-19333159>>>0<=33){d=0;while(1){if((d|0)!=5){b=d+77|0;xb(g+32|0,j,b);zf(Kb(j,d+86|0,yb(v[v[g+32>>2]>>2],v[g+36>>2])),b);d=d+1|0;continue}break}d=v[k>>2]}X:{if(d>>>0>=18284544){if(d>>>0>18874627){break X}c=6;if((d|0)==18874368){break X}}Kb(j,c,1)}b=v[a+1074308>>2];Y:{if(w[a+480208|0]&16){if(b>>>0<=19136511){zf(j,7);break Y}if(!(v[a+480180>>2]&16777248)|b>>>0>19267583){break Y}Kb(j,7,1);break Y}if((b|0)==19922944|b>>>0>19922997){break Y}zf(j,7)}xb(g+32|0,j,31);Z:{if(!yb(v[v[g+32>>2]>>2],v[g+36>>2])){break Z}b=v[k>>2];if(b>>>0<19071234|b>>>0>19398722){break Z}c=x[a+480192>>1];d=1;while(1){b=d&65535;if(b>>>0>c>>>0){break Z}_:{b=v[((b<<2)+a|0)+900380>>2];if(!b){break _}e=w[b+65|0];if(!(w[b+60|0]&4)|(e|0)==255|e>>>0<=w[b- -64|0]){break _}Kb(j,97,1);break Z}d=d+1|0;continue}}b=v[a+480180>>2];$:{if(!(b&16777218)){break $}c=x[a+480190>>1];d=1;while(1){e=d&65535;if(e>>>0>c>>>0){break $}d=d+1|0;if(!(w[(B(e,104)+a|0)+484415|0]&2)){continue}break}aa:{ba:{ca:{if(!(!x[a+480192>>1]|(b|0)!=16777216)){d=v[k>>2];if(d>>>0<19398688){break ba}if(d>>>0>19464277){break ca}Kb(j,109,1)}d=v[k>>2]}if((d|0)==19922944|d>>>0>19922996){break aa}}zf(j,111);d=v[k>>2]}b=v[a+480180>>2];if(!((b|0)!=2|d>>>0>19464191)){Kb(j,108,1);break $}if((b|0)==2){break $}zf(j,108)}da:{if(!(v[a+480180>>2]&16777252)|v[k>>2]-19333186>>>0>589827){break da}b=a+906300|0;d=0;while(1){if((d|0)==250){break da}a=b+B(d,160)|0;ea:{if(v[a+16>>2]!=1146637647|v[a+20>>2]!=-271958638){break ea}if((Wc(v[a+4>>2],v[a+8>>2])|0)!=32){break ea}c=a+80|0;a=Qb(g+32|0,16796);pq(c,a);ub(a)}d=d+1|0;continue}}fb=g+48|0}function wV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a:{n=wh(b,13804);if(!n){break a}o=a+480192|0;b:while(1){if(!Lb(v[b>>2],v[b+8>>2],6)){break a}c:{f=mg(b);d:{if((f|0)==(rm(13623)|0)){break d}c=w[21574]|w[21575]<<8|(w[21576]<<16|w[21577]<<24);if(!(f&1616928864)|f&-2139062144){break d}if((c|0)!=(f|0)){break c}}jg(b,4);break a}l=1;c=Ag(b);while(1){d=l&65535;if(d>>>0>x[o>>1]){continue b}d=v[((d<<2)+a|0)+900380>>2];if(d){e:{g=0;if((rm(16699)|0)==(f|0)){Yb(b,c);break e}e=fb-48|0;fb=e;f:{if(!d){break f}g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{switch(f-1349079874|0){default:if((f|0)==1095062094){break v}if((f|0)==1095126087){break s}if((f|0)==1129524782){break B}if((f|0)==1145263150){break Y}if((f|0)==1145979182){break X}if((f|0)==1179463214){break z}if((f|0)==1851469358){break F}if((f|0)==1179931728){break n}$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{if((f|0)!=1196830254){if((f|0)==1229341486){break U}if((f|0)==1229345326){break T}if((f|0)==1264266798){break G}if((f|0)==1296182830){break S}if((f|0)==1296248366){break Q}if((f|0)==1297100334){break R}if((f|0)==1297110852){break q}if((f|0)==1298747438){break D}if((f|0)==1313692462){break H}if((f|0)==1313751342){break Z}if((f|0)==1345203758){break ja}if((f|0)==1346711086){break l}if((f|0)==1346720334){break w}if((f|0)==1346722606){break J}if((f|0)==1346784327){break t}if((f|0)==1347175726){break da}if((f|0)==1347179310){break ea}if((f|0)==1347437358){break O}if((f|0)==1347441454){break P}if((f|0)==1347443502){break M}if((f|0)==1347628590){break W}if((f|0)==1347633710){break ca}if((f|0)==1347634478){break ba}if((f|0)==1347703884){break o}if((f|0)==1347831112){break y}if((f|0)==1347833672){break x}if((f|0)==1349076270){break k}if((f|0)==1349076315){break I}if((f|0)==1349078085){break $}if((f|0)==1349078099){break aa}if((f|0)==1349079131){break L}if((f|0)==1378758190){break p}if((f|0)==1381183022){break A}if((f|0)==1447374382){break m}if((f|0)==1447383630){break u}if((f|0)==1447385902){break K}if((f|0)==1447447623){break r}if((f|0)==1447839022){break ha}if((f|0)==1447842606){break ia}if((f|0)==1448106798){break N}if((f|0)==1448226350){break C}if((f|0)==1448291886){break V}if((f|0)==1448297006){break ga}if((f|0)==1448297774){break fa}if((f|0)!=1682320942){if((f|0)==1718508334){break E}if((f|0)!=1179594286|c>>>0>4){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Qu(b,c),v[p>>2]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+15|0]=q;break g}if(c>>>0>4){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Qu(b,c),v[p+4>>2]=q;break g}if(c>>>0>4){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Qu(b,c),v[p+8>>2]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+61|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+62|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+63|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d- -64|0,q=ud(b,c),t[p|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+81|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+82|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+83|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+84|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+101|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+102|0]=q;break g;case 0:if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+103|0]=q;break g;case 3:break _;case 1:case 2:break f}}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+104|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+16|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+17|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+18|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+19|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+20|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+21|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+22|0]=q;break g}if(c>>>0>2){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=HC(b,c),u[p+28>>1]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+30|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+31|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=GC(b,c),t[p+26|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+27|0]=q;break g}Qd(e,b,c);i=gc(e+24|0,e);wb(e);j=Bi(d,0);h=v[j>>2];while(1){if(ne(h,v[j+4>>2])>>>0<=g>>>0){wb(i);break g}v[23220]=0;k=T(184,i|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break j}h=v[j>>2];p=zb(h,g),q=k,u[p>>1]=q;g=g+1|0;continue}}Qd(e,b,c);i=gc(e+24|0,e);wb(e);j=Bi(d,1);h=v[j>>2];while(1){if(ne(h,v[j+4>>2])>>>0<=g>>>0){wb(i);break g}v[23220]=0;k=T(184,i|0)|0;h=v[23220];v[23220]=0;if((h|0)!=1){h=v[j>>2];p=zb(h,g),q=k,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Qd(e,b,c);i=gc(e+24|0,e);wb(e);j=Bi(d,2);h=v[j>>2];while(1){if(ne(h,v[j+4>>2])>>>0<=g>>>0){wb(i);break g}v[23220]=0;k=T(184,i|0)|0;h=v[23220];v[23220]=0;if((h|0)!=1){h=v[j>>2];p=zb(h,g),q=k,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Qd(e,b,c);i=gc(e+24|0,e);wb(e);j=Bi(d,0);h=v[j>>2];while(1){if(ne(h,v[j+4>>2])>>>0<=g>>>0){wb(i);break g}v[23220]=0;k=T(185,i|0)|0;h=v[23220];v[23220]=0;if((h|0)!=1){h=v[j>>2];p=zb(h,g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Qd(e,b,c);i=gc(e+24|0,e);wb(e);j=Bi(d,1);h=v[j>>2];while(1){if(ne(h,v[j+4>>2])>>>0<=g>>>0){wb(i);break g}v[23220]=0;k=T(185,i|0)|0;h=v[23220];v[23220]=0;if((h|0)!=1){h=v[j>>2];p=zb(h,g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Qd(e,b,c);i=gc(e+24|0,e);wb(e);j=Bi(d,2);h=v[j>>2];while(1){if(ne(h,v[j+4>>2])>>>0<=g>>>0){wb(i);break g}v[23220]=0;k=T(185,i|0)|0;h=v[23220];v[23220]=0;if((h|0)!=1){h=v[j>>2];p=zb(h,g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>128){break f}h=d+108|0;Qd(e,b,c);i=gc(e+24|0,e);wb(e);while(1){if((g|0)==128){wb(i);break g}v[23220]=0;j=T(185,i|0)|0;k=v[23220];v[23220]=0;if((k|0)!=1){p=Hb(h,g),q=j,t[p|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>256){break f}h=d+236|0;Qd(e,b,c);i=gc(e+24|0,e);wb(e);while(1){if((g|0)==128){wb(i);break g}v[23220]=0;j=T(184,i|0)|0;k=v[23220];v[23220]=0;if((k|0)!=1){p=ac(h,g),q=j,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>32){break f}j=d+492|0;Qd(e,b,c);i=gc(e+24|0,e);wb(e);h=Gb(e);while(1){if((c|0)==(g|0)){break h}v[23220]=0;k=T(186,i|0)|0;m=v[23220];v[23220]=0;ka:{if((m|0)==1){break ka}v[23220]=0;Q(187,h|0,k|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break ka}g=g+1|0;continue}break}g=P()|0;O()|0;ub(h);break i}if(c>>>0>32){break f}j=d+524|0;Qd(e,b,c);i=gc(e+24|0,e);wb(e);h=Gb(e);la:{while(1){if((c|0)!=(g|0)){v[23220]=0;k=T(186,i|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break la}v[23220]=0;Q(187,h|0,k|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break la}g=g+1|0;continue}break}yc(j,h);ub(h);wb(i);break g}g=P()|0;O()|0;ub(h);break i}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+34|0]=q;break g}if(c>>>0>2){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=HC(b,c),u[p+12>>1]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+23|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+24|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+25|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+35|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+36|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+105|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+85|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+65|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+100|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+80|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=ud(b,c),t[p+60|0]=q;break g}if(c>>>0>1){break f}if(!Lb(v[b>>2],v[b+8>>2],c)){break f}p=d,q=GC(b,c),t[p+33|0]=q;break g}g=1;i=ro(b,c);if(!qo(i)){break f}t[d+14|0]=i;break f}p=d,q=B(Ou(b,c),1e4)+(y[d+40>>2]%1e4|0)|0,v[p+40>>2]=q;break g}g=Ou(b,c);i=v[d+40>>2];v[d+40>>2]=i-((i>>>0)%1e4|0)+(g>>>0)%1e4;break g}v[e+24>>2]=240;p=e,q=ro(b,c),v[p>>2]=q;Zg(d+48|0,v[Eb(e+24|0,e)>>2]);break g}v[e+24>>2]=240;p=e,q=ro(b,c),v[p>>2]=q;Zg(d+68|0,v[Eb(e+24|0,e)>>2]);break g}v[e+24>>2]=240;p=e,q=ro(b,c),v[p>>2]=q;Zg(d+88|0,v[Eb(e+24|0,e)>>2]);break g}g=P()|0;O()|0}wb(i);S(g|0);L()}yc(j,h);ub(h);wb(i)}g=1}fb=e+48|0;if(!g){Yb(b,c);break e}if((rm(16704)|0)==(f|0)){e=w[d+15|0];t[d+15|0]=0;t[d+100|0]=w[d+100|0]&224|(e>>>5&4|e>>>6&1);t[d+60|0]=e>>>1&2|(e<<1&4|(w[d+60|0]&240|e&1));t[d+80|0]=w[d+80|0]&240|(e>>>4&2|(e>>>2&4|e>>>3&1))}}}l=l+1|0;continue}}}return n|0}function PU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-304|0;fb=e;wc(b);if(zq(b,17771)){o=Gb(e+288|0);v[23220]=0;f=Q(220,b|0,o|0)|0;g=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{if((g|0)!=1){if(!f){break a}v[23220]=0;f=Q(235,b|0,e+280|0)|0;g=v[23220];v[23220]=0;g:{if((g|0)==1){break g}if(!f){break a}if(!QB(w[e+280|0],w[e+281|0])){break a}f=Pc(PB(e+280|0),ib);g=v[b+8>>2];m=v[b>>2];v[23220]=0;f=W(143,m|0,g|0,f|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break g}if(!f){break a}if(!c){break b}v[23220]=0;R(236,a|0,4096);d=v[23220];v[23220]=0;if((d|0)==1){break g}v[23220]=0;R(237,a+1298308|0,o|0);d=v[23220];v[23220]=0;if((d|0)==1){break g}d=w[e+282|0];u[a+480188>>1]=32;u[a+480192>>1]=d;th(a,1);v[23220]=0;d=Q(1,e+264|0,9447)|0;f=v[23220];v[23220]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{if((f|0)!=1){Db(a+1298344|0,d);vb(d);v[23220]=0;d=Q(1,e+248|0,7011)|0;f=v[23220];v[23220]=0;if((f|0)==1){break p}Db(a+1298356|0,d);vb(d);v[23220]=0;Y(238,e+48|0);d=v[23220];v[23220]=0;if((d|0)==1){break o}t[e+216|0]=w[e+281|0];v[23220]=0;t[e+8|0]=w[e+280|0];R(239,e+232|0,e+8|0);d=v[23220];v[23220]=0;if((d|0)==1){break n}v[23220]=0;X(240,e+96|0,e+48|0,e+216|0,e+232|0);d=v[23220];v[23220]=0;if((d|0)==1){break m}d=e+96|0;Db(a+1298368|0,d);vb(d);vb(e+232|0);bc(e+48|0);v[a+1298404>>2]=5;if(w[e+280|0]<2){break i}u[e+96>>1]=8192;v[23220]=0;d=T(181,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break k}u[e+48>>1]=d;q=a,r=B(x[Re(e+96|0,e+48|0)>>1],1e4)>>>8|0,v[q+480204>>2]=r;v[23220]=0;t[e+96|0]=1;d=T(193,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break j}t[e+48|0]=d;q=a,r=w[$e(e+96|0,e+48|0)|0],v[q+480196>>2]=r;v[23220]=0;Q(175,b|0,3)|0;d=v[23220];v[23220]=0;if((d|0)!=1){v[23220]=0;d=T(181,b|0)|0;f=v[23220];v[23220]=0;if((f|0)!=1){break h}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(e+232|0)}bc(e+48|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}t[e+96|0]=32;v[23220]=0;d=T(193,b|0)|0;f=v[23220];v[23220]=0;q:{if((f|0)!=1){t[e+48|0]=d;q=a,r=B(w[$e(e+96|0,e+48|0)|0],1e4),v[q+480204>>2]=r;v[23220]=0;t[e+96|0]=1;d=T(193,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break q}t[e+48|0]=d;q=a,r=w[$e(e+96|0,e+48|0)|0],v[q+480196>>2]=r;v[23220]=0;d=T(193,b|0)|0;f=v[23220];v[23220]=0;if((f|0)!=1){break h}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[a+480208>>2]=d>>>2&16|12;m=Ib(e+232|0);p=e+96|12;n=Ib(e+216|0);h=a+480190|0;i=1;while(1){r:{s:{d=i&65535;if(d>>>0>x[a+480192>>1]){break s}v[23220]=0;f=W(241,a|0,d|0,0)|0;d=v[23220];v[23220]=0;t:{if((d|0)==1){break t}if(!f){break s}v[23220]=0;d=Q(230,b|0,f+492|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break t}if(!d){break s}v[23220]=0;k=T(193,b|0)|0;d=v[23220];v[23220]=0;u:{v:{w:{if((d|0)!=1){Sb(e+96|0,0,120);if(!k){break r}x:{if(w[e+280|0]){v[23220]=0;d=Q(242,b|0,e+96|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break w}if(!d){break r}if(w[e+280|0]){break x}}d=v[cc(e+88|0,p,96)>>2];v[23220]=0;X(152,e+48|0,b|0,d|0,v[e+92>>2]);d=v[23220];v[23220]=0;if((d|0)==1){break v}if(!v[e+52>>2]){break r}}g=f+236|0;d=0;break u}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}while(1){if((d|0)!=120){q=ac(g,d),r=(w[(e+96|0)+d|0]+x[h>>1]|0)+1|0,u[q>>1]=r;d=d+1|0;continue}break}v[23220]=0;j=f+48|0;U(243,e+8|0,j|0,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break e}v[23220]=0;d=f+68|0;U(243,e+32|0,d|0,b|0);g=v[23220];v[23220]=0;if((g|0)==1){break e}v[23220]=0;g=f+88|0;U(243,e+80|0,g|0,b|0);l=v[23220];v[23220]=0;if((l|0)==1){break e}v[23220]=0;R(244,b|0,e+72|0);l=v[23220];v[23220]=0;if((l|0)==1){break f}v[f>>2]=(w[e+73|0]|w[e+74|0]<<8)&4095;l=w[e+73|0]|w[e+74|0]<<8;su(w[e+75|0]|w[e+76|0]<<8,j,0);su(w[e+75|0]|w[e+76|0]<<8,d,1);su(w[e+75|0]|w[e+76|0]<<8,g,2);q=e,r=Ab(v[f+48>>2]),v[q+48>>2]=r;j=l>>>12&3;l=Ab(v[f+52>>2]);while(1){f=v[e+48>>2];if(Nb(f,l)){t[e+44|0]=64;t[e+70|0]=((w[f+2|0]<<6)- -64>>>0)/127;q=f,r=w[Rb(e+44|0,e+70|0)|0],t[q+2|0]=r;ye(e+48|0);continue}else{q=e,r=Ab(v[d>>2]),v[q+48>>2]=r;d=Ab(v[d+4>>2])}break}while(1){f=v[e+48>>2];if(Nb(f,d)){t[e+44|0]=64;t[e+70|0]=((w[f+2|0]<<6)+128>>>0)/255;q=f,r=w[Rb(e+44|0,e+70|0)|0],t[q+2|0]=r;ye(e+48|0);continue}break}q=e,r=Ab(v[g>>2]),v[q+48>>2]=r;j=1<<j;l=Ab(v[g+4>>2]);while(1){d=v[e+48>>2];if(Nb(d,l)){g=d;d=t[d+2|0];d=Bia(d^-128,d>>31^-1,j,0);f=ib;y:{if((f|0)>=-1&d>>>0>=4294967292|(f|0)>=0){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break y}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}q=g,r=Dc(d,f)^128,t[q+2|0]=r;ye(e+48|0);continue}else{f=x[h>>1]+1|0;u[e+70>>1]=f;d=0;f=f&65535;g=4e3-f|0;g=g>>>0>4e3?0:g;z:{A:{B:{while(1){if((d|0)==(k|0)){break A}if((d|0)==(g|0)){v[23220]=0;Q(175,b|0,20)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break A}b=P()|0;O()|0;break d}v[23220]=0;j=d+f|0;Q(230,b|0,((j<<5)+a|0)+946304|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break z}v[23220]=0;R(245,b|0,e+48|0);l=v[23220];v[23220]=0;C:{if((l|0)==1){break C}v[23220]=0;R(246,e+48|0,(B(j,104)+a|0)+484380|0);j=v[23220];v[23220]=0;if((j|0)==1){break C}v[23220]=0;u[e+44>>1]=w[e+72|0]|d<<8&32512|((w[e+67|0]&3)!=0)<<15;R(247,n|0,e+44|0);j=v[23220];v[23220]=0;if((j|0)==1){break B}d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[23220]=0;R(247,m|0,e+70|0);d=v[23220];v[23220]=0;if((d|0)!=1){v[e+48>>2]=3999;v[e+44>>2]=k+x[h>>1];q=h,r=v[nd(e+48|0,e+44|0)>>2],u[q>>1]=r;break r}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}}}b=P()|0;O()|0;break d}d=Gb(e+96|0);v[23220]=0;f=Q(220,b|0,d|0)|0;g=v[23220];v[23220]=0;D:{E:{F:{G:{H:{if((g|0)!=1){I:{if(f){v[23220]=0;U(11,e+48|0,7,d|0);f=v[23220];v[23220]=0;if((f|0)==1){break I}f=e+48|0;Db(a+1298320|0,f);vb(f)}ub(d);d=0;J:{while(1){if((d|0)==32){v[23220]=0;d=Q(248,b|0,e+32|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break G}if(!d){break F}d=v[e+32>>2];if(d>>>0<12){break H}f=v[b+8>>2];g=v[b>>2];v[23220]=0;d=W(143,g|0,f|0,d-11|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break G}if(d){break J}break H}f=(d<<5)+a|0;Pe(f+480280|0);v[23220]=0;R(221,b|0,f+480289|0);f=v[23220];v[23220]=0;if((f|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}d=v[e+32>>2]-11|0;v[e+80>>2]=d;h=Ib(e+96|0);v[23220]=0;U(224,b|0,h|0,d|0);d=v[23220];v[23220]=0;K:{if((d|0)!=1){v[e+48>>2]=50529027;d=e+48|0;q=e,r=B(v[Eb(e+80|0,d)>>2],85),v[q+72>>2]=r;g=Gb(d);v[e+8>>2]=v[e+36>>2];d=v[Eb(e+72|0,e+8|0)>>2];v[23220]=0;R(43,g|0,d|0);d=v[23220];v[23220]=0;L:{if((d|0)==1){break L}d=0;M:{while(1){f=v[e+80>>2];if(f>>>0<=d>>>0){break M}i=v[h>>2];k=w[Hb(i,d)|0];j=f;f=d+1|0;if(!((k|0)!=255|j-f>>>0<2)){f=t[Hb(i,f)|0];i=w[Hb(i,d+2|0)|0];q=e,r=ih(g),v[q+8>>2]=r;k=v[Ef(e+24|0,e+8|0)>>2];v[23220]=0;X(227,g|0,k|0,i|0,f|0);f=v[23220];v[23220]=0;if((f|0)!=1){d=d+3|0;continue}break L}v[23220]=0;R(44,g|0,k<<24>>24);i=v[23220];v[23220]=0;d=f;if((i|0)!=1){continue}break}break L}v[23220]=0;X(225,e+8|0,5,7,g|0);d=v[23220];v[23220]=0;if((d|0)!=1){N:{f=e+8|0;d=xc(g,f);ub(f);f=Ec(d);i=Bb(d);v[23220]=0;da(226,a+1298332|0,f|0,i|0,74,0);f=v[23220];v[23220]=0;if((f|0)==1){break N}ub(d);$b(h);break H}}}b=P()|0;O()|0;ub(g);break K}b=P()|0;O()|0}$b(h);break d}}b=P()|0;O()|0;ub(d);break d}d=w[a+484376|0];f=v[a+484360>>2];v[23220]=0;U(228,Vb(f,d)|0,b|0,w[e+285|0]|w[e+286|0]<<8);d=v[23220];v[23220]=0;if((d|0)==1){break G}i=c&1;if(i){v[23220]=0;R(212,a+484344|0,w[e+283|0]|w[e+284|0]<<8);d=v[23220];v[23220]=0;if((d|0)==1){break G}}h=a+484344|0;f=b;d=0;while(1){O:{if((w[e+283|0]|w[e+284|0]<<8)>>>0>d>>>0){b=v[f+8>>2];g=v[f>>2];v[23220]=0;b=W(143,g|0,b|0,4)|0;g=v[23220];v[23220]=0;if((g|0)==1){break D}if(b){break O}}if(!(c&2)){break F}d=0;c=a+480190|0;while(1){b=x[c>>1];if(d>>>0>=b>>>0){d=0;f=a+480190|0;while(1){if(b>>>0<=d>>>0){break F}c=x[ac(v[n>>2],d)>>1];g=c&255;P:{if(!g){break P}h=v[m>>2];g=g-1&65535;if(Ic(h,v[m+4>>2])>>>0<=g>>>0){break P}j=b;b=x[ac(h,g)>>1]+(c>>>8&127)&65535;if(j>>>0<b>>>0){break P}b=B(b,104);g=b+a|0;c=g+484380|0;h=v[c>>2];if(!Md(h,v[g+484400>>2])){break P}g=b;b=a+484380|0;g=g+b|0;i=x[g+34>>1];b=b+B(d+1|0,104)|0;v[b>>2]=h;u[b+34>>1]=x[b+34>>1]&65534|i&1;if(!wg(b)){break P}nc(v[b+20>>2],v[g+20>>2],sj(v[c>>2],x[c+34>>1]))}d=d+1|0;b=x[f>>1];continue}}b=x[ac(v[n>>2],d)>>1];if(b&255){d=d+1|0;continue}d=d+1|0;g=B(d,104)+a|0;b=Uc(e+96|0,u[g+484414>>1]&1?16:8,1,0,b<<16>>16>=0?0:6);v[23220]=0;W(206,b|0,g+484380|0,f|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){continue}break}b=P()|0;O()|0;break d}v[23220]=0;b=T(144,f|0)|0;g=v[23220];v[23220]=0;Q:{R:{S:{T:{if((g|0)!=1){v[23220]=0;U(177,e+48|0,f|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break T}b=e+48|0;g=gc(e+96|0,b);wb(b);if(!i){break R}v[23220]=0;b=T(193,g|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break Q}v[23220]=0;Q(175,g|0,1)|0;k=v[23220];v[23220]=0;if((k|0)==1){break Q}v[23220]=0;b=W(213,h|0,d&65535,b+1|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break Q}if(!b){break R}v[23220]=0;b=Q(222,g|0,e+48|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break E}if(!b){break S}b=v[h>>2];v[23220]=0;R(223,Xb(b,d)|0,e+48|0);b=v[23220];v[23220]=0;if((b|0)!=1){break S}break E}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=v[h>>2];v[23220]=0;U(229,Xb(b,d)|0,1,g|0);b=v[23220];v[23220]=0;if((b|0)==1){break E}}wb(g);d=d+1|0;continue}break}break E}b=P()|0;O()|0;break d}ld(n);ld(m);break b}b=P()|0;O()|0;wb(g);break d}b=P()|0;O()|0;break d}i=i+1|0;continue}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0}ld(n);ld(m)}ub(o);S(b|0);L()}d=1}ub(o)}fb=e+304|0;return d|0}function Wha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;e=fb-368|0;fb=e;wc(b);g=e+344|0;f=TB(b,g);if(!f){vu(g)}a:{b:{c:{d:{e:{if(!f){break e}if(!CT(e+344|0)){break e}if(!Lb(v[b>>2],v[b+8>>2],Pc(72,0))){break e}if(!c){d=1;break e}zd(a,1);v[a+480208>>2]=v[a+480208>>2]&-25231361|16842752;g=w[e+353|0];u[a+480190>>1]=63;u[a+480188>>1]=g;f:{g:{while(1){if((g&65535)>>>0<=d>>>0){h:{d=1;i:{while(1){j:{g=d&65535;if(g>>>0>x[a+480190>>1]){YB(b,a+1298308|0);g=e+264|0;d=fb-16|0;fb=d;k:{if(!Lb(v[b>>2],v[b+8>>2],8)){t[d|0]=0;Wh(g,8,d);break k}Bm(d+8|0,g);md(d,b,v[d+8>>2],v[d+12>>2])}fb=d+16|0;n=Ib(e+248|0);g=x[e+354>>1];if(!g){break i}d=0;v[23220]=0;g=W(312,b|0,n|0,B(g,w[e+353|0])<<1)|0;f=v[23220];v[23220]=0;if((f|0)!=1){break j}g=P()|0;O()|0;break a}f=(B(g,104)+a|0)+484380|0;kd(f,1);i=g+(e+272|0)|0;g=Ae(b);t[i|0]=g;if(g<<24>>24>=0){A=f,C=zT(b)<<1,v[A>>2]=C}d=d+1|0;continue}break}if(!g){break f}}d=v[n>>2];ec(e+240|0,d,Wc(d,v[n+4>>2])>>>1|0);m=Ib(e+224|0);v[23220]=0;R(313,m|0,x[e+356>>1]<<8);d=v[23220];v[23220]=0;if((d|0)==1){break h}d=0;l:{m:{n:{while(1){g=d&65535;d=x[e+356>>1];if(g>>>0>=d>>>0){break m}v[e+176>>2]=d-g;v[e+120>>2]=2e3;d=e+176|0;f=v[nd(d,e+120|0)>>2];d=Ib(d);v[23220]=0;f=W(312,b|0,d|0,f<<8)|0;h=v[23220];v[23220]=0;if((h|0)==1){break l}if(!f){break n}f=dc(e+216|0,Ab(v[m+4>>2]));h=Ab(v[d>>2]);j=Ab(v[e+180>>2]);f=v[f>>2];v[23220]=0;X(314,m|0,f|0,h|0,j|0);f=v[23220];v[23220]=0;if((f|0)!=1){$b(d);d=g+2e3|0;continue}break}break c}$b(d);d=0;break g}ge(e+200|0,v[m>>2],v[m+4>>2]);Hg(e+208|0,v[e+200>>2],v[e+204>>2]);p=a+484376|0;d=w[p|0];g=v[a+484360>>2];v[23220]=0;R(315,Vb(g,d)|0,x[e+354>>1]);d=v[23220];v[23220]=0;if((d|0)==1){break d}q=a+484344|0;s=c&1;j=0;while(1){if(x[e+354>>1]<=j>>>0){h=c&2;g=1;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{while(1){c=g&65535;if(c>>>0>x[a+480190>>1]){break v}v[23220]=0;d=w[c+(e+272|0)|0];U(316,b|0,((c<<5)+a|0)+946304|0,d&63);f=v[23220];v[23220]=0;if((f|0)==1){break t}A:{B:{if(d<<24>>24<0){break B}v[23220]=0;d=T(317,b|0)|0;f=v[23220];v[23220]=0;C:{D:{E:{F:{G:{H:{I:{J:{if((f|0)==1){break J}c=B(c,104)+a|0;f=c+484392|0;v[f>>2]=d<<1;v[23220]=0;d=T(317,b|0)|0;j=v[23220];v[23220]=0;if((j|0)==1){break I}d=d<<1;if(d>>>0>=3){v[c+484396>>2]=d+v[f>>2];d=c+484414|0;u[d>>1]=x[d>>1]|8}v[23220]=0;d=T(193,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break s}t[e+40|0]=d;t[e+144|0]=64;A=c+484410|0,C=w[Rb(e+40|0,e+144|0)|0]<<2,u[A>>1]=C;v[23220]=0;d=T(193,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break J}t[c+484417|0]=d<<4;c=c+484380|0;dB(c);if(!v[c>>2]){break B}v[23220]=0;f=T(193,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break D}d=0;switch(f|0){case 4:case 5:break C;case 2:case 3:break F;case 1:break G;case 0:break H;default:break g}}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}if(h){f=Ib(e+40|0);j=v[b+8>>2];i=v[b>>2];k=v[c>>2];v[23220]=0;j=W(143,i|0,j|0,k|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break r}if(!j){break w}d=v[c>>2];v[23220]=0;U(318,b|0,f|0,d|0);d=v[23220];v[23220]=0;if((d|0)==1){break r}A=e,C=Ab(v[f>>2]),v[A+144>>2]=C;j=Ab(v[e+44>>2]);while(1){d=v[e+144>>2];if(Nb(d,j)){i=d;d=w[d|0];t[i|0]=d<<7|(d^-1)<<24>>>25;xe(e+144|0);continue}break}ge(e+168|0,v[f>>2],v[e+44>>2]);d=v[Xd(e+160|0)>>2];v[23220]=0;d=ga(319,e+176|0,v[e+168>>2],v[e+172>>2],d|0,v[e+164>>2])|0;j=v[23220];v[23220]=0;K:{if((j|0)!=1){j=Uc(e+144|0,16,1,0,16);v[23220]=0;W(206,j|0,c|0,d|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break K}wb(d);$b(f);break B}g=P()|0;O()|0;break o}g=P()|0;O()|0;wb(d);break o}c=v[c>>2];break E}f=Ib(e+40|0);d=v[c>>2];v[23220]=0;U(320,e+144|0,b|0,d|0);d=v[23220];v[23220]=0;L:{M:{N:{if((d|0)!=1){d=e+144|0;j=hm(f,d);$b(d);if(h){ge(e+112|0,v[j>>2],v[e+44>>2]);d=v[Xd(e+104|0)>>2];v[23220]=0;d=ga(319,e+120|0,v[e+112>>2],v[e+116>>2],d|0,v[e+108>>2])|0;i=v[23220];v[23220]=0;if((i|0)==1){break N}i=Uc(e+144|0,8,1,0,2);v[23220]=0;W(206,i|0,c|0,d|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break M}wb(d)}$b(j);break B}g=V(30480)|0;if((O()|0)!=(ea(30480)|0)){break L}_(g|0)|0;d=0;v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)!=1){break u}g=P()|0;O()|0;break L}g=P()|0;O()|0;break L}g=P()|0;O()|0;wb(d)}$b(f);break b}if(h){d=Uc(e+40|0,(f|0)==2?8:16,1,0,0);v[23220]=0;W(206,d|0,c|0,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break B}g=P()|0;O()|0;break b}c=B(v[c>>2],f-1|0)}v[23220]=0;Q(175,b|0,c|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break B}}g=P()|0;O()|0;break b}j=Ib(e+40|0);d=v[c>>2];v[23220]=0;U(321,e+144|0,b|0,d|0);d=v[23220];v[23220]=0;O:{P:{if((d|0)!=1){i=e+144|0;d=hm(j,i);$b(i);if(!h){break O}if((f|0)!=5){break P}A=e,C=Ab(v[d>>2]),v[A+144>>2]=C;k=Ab(v[e+44>>2]);while(1){i=v[e+144>>2];if(!Nb(i,k)){break P}l=i;i=w[i|0];t[l|0]=w[(i>>>7|0)+26369|0]^i;xe(e+144|0);continue}}g=V(30480)|0;if((O()|0)!=(ea(30480)|0)){break x}_(g|0)|0;d=0;v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)!=1){break A}g=P()|0;O()|0;break x}ge(e+72|0,v[d>>2],v[e+44>>2]);i=v[Xd(e- -64|0)>>2];v[23220]=0;i=ga(319,e+80|0,v[e+72>>2],v[e+76>>2],i|0,v[e+68>>2])|0;k=v[23220];v[23220]=0;if((k|0)==1){break z}f=(f|0)==5;f=Uc(e+144|0,f?16:8,1,0,f?16:1);v[23220]=0;W(206,f|0,c|0,i|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break y}wb(i)}$b(d)}g=g+1|0;continue}break}$b(j);break g}g=P()|0;O()|0;break x}g=P()|0;O()|0;wb(i)}$b(j);break b}$b(f);break g}Q:{R:{S:{T:{U:{V:{W:{d=x[e+358>>1]|w[e+360|0]<<16;if(d){c=Ib(e+144|0);v[23220]=0;b=W(312,b|0,c|0,d|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break q}if(!b){break U}ge(e+32|0,v[c>>2],v[c+4>>2]);b=Xd(e+24|0);g=v[b+4>>2];b=v[b>>2];v[23220]=0;b=ga(319,e+40|0,v[e+32>>2],v[e+36>>2],b|0,g|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break W}v[23220]=0;X(322,a+1298332|0,b|0,d|0,1);d=v[23220];v[23220]=0;if((d|0)==1){break V}wb(b);$b(c)}v[23220]=0;Y(323,e+8|0);b=v[23220];v[23220]=0;if((b|0)==1){break T}v[23220]=0;U(200,e+144|0,e+8|0,w[e+352|0]);b=v[23220];v[23220]=0;if((b|0)==1){break S}b=e+144|0;Db(a+1298344|0,b);vb(b);bc(e+8|0);v[23220]=0;b=Q(1,b|0,10057)|0;c=v[23220];v[23220]=0;if((c|0)==1){break R}Db(a+1298356|0,b);vb(b);v[23220]=0;b=Q(1,e+8|0,5062)|0;c=v[23220];v[23220]=0;if((c|0)==1){break Q}Db(a+1298368|0,b);vb(b);v[a+1298404>>2]=10;d=1;break g}g=P()|0;O()|0;break p}g=P()|0;O()|0;wb(b);break p}$b(c);d=0;break g}g=P()|0;O()|0;break b}g=P()|0;O()|0;bc(e+8|0);break b}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}$b(f);break g}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}g=P()|0;O()|0;break o}g=P()|0;O()|0}$b(c);break b}$b(f);break b}A=ac(v[Vb(v[a+484360>>2],w[p|0])>>2],j),C=j,u[A>>1]=C;X:{Y:{if(!s){break Y}v[23220]=0;r=j&65535;d=W(213,q|0,r|0,64)|0;g=v[23220];v[23220]=0;if((g|0)==1){break X}if(!d){break Y}f=x[a+480188>>1];i=0;while(1){d=f&65535;if(d>>>0<=i>>>0){break Y}d=ac(v[e+240>>2],B(d,j)+i|0);d=w[d|0]|w[d+1|0]<<8;Z:{if(d>>>0>=x[e+356>>1]){break Z}g=0;y=0-i|0;z=d<<8;d=Xb(v[q>>2],j);d=$c(v[d>>2],v[v[d+48>>2]+12>>2],0,i&65535);while(1){if((g|0)==64){break Z}dq(e+176|0,v[e+208>>2],v[e+212>>2],(g<<2)+z|0,4);f=v[e+176>>2];h=Hb(f,0);o=w[h|0]&63;t[d|0]=o?o+48|0:0;k=Hb(f,1);t[d+1|0]=w[k|0]<<2&60|w[h|0]>>>6;h=w[k|0];l=Hb(f,2);k=w[Hb(f,3)|0];l=w[l|0];f=k<<4|l>>>4;u[e+40>>1]=f;h=l<<2&60|h>>>6;_:{if(!(w[Hb(e+264|0,h>>>3|0)|0]>>>(h&7)&1)|!(f?1:h)){break _}t[d+5|0]=f;t[d+3|0]=h;l=k>>>4|0;t[d+4|0]=l;$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{switch(h|0){case 0:case 1:case 2:case 32:case 33:case 34:t[d+3|0]=h&15;Mf(d);if(!w[d+4|0]){break _}t[d+2|0]=h>>>0<32?3:4;break _;case 9:t[d+3|0]=10;t[d+5|0]=f>>>1;if(f>>>0<512){break _}t[d+2|0]=15;t[d+4|0]=k>>>5;break _;case 10:case 42:if(f>>>0>254){break ja}t[d+3|0]=h&15;break;case 50:break aa;case 48:break ba;case 43:break ca;case 47:break da;case 17:case 18:case 26:case 27:break ea;case 22:case 25:case 28:case 29:case 30:break fa;case 16:case 19:case 20:case 21:case 23:case 31:break ga;case 13:break ha;case 11:case 15:break ia;case 3:case 4:case 5:case 6:case 7:case 12:break ka;default:break $}}Mf(d);break _}t[d+3|0]=19;t[d+5|0]=l|(h>>>0<32?16:32);if(k&15){t[d+2|0]=3;t[d+4|0]=(f&240)>>>4;break _}t[d+2|0]=4;t[d+4|0]=f&15;break _}t[d+3|0]=(h|0)==11?12:16;A=d,C=_t(f),t[A+5|0]=C;break _}t[d+3|0]=14;if((f&255)>>>0<64){break _}t[d+5|0]=0;break _}t[d+3|0]=19;t[d+5|0]=f&15|h<<4;break _}t[d+3|0]=19;u[e+120>>1]=15;A=d,C=w[Tc(e+40|0,e+120|0)|0]|h<<4,t[A+5|0]=C;break _}t[d+3|0]=19;if(f&255){t[d+5|0]=f&15|((h|0)==17?16:(h|0)==26?16:32);if(!(k&240)){break _}t[d+2|0]=h>>>0>25?6:5;break _}t[d+5|0]=l|(h>>>0>25?-80:-96);break _}if(!f){break $}t[d+3|0]=17;v[e+120>>2]=8;v[e+80>>2]=f+4;A=d,C=vi(v[Ke(e+120|0,e+80|0)>>2]/8|0),t[A+5|0]=C;break _}t[d+3|0]=14;k=B(y,6)+d|0;o=x[a+480188>>1];f=0;while(1){if((f|0)==(o|0)){break _}h=k+B(f,6)|0;if(!w[h+3|0]){t[h+3|0]=12;A=h,C=_t(r),t[A+5|0]=C}f=f+1|0;continue}}t[d+3|0]=9;h=f&7;if(h){t[d+5|0]=w[h+26361|0];break _}h=f>>>4|0;if((h|0)==128){break $}t[d+5|0]=h;if(!(f&2048)){t[d+5|0]=h^128;break _}t[d+5|0]=h^-1;break _}t[d+5|0]=0;t[d+3|0]=0;if(!o){t[d|0]=255;break _}t[d+3|0]=25;break _}t[d+3|0]=0}g=g+1|0;f=x[a+480188>>1];d=B(f,6)+d|0;continue}}i=i+1|0;continue}}j=j+1|0;continue}break}g=P()|0;O()|0;break b}break c}}else{bB(a,d&65535);u[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;g=x[a+480188>>1];continue}break}g=P()|0;O()|0;break b}$b(m)}$b(n)}fb=e+368|0;return d|0}g=P()|0;O()|0;break b}g=P()|0;O()|0;$b(d)}$b(m)}$b(n);S(g|0);L()}function G3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=fb-32|0;fb=g;d=Qb(g+16|0,11574);h=Kg(c,d);ub(d);a:{b:{c:{d:{e:{if(h){Jk(a,v[b+24>>2]+1298356|0);break e}d=Qb(g+16|0,10912);h=Kg(c,d);ub(d);if(h){Jk(a,v[b+24>>2]+1298344|0);break e}d=Qb(g+16|0,11404);h=Kg(c,d);ub(d);if(h){Jk(a,v[b+24>>2]+1298392|0);break e}d=Qb(g+16|0,10904);h=Kg(c,d);ub(d);if(h){Jk(a,v[b+24>>2]+1298380|0);break e}d=Qb(g+16|0,8230);h=Kg(c,d);ub(d);if(h){c=g+16|0;d=v[v[b+24>>2]+480184>>2];b=32784;f:{g:{while(1){if((b|0)==32832){break g}if((d|0)!=v[b>>2]){b=b+12|0;continue}break}Im(c,0,v[b+8>>2]);break f}Gb(c)}v[23220]=0;R(981,a|0,c|0);a=v[23220];v[23220]=0;if((a|0)==1){break d}vb(g+16|0);break e}d=Qb(g+16|0,10889);h=Kg(c,d);ub(d);if(h){f=v[v[b+24>>2]+480184>>2];c=fb+-64|0;fb=c;b=32784;e=eg(c+48|0);j=g+16|0;d=Gb(j);while(1){if((b|0)!=32832){if((f|0)==v[b>>2]){h=v[b+4>>2];v[23220]=0;h=Q(1,c+32|0,h|0)|0;i=v[23220];v[23220]=0;h:{i:{j:{k:{l:{m:{if((i|0)!=1){v[23220]=0;U(817,c+24|0,e|0,h|0);i=v[23220];v[23220]=0;if((i|0)==1){break k}if(!w[c+28|0]){break h}if(!ah(v[d+4>>2],w[d+11|0])){v[23220]=0;i=Q(1,c+8|0,17716)|0;k=v[23220];v[23220]=0;if((k|0)==1){break m}v[23220]=0;Q(85,d|0,i|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break l}vb(i)}v[23220]=0;Q(85,d|0,h|0)|0;i=v[23220];v[23220]=0;if((i|0)!=1){break h}b=P()|0;O()|0;break j}b=P()|0;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;vb(i);break j}b=P()|0;O()|0}vb(h)}vb(d);zL(e);S(b|0);L()}vb(h)}b=b+12|0;continue}break}zL(e);fb=c- -64|0;v[23220]=0;R(981,a|0,j|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(g+16|0);break e}c=P()|0;O()|0;vb(g+16|0);break a}d=Qb(g+16|0,8296);h=Kg(c,d);ub(d);if(h){Jk(a,v[b+24>>2]+1298368|0);break e}d=Qb(g+16|0,5581);h=Kg(c,d);ub(d);if(h){Jk(a,v[b+24>>2]+1298320|0);break e}d=Qb(g+16|0,11978);h=Kg(c,d);ub(d);if(h){c=g+16|0;Oh(c,v[b+24>>2]+1298308|0);b=v[b+24>>2];v[23220]=0;U(975,a|0,b|0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){ub(g+16|0);break e}c=P()|0;O()|0;ub(g+16|0);break a}d=Qb(g+16|0,11347);h=Kg(c,d);ub(d);if(h){c=v[b+24>>2]+1298408|0;b=v[c+4>>2];n:{if(!rc(v[c>>2],b)){b=b-48|0;if(sd(v[b+12>>2])){break n}}Gb(a);break e}o=g+16|0;j=fb-144|0;fb=j;nc(j+96|0,b,44);e=v[b+44>>2];if(e){nc(j+44|0,b,44);h=fb-16|0;fb=h;b=Vw(v[j+64>>2]+1900|0,v[j+60>>2]+1|0,v[j+56>>2])-Vw(1970,1,1)|0;b=Bia(b,b>>31,86400,0);c=B(v[j+52>>2],3600);b=b+c|0;d=ib+(c>>31)|0;d=b>>>0<c>>>0?d+1|0:d;c=B(v[j+48>>2],60);i=c;b=c+b|0;c=(c>>31)+d|0;c=b>>>0<i>>>0?c+1|0:c;d=v[j+44>>2];i=d;b=d+b|0;d=(d>>31)+c|0;c=kn(h+8|0,b,b>>>0<i>>>0?d+1|0:d);b=v[c>>2];i=v[c+4>>2];fb=h+16|0;h=j+88|0;d=2147483647;m=de(+(e>>>0)/18.2);c=-1;o:{if(m>=0x8000000000000000){break o}d=-2147483648;c=0;if(m<=-0x8000000000000000){break o}if(D(m)<0x8000000000000000){d=D(m)>=1?~~(m>0?F(H(m*2.3283064365386963e-10),4294967295):I((m-+(~~m>>>0>>>0))*2.3283064365386963e-10))>>>0:0;c=~~m>>>0;break o}c=0}d=d+i|0;c=b+c|0;d=c>>>0<b>>>0?d+1|0:d;b=kn(h,c,d);i=v[b+4>>2];h=v[b>>2];k=fb-16|0;fb=k;v[k+12>>2]=0;v[k+8>>2]=0;v[k+4>>2]=0;b=Vw(1970,1,1)+Cia(h,i,86400,0)|0;f=b>>31;d=Bia(b,f,1e4,0)+14780|0;c=ib;e=d;c=d>>>0<14780?c+1|0:c;l=Cia(d,c,-14609700,-1)+b|0;d=f+ib|0;d=b>>>0>l>>>0?d+1|0:d;n=Cia(e,c,365242500,0);l=n+l|0;d=ib+d|0;d=l>>>0<n>>>0?d+1|0:d;n=Cia(e,c,-146097e4,-1);l=n+l|0;d=ib+d|0;d=l>>>0<n>>>0?d+1|0:d;c=Cia(e,c,3652425,0);e=ib;n=e;p=l;l=Bia(c,e,-365,-1);e=p+l|0;d=ib+d|0;d=e>>>0<l>>>0?d+1|0:d;if(!((d|0)>0|(d|0)>=0)){d=n-!c|0;c=c-1|0;e=Bia(c,d,-365,-1)+b|0;d=f+ib|0;d=b>>>0>e>>>0?d+1|0:d;b=e;e=(c|0)/-4|0;b=b+e|0;d=(e>>31)+d|0;d=b>>>0<e>>>0?d+1|0:d;e=b;b=(c|0)/100|0;f=b;e=e+b|0;b=(b>>31)+d|0;b=e>>>0<f>>>0?b+1|0:b;d=(c|0)/-400|0;f=d;e=d+e|0;d=(d>>31)+b|0;d=e>>>0<f>>>0?d+1|0:d}f=c;b=Bia(e,d,100,0)+52|0;c=ib;b=Cia(b,b>>>0<52?c+1|0:c,3060,0);c=b+2|0;d=(c|0)/12|0;v[k+12>>2]=f+d;v[k+8>>2]=(c+B(d,-12)|0)+1;b=Bia(b,ib,306,0)+5|0;d=ib;b=Cia(b,b>>>0<5?d+1|0:d,-10,-1)+e|0;v[k+4>>2]=b+1;v[j+136>>2]=0;v[j+128>>2]=0;v[j+132>>2]=0;v[j+120>>2]=0;v[j+124>>2]=0;v[j+116>>2]=v[k+12>>2]-1900;v[j+112>>2]=v[k+8>>2]-1;b=v[k+4>>2];q=j,r=Dia(Cia(h,i,3600,0),ib,24),v[q+104>>2]=r;v[j+108>>2]=b;b=Cia(h,i,60,0);c=ib;q=j,r=Dia(b,c,60),v[q+100>>2]=r;b=Bia(b,c,-60,0)+h|0;v[j+96>>2]=b;fb=k+16|0}c=nc(j,j+96|0,44);b=fb-176|0;fb=b;h=Gb(b+160|0);v[23220]=0;d=Q(1,b+144|0,13449)|0;e=v[23220];v[23220]=0;p:{q:{r:{s:{t:{if((e|0)!=1){e=v[c+20>>2];if(!e){break q}v[23220]=0;v[b+112>>2]=e+1900;R(84,b+128|0,b+112|0);e=v[23220];v[23220]=0;if((e|0)!=1){v[23220]=0;i=Q(85,h|0,b+128|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break t}vb(b+128|0);f=v[c+16>>2];if(f>>>0>11){break q}v[23220]=0;e=Q(1,b+112|0,16743)|0;j=v[23220];v[23220]=0;u:{v:{w:{x:{y:{z:{if((j|0)!=1){v[23220]=0;v[b+80>>2]=f+1;R(86,b+96|0,b+80|0);f=v[23220];v[23220]=0;if((f|0)==1){break z}v[23220]=0;U(2,b+128|0,e|0,b+96|0);f=v[23220];v[23220]=0;if((f|0)==1){break y}v[23220]=0;i=Q(85,i|0,b+128|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break x}vb(b+128|0);vb(b+96|0);vb(e);if(v[c+12>>2]-32>>>0>=4294967265){break u}break q}a=P()|0;O()|0;break s}a=P()|0;O()|0;break v}a=P()|0;O()|0;break w}a=P()|0;O()|0;vb(b+128|0)}vb(b+96|0)}vb(e);break s}v[23220]=0;e=Q(1,b+96|0,16743)|0;f=v[23220];v[23220]=0;A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((f|0)!=1){v[23220]=0;R(86,b+80|0,c+12|0);f=v[23220];v[23220]=0;if((f|0)==1){break Z}v[23220]=0;U(2,b+128|0,e|0,b+80|0);f=v[23220];v[23220]=0;if((f|0)==1){break Y}v[23220]=0;i=Q(85,i|0,b+128|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break X}vb(b+128|0);vb(b+80|0);vb(e);j=v[c>>2];e=v[c+8>>2];f=v[c+4>>2];if(!(j|(e|f))|e>>>0>23|f>>>0>59){break q}v[23220]=0;e=Q(1,b+128|0,13616)|0;f=v[23220];v[23220]=0;if((f|0)==1){break U}v[23220]=0;i=Q(85,i|0,e|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break T}vb(e);if(v[c+32>>2]>0){v[23220]=0;e=Q(1,b+80|0,15533)|0;f=v[23220];v[23220]=0;if((f|0)==1){break S}Db(d,e);vb(e)}v[23220]=0;R(86,b+32|0,c+8|0);e=v[23220];v[23220]=0;if((e|0)==1){break R}v[23220]=0;e=Q(1,b+16|0,14621)|0;f=v[23220];v[23220]=0;if((f|0)==1){break Q}v[23220]=0;U(2,b+48|0,b+32|0,e|0);f=v[23220];v[23220]=0;if((f|0)==1){break P}v[23220]=0;R(86,b|0,c+4|0);f=v[23220];v[23220]=0;if((f|0)==1){break O}v[23220]=0;U(2,b- -64|0,b+48|0,b|0);f=v[23220];v[23220]=0;if((f|0)==1){break N}v[23220]=0;i=Q(85,i|0,b- -64|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break M}vb(b- -64|0);vb(b);vb(b+48|0);vb(e);vb(b+32|0);if(j>>>0<62){break H}v[23220]=0;U(87,o|0,i|0,d|0);e=v[23220];v[23220]=0;if((e|0)==1){break G}break p}a=P()|0;O()|0;break s}a=P()|0;O()|0;break V}a=P()|0;O()|0;break W}a=P()|0;O()|0;vb(b+128|0)}vb(b+80|0)}vb(e);break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;vb(e);break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;break K}a=P()|0;O()|0;break L}a=P()|0;O()|0;vb(b- -64|0)}vb(b)}vb(b+48|0)}vb(e)}vb(b+32|0);break s}v[23220]=0;e=Q(1,b+48|0,14621)|0;f=v[23220];v[23220]=0;if((f|0)==1){break F}v[23220]=0;R(86,b+32|0,c|0);f=v[23220];v[23220]=0;if((f|0)==1){break E}v[23220]=0;U(2,b- -64|0,e|0,b+32|0);f=v[23220];v[23220]=0;if((f|0)==1){break D}v[23220]=0;i=Q(85,i|0,b- -64|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break C}vb(b- -64|0);vb(b+32|0);vb(e);v[23220]=0;Q(85,i|0,d|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){break q}}a=P()|0;O()|0;break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;break A}a=P()|0;O()|0;break B}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(e);break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(b+128|0)}vb(d)}vb(h);S(a|0);L()}Mc(o,h)}vb(d);vb(h);fb=b+176|0;fb=c+144|0;v[23220]=0;R(981,a|0,o|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(g+16|0);break e}c=P()|0;O()|0;vb(g+16|0);break a}d=Qb(g+16|0,12179);h=Kg(c,d);ub(d);if(h){c=g+16|0;aP(c,v[b+24>>2]+1298332|0);_:{if(!ze(c)){break _}d=v[v[b+24>>2]+480180>>2];$:{aa:{if((d|0)==33554432){break aa}c=1;if((d|0)==32){break $}if((d|0)==16384){break aa}if((d|0)==16777216){break $}}c=2}ba:{switch(c-1|0){case 0:v[23220]=0;R(982,g|0,b|0);c=v[23220];v[23220]=0;if((c|0)!=1){xc(g+16|0,g);ub(g);break _}break b;case 1:break ba;default:break _}}if(ze(g+16|0)){v[23220]=0;R(983,g|0,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}xc(g+16|0,g);ub(g)}if(!ze(g+16|0)){break _}v[23220]=0;R(982,g|0,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}xc(g+16|0,g);ub(g)}b=v[b+24>>2];v[23220]=0;U(975,a|0,b|0,g+16|0);a=v[23220];v[23220]=0;if((a|0)!=1){ub(g+16|0);break e}break b}d=Qb(g+16|0,5433);h=Kg(c,d);ub(d);if(h){c=g+16|0;aP(c,v[b+24>>2]+1298332|0);b=v[b+24>>2];v[23220]=0;U(975,a|0,b|0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){ub(g+16|0);break e}c=P()|0;O()|0;ub(g+16|0);break a}e=c;c=Qb(g+16|0,7253);d=Kg(e,c);ub(c);if(d){a=Gb(a);q=g,r=Ab(v[b+68>>2]),v[q+16>>2]=r;b=Ab(v[b+72>>2]);c=1;while(1){d=v[g+16>>2];if(!Nb(d,b)){break e}if(!(c&1)){v[23220]=0;Q(908,a|0,21568)|0;c=v[23220];v[23220]=0;if((c|0)==1){break c}}v[23220]=0;Q(772,a|0,d|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break c}Sp(g+16|0);c=0;continue}}Qb(a,21598)}fb=g+32|0;return}c=P()|0;O()|0;vb(g+16|0);break a}c=P()|0;O()|0;ub(a);break a}c=P()|0;O()|0;ub(g+16|0)}S(c|0);L()}function nG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,D=0,E=0,F=0,G=0,H=C(0),I=0;e=fb-144|0;fb=e;d=Sb(e,0,144);v[d+76>>2]=-1;v[d+44>>2]=a;v[d+32>>2]=1085;v[d+84>>2]=a;x=c;a=0;h=fb-304|0;fb=h;a:{b:{c:{d:{if(v[d+4>>2]){break d}Ew(d);if(v[d+4>>2]){break d}break c}g=w[b|0];if(!g){break a}e:{f:{g:{h:{while(1){i:{c=g&255;j:{if(wk(c)){while(1){g=b;b=b+1|0;if(wk(w[g+1|0])){continue}break}ai(d,0,0);while(1){b=v[d+4>>2];k:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break k}b=jd(d)}if(wk(b)){continue}break}b=v[d+4>>2];c=v[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;v[d+4>>2]=b}b=b-v[d+44>>2]|0;c=b>>31;i=b;e=o+v[d+124>>2]|0;b=n+v[d+120>>2]|0;e=b>>>0<n>>>0?e+1|0:e;f=b;b=i+b|0;i=c+e|0;n=b;o=b>>>0<f>>>0?i+1|0:i;break j}l:{m:{n:{if((c|0)==37){c=w[b+1|0];if((c|0)==42){break n}if((c|0)!=37){break m}}ai(d,0,0);o:{if(w[b|0]==37){while(1){c=v[d+4>>2];p:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;g=w[c|0];break p}g=jd(d)}if(wk(g)){continue}break}b=b+1|0;break o}c=v[d+4>>2];if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;g=w[c|0];break o}g=jd(d)}if(w[b|0]!=(g|0)){b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}if((g|0)>=0){break a}f=0;if(y){break a}break c}c=v[d+4>>2]-v[d+44>>2]|0;g=c>>31;f=c;c=o+v[d+124>>2]|0;e=n+v[d+120>>2]|0;c=e>>>0<n>>>0?c+1|0:c;i=e;e=f+e|0;f=c+g|0;n=e;o=e>>>0<i>>>0?f+1|0:f;g=b;break j}l=0;b=b+2|0;break l}if(!(!Jj(c)|w[b+2|0]!=36)){e=fb-16|0;v[e+12>>2]=x;c=c-48|0;c=(c>>>0>1?(c<<2)-4|0:0)+x|0;v[e+8>>2]=c+4;l=v[c>>2];b=b+3|0;break l}l=v[x>>2];x=x+4|0;b=b+1|0}c=0;while(1){e=w[b|0];if(Jj(e)){b=b+1|0;c=(B(c,10)+e|0)-48|0;continue}break}r=0;if((e|0)==109){m=0;r=(l|0)!=0;e=w[b+1|0];b=b+1|0;a=0}g=b+1|0;k=3;f=r;q:{r:{switch((e&255)-65|0){case 39:e=b+2|0;b=w[b+1|0]==104;g=b?e:g;k=b?-2:-1;break q;case 43:e=b+2|0;b=w[b+1|0]==108;g=b?e:g;k=b?3:1;break q;case 51:case 57:k=1;break q;case 11:k=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break e}}k=0;g=b}b=w[g|0];e=(b&47)==3;D=e?1:k;p=e?b|32:b;s:{if((p|0)==91){break s}t:{if((p|0)!=110){if((p|0)!=99){break t}c=(c|0)>1?c:1;break s}oG(l,D,n,o);break j}ai(d,0,0);while(1){b=v[d+4>>2];u:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break u}b=jd(d)}if(wk(b)){continue}break}b=v[d+4>>2];e=v[d+116>>2];if((e|0)>0|(e|0)>=0){b=b-1|0;v[d+4>>2]=b}b=b-v[d+44>>2]|0;f=b>>31;j=b;e=o+v[d+124>>2]|0;b=n+v[d+120>>2]|0;e=b>>>0<n>>>0?e+1|0:e;i=b;b=j+b|0;o=e+f|0;o=b>>>0<i>>>0?o+1|0:o;n=b}j=c;s=c>>31;ai(d,c,s);b=v[d+4>>2];v:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;break v}if((jd(d)|0)<0){break f}}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}b=16;w:{x:{y:{z:{A:{switch(p-88|0){default:b=p-65|0;if(b>>>0>6|!(1<<b&113)){break w}case 9:case 13:case 14:case 15:qG(h+8|0,d,D,0);b=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]!=(0-b|0)|v[d+124>>2]!=(0-((b>>31)+((b|0)!=0)|0)|0)){break y}break g;case 3:case 11:case 27:if((p&239)==99){Sb(h+32|0,-1,257);t[h+32|0]=0;if((p|0)!=115){break x}t[h+65|0]=0;t[h+46|0]=0;u[h+42>>1]=0;u[h+44>>1]=0;break x}e=w[g+1|0];f=(e|0)==94;Sb(h+32|0,f,257);t[h+32|0]=0;b=f?g+2|0:g+1|0;B:{C:{D:{g=w[(f?2:1)+g|0];if((g|0)!=45){if((g|0)==93){break D}k=(e|0)!=94;break B}k=(e|0)!=94;t[h+78|0]=k;break C}k=(e|0)!=94;t[h+126|0]=k}b=b+1|0}g=b;while(1){e=w[g|0];E:{if((e|0)!=45){if(!e){break f}if((e|0)!=93){break E}break x}e=45;f=w[g+1|0];if(!f|(f|0)==93){break E}i=g+1|0;b=w[g-1|0];F:{if(f>>>0<=b>>>0){e=f;break F}while(1){b=b+1|0;t[b+(h+32|0)|0]=k;e=w[i|0];if(e>>>0>b>>>0){continue}break}}g=i}t[(e+h|0)+33|0]=k;g=g+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}b=0}j=0;i=0;e=0;f=0;s=0;E=fb-16|0;fb=E;G:{if((b|0)==1){v[115696]=28;break G}while(1){c=v[d+4>>2];H:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break H}c=jd(d)}if(wk(c)){continue}break}I:{J:{switch(c-43|0){case 0:case 2:break J;default:break I}}s=(c|0)==45?-1:0;c=v[d+4>>2];if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break I}c=jd(d)}K:{L:{M:{N:{if(!(b&-17|(c|0)!=48)){c=v[d+4>>2];O:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break O}c=jd(d)}if((c&-33)==88){b=16;c=v[d+4>>2];P:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break P}c=jd(d)}if(w[c+78273|0]<16){break M}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}ai(d,0,0);break G}if(b){break N}b=8;break M}b=b?b:10;if(b>>>0>w[c+78273|0]){break N}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}ai(d,0,0);v[115696]=28;break G}if((b|0)!=10){break M}e=c-48|0;if(e>>>0<=9){b=0;while(1){b=B(b,10)+e|0;f=b>>>0<429496729;c=v[d+4>>2];Q:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break Q}c=jd(d)}e=c-48|0;if(f&e>>>0<=9){continue}break}j=b}R:{if(e>>>0>9){break R}k=Bia(j,0,10,0);f=ib;b=e;while(1){c=v[d+4>>2];S:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break S}c=jd(d)}e=c-48|0;q=e>>>0>9;j=b+k|0;i=j>>>0<b>>>0?f+1|0:f;if((i|0)==429496729&j>>>0>=2576980378|i>>>0>429496729|q){break R}k=Bia(j,i,10,0);f=ib;b=e;if((f|0)==-1&k>>>0<=(b^-1)>>>0|(f|0)!=-1){continue}break}b=10;break L}b=10;if(e>>>0<=9){break L}break K}if(b-1&b){f=w[c+78273|0];if(f>>>0<b>>>0){while(1){e=B(b,e)+f|0;j=e>>>0<119304647;c=v[d+4>>2];T:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break T}c=jd(d)}f=w[c+78273|0];if(j&f>>>0<b>>>0){continue}break}j=e}if(b>>>0<=f>>>0){break L}while(1){k=Bia(j,i,b,0);e=ib;f=f&255;if((e|0)==-1&(f^-1)>>>0<k>>>0){break L}c=f+k|0;e=c>>>0<f>>>0?e+1|0:e;j=c;i=e;c=v[d+4>>2];U:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break U}c=jd(d)}f=w[c+78273|0];if(b>>>0<=f>>>0){break L}gf(E,b,0,0,0,j,i,0,0);if(!(v[E+8>>2]|v[E+12>>2])){continue}break}break L}k=t[(B(b,23)>>>5&7)+78529|0];e=w[c+78273|0];if(e>>>0<b>>>0){while(1){f=f<<k|e;j=f>>>0<134217728;c=v[d+4>>2];V:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break V}c=jd(d)}e=w[c+78273|0];if(j&e>>>0<b>>>0){continue}break}j=f}if(b>>>0<=e>>>0){break L}f=k;q=f&31;if((f&63)>>>0>=32){f=0;q=-1>>>q|0}else{f=-1>>>q|0;q=f|(1<<q)-1<<32-q}if(!f&j>>>0>q>>>0){break L}while(1){c=k&31;F=e&255;if((k&63)>>>0>=32){e=j<<c;c=0}else{e=(1<<c)-1&j>>>32-c|i<<c;c=j<<c}j=F|c;i=e;c=v[d+4>>2];W:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break W}c=jd(d)}e=w[c+78273|0];if(b>>>0<=e>>>0){break L}if((f|0)==(i|0)&j>>>0<=q>>>0|f>>>0>i>>>0){continue}break}}if(w[c+78273|0]>=b>>>0){break K}while(1){c=v[d+4>>2];X:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break X}c=jd(d)}if(w[c+78273|0]<b>>>0){continue}break}v[115696]=68;j=-1;i=-1;s=0}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}b=s;c=b^j;j=c-b|0;e=b>>31;i=(e^i)-((b>>>0>c>>>0)+e|0)|0}fb=E+16|0;b=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]==(0-b|0)&v[d+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break g}if(!(!l|(p|0)!=112)){v[l>>2]=j;break w}oG(l,D,j,i);break w}if(!l){break w}b=v[h+16>>2];c=v[h+20>>2];e=v[h+8>>2];f=v[h+12>>2];Y:{switch(D|0){case 0:G=l,H=yF(e,f,b,c),z[G>>2]=H;break w;case 1:G=l,I=Ww(e,f,b,c),A[G>>3]=I;break w;case 2:break Y;default:break w}}v[l>>2]=e;v[l+4>>2]=f;v[l+8>>2]=b;v[l+12>>2]=c;break w}i=(p|0)==99;c=i?c+1|0:31;Z:{if((D|0)==1){e=l;if(r){e=Fd(c<<2);if(!e){break h}}v[h+296>>2]=0;v[h+300>>2]=0;b=0;while(1){a=e;_:{while(1){e=v[d+4>>2];$:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break $}e=jd(d)}if(!w[(e+h|0)+33|0]){break _}t[h+27|0]=e;e=yr(h+28|0,h+27|0,1,h+296|0);if((e|0)==-2){continue}m=0;if((e|0)==-1){break f}if(a){v[(b<<2)+a>>2]=v[h+28>>2];b=b+1|0}if(!((b|0)==(c|0)&r)){continue}break}f=1;b=c;c=b<<1|1;e=Pr(a,c<<2);if(e){continue}break e}break}m=0;c=a;if(h+296|0?v[h+296>>2]:0){break f}break Z}if(r){b=0;e=Fd(c);if(!e){break h}while(1){m=e;while(1){a=v[d+4>>2];aa:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break aa}a=jd(d)}if(!w[(a+h|0)+33|0]){c=0;a=m;break Z}t[b+m|0]=a;b=b+1|0;if((c|0)!=(b|0)){continue}break}f=1;a=0;b=c;c=b<<1|1;e=Pr(m,c);if(e){continue}break}break e}b=0;if(l){while(1){a=v[d+4>>2];ba:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break ba}a=jd(d)}if(w[(a+h|0)+33|0]){t[b+l|0]=a;b=b+1|0;continue}else{c=0;a=l;m=a;break Z}}}while(1){a=v[d+4>>2];ca:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break ca}a=jd(d)}if(w[(a+h|0)+33|0]){continue}break}a=0;m=0;c=0}e=v[d+4>>2];f=v[d+116>>2];if((f|0)>0|(f|0)>=0){e=e-1|0;v[d+4>>2]=e}f=e-v[d+44>>2]|0;k=f;e=f+v[d+120>>2]|0;f=v[d+124>>2]+(f>>31)|0;f=e>>>0<k>>>0?f+1|0:f;if(!(f|e)|((e|0)!=(j|0)|(f|0)!=(s|0))&(p|0)==99){break i}if(r){v[l>>2]=a}da:{if(i){break da}if(c){v[(b<<2)+c>>2]=0}if(!m){m=0;break da}t[b+m|0]=0}a=c}b=v[d+4>>2]-v[d+44>>2]|0;e=b>>31;i=b;c=o+v[d+124>>2]|0;b=n+v[d+120>>2]|0;c=b>>>0<n>>>0?c+1|0:c;f=b;b=i+b|0;e=c+e|0;n=b;o=b>>>0<f>>>0?e+1|0:e;y=((l|0)!=0)+y|0}b=g+1|0;g=w[g+1|0];if(g){continue}break a}break}a=c;break g}f=1;m=0;a=0;break e}f=r;break b}f=r}if(y){break b}}y=-1}if(!f){break a}Fb(m);Fb(a)}fb=h+304|0;fb=d+144|0;return y}function Q8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=fb-784|0;fb=d;wc(b);a:{b:{c:{d:{e:{f:{if(!Xh(b,d+776|0)){break f}if(!rL(v[d+776>>2],v[d+780>>2])){break f}if(!sA(b,d+768|0)){break f}f=v[d+768>>2];if(!qL(f)){break f}h=1313423693;if((f|0)!=1179012417){h=1414090313;if((f|0)!=538987841){break f}}m=fe(d+744|0,b);j=Ib(d+728|0);g:{h:{i:{j:{k:{l:{m:{if(!c){v[23220]=0;X(823,d+136|0,m|0,((f|0)==1179012417?1:2)|0,h|0);b=v[23220];v[23220]=0;if((b|0)!=1){break m}a=P()|0;O()|0;break a}v[23220]=0;U(824,d+136|0,m|0,((f|0)==1179012417?1:2)|0);b=v[23220];v[23220]=0;if((b|0)==1){break l}}b=d+136|0;wt(j,b);Vd(b);v[23220]=0;U(825,d+704|0,j|0,h|0);b=v[23220];v[23220]=0;if((b|0)!=1){v[23220]=0;b=T(165,v[d+704>>2])|0;e=v[23220];v[23220]=0;if((e|0)==1){break k}e=0;if(!b){break g}v[23220]=0;b=Q(826,d+704|0,d+624|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break k}if(!b){break g}b=w[d+689|0];if(!b){break g}v[23220]=0;e=W(143,v[d+704>>2],v[d+712>>2],b|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break k}if(!c|e^1){break g}v[23220]=0;R(236,a|0,8388608);b=v[23220];v[23220]=0;if((b|0)==1){break k}v[a+480208>>2]=w[d+688|0]<<4&16^28;u[d+136>>1]=w[d+689|0];u[d+496>>1]=127;p=a,q=x[Tc(d+136|0,d+496|0)>>1],u[p+480188>>1]=q;v[a+480196>>2]=w[d+690|0];v[a+480204>>2]=B(w[d+691|0],1e4);v[a+480200>>2]=w[d+696|0]<<1;v[23220]=0;Q(123,a+1298344|0,((f|0)==1179012417?16914:16880)|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break k}v[23220]=0;b=Q(1,d+608|0,13233)|0;e=v[23220];v[23220]=0;if((e|0)==1){break i}Db(a+1298356|0,b);vb(b);v[a+1298404>>2]=5;b=d+496|0;Uz(b,2,d+624|0);v[23220]=0;R(209,d+136|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break j}l=(f|0)!=1179012417;b=d+136|0;xc(a+1298308|0,b);ub(b);k=(f|0)==1179012417;b=0;while(1){n:{o:{p:{if(x[a+480188>>1]<=b>>>0){b=Ab(v[j>>2]);h=Ab(v[j+4>>2]);e=fb-16|0;fb=e;v[e+8>>2]=b;while(1){q:{if(!Nb(b,h)){break q}if(RT(1380209231,v[b>>2],v[b+4>>2])){break q}b=v[jm(e+8|0)>>2];continue}break}fb=e+16|0;if(Nb(b,Ab(v[j+4>>2]))){break p}break h}h=(b<<5)+a|0;g=h+480280|0;Pe(g);v[23220]=0;e=T(193,d+704|0)|0;n=v[23220];v[23220]=0;r:{s:{if((n|0)!=1){if(k){break r}if(e>>>0<129){break s}break o}a=P()|0;O()|0;break b}u[h+480284>>1]=e<<1;break n}if(e<<24>>24<0){break o}v[d+136>>2]=e<<2;v[d+496>>2]=256;p=h+480284|0,q=v[nd(d+136|0,d+496|0)>>2],u[p>>1]=q;break n}v[23220]=0;U(825,d+136|0,j|0,1380209231);b=v[23220];v[23220]=0;t:{if((b|0)!=1){v[23220]=0;b=T(193,d+136|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break t}e=w[a+484376|0];h=v[a+484360>>2];v[23220]=0;da(333,Vb(h,e)|0,d+136|0,b+1&255,255,254);b=v[23220];v[23220]=0;if((b|0)==1){break t}wb(d+136|0);break h}a=P()|0;O()|0;break b}a=P()|0;O()|0;wb(d+136|0);break b}v[g>>2]=1024}b=b+1|0;continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}u:{if(!(c&1)){break u}u[d+56>>1]=0;v[23220]=0;U(827,d+560|0,j|0,1414807888);b=v[23220];v[23220]=0;if((b|0)==1){break c}b=v[d+564>>2];e=v[d+560>>2];v[23220]=0;h=a+484344|0;R(212,h|0,Bf(e,b)&65535);b=v[23220];v[23220]=0;v:{if((b|0)!=1){p=d,q=Ab(v[d+560>>2]),v[p+88>>2]=q;k=Ab(v[d+564>>2]);w:{x:{y:{z:{A:{while(1){b=v[d+88>>2];if(!Nb(b,k)){b=0;break w}b=fe(d+136|0,b);v[23220]=0;e=T(193,b|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){v[23220]=0;u[d+480>>1]=e;e=T(144,b|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break A}v[23220]=0;U(177,d+496|0,b|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){break z}e=gc(d+584|0,d+496|0);v[23220]=0;g=v[e+12>>2];v[d+8>>2]=v[e+8>>2];v[d+12>>2]=g;v[d+16>>2]=v[e+16>>2];g=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=g;X(828,d|0,x[d+480>>1],l|0,a|0);e=v[23220];v[23220]=0;if((e|0)==1){break y}wb(d+496|0);p=d,q=x[Re(d+56|0,d+480|0)>>1],u[p+56>>1]=q;wb(b);rh(d+88|0);continue}break}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;wb(d+496|0)}wb(b);break v}while(1){e=b&65535;if(e>>>0>=x[d+56>>1]){fd(d+560|0);break u}B:{if(!ke(v[h>>2],v[h+4>>2],e)){v[23220]=0;W(213,h|0,e|0,64)|0;e=v[23220];v[23220]=0;if((e|0)==1){break B}}b=b+1|0;continue}break}a=P()|0;O()|0;break v}a=P()|0;O()|0}fd(d+560|0);break b}C:{if((f|0)==1179012417){v[23220]=0;U(827,d+88|0,j|0,1414745673);b=v[23220];v[23220]=0;if((b|0)==1){break d}p=d,q=Ab(v[d+88>>2]),v[p+120>>2]=q;e=c&2;h=d+504|0;l=Ab(v[d+92>>2]);k=a+480190|0;while(1){b=v[d+120>>2];if(!Nb(b,l)){fd(d+88|0);break C}c=fe(d+560|0,b);v[23220]=0;b=Q(829,c|0,d+136|0)|0;f=v[23220];v[23220]=0;if((f|0)!=1){D:{if(!b){break D}b=w[d+137|0];if((b|0)==255){break D}v[23220]=0;f=W(241,a|0,b+1|0,0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break e}if(!f){break D}g=x[a+480190>>1];b=0;v[23220]=0;U(830,d+136|0,f|0,g|0);f=v[23220];v[23220]=0;if((f|0)==1){break e}while(1){if(w[d+166|0]<=b>>>0){break D}E:{if(!Ph(x[k>>1])){break E}v[23220]=0;f=Q(831,c|0,d+496|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break e}if(!f){break E}f=x[a+480190>>1]+1|0;u[a+480190>>1]=f;if(v[d+496>>2]!=1347240275){break E}g=d+480|0;$k(g,2,h);v[23220]=0;R(209,d+56|0,g|0);g=v[23220];v[23220]=0;F:{if((g|0)!=1){f=f&65535;g=d+56|0;yc(((f<<5)+a|0)+946304|0,g);ub(g);v[23220]=0;f=(B(f,104)+a|0)+484380|0;U(832,d+496|0,d+136|0,f|0);g=v[23220];v[23220]=0;if((g|0)==1){break e}if(!e){break F}g=d+56|0;pL(g,x[d+534>>1]);v[23220]=0;W(206,g|0,f|0,c|0)|0;f=v[23220];v[23220]=0;if((f|0)!=1){break E}break e}break e}g=x[f+34>>1];f=v[f>>2];v[23220]=0;Q(175,c|0,sj(f,g)|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break e}}b=b+1|0;continue}}wb(c);rh(d+120|0);continue}break}break e}v[23220]=0;U(827,d+480|0,j|0,1179011410);b=v[23220];v[23220]=0;if((b|0)!=1){p=d,q=Ab(v[d+480>>2]),v[p+472>>2]=q;h=c&2;l=d+496|4;k=Ab(v[d+484>>2]);g=a+480190|0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{while(1){b=v[d+472>>2];if(!Nb(b,k)){fd(d+480|0);break C}c=fe(d+560|0,b);v[23220]=0;b=T(144,c|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break P}Q:{R:{if((b|0)!=538986817){break R}v[23220]=0;b=Q(833,c|0,d+464|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break O}if(!(b&v[d+464>>2]==1414745673)){break R}v[23220]=0;b=Q(834,c|0,d+136|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break N}if(!b){break R}b=w[d+141|0];if((b|0)==255){break R}v[23220]=0;b=W(241,a|0,b+1|0,0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break M}if(!b){break R}f=x[a+480190>>1];v[23220]=0;U(835,d+136|0,b|0,f|0);b=v[23220];v[23220]=0;if((b|0)==1){break M}v[23220]=0;U(824,d+496|0,c|0,2);b=v[23220];v[23220]=0;if((b|0)==1){break Q}v[23220]=0;U(827,d+120|0,d+496|0,1179011410);b=v[23220];v[23220]=0;if((b|0)==1){break L}Vd(d+496|0);p=d,q=Ab(v[d+120>>2]),v[p+112>>2]=q;n=Ab(v[d+124>>2]);S:{T:{while(1){b=v[d+112>>2];if(!Nb(b,n)){break S}b=fe(d+88|0,b);v[23220]=0;f=T(144,b|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break K}U:{V:{if((f|0)!=538989377){break V}f=x[g>>1];if(!Ph(f)){break V}e=x[d+460>>1];u[d+460>>1]=e-1;if(!e){wb(b);break S}i=f+1|0;u[a+480190>>1]=i;v[23220]=0;f=Q(833,b|0,d+80|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break J}if(!(f&v[d+80>>2]==1347240275)){break T}v[23220]=0;U(177,d+496|0,b|0,v[d+84>>2]);f=v[23220];v[23220]=0;W:{if((f|0)!=1){e=d+496|0;f=gc(d+56|0,e);wb(e);v[23220]=0;e=Q(836,f|0,e|0)|0;o=v[23220];v[23220]=0;if((o|0)==1){break U}if(e){break W}wb(f);wb(b);break S}a=P()|0;O()|0;break H}e=d+24|0;Ue(e,2,l);v[23220]=0;R(209,d+40|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){break I}e=i&65535;i=d+40|0;yc(((e<<5)+a|0)+946304|0,i);ub(i);v[23220]=0;e=(B(e,104)+a|0)+484380|0;U(837,d+496|0,d+136|0,e|0);i=v[23220];v[23220]=0;if((i|0)==1){break U}X:{if(!h){break X}v[23220]=0;Q(142,f|0,v[d+496>>2]+4|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break U}i=d+40|0;pL(i,x[d+536>>1]);v[23220]=0;W(206,i|0,e|0,f|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){break X}break I}wb(f)}wb(b);rh(d+112|0);continue}break}break I}wb(b)}fd(d+120|0)}wb(c);rh(d+472|0);continue}break}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;Vd(d+496|0);break G}a=P()|0;O()|0;break H}a=P()|0;O()|0;break H}a=P()|0;O()|0;wb(f)}wb(b);fd(d+120|0)}wb(c);fd(d+480|0);break b}a=P()|0;O()|0;break b}e=1}wb(d+704|0);Vd(j);wb(m)}fb=d+784|0;return e|0}a=P()|0;O()|0;wb(c);fd(d+88|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0}wb(d+704|0)}Vd(j);wb(m);S(a|0);L()}function lda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;l=fb-208|0;fb=l;if(!ot(a)){e=l+48|0;nc(e,a,128);f=l+176|0;_e(f,e,128,2);e=l+192|0;Ac(e,f);yc(b+492|0,e);ub(e)}u[c+34>>1]=x[c+34>>1]&65489;i=l+192|0;f=fb-32|0;fb=f;a:{b:{switch(w[a+128|0]-4|0){default:v[f+28>>2]=0;Tn(i,0,f+28|0);break a;case 0:case 4:break b}}t[f+28|0]=w[a+129|0];t[f+24|0]=100;e=f+24|0;k=w[Rb(f+28|0,e)|0];t[f+24|0]=w[a+130|0];t[f+20|0]=100;e=w[Rb(e,f+20|0)|0];v[f+28>>2]=e;c:{if(w[a+140|0]&16){h=Jb(w[a+150|0]|w[a+151|0]<<8);o=Jb(w[a+152|0]|w[a+153|0]<<8);j=v[c>>2];r=+(j>>>0)/6553600;k=bq(r*+((h|k<<16)>>>0));v[f+24>>2]=j-k;s=f,y=bq(r*+((o|e<<16)>>>0)),v[s+20>>2]=y;s=f,y=v[Eb(f+24|0,f+20|0)>>2],v[s+28>>2]=y;break c}h=v[c>>2];o=v[c+20>>2];if(!Md(h,o)){break c}j=h>>>7|0;k=B(j,(k<<7>>>0)/100|0);v[f+24>>2]=h-k;v[f+20>>2]=B(j,(e<<7>>>0)/100|0);e=v[Eb(f+24|0,f+20|0)>>2];j=x[c+34>>1];h=B(Cd(j),h);d:{if(j&1){ec(f+8|0,o,h);o=v[f+8>>2];j=Cd(x[c+34>>1]);h=o+(B(j,e+k|0)<<1)|0;n=u[o+(B(k,j)<<1)>>1];j=0-j<<1;while(1){e:{f:{if(e){p=u[h>>1]-n|0;o=p>>31;if((o^p)-o>>>0>=1536){break f}}else{e=0}break e}e=e-1|0;h=h+j|0;continue}break}break d}ec(f,o,h);o=v[f>>2];j=Cd(x[c+34>>1]);n=0-j|0;h=o+B(j,e+k|0)|0;j=t[o+B(k,j)|0];while(1){g:{h:{if(e){p=t[h|0]-j|0;o=p>>31;if((o^p)-o>>>0>=6){break h}}else{e=0}break g}e=e-1|0;h=h+n|0;continue}break}}v[f+28>>2]=e}Tn(i,k,f+28|0)}fb=f+32|0;o=fc(i);if(!(!v[o>>2]|w[a+128|0]!=4)){u[c+34>>1]=x[c+34>>1]|2;e=v[l+192>>2];v[c+4>>2]=e;v[c+8>>2]=e+v[o>>2]}e=w[a+134|0];if((e-1&255)>>>0<=198){t[l+48|0]=e;t[l+176|0]=100;e=(w[Rb(l+48|0,l+176|0)|0]<<7>>>0)/100|0}else{e=128}t[l+47|0]=e;t[l+48|0]=64;e=l+47|0;f=l+48|0;s=c,y=w[$e(e,f)|0]>>>1|0,u[s+32>>1]=y;t[l+48|0]=64;s=b,y=w[Rb(e,f)|0],v[s+4>>2]=y;v[c+24>>2]=40460;aq(c,+t[a+139|0]/12+ +(0-w[a+143|0]|0)+ +t[a+138|0]/1536);t[b+34|0]=w[a+142|0]&2?2:1;if(w[a+142|0]&2){um(b,127,1);tm(b,0,1)}i:{if(!Md(v[c>>2],v[c+20>>2])){break i}b=w[a+140|0];if(b&1){b=v[c>>2];e=v[c+20>>2];j:{if(!Md(b,e)|b>>>0<2){break j}k:{l:{switch(ik(x[c+34>>1])-1|0){case 3:f=0;i=b>>>1|0;while(1){if((f|0)!=(i|0)){kc(e+(f<<2)|0,e+(b+(f^-1)<<2)|0);f=f+1|0;continue}break};break k;case 1:f=0;i=b>>>1|0;while(1){if((f|0)!=(i|0)){ay(e+(f<<1)|0,e+(b+(f^-1)<<1)|0);f=f+1|0;continue}break};break k;case 0:break l;default:break j}}f=0;i=b>>>1|0;while(1){if((f|0)!=(i|0)){Wg(e+f|0,e+(b+(f^-1)|0)|0);f=f+1|0;continue}break}}ij(c,d)}b=w[a+140|0]}if(b&4){m:{e=v[c>>2];b=v[c+20>>2];if(!Md(e,b)){break m}f=x[c+34>>1];e=B(Cd(f),e);n:{o:{switch(ym(f)-1|0){case 1:f=0;while(1){if((e|0)!=(f|0)){i=b+(f<<1)|0;u[i>>1]=x[i>>1]^-1;f=f+1|0;continue}break};break n;case 0:break o;default:break m}}f=0;while(1){if((e|0)!=(f|0)){i=b+f|0;t[i|0]=w[i|0]^-1;f=f+1|0;continue}break}}ij(c,d)}}g=w[a+170|0]!=2|w[a+171|0]>100?g:w[a+172|0]<101;b=x[c+34>>1];if(!(!(w[a+141|0]?1:g|w[a+160|0]!=0)|b&1)){e=nt(v[c>>2],Cd(b)<<1&254);if(!e){break i}b=e;i=v[c>>2];h=x[c+34>>1];k=B(Cd(h),i);f=v[c+20>>2];h=sj(i,h);i=fb-16|0;fb=i;v[i+12>>2]=k;uc(i+12|0,h);h=v[i+12>>2];while(1){if(h){u[b>>1]=t[f|0]<<8;f=f+1|0;b=b+2|0;h=h-1|0;continue}break}fb=i+16|0;u[c+34>>1]=x[c+34>>1]|1;DP(c,e,v[c>>2],d)}p:{if(t[a+141|0]>=0){break p}ec(l+48|0,v[c+20>>2],B(v[c>>2],Cd(x[c+34>>1])));f=v[l+52>>2];e=v[l+48>>2];q:while(1){if((0-t[a+141|0]|0)<=(m|0)){break p}k=u[e>>1];i=ac(e,f);b=e;while(1)if((b|0)==(i|0)){m=m+1|0;continue q}else{k=dd(u[b>>1]-dd(k,1)|0,1);u[b>>1]=k;b=b+2|0;continue}}}r:{if(!g){break r}ec(l+48|0,v[c+20>>2],B(v[c>>2],Cd(x[c+34>>1])));g=v[l+52>>2];b=(g|0)/2|0;m=b>>31;n=b;b=w[a+172|0];i=w[a+171|0];e=i;f=0-(b>>>0<e>>>0)|0;b=b-e|0;h=b<<24;e=n+h|0;b=(f<<24|b>>>8)+m|0;b=Dc(Cia(e,e>>>0<h>>>0?b+1|0:b,g,g>>31),ib);f=b;k=f>>31;b=i<<24;m=b;e=b>>31;b=v[l+48>>2];i=ac(b,g);while(1){if((b|0)==(i|0)){break r}g=u[b>>1];g=Bia(m,e,g,g>>31)+838860800|0;h=ib;s=b,y=Dc(Cia(g,g>>>0<838860800?h+1|0:h,1677721600,0),ib),u[s>>1]=y;b=b+2|0;e=e+k|0;g=f+m|0;e=g>>>0<f>>>0?e+1|0:e;m=g;continue}}s:{if(!w[a+160|0]){break s}ec(l+176|0,v[c+20>>2],B(v[c>>2],Cd(x[c+34>>1])));b=w[a+163|0];m=w[a+162|0];k=0;e=v[l+180>>2];f=0;h=0;if(w[a+161|0]>=2){g=(e|0)/2|0;f=g>>31;i=f;f=w[a+164|0];h=0-(m>>>0>f>>>0)|0;f=f-m|0;n=f<<23;j=n+g|0;f=(h<<23|f>>>9)+i|0;f=j>>>0<n>>>0?f+1|0:f;n=e>>31;f=Dc(Cia(j,f,e,n),ib);h=w[a+165|0];p=0-(b>>>0>h>>>0)|0;j=h-b|0;h=p<<23|j>>>9;j=g+(j<<23)|0;i=h+i|0;h=Dc(Cia(j,g>>>0>j>>>0?i+1|0:i,e,n),ib)}g=b<<23;m=m<<23;i=(l+48|0)+((w[a+160|0]&2)<<2)|0;b=v[l+176>>2];j=ac(b,e);e=0;while(1){if((b|0)==(j|0)){break s}n=(u[b>>1]>>1)-e|0;v[l+56>>2]=n;p=n;n=(m|0)/8388608|0;k=dd(B(p,n),8)+k|0;v[l+52>>2]=k;e=dd(B(k,n),6)+e|0;e=dd(dd(B(e,(g|0)/8388608|0),6)+e|0,2);v[l+48>>2]=e;s=b,y=Rc(v[i>>2]),u[s>>1]=y;b=b+2|0;g=h+g|0;m=f+m|0;continue}}t:{if(t[a+141|0]<=0){break t}ec(l+48|0,v[c+20>>2],B(v[c>>2],Cd(x[c+34>>1])));m=0;f=v[l+52>>2];e=v[l+48>>2];u:while(1){if(t[a+141|0]<=(m|0)){break t}k=u[e>>1];g=ac(e,f);b=e;while(1)if((b|0)==(g|0)){m=m+1|0;continue u}else{k=((u[b>>1]<<1)+k|0)/3|0;u[b>>1]=k;b=b+2|0;continue}}}b=v[c+20>>2];f=x[c+34>>1];e=B(v[c>>2],Cd(f));v:{if(f&1){ec(l+32|0,b,e);h=fb-16|0;fb=h;b=v[l+32>>2];k=ac(b,v[l+36>>2]);j=fb-16|0;fb=j;v[j+12>>2]=b;q=h+8|0;f=Tn(q,b,j+12|0);w:{if((b|0)==(k|0)){break w}e=b+2|0;if((k|0)==(e|0)){break w}s=(Vj(x[e>>1],x[v[f>>2]>>1])?0:4)+f|0,y=e,v[s>>2]=y;m=f+4|0;while(1){i=e;g=e+2|0;if((k|0)!=(g|0)){e=i+4|0;if((k|0)==(e|0)){v[j+12>>2]=k;e=x[i+2>>1];if(!Vj(e,x[v[f>>2]>>1])){f=m;if(Vj(e,x[v[f>>2]>>1])){break w}}v[f>>2]=g;break w}n=x[v[f>>2]>>1];p=x[e>>1];i=x[i+2>>1];x:{if(Vj(p,i)){if(Vj(p,n)){v[f>>2]=e}if(Vj(i,x[v[m>>2]>>1])){continue}break x}if(Vj(i,n)){v[f>>2]=g}g=e;if(Vj(p,x[v[m>>2]>>1])){continue}}v[m>>2]=g;continue}break}v[j+12>>2]=i}fb=j+16|0;v[h+4>>2]=0-u[v[h+8>>2]>>1];s=h,y=u[v[fc(q)>>2]>>1],v[s>>2]=y;y:{e=v[Ke(h+4|0,h)>>2];if((e|0)>32766|!e){break y}while(1){if((b|0)==(k|0)){break y}u[b>>1]=(B(u[b>>1],32767)|0)/(e|0);b=b+2|0;continue}}break v}ec(l+24|0,b,e);h=fb-16|0;fb=h;b=v[l+24>>2];k=Hb(b,v[l+28>>2]);j=fb-16|0;fb=j;v[j+12>>2]=b;q=h+8|0;f=Tn(q,b,j+12|0);z:{if((b|0)==(k|0)){break z}e=b+1|0;if((k|0)==(e|0)){break z}s=(Vk(w[e|0],w[v[f>>2]])?0:4)+f|0,y=e,v[s>>2]=y;m=f+4|0;while(1){i=e;g=e+1|0;if((k|0)!=(g|0)){e=i+2|0;if((k|0)==(e|0)){v[j+12>>2]=k;e=w[i+1|0];if(!Vk(e,w[v[f>>2]])){f=m;if(Vk(e,w[v[f>>2]])){break z}}v[f>>2]=g;break z}n=w[v[f>>2]];p=w[e|0];i=w[i+1|0];A:{if(Vk(p,i)){if(Vk(p,n)){v[f>>2]=e}if(Vk(i,w[v[m>>2]])){continue}break A}if(Vk(i,n)){v[f>>2]=g}g=e;if(Vk(p,w[v[m>>2]])){continue}}v[m>>2]=g;continue}break}v[j+12>>2]=i}fb=j+16|0;v[h+4>>2]=0-t[v[h+8>>2]];s=h,y=t[v[fc(q)>>2]],v[s>>2]=y;B:{e=v[Ke(h+4|0,h)>>2];if((e|0)>126|!e){break B}while(1){if((b|0)==(k|0)){break B}t[b|0]=(B(t[b|0],127)|0)/(e|0);b=b+1|0;continue}}}fb=h+16|0;C:{if((w[a+134|0]-101&255)>>>0>98){break C}f=x[c+34>>1];e=B(v[c>>2],Cd(f));b=v[c+20>>2];if(f&1){g=l+16|0;v[g>>2]=b;v[g+4>>2]=(b+(e<<1)|0)-b>>1;b=(3276800-(w[a+134|0]<<14)|0)/100|0;m=0-b|0;f=32768-b|0;e=v[g>>2];i=ac(e,v[g+4>>2]);while(1){if((e|0)!=(i|0)){g=u[e>>1];D:{if((g|0)>(b|0)){n=f+((B(b,g-b|0)|0)/(f|0)|0)|0;break D}n=((B(b,b+g|0)|0)/(f|0)|0)-f|0;if((g|0)<(m|0)){break D}n=(B(f,g)|0)/(b|0)|0}s=e,y=Rc(n),u[s>>1]=y;e=e+2|0;continue}break}break C}g=_m(l+8|0,b,b+e|0);e=v[g>>2];b=(3276800-(w[a+134|0]<<14)|0)/100|0;m=0-b|0;f=32768-b|0;i=Hb(e,v[g+4>>2]);while(1){if((e|0)!=(i|0)){g=t[e|0]<<8;E:{if((g|0)>(b|0)){n=f+((B(b,g-b|0)|0)/(f|0)|0)|0;break E}n=((B(b,b+g|0)|0)/(f|0)|0)-f|0;if((g|0)<(m|0)){break E}n=(B(f,g)|0)/(b|0)|0}s=e,y=DR((n|0)/256|0),t[s|0]=y;e=e+1|0;continue}break}}CP(c);if(w[a+128|0]!=8){break i}b=w[a+131|0];if(!b){break i}e=v[o>>2];if(!e){break i}s=zb(c+68|0,0),y=v[l+192>>2]+B(e,b+1|0)|0,v[s>>2]=y;b=v[l+192>>2];v[c+12>>2]=b;v[c+16>>2]=b+v[o>>2];m=v[o>>2];g=w[a+131|0];if(m>>>0>268435456/(g>>>0)>>>0){break i}f=v[c>>2];e=B(g,m);if(f>>>0>268435456-e>>>0){break i}f=e+f|0;e=ik(x[c+34>>1]);h=nt(f,e);if(!h){break i}i=b+B(m,g+1|0)|0;v[c>>2]=f;b=h;h=v[c+20>>2];g=v[l+192>>2];m=nc(b,h,B(e,g+v[o>>2]|0));k=h+B(e,g)|0;a=w[a+131|0];b=0;while(1){if((a|0)==(b|0)){nc(m+B(e,i)|0,h+B(e,g+v[o>>2]|0)|0,B(e,f-i|0));DP(c,m,f,d)}else{b=b+1|0;j=v[o>>2];nc(m+B(e,g+B(b,j)|0)|0,k,B(e,j));continue}break}}fb=l+208|0}function gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;e=fb+-64|0;fb=e;wc(a);a:{b:{if(b>>>0<=2){C=e,D=Ae(a),t[C+56|0]=D;Yb(a,2);C=e,D=Ag(a),u[C+58>>1]=D;C=e,D=mg(a),v[C+60>>2]=D;break b}hq(a,e+56|0);if(b>>>0>5){break a}}t[e+57|0]=0}c:{n=d+484344|0;s=Pd(x[e+58>>1],1,1024);m=kB(n,s);if((m|0)==65535){break c}b=Xb(v[d+484344>>2],m);g=Of(v[b>>2],v[v[b+48>>2]+12>>2],0);f=x[d+480188>>1];u[e>>1]=f-1;u[e+40>>1]=w[e+56|0];y=x[Tc(e,e+40|0)>>1];h=y+1|0;b=h&65535;f=b>>>0<f>>>0?f:b;while(1)if((b|0)==(f|0)){t[c+13|0]=w[e+57|0]>>>4;b=w[c+12|0];t[e|0]=0;b=(b|0)!=0;p=eu(e+40|0,h,e);z=d+480188|0;d:while(1){if((l|0)==(s|0)){$b(p);break c}e:{d=Hb(v[p>>2],0);f=w[d|0];f:{g:{if(!f){v[23220]=0;d=T(193,a|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break e}d=d<<24>>24;if((d|0)<0){v[23220]=0;f=T(193,a|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break e}C=Hb(v[p>>2],0),D=f,t[C|0]=D}t[e|0]=0;h:{i:{d=d&63;if(!d){break i}v[23220]=0;j=T(193,a|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break h}t[e|0]=j;j:{k:{switch(d-1|0){case 0:t[c+12|0]=0;t[e+36|0]=1;C=c,D=w[$e(e+36|0,e)|0],t[C+14|0]=D;t[c+15|0]=0;break j;case 1:if(!j){break i}t[c+15|0]=j;t[c+12|0]=1;b=w[c+13|0];if(!b){break j}t[c+14|0]=B(B(b,j),15);break j;case 2:t[c+13|0]=j>>>4;if(j>>>0>=16){b=w[c+12|0];j=0;v[e+36>>2]=0;v[e+32>>2]=0;o=0;if(!b){break f}break g}j=0;t[c+12|0]=0;v[e+36>>2]=0;v[e+32>>2]=0;o=0;if(!(b&1)){break f}break g;case 3:o=0;v[e+36>>2]=0;v[e+32>>2]=0;if(b&1){break g}break f;case 5:if(!j){break i}d=(w[c+12|0]?15:14)+c|0;b=w[d|0];t[d|0]=b>>>0<256-j>>>0?b+j|0:-1;break j;case 6:break k;default:break i}}if(!j){break i}d=(w[c+12|0]?15:14)+c|0;b=w[d|0];t[d|0]=b>>>0>j+1>>>0?b-j|0:1}j=0;v[e+36>>2]=0;v[e+32>>2]=0;break g}j=0;v[e+36>>2]=0;v[e+32>>2]=0;o=0;if(!(b&1)){break f}break g}break e}t[d|0]=f-1;j=0;v[e+36>>2]=0;v[e+32>>2]=0;o=0;if(!(b&1)){break f}}b=w[c+13|0];d=w[c+12|0];if(d){o=0;if(!b){break f}}l:{if(d){v[e>>2]=1;v[e+28>>2]=B(b,w[c+15|0])<<1;d=v[Ke(e,e+28|0)>>2];break l}d=B(w[c+14|0],30)+30|0}b=255;f=0;while(1){m:{if(!b){b=0;break m}g=B(b,d);f=(g|0)/48|0;if(g-1536>>>0<10752){break m}b=b-1|0;continue}break}v[e+36>>2]=b;v[e+32>>2]=f;ee(e+32|0,32,255);o=1;v[e>>2]=1;C=c,D=v[Ke(e,e+36|0)>>2],t[C+16|0]=D}q=l-1|0;r=1;b=Xb(v[n>>2],m);b=$c(v[b>>2],v[v[b+48>>2]+12>>2],l,1);while(1){h=r&65535;if(h>>>0>y>>>0){if(o){me(Xb(v[n>>2],m),uh(io(He(Be(e,17,w[e+32|0]),l),0)));me(Xb(v[n>>2],m),uh(He(Be(e,16,w[e+36|0]),l)))}if(j&240){me(Xb(v[n>>2],m),YT(He(Be(e,20,j>>>4|224),l)))}b=j&15;if(b){me(Xb(v[n>>2],m),YT(He(Be(e,20,Pd((B(b,w[c+16|0])>>>0)/15&255,1,15)|96),l)))}l=l+1|0;b=0;continue d}n:{o:{p:{q:{r:{d=Hb(v[p>>2],h);f=w[d|0];if(!f){v[23220]=0;k=T(193,a|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}if(k&128){v[23220]=0;d=T(193,a|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break e}C=Hb(v[p>>2],h),D=d,t[C|0]=D}A=1;if(k&64){v[23220]=0;d=T(193,a|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break e}t[b+1|0]=d;A=!d}if(!(k&32)){d=w[b|0];break r}v[23220]=0;d=T(193,a|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break e}t[b|0]=d;if((d-1&255)>>>0<=107){d=ho(d+24|0);t[b|0]=d;C=yd(v[c>>2],h),D=d,t[C+1|0]=D;d=w[b|0];break o}if((d+127&255)>>>0<=107){d=ho((d&127)+24|0);C=yd(v[c>>2],h),D=d,t[C|0]=D;t[b|0]=0;break q}if((d|0)!=255){break r}d=254;break p}t[d|0]=f-1;break n}if(d&255){break o}}if(!w[b+1|0]){d=0;break o}d=w[yd(v[c>>2],h)+1|0];t[b+1|0]=0}t[b|0]=d}if(Oc(d)){C=yd(v[c>>2],h),D=0,t[C+5|0]=D}t[e+28|0]=0;t[e+27|0]=0;t[e+26|0]=0;t[e+25|0]=0;t[e+24|0]=0;t[e+23|0]=0;s:{if(k&16){t[b+2|0]=1;v[23220]=0;d=T(193,a|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break s}t[b+4|0]=d+2>>>2}f=0;d=0;t:{if(!(k&8)){break t}v[23220]=0;d=T(193,a|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break s}v[23220]=0;g=T(193,a|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break s}t[e+25|0]=g;u:{v:{switch(d-1|0){case 1:t[b|0]=255;break u;case 2:d=yd(v[c>>2],h);t[b|0]=w[d+1|0];t[d+5|0]=0;break u;case 3:d=du(g,w[c+16|0]);t[e+25|0]=d;w:{if(d){t[e+28|0]=20;t[e+25|0]=d|208;d=20;break w}t[e+28|0]=0;d=0}if(w[b|0]){break t}g=yd(v[c>>2],h);t[b|0]=w[g+1|0];t[g+5|0]=0;break t;case 4:t[e|0]=1;C=e,D=du(g,w[c+16|0]),t[C+22|0]=D;C=e,D=w[$e(e,e+22|0)|0],t[C+25|0]=D;t[e+28|0]=15;C=yd(v[c>>2],h),D=0,t[C+5|0]=D;d=20;break t;case 5:case 6:case 7:case 8:x:{if(!l){break x}if((d|0)==w[yd(v[c>>2],h)+4|0]){break x}if(!me(Xb(v[n>>2],m),im(io(He(Be(e,20,(d+122|160)&255),q),h)))){break x}C=yd(v[c>>2],h),D=d,t[C+4|0]=D}t[e+28|0]=10;d=yd(v[c>>2],h);if(!w[b|0]){t[b|0]=w[d+1|0]}t[d+5|0]=0;d=20;break t;case 9:d=20;t[e+28|0]=20;g=yd(v[c>>2],h);i=w[g+5|0];t[e+25|0]=i?-98:-97;t[g+5|0]=i^1;break t;case 0:break v;default:break u}}t[b|0]=254}d=0;t[e+28|0]=0}y:{if(!(k&4)){break y}v[23220]=0;g=T(193,a|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break s}v[23220]=0;t[e+27|0]=g;g=T(193,a|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break s}t[e+24|0]=g;z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{i=w[e+27|0];switch(i-1|0){case 11:break B;case 10:break C;case 7:case 8:case 9:break D;case 6:break E;case 5:break F;case 3:case 4:break G;case 2:break H;case 1:break I;case 0:break J;default:break A}}jB(e,g<<24>>24<<3,128);g=w[b|0];if(Oc(g)){C=b,D=ho(g+v[e>>2]|0),t[C|0]=D}t[e+27|0]=35;t[e+24|0]=w[e+4|0]^128;break y}f=du(g,w[c+16|0]);t[e+24|0]=f;if(f){t[e+27|0]=20;t[e+24|0]=f|208;f=1;break y}t[e+27|0]=0;f=1;break y}f=1;break z}f=1;g=XT(g,w[c+16|0],1);t[e+27|0]=(i|0)==4?2:3;t[e+24|0]=g;break y}if(!w[b|0]){C=b,D=w[yd(v[c>>2],h)|0],t[C|0]=D;g=w[e+24|0]}f=XT(g&255,w[c+16|0],0);t[e+27|0]=4;t[e+24|0]=f;f=1;break y}C=b,D=ho(g+25|0),t[C|0]=D;t[e+24|0]=255;t[e+27|0]=4;f=1;break y}K:{if(!l){break K}if((i|0)==w[yd(v[c>>2],h)+2|0]){break K}if(!me(Xb(v[n>>2],m),im(io(He(Be(e,20,(i-8|48)&255),q),h)))){break K}C=yd(v[c>>2],h),D=w[e+27|0],t[C+2|0]=D}t[e+27|0]=5;C=e,D=iB(w[e+24|0],w[c+16|0]),t[C+24|0]=D;f=1;break y}f=w[c+16|0];t[e+27|0]=18;C=e,D=WT(g,f),t[C+24|0]=D;f=1;break y}f=du(g,w[c+16|0]);t[e+24|0]=f;if(f){t[e+27|0]=20;t[e+24|0]=f|192;f=1;break y}t[e+27|0]=0;t[b|0]=254;f=1;break y}f=0}t[e+27|0]=f}g=0;L:{if(!(k&2)){break L}v[23220]=0;k=T(193,a|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break s}v[23220]=0;t[e+26|0]=k;k=T(193,a|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break s}t[e+23|0]=k;M:{N:{O:{P:{Q:{R:{S:{i=w[e+26|0];switch(i-1|0){case 9:break N;case 7:case 8:break O;case 6:break P;case 3:case 4:case 5:break Q;case 2:break R;case 0:case 1:break S;default:break M}}g=1;h=VT(k,w[c+16|0],(i|0)==1);t[e+26|0]=11;t[e+23|0]=h;break L}g=w[c+16|0];t[e+26|0]=18;C=e,D=WT(k,g),t[C+23|0]=D;g=1;break L}T:{if(!l){break T}if((i|0)==w[yd(v[c>>2],h)+3|0]){break T}if(!me(Xb(v[n>>2],m),im(io(He(Be(e,20,(i-4|64)&255),q),h)))){break T}C=yd(v[c>>2],h),D=w[e+26|0],t[C+3|0]=D}t[e+26|0]=8;C=e,D=iB(w[e+23|0],w[c+16|0]),t[C+23|0]=D;g=1;break L}t[e+26|0]=9;break L}g=VT(k,w[c+16|0],(i|0)==8);t[e+26|0]=29;t[e+23|0]=g;g=1;break L}t[e+26|0]=27;C=e,D=iB(k,w[c+16|0]),t[C+23|0]=D;g=1;break L}t[e+26|0]=0}if(f){UT(b,l,x[z>>1],w[e+27|0],e+24|0)}if(g){UT(b,l,x[z>>1],w[e+26|0],e+23|0)}U:{if(!A){break U}if(!Oc(w[b|0])){break U}f=w[e+27|0];if(!f){t[e+24|0]=255;t[e+27|0]=4;break U}if(w[e+26|0]|(f|0)==4){break U}t[e+23|0]=255;t[e+26|0]=4}V:{if(w[b+2|0]!=1){break V}W:{if(!w[e+27|0]){t[e+27|0]=13;t[e+24|0]=w[b+4|0];break W}if(w[e+26|0]){break V}t[e+26|0]=13;t[e+23|0]=w[b+4|0]}t[b+2|0]=0}lo(e,e+27|0,e+24|0,e+26|0,e+23|0);X:{if(w[b+2|0]){break X}f=w[e+27|0];if(!f){break X}t[b+2|0]=f;t[b+4|0]=w[e+24|0]}Y:{if(d){lo(e,e+26|0,e+23|0,e+28|0,e+25|0);Z:{if(w[b+2|0]){break Z}d=w[e+26|0];if(!d){break Z}t[b+2|0]=d;t[b+4|0]=w[e+23|0]}f=e+25|0;d=w[e+28|0];break Y}f=e+23|0;d=w[e+26|0];if(!d){break n}}t[b+3|0]=d;t[b+5|0]=w[f|0];break n}break e}b=b+6|0;r=r+1|0;continue}}break}a=P()|0;O()|0;$b(p);S(a|0);L()}else{t[g+B(b,6)|0]=254;b=b+1|0;continue}}fb=e- -64|0;return m|0}function tW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0;e=fb-1456|0;fb=e;wc(b);Fo(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!$q(b,e+1432|0)){break n}if(!KD(e+1432|0)){break n}if(!c){j=1;break n}if(!_q(v[b>>2],x[e+1450>>1]|x[e+1452>>1]<<16)){break n}if(!_q(v[b>>2],(x[e+1450>>1]|x[e+1452>>1]<<16)+(x[e+1444>>1]<<2)|0)){break n}rv(a);z=e,A=qv(),v[z+56>>2]=A;c=e+56|0;pv(Aj(v[a+4>>2])+32|0,c);Zq(c);l=v[Aj(v[a+4>>2])+32>>2];v[e+1428>>2]=x[e+1446>>1]|x[e+1448>>1]<<16;z=e,A=$g(v[b>>2]),v[z+1168>>2]=A;v[e+1128>>2]=214748364;d=e+1168|0;z=e,A=B(v[Eb(d,e+1128|0)>>2],20),v[z+56>>2]=A;Zm(l,v[Eb(e+1428|0,c)>>2]);Sb(d,0,256);r=Ib(e+1152|0);o:{while(1){j=x[e+1444>>1]<=s>>>0;if(!j){v[23220]=0;c=Q(142,b|0,(x[e+1450>>1]|x[e+1452>>1]<<16)+(s<<2)|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break m}if(!c){break o}c=v[b+8>>2];d=v[b>>2];v[23220]=0;c=W(143,d|0,c|0,4)|0;d=v[23220];v[23220]=0;if((d|0)==1){break m}if(!c){break o}v[23220]=0;c=T(144,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break l}v[23220]=0;d=Q(142,b|0,c|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break l}if(!d){break o}v[23220]=0;d=Q(145,b|0,e+1128|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break k}if(!d){break o}v[23220]=0;d=W(146,b|0,r|0,x[e+1140>>1])|0;g=v[23220];v[23220]=0;if((g|0)==1){break k}if(!d){break o}g=v[r>>2];f=v[b>>2];v[23220]=0;d=x[e+1140>>1];f=T(147,f|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break j}h=c+20|0;if(f>>>0<=h+(d<<3)>>>0){break o}c=d?g:0;g=x[e+1140>>1];f=h+(g<<3)|0;d=0;h=x[e+1142>>1];p:{if(!(h&1)){while(1){if(d>>>0>=g>>>0){break p}if(!c){break o}g=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23220]=0;g=fa(148,h|0,g|0,l|0,v[e+1428>>2])|0;h=v[23220];v[23220]=0;if((h|0)==1){break i}if(!g){break o}v[23220]=0;g=Q(142,b|0,f|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break i}if(!g){break o}g=v[cc(e+1120|0,Hb(v[l>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))>>2];v[23220]=0;X(149,e+56|0,b|0,g|0,v[e+1124>>2]);g=v[23220];v[23220]=0;if((g|0)==1){break h}if(v[e+60>>2]!=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))){break o}d=d+1|0;c=c+8|0;g=x[e+1140>>1];continue}}q:{r:{s:{t:{u:{if(h&4){if(!c){break o}d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);g=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23220]=0;d=fa(148,g|0,d|0,l|0,v[e+1428>>2])|0;g=v[23220];v[23220]=0;if((g|0)==1){break g}if(!d){break o}m=Hb(v[l>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));k=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&-2;if(!k){break o}v[23220]=0;g=x[e+1146>>1];d=Q(142,b|0,f+x[e+1144>>1]|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break f}if(!d){break o}d=v[b+8>>2];f=v[b>>2];v[23220]=0;d=W(143,f|0,d|0,v[e+1132>>2]-x[e+1144>>1]|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break f}if(!d){break o}v[23220]=0;U(150,e+32|0,b|0,v[e+1132>>2]-x[e+1144>>1]|0);d=v[23220];v[23220]=0;if((d|0)==1){break b}d=e+32|0;f=Yq(e+56|0,d);wb(d);q=0;n=0;v:{w:{x:{while(1){h=0;y:{while(1){if(x[e+1140>>1]<=(n&65535)>>>0){break x}v[23220]=0;d=Q(151,f|0,g+1|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break y}i=g&15;o=x[(i<<1)+25984>>1];z:{A:{if(o>>>0<=d>>>0){v[23220]=0;i=w[i+26032|0];p=Q(151,f|0,i|0)|0;u=v[23220];v[23220]=0;if((u|0)==1){break y}d=p+(d-o<<i)|0;if((d|0)!=(g|0)){g=d&15;break z}v[23220]=0;d=Q(151,f|0,4)|0;i=v[23220];v[23220]=0;if((i|0)==1){break y}if((d|0)==15){v[23220]=0;i=Q(151,f|0,1)|0;d=v[23220];v[23220]=0;if((d|0)==1){break y}d=65535;if(!i){break A}wb(f);break p}d=d+65520|0}if(d>>>0>65535){break z}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;p=h+m|0;i=x[e+1142>>1];B:{if(i&2){q=d+q|0;d=q;break B}d=i&512?d:d^32768}o=d>>>8|0;i=i&1024;t[p+1|0]=i?d:o;t[p|0]=i?o:d;h=h+2|0}if(h>>>0<k>>>0){continue}break}n=n+1|0;if(n>>>0>=x[e+1140>>1]){break r}d=(n<<3)+c|0;h=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);k=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);v[23220]=0;h=fa(148,h|0,k|0,l|0,v[e+1428>>2])|0;k=v[23220];v[23220]=0;if((k|0)==1){break y}if(!h){break t}k=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))&-2;if(!k){break u}m=Hb(v[l>>2],w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));continue}break}j=V(30480)|0;if((O()|0)!=(ea(30480)|0)){break v}_(j|0)|0;v[23220]=0;Z(17);c=v[23220];v[23220]=0;if((c|0)==1){break w}}wb(f);break p}j=P()|0;O()|0}wb(f);break a}if(!c){break o}d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);g=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23220]=0;d=fa(148,g|0,d|0,l|0,v[e+1428>>2])|0;g=v[23220];v[23220]=0;if((g|0)==1){break e}if(!d){break o}q=Hb(v[l>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));if(x[e+1144>>1]>256){break o}m=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);g=x[e+1146>>1];v[23220]=0;d=Q(142,b|0,f|0)|0;f=v[23220];v[23220]=0;C:{D:{if((f|0)!=1){if(!d){break o}d=v[cc(e+24|0,e+1168|0,x[e+1144>>1])>>2];v[23220]=0;X(152,e+56|0,b|0,d|0,v[e+28>>2]);d=v[23220];v[23220]=0;if((d|0)==1){break D}d=x[e+1144>>1];if(d>>>0>y[e+60>>2]){break o}f=v[b+8>>2];h=v[b>>2];v[23220]=0;d=W(143,h|0,f|0,v[e+1132>>2]-d|0)|0;f=v[23220];v[23220]=0;if((f|0)!=1){break C}}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}if(!d){break o}v[23220]=0;U(150,e+32|0,b|0,v[e+1132>>2]-x[e+1144>>1]|0);d=v[23220];v[23220]=0;if((d|0)==1){break c}d=e+32|0;f=Yq(e+56|0,d);wb(d);k=0;n=0;E:{F:{G:{while(1){h=0;H:{while(1){if(x[e+1140>>1]<=(k&65535)>>>0){break G}v[23220]=0;d=Q(151,f|0,g+1|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break H}i=g&7;o=w[i+26016|0];I:{J:{if(o>>>0<=d>>>0){v[23220]=0;i=w[i+26024|0];p=Q(151,f|0,i|0)|0;u=v[23220];v[23220]=0;if((u|0)==1){break H}d=p+(d-o<<i)|0;if((d|0)!=(g|0)){g=d&7;break I}v[23220]=0;d=Q(151,f|0,3)|0;i=v[23220];v[23220]=0;if((i|0)==1){break H}if((d|0)==7){v[23220]=0;i=Q(151,f|0,1)|0;d=v[23220];v[23220]=0;if((d|0)==1){break H}d=255;if(!i){break J}wb(f);break p}d=d+248|0}if(d>>>0>255){break I}}d=w[(e+1168|0)+d|0];i=d+n|0;p=d;d=x[e+1142>>1]&2;t[h+q|0]=d?i:p;n=d?i:n;h=h+1|0}if(h>>>0<m>>>0){continue}break}k=k+1|0;if(k>>>0>=x[e+1140>>1]){break q}d=(k<<3)+c|0;h=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);m=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);v[23220]=0;h=fa(148,h|0,m|0,l|0,v[e+1428>>2])|0;m=v[23220];v[23220]=0;if((m|0)==1){break H}if(!h){break s}m=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);q=Hb(v[l>>2],w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));continue}break}j=V(30480)|0;if((O()|0)!=(ea(30480)|0)){break E}_(j|0)|0;v[23220]=0;Z(17);c=v[23220];v[23220]=0;if((c|0)==1){break F}}wb(f);break p}j=P()|0;O()|0}wb(f);break a}wb(f);break o}wb(f);break o}wb(f);break o}wb(f);break p}wb(f)}s=s+1|0;continue}break}ge(e+8|0,v[l>>2],v[l+4>>2]);Hg(e+16|0,v[e+8>>2],v[e+12>>2]);b=Xd(e);c=v[b+4>>2];b=v[b>>2];v[23220]=0;b=ga(153,e+56|0,v[e+16>>2],v[e+20>>2],b|0,c|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}Yc(Aj(v[a+4>>2])+12|0,b);wb(b)}Wd(r)}fb=e+1456|0;return j|0}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0}Wd(r);S(j|0);L()}function Ss(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=fb-32|0;fb=h;v[h+28>>2]=c;a:{if((c|0)<=0){break a}k=v[b+656>>2];if(!(!k|v[a+480180>>2]!=16777216)){m=v[k+44>>2]!=0}i=v[b+104>>2];b:{c:{d:{if(!k){j=c;break d}if((c|0)>128){break c}j=c-1|0;l=x[ac(k+236|0,j)>>1];e:{if((l-1&65535)>>>0<=3998){i=(B(l,104)+a|0)+484380|0;break e}xb(h+16|0,a+1074312|0,43);if(!yb(v[v[h+16>>2]>>2],v[h+20>>2])){break e}if(!Qj(v[b+656>>2])){break a}}j=w[Hb(k+108|0,j)|0];v[h+28>>2]=j}if(j>>>0<121){break b}c=j}f:{if(!(v[a+480180>>2]&16777248?(c|0)!=255:0)){Fn(a,b);if(d){break f}xb(h+16|0,a+1074312|0,100);if(!yb(v[v[h+16>>2]>>2],v[h+20>>2])|!(w[a+480208|0]&4)|!w[b+789|0]){break f}v[b+88>>2]=v[b+88>>2]&-6145;break f}if(!x[a+480192>>1]){break f}v[b+88>>2]=v[b+88>>2]|4096}g:{if((c|0)!=254){break g}d=v[b+88>>2];c=a+480180|0;if(!(!(d&512)|v[c>>2]!=2)){v[b+88>>2]=d|2048;break g}v[b+88>>2]=d|2101248;h:{if(v[c>>2]&16777248){if(!x[a+480192>>1]){break h}xb(h+16|0,a+1074312|0,50);if(yb(v[v[h+16>>2]>>2],v[h+20>>2])){break h}}v[b+688>>2]=0}xb(h+16|0,a+1074312|0,50);if(yb(v[v[h+16>>2]>>2],v[h+20>>2])){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}xb(h+16|0,a+1074312|0,20);if(!yb(v[v[h+16>>2]>>2],v[h+20>>2])){break a}t[b+797|0]=0;t[b+802|0]=0;break a}i:{j:{k:{if(m){if(d){l=w[b+797|0];if(l){break k}}v[b+708>>2]=0}if(d){break j}if(!(!(v[a+480180>>2]&1048588)|!i)){u[b+770>>1]=t[i+36|0];u[b+772>>1]=t[i+37|0]}if(i){xb(h+16|0,a+1074312|0,24);l=0;o=1;if(!yb(v[v[h+16>>2]>>2],v[h+20>>2])){break i}v[b+704>>2]=v[i+24>>2];break i}i=0;l=0;break i}l=B((v[v[k+44>>2]+36>>2]<<16>>16)+1|0,(j<<16>>16)-(l<<16>>16)|0)-v[b+852>>2]|0;v[b+708>>2]=l;v[b+852>>2]=0-l}o=(i|0)!=0;l=1;if(ni(v[b+8>>2],v[b+12>>2])){break i}l=a+1074312|0;xb(h+16|0,l,54);if(yb(v[v[h+16>>2]>>2],v[h+20>>2])){v[b+700>>2]=0;break a}xb(h+16|0,l,39);l=(yb(v[v[h+16>>2]>>2],v[h+20>>2])^-1)&d}l:{if(em(v[a+480180>>2])){v[h+28>>2]=u[b+770>>1]+j;ee(h+28|0,12,131);break l}ZQ(h+28|0)}j=a+1074312|0;xb(h+16|0,j,34);m:{if(yb(v[v[h+16>>2]>>2],v[h+20>>2])){d=ho(c);break m}d=v[h+28>>2]}t[b+797|0]=d;t[b+851|0]=w[b+851|0]&183|64;if(!(v[a+480180>>2]&16777250?0:l)){t[b+803|0]=0}d=Lg(a,v[h+28>>2],u[b+772>>1],v[b+704>>2]);t[b+831|0]=0;xb(h+16|0,j,48);if(yb(v[v[h+16>>2]>>2],v[h+20>>2])){XM(a,b,k,i)}xb(h+16|0,j,115);if(!(!yb(v[v[h+16>>2]>>2],v[h+20>>2])|!k|!w[k+26|0])){if(!x[b+784>>1]){u[b+784>>1]=x[b+692>>1]+1}WM(b+692|0,c,w[k+26|0],w[k+27|0])}n:{if(e^1|l){break n}v[b+776>>2]=0;v[b+780>>2]=0;if(!k){break n}xb(h+16|0,j,29);if(yb(v[v[h+16>>2]>>2],v[h+20>>2])){t[b+798|0]=w[k+16|0]}if(!(w[k+60|0]&8)){dj(b+724|0)}if(!(w[k+80|0]&8)){dj(b+732|0)}if(!(w[k+100|0]&8)){dj(b+740|0)}if(w[k+20|0]){c=Qs(En(a));n=w[k+20|0];xb(h+16|0,j,28);n=((B(c,n)<<16>>16)/64<<16)+65536>>16;o:{if(yb(v[v[h+16>>2]>>2],v[h+20>>2])){c=v[b+752>>2];break o}c=(v[b+688>>2]+1|0)/2|0}u[b+776>>1]=(B(c,n)|0)/199}p:{if(!w[k+19|0]){break p}q=b,r=(B(Qs(En(a)),w[k+19|0])<<16>>16)/32|0,u[q+778>>1]=r;xb(h+16|0,j,28);if(yb(v[v[h+16>>2]>>2],v[h+20>>2])|x[b+784>>1]){break p}u[b+784>>1]=x[b+692>>1]+1}c=w[k+23|0];if(c){n=Qs(En(a));p=w[b+837|0];t[b+796|0]=p+1;u[b+780>>1]=(B(p,(B(c,n+1|0)<<16>>16)/128<<16>>16)+1|0)/128}c=w[k+24|0];if(!c){break n}n=Qs(En(a));p=w[b+838|0];t[b+795|0]=p+1;u[b+782>>1]=(B(p,(B(c,n+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!o){break a}c=0;q:{r:{if(!d){break r}if(!(v[b+700>>2]?l:0)){v[b+700>>2]=d}s:{t:{if(!m){if(!l){xb(h+16|0,j,69);if(yb(v[v[h+16>>2]>>2],v[h+20>>2])){break t}xb(h+8|0,j,46);if(yb(v[v[h+8>>2]>>2],v[h+12>>2])|v[a+480180>>2]==1){break t}}v[b+708>>2]=d;t[b+851|0]=w[b+851|0]&239}if(!l){break t}if(v[b+76>>2]|w[a+480180|0]&2){break s}}v[b+104>>2]=i;d=v[i>>2];v[b+84>>2]=d;v[b+76>>2]=d;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;u:{v:{if(!(v[a+480208>>2]&2097152)){xb(h+16|0,j,96);if(!yb(v[v[h+16>>2]>>2],v[h+20>>2])){break v}}if(w[b+789|0]){break v}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[Eb(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break u}v[b+660>>2]=0}m=x[i+34>>1];d=m&1023;o=d|v[b+88>>2]&-525056;v[b+88>>2]=o;w:{x:{if(m&8){v[b+80>>2]=v[i+12>>2];m=v[i+16>>2];v[b+88>>2]=(d&16?o|4:o&-524295)|2;v[b+84>>2]=m;if(y[b+76>>2]>m>>>0){break x}break w}if(!(d&2)){break w}v[b+80>>2]=v[i+4>>2];m=v[i+8>>2];v[b+84>>2]=m;if(y[b+76>>2]<=m>>>0){break w}}v[b+76>>2]=m}xb(h+16|0,j,83);if(!(!yb(v[v[h+16>>2]>>2],v[h+20>>2])|v[b+80>>2])){d=v[i>>2];v[b+84>>2]=d;v[b+76>>2]=d}d=v[b+88>>2];y:{if(!(d&128)){break y}i=v[b+76>>2];if(!i){break y}v[b+4>>2]=i-1;v[b+88>>2]=d|128}z:{if(w[b+822|0]>3){break z}xb(h+16|0,j,21);A:{B:{C:{if(!yb(v[v[h+16>>2]>>2],v[h+20>>2])){i=v[a+480180>>2];if(!(i&16777248)){break C}m=16;if(v[a+480208>>2]&4){break B}break A}i=v[a+480180>>2]}m=32;if((i|0)==16){break A}}if(i&67633152){break z}m=0}t[b+819|0]=m}xb(h+16|0,j,21);if(yb(v[v[h+16>>2]>>2],v[h+20>>2])|w[b+825|0]>3){break s}t[b+820|0]=0}i=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){d=v[b+80>>2];v[b>>2]=i;v[b+4>>2]=d}if(!l){break r}c=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break r}d=1;if(!(w[a+480208|0]&8)){break q}d=1;if(!w[b+789|0]){break q}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){Ol(b);xb(h+16|0,j,21);if(!yb(v[v[h+16>>2]>>2],v[h+20>>2])){t[b+818|0]=0;v[b+756>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}D:{if(!c){i=w[b+789|0];break D}i=w[b+789|0];if(!(w[a+480208|0]&8)){break D}d=1;if(!(i&255)){break q}}if(!(i&255?0:v[a+480180>>2]&1048580)){v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}d=c}xb(h+16|0,j,40);E:{F:{if(yb(v[v[h+16>>2]>>2],v[h+20>>2])){if(d){if(!(!(w[a+480208|0]&8)|!w[b+789|0])){v[b+88>>2]=v[b+88>>2]&-4196353;i=1;break E}v[b+88>>2]=v[b+88>>2]&-4194305;i=1;break E}c=v[b+88>>2]&-4196353;break F}c=v[b+88>>2]&-4196353;v[b+88>>2]=c;i=1;if(d){break E}}u[b+842>>1]=65535;v[b+88>>2]=c&-6326273|2097152;xb(h+16|0,j,23);G:{if(yb(v[v[h+16>>2]>>2],v[h+20>>2])){break G}xb(h+8|0,j,22);if(yb(v[v[h+8>>2]>>2],v[h+12>>2])){break G}xb(h+16|0,j,52);if(yb(v[v[h+16>>2]>>2],v[h+20>>2])){break G}xb(h+8|0,j,71);if(yb(v[v[h+8>>2]>>2],v[h+12>>2])){break G}t[b+839|0]=0;t[b+808|0]=0}if(e){t[b+818|0]=0;v[b+756>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;H:{I:{if(k){i=1;d=w[k+22|0];J:{if(!nf(d)){i=!(c>>>13|0);break J}q=b,r=Iq(d),t[q+838|0]=r}c=w[k+21|0];if(nf(c)){q=b,r=Iq(c),t[q+837|0]=r;break I}if(i){break I}c=(i|0)!=0;break H}v[b+776>>2]=0;v[b+780>>2]=0;c=!c;break H}c=1;d=w[k+25|0];if((d|0)==255){break H}t[b+845|0]=d}K:{if(w[b+837|0]>=127){xb(h+16|0,j,36);if(!yb(v[v[h+16>>2]>>2],v[h+20>>2])){break K}}if(!c){break K}if((yp(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break K}c=v[a+1298300>>2];if(!sd(c)|(g|0)==65535){break K}Dp(c,g,w[b+837|0]>>>1|0,1)}i=0;if(!(w[b+89|0]&2)){break E}if(!sd(v[a+1298300>>2])|(g|0)==65535){break E}xb(h+16|0,j,111);if(yb(v[v[h+16>>2]>>2],v[h+20>>2])){Sj(v[a+1298300>>2],g);break E}xb(h+16|0,j,110);if(!yb(v[v[h+16>>2]>>2],v[h+20>>2])){break E}dz(v[a+1298300>>2],g,0,1,0)}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}L:{M:{if(w[a+24618|0]&16?c&1024:0){break M}a=v[b+104>>2];if(!(f?1:!a|!(w[a+35|0]&4))){break M}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break L}}if(f){break L}v[b+700>>2]=0}if(i){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}fb=h+32|0}function EP(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;l=fb-336|0;fb=l;m=i&65535;p=d;q=e&65535;s=(e^i)&-2147483648;k=h;z=i>>>16&32767;A=e>>>16&32767;a:{b:{if(z-32767>>>0>4294934529&A-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){o=d;s=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){o=h;s=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;s=2147450880;break a}s=s|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));o=b?0:o;s=b?2147450880:s;b=0;c=0;break a}if(!(f|h|(e|g))){s=s|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){i=b;d=!(p|q);h=d<<6;j=E(d?b:p)+32|0;b=E(d?c:q);b=h+((b|0)==32?j:b)|0;vf(l+320|0,i,c,p,q,b-15|0);n=16-b|0;p=v[l+328>>2];q=v[l+332>>2];c=v[l+324>>2];b=v[l+320>>2]}if(e>>>0>65535){break b}d=!(k|m);e=d<<6;h=E(d?f:k)+32|0;d=E(d?g:m);d=e+((d|0)==32?h:d)|0;vf(l+304|0,f,g,k,m,d-15|0);n=(d+n|0)-16|0;k=v[l+312>>2];m=v[l+316>>2];f=v[l+304>>2];g=v[l+308>>2]}e=m|65536;B=e;C=k;d=k;k=e<<15|d>>>17;d=d<<15|g>>>17;h=0-d|0;e=k;i=1963258675-(e+((d|0)!=0)|0)|0;gf(l+288|0,d,e,0,0,h,i,0,0);j=v[l+296>>2];gf(l+272|0,0-j|0,0-(v[l+300>>2]+((j|0)!=0)|0)|0,0,0,h,i,0,0);h=v[l+280>>2];i=h<<1|v[l+276>>2]>>>31;h=v[l+284>>2]<<1|h>>>31;gf(l+256|0,i,h,0,0,d,e,0,0);j=h;h=v[l+264>>2];gf(l+240|0,i,j,0,0,0-h|0,0-(v[l+268>>2]+((h|0)!=0)|0)|0,0,0);h=v[l+248>>2];i=h<<1|v[l+244>>2]>>>31;h=v[l+252>>2]<<1|h>>>31;gf(l+224|0,i,h,0,0,d,e,0,0);j=h;h=v[l+232>>2];gf(l+208|0,i,j,0,0,0-h|0,0-(v[l+236>>2]+((h|0)!=0)|0)|0,0,0);h=v[l+216>>2];i=h<<1|v[l+212>>2]>>>31;h=v[l+220>>2]<<1|h>>>31;gf(l+192|0,i,h,0,0,d,e,0,0);e=h;h=v[l+200>>2];gf(l+176|0,i,e,0,0,0-h|0,0-(v[l+204>>2]+((h|0)!=0)|0)|0,0,0);i=d;h=v[l+184>>2];d=h<<1|v[l+180>>2]>>>31;e=d-1|0;h=(v[l+188>>2]<<1|h>>>31)-!d|0;gf(l+160|0,i,k,0,0,e,h,0,0);d=f;j=g<<15|d>>>17;gf(l+144|0,d<<15,j,0,0,e,h,0,0);k=v[l+172>>2];m=v[l+160>>2];D=v[l+152>>2];d=m+D|0;i=v[l+164>>2];j=i+v[l+156>>2]|0;j=d>>>0<D>>>0?j+1|0:j;m=(i|0)==(j|0)&d>>>0<m>>>0|i>>>0>j>>>0;i=m+v[l+168>>2]|0;k=i>>>0<m>>>0?k+1|0:k;m=!j&d>>>0>1|(j|0)!=0;i=m+i|0;k=i>>>0<m>>>0?k+1|0:k;gf(l+112|0,e,h,0,0,0-i|0,0-(((i|0)!=0)+k|0)|0,0,0);gf(l+128|0,1-d|0,0-((d>>>0>1)+j|0)|0,0,0,e,h,0,0);J=(A-z|0)+n|0;e=v[l+116>>2];x=e;d=v[l+112>>2];j=e<<1|d>>>31;m=d<<1;n=j;d=j;h=v[l+140>>2];u=h;e=v[l+136>>2];j=h<<1|e>>>31;i=e<<1|v[l+132>>2]>>>31;h=i+m|0;j=d+j|0;j=h>>>0<i>>>0?j+1|0:j;i=h;e=j;j=j-(h>>>0<13927)|0;r=j;k=q|65536;M=k;D=p;j=p;k=k<<1|j>>>31;p=j<<1|c>>>31;d=0;j=d|k;q=j;w=Bia(r,d,j,0);d=ib;t=d;j=b;d=c<<1|j>>>31;z=j<<1;A=d;h=h-13927|0;j=(e|0)==(r|0)&h>>>0<i>>>0|e>>>0>r>>>0;e=(e|0)==(n|0)&i>>>0<m>>>0|e>>>0<n>>>0;d=v[l+120>>2];k=v[l+124>>2]<<1|d>>>31;i=d<<1;m=j;n=e;e=u>>>31|0;d=e+(x>>>31|i)|0;j=k;j=d>>>0<e>>>0?j+1|0:j;e=d;d=n+d|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=m+d|0;k=d>>>0<e>>>0?j+1|0:j;e=d;d=d-1|0;F=k-!e|0;G=0;i=Bia(A,o,F,G);e=i+w|0;k=ib+t|0;k=e>>>0<i>>>0?k+1|0:k;m=(k|0)==(t|0)&e>>>0<w>>>0|k>>>0<t>>>0;w=d;i=Bia(d,0,p,0);d=i+e|0;j=ib+k|0;j=d>>>0<i>>>0?j+1|0:j;n=d;i=j;e=(j|0)==(k|0)&d>>>0<e>>>0|j>>>0<k>>>0;d=m+e|0;k=0;k=d>>>0<e>>>0?1:k;e=Bia(q,o,F,G);d=e+d|0;j=ib+k|0;u=d;d=d>>>0<e>>>0?j+1|0:j;m=Bia(q,o,w,o);k=ib;x=Bia(F,G,p,o);e=x+m|0;j=ib+k|0;j=e>>>0<x>>>0?j+1|0:j;x=e;e=j;j=(k|0)==(j|0)&m>>>0>x>>>0|j>>>0<k>>>0;m=u+e|0;d=d+j|0;j=m;m=j>>>0<e>>>0?d+1|0:d;u=j;e=0;d=e+n|0;j=i+x|0;j=d>>>0<e>>>0?j+1|0:j;e=j;k=(j|0)==(i|0)&d>>>0<n>>>0|i>>>0>j>>>0;i=u+k|0;j=m;u=i;i=i>>>0<k>>>0?j+1|0:j;n=d;m=e;x=h;h=Bia(h,0,p,o);e=ib;t=Bia(r,o,A,o);d=t+h|0;j=ib+e|0;j=d>>>0<t>>>0?j+1|0:j;e=(e|0)==(j|0)&d>>>0<h>>>0|e>>>0>j>>>0;h=j;H=u;t=e;I=z&-2;k=Bia(w,o,I,0);e=k+d|0;j=ib+j|0;j=e>>>0<k>>>0?j+1|0:j;u=e;k=e;e=j;h=(j|0)==(h|0)&d>>>0>k>>>0|h>>>0>j>>>0;d=t+h|0;k=0;k=d>>>0<h>>>0?1:k;j=d;h=n+d|0;d=k+m|0;d=h>>>0<j>>>0?d+1|0:d;t=h;j=h;h=d;k=(d|0)==(m|0)&j>>>0<n>>>0|d>>>0<m>>>0;d=H+k|0;j=i;N=d;n=d>>>0<k>>>0?j+1|0:j;K=Bia(q,o,x,o);H=ib;i=Bia(F,G,I,o);d=i+K|0;j=ib+H|0;j=d>>>0<i>>>0?j+1|0:j;F=d;k=Bia(r,o,p,o);i=d+k|0;m=j;d=j+ib|0;d=i>>>0<k>>>0?d+1|0:d;L=i;j=Bia(A,o,w,o);i=i+j|0;k=ib+d|0;G=i;k=i>>>0<j>>>0?k+1|0:k;i=k;w=0;O=(d|0)==(k|0)&G>>>0<L>>>0|d>>>0>k>>>0;j=(d|0)==(m|0)&F>>>0>L>>>0|d>>>0<m>>>0;d=j+((m|0)==(H|0)&F>>>0<K>>>0|m>>>0<H>>>0)|0;k=0;d=O+d|0;m=i|0;k=m+t|0;j=(d|w)+h|0;w=k;d=k;j=d>>>0<m>>>0?j+1|0:j;m=j;h=(h|0)==(j|0)&d>>>0<t>>>0|h>>>0>j>>>0;d=h+N|0;j=n;H=d;h=d>>>0<h>>>0?j+1|0:j;t=Bia(r,o,I,o);r=ib;k=Bia(A,o,x,o);d=k+t|0;j=ib+r|0;j=d>>>0<k>>>0?j+1|0:j;n=0;k=(j|0)==(r|0)&d>>>0<t>>>0|j>>>0<r>>>0;r=j;d=j+u|0;j=(k|n)+e|0;n=d;j=d>>>0<r>>>0?j+1|0:j;u=(e|0)==(j|0)&d>>>0<u>>>0|e>>>0>j>>>0;i=0;e=i+d|0;d=j;k=G+d|0;k=e>>>0<i>>>0?k+1|0:k;e=(d|0)==(k|0)&e>>>0<n>>>0|d>>>0>k>>>0;d=u+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=d+w|0;j=j+m|0;j=d>>>0<e>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&d>>>0<w>>>0|j>>>0<m>>>0;i=j+H|0;k=h;h=i;k=h>>>0<j>>>0?k+1|0:k;i=k;c:{if((k|0)==131071|k>>>0<131071){gf(l+80|0,d,e,h,i,f,g,C,B);j=b<<17;b=0;c=v[l+88>>2];n=b-c|0;k=v[l+80>>2];m=v[l+84>>2];D=(k|m)!=0;r=n-D|0;n=(j-(v[l+92>>2]+(b>>>0<c>>>0)|0)|0)-(n>>>0<D>>>0)|0;b=k;k=0-k|0;m=0-(((b|0)!=0)+m|0)|0;b=J+16382|0;break c}k=h<<31;d=(e&1)<<31|d>>>1;e=e>>>1|k;h=(i&1)<<31|h>>>1;i=i>>>1|0;gf(l+96|0,d,e,h,i,f,g,C,B);q=0;m=v[l+104>>2];n=q-m|0;k=v[l+96>>2];p=v[l+100>>2];z=(k|p)!=0;r=n-z|0;n=((b<<16)-(v[l+108>>2]+(m>>>0>q>>>0)|0)|0)-(n>>>0<z>>>0)|0;j=k;k=0-j|0;m=0-(((j|0)!=0)+p|0)|0;z=b;A=c;p=D;q=M;b=J+16383|0}if((b|0)>=32767){s=s|2147418112;b=0;c=0;break a}d:{if((b|0)>0){c=r;j=n<<1|c>>>31;r=c<<1|m>>>31;n=j;p=h;q=i&65535|b<<16;j=m<<1|k>>>31;b=k<<1;break d}if((b|0)<=-113){b=0;c=0;break a}cm(l- -64|0,d,e,h,i,1-b|0);vf(l+48|0,z,A,p,q,b+112|0);d=v[l+64>>2];e=v[l+68>>2];p=v[l+72>>2];q=v[l+76>>2];gf(l+32|0,f,g,C,B,d,e,p,q);c=v[l+40>>2];i=c<<1;c=v[l+44>>2]<<1|c>>>31;b=v[l+56>>2];h=v[l+36>>2];n=h>>>31|i;i=b-n|0;n=v[l+60>>2]-((b>>>0<n>>>0)+c|0)|0;c=v[l+32>>2];k=h<<1|c>>>31;c=c<<1;j=v[l+52>>2];b=v[l+48>>2];h=(k|0)==(j|0)&c>>>0>b>>>0|j>>>0<k>>>0;r=i-h|0;n=n-(h>>>0>i>>>0)|0;h=b;b=h-c|0;j=j-((c>>>0>h>>>0)+k|0)|0}gf(l+16|0,f,g,C,B,3,0,0,0);gf(l,f,g,C,B,5,0,0,0);h=d;m=p;p=d&1;c=b+p|0;d=0;k=j+d|0;k=b>>>0>c>>>0?k+1|0:k;i=c;c=k;g=(k|0)==(g|0)&i>>>0>f>>>0|g>>>0<k>>>0;d=(d|0)==(k|0)&i>>>0<p>>>0|d>>>0>k>>>0;b=d+r|0;j=n;j=b>>>0<d>>>0?j+1|0:j;f=b;d=b;b=j;g=(d|0)==(C|0)&(j|0)==(B|0)?g:(B|0)==(j|0)&d>>>0>C>>>0|j>>>0>B>>>0;d=h+g|0;k=e;k=d>>>0<g>>>0?k+1|0:k;g=(e|0)==(k|0)&d>>>0<h>>>0|e>>>0>k>>>0;e=m+g|0;j=q;j=e>>>0<g>>>0?j+1|0:j;g=e;e=d;m=g;d=v[l+20>>2];h=(d|0)==(c|0)&y[l+16>>2]<i>>>0|c>>>0>d>>>0;d=v[l+28>>2];g=v[l+24>>2];h=j>>>0<2147418112&((f|0)==(g|0)&(b|0)==(d|0)?h:(d|0)==(b|0)&g>>>0<f>>>0|b>>>0>d>>>0);g=e+h|0;d=k;d=g>>>0<h>>>0?d+1|0:d;h=(d|0)==(k|0)&e>>>0>g>>>0|d>>>0<k>>>0;e=m+h|0;k=e>>>0<h>>>0?j+1|0:j;h=e;e=v[l+4>>2];i=(e|0)==(c|0)&y[l>>2]<i>>>0|c>>>0>e>>>0;c=v[l+12>>2];e=v[l+8>>2];c=k>>>0<2147418112&((e|0)==(f|0)&(b|0)==(c|0)?i:(c|0)==(b|0)&e>>>0<f>>>0|b>>>0>c>>>0);b=c+g|0;j=b>>>0<c>>>0?d+1|0:d;c=j;f=(d|0)==(j|0)&b>>>0<g>>>0|d>>>0>j>>>0;e=h+f|0;d=k;o=e|o;s=s|(e>>>0<f>>>0?d+1|0:d)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=o;v[a+12>>2]=s;fb=l+336|0}function kia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=fb-304|0;fb=e;wc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if(!aU(b,e+232|0)){break p}if(!bU(e+232|0)){break p}if(!c){d=1;break p}zd(a,131072);d=fb-16|0;fb=d;i=e+136|0;f=Qb(d,3913);Mc(i,f);vb(f);fb=d+16|0;v[23220]=0;U(294,e+184|0,i|0,e+232|4);d=v[23220];v[23220]=0;q:{if((d|0)!=1){d=e+184|0;Db(a+1298344|0,d);vb(d);i=e+136|0;bc(i);f=Qb(d,11052);Db(a+1298356|0,f);vb(f);v[a+1298404>>2]=5;mu(i,3,e+245|0);Ac(d,i);xc(a+1298308|0,d);ub(d);f=e+112|0;rj(f,3,e+275|0);Ac(i,f);v[23220]=0;U(11,d|0,5,i|0);d=v[23220];v[23220]=0;if((d|0)==1){break b}d=e+184|0;Db(a+1298320|0,d);vb(d);ub(e+136|0);d=jq(d);o=d,p=Pd(w[e+295|0],1,31),v[o+12>>2]=p;o=d,p=Pd(w[e+296|0],1,12)-1|0,v[o+16>>2]=p;v[d+20>>2]=w[e+297|0];i=a+1298408|0;Bc(i);_T(i,d);g=e+144|0;i=Ib(e+168|0);r:{s:{t:{while(1){d=v[b+8>>2];f=v[b>>2];v[23220]=0;d=W(143,f|0,d|0,8)|0;f=v[23220];v[23220]=0;u:{v:{w:{x:{y:{if((f|0)!=1){if(!d){break r}v[23220]=0;R(295,b|0,e+72|0);d=v[23220];v[23220]=0;if((d|0)==1){break y}d=v[e+76>>2];z:{l=w[e+236|0];switch(l-3|0){case 1:break x;case 0:break z;default:break w}}f=2;if(v[e+72>>2]!=1431389523){break v}break u}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}f=4;if(v[e+72>>2]!=1431389523){break v}break u}f=0;if(l>>>0>7){break u}}d=v[e+72>>2]==1146113363?-1:d;f=0}l=v[e+76>>2];v[e+136>>2]=v[e+72>>2];v[e+140>>2]=l;v[23220]=0;U(177,e+112|0,b|0,d|0);d=v[23220];v[23220]=0;if((d|0)==1){break t}gc(g,e+112|0);v[23220]=0;R(296,i|0,e+136|0);d=v[23220];v[23220]=0;if((d|0)==1){break s}Id(e+136|0);wb(e+112|0);v[23220]=0;Q(175,b|0,f|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){continue}break}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;Id(e+136|0);wb(e+112|0);break c}v[23220]=0;l=T(161,e+136|0)|0;b=v[23220];v[23220]=0;A:{B:{C:{if((b|0)!=1){v[23220]=0;U(297,e+112|0,i|0,1431389523);b=v[23220];v[23220]=0;if((b|0)==1){break C}d=e+112|0;b=Yc(l,d);wb(d);u[e+110>>1]=0;u[e+108>>1]=65534;if(w[e+236|0]<3){break A}v[23220]=0;d=T(181,b|0)|0;f=v[23220];v[23220]=0;if((f|0)!=1){break B}break e}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}u[e+110>>1]=d;if(w[e+236|0]<4){break A}v[23220]=0;d=T(181,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break e}u[e+108>>1]=w[e+236|0]==4?d?d:-2:d}d=w[a+484376|0];f=v[a+484360>>2];v[23220]=0;g=T(189,b|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break e}v[23220]=0;U(228,Vb(f,d)|0,b|0,g>>>1|0);d=v[23220];v[23220]=0;if((d|0)==1){break e}d=Vb(v[a+484360>>2],w[a+484376|0]);d=mB(v[d>>2],v[d+4>>2]);qg(e+110|0,d);qg(e+108|0,d);v[23220]=0;U(297,e+112|0,i|0,1414807888);d=v[23220];v[23220]=0;if((d|0)==1){break h}d=e+112|0;b=Yc(b,d);wb(d);d=v[b>>2];v[23220]=0;d=T(165,d|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break e}if(!(c&1)|d^1){break q}v[23220]=0;R(298,b|0,e+8|0);d=v[23220];v[23220]=0;if((d|0)==1){break i}o=a,p=Pd(w[e+10|0],1,32)+1|0,u[o+480188>>1]=p;v[23220]=0;d=Q(205,e+96|0,x[e+8>>1])|0;f=v[23220];v[23220]=0;if((f|0)==1){break j}o=e,p=Ab(v[d>>2]),v[o+48>>2]=p;g=Ab(v[d+4>>2]);D:{E:{while(1){h=v[e+48>>2];if(!Nb(h,g)){f=x[a+480188>>1];v[23220]=0;f=Q(299,e+112|0,f|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){g=a+484376|0;h=Vb(v[a+484360>>2],w[g|0]);h=al(v[h>>2],v[h+4>>2]);v[23220]=0;k=a+484344|0;R(212,k|0,h|0);h=v[23220];v[23220]=0;if((h|0)==1){break g}g=Vb(v[a+484360>>2],w[g|0]);o=e,p=Ab(v[g>>2]),v[o+72>>2]=p;h=Ab(v[g+4>>2]);F:{while(1){G:{g=v[e+72>>2];if(!Nb(g,h)){g=w[a+484376|0];h=v[a+484360>>2];v[23220]=0;j=Vb(h,g);h=x[e+108>>1];g=Q(300,j|0,h|0)|0;j=v[23220];v[23220]=0;if((j|0)!=1){break G}break g}j=v[d>>2];n=Bf(j,v[d+4>>2]);m=x[g>>1];if(n>>>0>m>>>0){v[23220]=0;j=fa(301,xg(j,m)|0,w[e+236|0],f|0,a|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break F}u[g>>1]=j}Oe(e+72|0);continue}break}H:{if(!g){break H}g=Vb(v[a+484360>>2],w[a+484376|0]);j=x[e+110>>1];if(!j){if(mB(v[g>>2],v[g+4>>2])>>>0<=h>>>0){break H}}g=Xb(v[k>>2],x[ac(v[g>>2],h)>>1]);me(g,im(He(Be(e+72|0,12,j&255),v[g+12>>2]-1|0)))}qh(f);fd(d);break q}break g}b=P()|0;O()|0;break f}v[23220]=0;f=w[e+236|0]<3?9:8;Q(175,b|0,f-4|0)|0;k=v[23220];v[23220]=0;if((k|0)!=1){v[23220]=0;k=T(144,b|0)|0;j=v[23220];v[23220]=0;if((j|0)==1){break E}jg(b,f);v[23220]=0;U(177,e+72|0,b|0,f+k|0);f=v[23220];v[23220]=0;if((f|0)==1){break D}j=h;f=e+72|0;h=gc(e+112|0,f);Yc(j,h);wb(h);wb(f);rh(e+48|0);continue}break}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;bc(e+136|0);break a}v[23220]=0;U(297,e+72|0,i|0,1196641603);d=v[23220];v[23220]=0;if((d|0)==1){break n}d=e+72|0;b=Yc(b,d);wb(d);d=v[b>>2];v[23220]=0;d=T(165,d|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break e}if(d){v[23220]=0;Q(175,b|0,1)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}v[23220]=0;d=T(189,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break e}v[23220]=0;da(302,a+1298332|0,b|0,d|0,40,0);d=v[23220];v[23220]=0;if((d|0)==1){break e}}v[23220]=0;U(297,e+72|0,i|0,1146113363);d=v[23220];v[23220]=0;if((d|0)==1){break k}v[23220]=0;U(297,e+48|0,i|0,1229999443);d=v[23220];v[23220]=0;if((d|0)==1){break o}d=e+48|0;b=Yc(b,d);wb(d);v[23220]=0;d=T(193,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break m}u[a+480190>>1]=d;h=!(c&2);k=a+480190|0;f=1;I:{while(1){J:{c=f&65535;if(c>>>0>(d&65535)>>>0){break I}d=30;K:{L:{M:{if(w[e+236|0]>=2){v[23220]=0;d=T(193,b|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break M}}v[23220]=0;U(303,b|0,((c<<5)+a|0)+946304|0,d|0);d=v[23220];v[23220]=0;if((d|0)==1){break M}v[23220]=0;R(304,b|0,e+32|0);d=v[23220];v[23220]=0;if((d|0)==1){break L}v[23220]=0;g=B(c,104)+a|0;j=g+484380|0;R(305,e+32|0,j|0);c=v[23220];v[23220]=0;if((c|0)==1){break L}d=w[e+236|0];if(d>>>0>=8){v[23220]=0;R(306,b|0,g+484423|0);c=v[23220];v[23220]=0;if((c|0)==1){break L}d=w[e+236|0]}v[23220]=0;Q(175,b|0,((d&255)>>>0>1?6:2)|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break L}v[23220]=0;c=T(144,e+72|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){v[23220]=0;U(177,e+8|0,e+72|0,c|0);c=v[23220];v[23220]=0;if((c|0)!=1){break K}}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}d=e+8|0;c=gc(e+48|0,d);wb(d);d=v[c>>2];v[23220]=0;d=T(165,d|0)|0;m=v[23220];v[23220]=0;if((m|0)!=1){N:{if(h|d^1){break N}d=Uc(e+8|0,u[g+484414>>1]&1?16:8,1,0,(w[e+47|0]&12)==4?7:0);v[23220]=0;W(206,d|0,j|0,c|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break N}break J}wb(c);f=f+1|0;d=x[k>>1];continue}}break}b=P()|0;O()|0;wb(c);break l}yg(a);v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;v[23220]=0;d=1;W(254,a+1074312|0,114,1)|0;a=v[23220];v[23220]=0;if((a|0)==1){break m}wb(e+72|0);wb(b);Vd(i)}fb=e+304|0;return d|0}b=P()|0;O()|0;break l}b=P()|0;O()|0;break d}b=P()|0;O()|0}wb(e+72|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;qh(f)}fd(d);break d}b=P()|0;O()|0}wb(l)}Vd(i);break a}b=P()|0;O()|0;ub(e+136|0)}S(b|0);L()}function yea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;d=fb-1344|0;fb=d;wc(b);f=fb-16|0;fb=f;TQ(f+8|0,d+232|0);e=v[f+12>>2];jc(f,v[b>>2],v[b+8>>2],v[f+8>>2],e);i=v[f+4>>2];if((i|0)==(e|0)){Yb(b,v[f+12>>2])}fb=f+16|0;a:{if((e|0)!=(i|0)){break a}if(!VQ(d+232|0)){break a}if(!Lb(v[b>>2],v[b+8>>2],Pc(UQ(v[d+1336>>2]),ib))){break a}if(!c){n=1;break a}wc(b);b=fe(d+232|0,b);v[23220]=0;R(581,d+216|0,b|0);f=v[23220];v[23220]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((f|0)!=1){wb(b);v[23220]=0;U(582,d+200|0,d+216|0,1196314451);b=v[23220];v[23220]=0;if((b|0)==1){break i}v[23220]=0;U(582,d+184|0,d+216|0,1280331091);b=v[23220];v[23220]=0;if((b|0)==1){break h}if(rc(v[d+200>>2],v[d+204>>2])){break b}if(!rc(v[d+184>>2],v[d+188>>2])){break g}break b}c=P()|0;O()|0;wb(b);break d}c=P()|0;O()|0;break e}c=P()|0;O()|0;break f}v[23220]=0;R(236,a|0,1);b=v[23220];v[23220]=0;j:{k:{l:{m:{if((b|0)!=1){yg(a);v[a+480188>>2]=4;v[a+480208>>2]=25231360;C=d,D=Ab(v[d+184>>2]),v[C+48>>2]=D;k=c&2;g=Ab(v[d+188>>2]);l=a+480190|0;n:{o:{while(1){f=v[d+48>>2];if(!Nb(f,g)){break o}b=x[l>>1];if(!Ph(b)){break o}b=b+1|0;u[a+480190>>1]=b;v[23220]=0;b=B(b&65535,104)+a|0;e=b+484380|0;R(267,e|0,1);i=v[23220];v[23220]=0;p:{q:{if((i|0)!=1){v[23220]=0;i=Q(583,f|0,d+232|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break q}if(!i){break c}if(yt(d+232|0)){break p}break c}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}v[23220]=0;i=Q(52,d+168|0,d+232|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break n}yc(((x[a+480190>>1]<<5)+a|0)+946304|0,i);ub(i);i=v[d+268>>2];v[e>>2]=i;v[b+484388>>2]=i;v[b+484384>>2]=v[d+264>>2];i=b+484414|0;u[i>>1]=x[i>>1]|2;u[b+484410>>1]=255;r:{if(k){b=Uc(d+16|0,8,1,0,0);v[23220]=0;W(206,b|0,e|0,f|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break r}}rh(d+48|0);continue}break}c=P()|0;O()|0;break j}C=d,D=Ab(v[d+200>>2]),v[C+160>>2]=D;q=a+484344|0;s=c&1;A=Ab(v[d+204>>2]);l=a+484360|0;y=a+484380|0;z=a+946304|0;c=1;n=1;while(1){s:{t:{u:{v:{w:{x:{b=v[d+160>>2];if(!Nb(b,A)){break x}if(!(c&1)){v[23220]=0;c=T(262,l|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break w}if(!c){break x}}Bc(Vb(v[l>>2],w[l+16|0]));v[23220]=0;c=Q(584,b|0,d+232|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break v}if(!(c&!x[d+1318>>1])|v[d+1320>>2]-5>>>0<4294967292){break c}c=w[l+16|0];f=v[l>>2];v[23220]=0;U(5,d+48|0,5,d+232|0);e=v[23220];v[23220]=0;if((e|0)==1){break k}v[23220]=0;R(263,Vb(f,c)|0,d+48|0);c=v[23220];v[23220]=0;if((c|0)==1){break l}vb(d+48|0);y:{if(s){v[23220]=0;U(177,d+48|0,b|0,v[d+1328>>2]);b=v[23220];v[23220]=0;if((b|0)!=1){break y}c=P()|0;O()|0;break j}v[23220]=0;b=T(161,d+112|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break m}vD(d+48|0,b)}b=d+48|0;m=gc(d+136|0,b);wb(b);if(!s){wb(d+112|0)}Sb(d+48|0,0,64);c=1;z:{A:{B:{while(1){if((c|0)==32){break B}b=(B(c,34)+d|0)+198|0;f=b+32|0;vm(d,f);C:{D:{if(!w[v[d>>2]]){break D}e=w[b- -64|0];if(e>>>0>15){break A}b=w[b+65|0];if(b>>>0>64){break A}if(!yt(f)){break A}i=b<<2;k=e<<4;f=0;b=1;E:{while(1){g=b&65535;e=x[a+480190>>1];if(g>>>0>e>>>0){break E}v[23220]=0;U(482,d+16|0,v[d>>2],v[d+4>>2]);e=v[23220];v[23220]=0;if((e|0)==1){break C}e=fb-16|0;fb=e;j=d+16|0;re(e+8|0,j);RQ(e,((g<<5)+a|0)+946304|0);h=v[e+8>>2];r=v[e>>2];o=v[e+12>>2];p=v[e+4>>2];if((o|0)==(p|0)){h=(DS(h,o,r,p)|0)!=0}else{h=1}fb=e+16|0;ub(j);F:{G:{if(h){break G}C=ac(d+48|0,c),D=b,u[C>>1]=D;e=B(g,104)+a|0;g=e+484410|0;h=x[g>>1];if((h|0)==255){break F}f=b;if(w[e+484417|0]!=(k&255)){break G}if((h|0)==(i|0)){break F}}b=b+1|0;continue}break}t[e+484417|0]=k;u[g>>1]=i;break D}f=f&65535;if(!f){break D}if(!Ph(e)){break D}b=e+1|0;u[a+480190>>1]=b;C=ac(d+48|0,c),D=b,u[C>>1]=D;b=B(x[a+480190>>1],104)+y|0;am(b);e=B(f,104)+y|0;g=Wn(b,e);u[b+30>>1]=i;t[b+37|0]=k;NR(g,e);f=(f<<5)+z|0;e=v[f+4>>2];b=(x[a+480190>>1]<<5)+z|0;v[b>>2]=v[f>>2];v[b+4>>2]=e;e=v[f+28>>2];v[b+24>>2]=v[f+24>>2];v[b+28>>2]=e;e=v[f+20>>2];v[b+16>>2]=v[f+16>>2];v[b+20>>2]=e;e=v[f+12>>2];v[b+8>>2]=v[f+8>>2];v[b+12>>2]=e}c=c+1|0;continue}break}break u}k=0;v[d+40>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;e=64;i=65535;r=x[d+1320>>1];f=0;H:while(1){I:{if(f){break I}b=v[m>>2];v[23220]=0;b=W(143,b|0,v[d+144>>2],1)|0;c=v[23220];v[23220]=0;if((c|0)==1){break z}if(b){break I}b=i;break t}e=e+1|0;if(e>>>0>=64){v[23220]=0;i=Q(352,q|0,64)|0;b=v[23220];v[23220]=0;if((b|0)==1){break z}b=65535;if((i|0)==65535){break t}b=w[l+16|0];c=v[l>>2];e=0;v[23220]=0;R(480,Vb(c,b)|0,i|0);b=v[23220];v[23220]=0;if((b|0)==1){break z}}b=0;c=Xb(v[q>>2],i&65535);c=$c(v[c>>2],v[v[c+48>>2]+12>>2],e,0);while(1){if((b|0)==(r|0)){continue H}g=(d+16|0)+B(b,7)|0;h=w[g+6|0];J:{if(h){t[g+6|0]=h-1;h=w[g+4|0]|w[g+5|0]<<8;t[c+4|0]=h;t[c+5|0]=h>>>8;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[c|0]=g;t[c+1|0]=g>>>8;t[c+2|0]=g>>>16;t[c+3|0]=g>>>24;f=f-1|0;break J}h=v[m>>2];v[23220]=0;h=W(143,h|0,v[d+144>>2],1)|0;j=v[23220];v[23220]=0;if((j|0)==1){break u}if(!h){break J}if(v[d+144>>2]==v[d+1324>>2]){k=Vb(v[l>>2],w[l+16|0]);Ve(k,mB(v[k>>2],v[k+4>>2]));k=e}v[23220]=0;h=T(193,m|0)|0;j=v[23220];v[23220]=0;K:{if((j|0)!=1){h=h<<24>>24;if((h|0)>=0){break K}h=h&127;t[g+6|0]=h;j=w[g+4|0]|w[g+5|0]<<8;t[c+4|0]=j;t[c+5|0]=j>>>8;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[c|0]=g;t[c+1|0]=g>>>8;t[c+2|0]=g>>>16;t[c+3|0]=g>>>24;f=f+h|0;break J}break u}if((h-1&255)>>>0<=35){t[c|0]=h+48}v[23220]=0;h=T(193,m|0)|0;j=v[23220];v[23220]=0;L:{M:{if((j|0)!=1){C=c,D=w[ac(d+48|0,h&31)|0],t[C+1|0]=D;if(!(h&128)){break M}t[c+3|0]=w[g+3|0];t[c+5|0]=w[g+5|0];break L}break u}v[23220]=0;R(250,d|0,m|0);h=v[23220];v[23220]=0;N:{if((h|0)!=1){h=w[d|0];if(h>>>0>19){break L}o=h<<1;p=w[o+26944|0];t[c+3|0]=p;j=w[gd(d)|0];t[c+5|0]=j;if((p|0)!=16|j>>>0<32){break N}t[c+3|0]=17;break L}break u}if(819137>>>h&1){break L}t[c+5|0]=w[o+26945|0]|j&15}h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[g|0]=h;t[g+1|0]=h>>>8;t[g+2|0]=h>>>16;t[g+3|0]=h>>>24;h=w[c+4|0]|w[c+5|0]<<8;t[g+4|0]=h;t[g+5|0]=h>>>8}c=c+6|0;b=b+1|0;continue}}}n=0;break s}break u}xi(l,0);v[23220]=0;b=Q(1,d+232|0,6428)|0;c=v[23220];v[23220]=0;O:{if((c|0)!=1){Db(a+1298344|0,b);vb(b);v[23220]=0;b=Q(1,d+48|0,6730)|0;c=v[23220];v[23220]=0;if((c|0)==1){break O}Db(a+1298356|0,b);vb(b);v[a+1298404>>2]=5;n=1;break b}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;wb(m);break j}P:{if(!k&e>>>0>62){break P}b=b&65535;if((b|0)==65535){break P}me(Xb(v[q>>2],b),uh(He(Be(d,14,k&255),e)))}c=32}wb(m);if(c>>>0<32){break b}rh(d+160|0);c=0;continue}}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;vb(d+48|0);break j}c=P()|0;O()|0}fd(d+184|0)}fd(d+200|0)}Vd(d+216|0)}S(c|0);L()}n=0}fd(d+184|0);fd(d+200|0);Vd(d+216|0)}fb=d+1344|0;return n|0}function Zea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,T=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0;d=fb-336|0;fb=d;a:{if(!Vc(b,1080)){break a}if(!eo(b,d+332|0)){break a}zd(a,1);m=zR(d+312|0);if(!yR(d+332|0,m)){break a}h=x[m+10>>1];e=h;if(!e|e>>>0>127){break a}if(!c){g=1;break a}u[a+480188>>1]=h;r=w[m+14|0];J=w[m+13|0];f=w[m+12|0];C=1;if(!ce(d+332|0,26874)){C=ce(d+332|0,26879)}if(w[m+15|0]){Kb(a+1074312|0,5,1);h=x[a+480188>>1]}g=d+332|0;q=ce(g,16671);e=1;if(!ce(g,17435)){e=ce(d+332|0,13563)}D=a+480188|0;y=(h&65535)==8&(J|0)!=0;Vc(b,0);IA(b,a+1298308|0,20);u[a+480190>>1]=31;n=(f|0)!=0;g=1;h=q;while(1)if((g|0)==32){b:{c:{d:{e:{f:{g:{K=v[m+4>>2];if(K>>>0>=E>>>0){f=d+176|0;uR(b,f);Vc(b,x[m+8>>1]);g=w[d+177|0];e=128;i=a+484376|0;kq(Vb(v[a+484360>>2],w[i|0]),f|2,128);h=!g&h;k=h?k:0;f=w[d+176|0];h:{if(f>>>0>128){break h}e=f;if(e){break h}f=v[Vb(v[a+484360>>2],w[a+484376|0])>>2];g=128;while(1){e=g;if(e>>>0<2){e=1;break h}g=e-1|0;if(!x[ac(f,g)>>1]){continue}break}}o=tR(b,Vb(v[a+484360>>2],w[i|0]),e&65535,j,D,k,0);F=1;i:{if(!(h&x[a+480188>>1]==8)){F=(r|0)!=0;break i}v[m>>2]=11237}j:{if(!y){break j}f=Vb(v[a+484360>>2],w[a+484376|0]);ca=d,da=Ab(v[f>>2]),v[ca+160>>2]=da;h=Ab(v[f+4>>2]);while(1){f=v[d+160>>2];if(!Nb(f,h)){break j}u[f>>1]=x[f>>1]>>>1;Oe(d+160|0);continue}}f=a+484376|0;Ve(Vb(v[a+484360>>2],w[f|0]),w[d+177|0]);M=e-1|0;e=w[d+177|0];k:{if((M&65535)>>>0>=e>>>0){g=x[D>>1];if((e|0)!=120|(g|0)!=4){break k}}Ve(Vb(v[a+484360>>2],w[f|0]),0);g=x[a+480188>>1]}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;v[a+480208>>2]=0;ca=a,da=Ub(256/((g&65535)>>>0)|0,32,128),v[ca+480228>>2]=da;th(a,0);t[d+175|0]=0;r=1;g=0;N=1;if(!n){s=d+160|5;n=0;e=0;k=0;f=q;l:while(1){if(o>>>0>(k&65535)>>>0){i=0;g=0;while(1)if((g|0)==256){k=k+1|0;continue l}else{h=Rh(d+160|0);iu(b,h);p=SA(w[h|0]);m:{n:{o:{p:{h=w[d+163|0];if((h-7&255)>>>0<3){f=0;break p}j=w[d+165|0];if(!((h|0)!=14|j>>>0<=1)){f=0;break o}if(!((h|0)==15&(j&255)>>>0>31)){f=p?f:0;if((h|0)!=13){break p}i=i+1|0;if((i&65535)>>>0<2){break m}}f=0;break m}if((h|0)==8){break n}if((h|0)!=14){break m}j=w[d+165|0]}if((j&240)!=128){break m}t[d+144|0]=j<<4;ca=d,da=w[$e(d+175|0,d+144|0)|0],t[ca+175|0]=da;break m}ca=d,da=w[$e(d+175|0,s)|0],t[ca+175|0]=da;h=t[d+165|0];if((h|0)>=0){n=1;break m}e=(h|0)!=-92&h>>>0>4294967183|e}r=p&r;g=g+1|0;continue}}break}g=0;g=(n^-1|e)&1?g:w[d+175|0]>47;N=f&1}Vc(b,x[m+8>>1]);e=x[a+480188>>1];p=a+484344|0;G=o+y&65535;ig(p,G);Q=y?4:e;n=a+1074312|0;$=g^1;aa=c&1;T=a+480188|0;k=0;j=0;o=0;s=0;q:{r:{s:{while(1){if((k|0)==(G|0)){break r}t:{if(y){e=(k&65534)>>>1|0;f=k&1;if(!f){if(!Xg(p,e,64)){break r}}h=f<<2;e=Xb(v[p>>2],e);break t}if(!Xg(p,k&65535,64)){break r}h=0;e=Xb(v[p>>2],k)}i=0;H=$c(v[e>>2],v[v[e+48>>2]+12>>2],0,h);if(!aa){o=0;s=0;break q}e=x[T>>1];t[d+80|0]=0;f=e;e=d+80|0;i=eu(d+160|0,f,e);f=x[T>>1];v[23220]=0;t[d+80|0]=0;z=W(539,d+144|0,f|0,e|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){I=0;u:while(1){if((I|0)!=64){h=0;f=0;V=0;while(1){if((h|0)==(Q|0)){I=I+1|0;o=f&V|o;H=B(x[D>>1],6)+H|0;continue u}v[23220]=0;g=B(h,6)+H|0;R(540,b|0,g|0);e=v[23220];v[23220]=0;v:{w:{if((e|0)!=1){e=w[g+3|0];x:{y:{z:{if(!e){if(w[g+5|0]){break z}break y}if(!J){break z}A:{switch(e-14|0){case 0:t[g+3|0]=0;t[g+5|0]=0;break z;case 1:break A;default:break z}}if(w[g+5|0]<32){break z}t[g+5|0]=31}Mf(g);e=1;B:{C:{D:{l=w[g+3|0];switch(l-14|0){case 2:break x;case 0:break C;case 3:break D;default:break B}}j=w[g+5|0]<100|j;V=1;break y}if(!N){break y}t[g+5|0]=0;break y}if(!((l|0)!=9|$)){e=w[g+5|0];if((e|0)==164){t[g+3|0]=20;t[g+5|0]=145;break y}ca=g,da=vi(e<<1),t[ca+5|0]=da;break y}if((l|0)!=19){break y}e=w[g+5|0];if(e>>>0>15){break y}l=e&1;e=!l;ba=!l;l=X&1;X=(l|0)==(e|0)?X:ba;s=((e|0)!=(l|0))+s|0}e=f}if(w[g|0]){break w}f=w[g+1|0];if(!f|y){break v}l=w[Hb(v[i>>2],h)|0];if(!l|(f|0)==(l|0)){break v}l=Hb(v[z>>2],h);f=w[l|0]+1|0;t[l|0]=f;if((f&255)>>>0<4){break v}v[23220]=0;W(254,n|0,85,1)|0;f=v[23220];v[23220]=0;if((f|0)!=1){break v}}h=P()|0;O()|0;$b(z);break s}ca=Hb(v[z>>2],h),da=0,t[ca|0]=da}f=w[g+1|0];if(f){ca=Hb(v[i>>2],h),da=f,t[ca|0]=da}h=h+1|0;f=e;continue}}break}$b(z);$b(i);k=k+1|0;continue}break}h=P()|0;O()|0}$b(i);break b}i=j}E:{F:{G:{if((r^-1|Y)&1){break G}H:{if(ce(d+332|0,16671)){break H}if(ce(d+332|0,17440)){break H}if(!ce(d+332|0,13553)){break G}}v[a+480208>>2]=v[a+480208>>2]|2162688;e=Kb(Kb(Kb(n,85,1),91,1),92,1);I:{if(w[d+175|0]>47){break I}e=Kb(e,84,1);if(w[d+177|0]==127){break I}Kb(e,83,1)}if(!(r&1)){break E}break F}if(r&1){break F}if(q^1|w[d+177|0]!=127|(M&65535)>>>0>128){break E}v[m>>2]=8481;break E}if((s|0)>6|F){break E}v[a+480208>>2]=v[a+480208>>2]|8388608}if((q|F)==1){Kb(n,89,1)}if(C){Kb(n,84,1)}J:{if(!(c&2)){break J}Vc(b,x[m+8>>1]+(B(G,Q)<<8)|0);f=(r&q^1|Z)&1;g=1;while(1){if((g|0)==32){break J}h=B(g,104)+a|0;c=h+484380|0;e=v[c>>2];if(e){j=2;if(!C){j=sR(b,13824)?10:0;e=v[c>>2]}j=Uc(d+160|0,8,1,0,j);e=KA(j,e)+v[b+8>>2]|0;if(!f){ca=c,da=v[Sc(c,h+484388|0)>>2],v[ca>>2]=da}hg(j,c,b);Vc(b,e)}g=g+1|0;continue}}K:{if((i&q^-1|o)&1){break K}b=rR(d+120|0,0);c=v[b+20>>2];v[d+40>>2]=v[b+16>>2];v[d+44>>2]=c;c=v[b+12>>2];v[d+32>>2]=v[b+8>>2];v[d+36>>2]=c;c=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=c;b=d+160|0;Bt(b,a,0,d+24|0);_=A[v[d+160>>2]>>3];ti(b);if(!(_>=480)){break K}c=Kb(n,5,1);b=qR(d+96|0,_);e=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=e;e=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=d+160|0;Bt(b,a,0,d);e=w[v[d+160>>2]+26|0];ti(b);if(e){zf(c,5);break K}v[m>>2]=17023}b=d+332|0;e=b;f=fc(e);c=e;while(1){if((e|0)!=(f|0)){q=w[e|0];t[c|0]=q>>>0>32?q:32;c=c+1|0;e=e+1|0;continue}break}og(d+80|0,16776);v[23220]=0;b=W(541,d+48|0,b|0,f|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break g}v[23220]=0;U(11,d- -64|0,1,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break f}v[23220]=0;U(132,d+160|0,d+80|0,d- -64|0);c=v[23220];v[23220]=0;if((c|0)==1){break e}c=d+160|0;Db(a+1298344|0,c);vb(c);vb(d- -64|0);ub(b);bc(d+80|0);b=Qb(c,12292);Db(a+1298356|0,b);vb(b);b=v[m>>2];if(b){ql(a+1298368|0,b)}v[a+1298404>>2]=13}g=E>>>0<=K>>>0;break a}h=P()|0;O()|0;break c}h=P()|0;O()|0;break d}h=P()|0;O()|0;vb(d- -64|0)}ub(b)}bc(d+80|0)}S(h|0);L()}else{i=B(g,104)+a|0;f=i+484380|0;p=bA(b,d+176|0,f,((g<<5)+a|0)+946304|0,x[a+480188>>1]==4);f=v[f>>2];L:{if(e){t[i+484417|0]=0-(w[d+200|0]<<3);break L}n=f>>>0<65536&n}i=Jb(x[d+198>>1]);M:{if(i){Y=!Jb(x[d+204>>1])|Y;break M}Z=w[d+201|0]==64|Z}o=h&1;h=0;N:{if(!o){break N}k=(i<<1)+k|0;o=w[d+200|0];h=!o;if(o|!i){break N}h=w[d+201|0]==64}E=p+E|0;j=f+j|0;g=g+1|0;continue}}fb=d+336|0;return g|0}function M5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=C(0),A=C(0),D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=C(0),_=C(0),$=0,aa=C(0);a:{if(!w[a+5046|0]){break a}g=z[a+4268>>2];YJ(a);if(g==z[a+4268>>2]){break a}sx(a)}b:{if(!w[a+5045|0]){break b}if(!Th(a+44|0)){break b}n=v[a+44>>2];q=zc(n,0);r=zc(n,1);n=v[a+56>>2];l=zc(n,0);m=zc(n,1);c:{if(!(!w[a+5044|0]|(!d|w[a+4264|0]&2))){z[l>>2]=z[a+5036>>2];z[m>>2]=z[a+5040>>2];t[a+5044|0]=0;r=r+4|0;q=q+4|0;m=m+4|0;l=l+4|0;p=d-1|0;break c}p=d}s=p;u=a+4888|0;x=a+4864|0;W=a+4504|0;X=a+4868|0;Y=a+4892|0;G=a+4628|0;H=a+4604|0;S=a+4916|0;I=a+4532|0;J=a+4508|0;K=a+4772|0;L=a+4748|0;T=a+4940|0;M=a+4676|0;N=a+4652|0;O=a+4724|0;P=a+4700|0;U=a+4844|0;Q=a+4580|0;R=a+4556|0;V=a+4820|0;d:{while(1){if(!s){break d}g=z[q>>2];g=C(C(C(z[a+5008>>2]-g)*z[a+4276>>2])+g);z[a+5008>>2]=g;$=Gc(v[a+4864>>2],v[X>>2],v[a+4880>>2]),aa=g,z[$>>2]=aa;g=z[r>>2];g=C(C(C(z[a+5012>>2]-g)*z[a+4276>>2])+g);z[a+5012>>2]=g;$=Gc(v[a+4888>>2],v[Y>>2],v[a+4904>>2]),aa=g,z[$>>2]=aa;g=C(C(C(C(C(Jh(x,v[a+4356>>2])*C(.6800000071525574))+C(Jh(x,v[a+4360>>2])*C(-.5)))-C(Jh(x,v[a+4364>>2])*C(.6200000047683716)))+C(Jh(x,v[a+4368>>2])*C(-.5)))-C(Jh(x,v[a+4372>>2])*C(.6200000047683716)));if(t[a+4264|0]&1){e=g;g=C(z[Gc(v[a+4816>>2],v[V>>2],v[a+4836>>2])>>2]+C(e*C(.6180340051651001)));$=Gc(v[a+4816>>2],v[V>>2],v[a+4832>>2]),aa=C(e-C(g*C(.6180340051651001))),z[$>>2]=aa}y=z[a+4280>>2];$=a,aa=C(Jh(x,v[a+4352>>2])+z[a+5020>>2]),z[$+5020>>2]=aa;e=C(Jh(u,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=e;f=z[a+5020>>2];h=C(C(C(z[a+4980>>2]-z[Gc(v[a+4624>>2],v[G>>2],v[a+4644>>2])>>2])*z[a+4444>>2])+z[Gc(v[a+4624>>2],v[G>>2],v[a+4644>>2])>>2]);z[a+4980>>2]=h;k=C(h*z[a+4440>>2]);j=C(e*C(.7070000171661377));i=C(f*C(-.7070000171661377));f=C(j+i);h=z[a+4272>>2];e=C(k+C(f*h));$=Gc(v[a+4624>>2],v[G>>2],v[a+4640>>2]),aa=C(f-C(h*e)),z[$>>2]=aa;f=C(C(C(z[a+4976>>2]-z[Gc(v[a+4600>>2],v[H>>2],v[a+4620>>2])>>2])*z[a+4436>>2])+z[Gc(v[a+4600>>2],v[H>>2],v[a+4620>>2])>>2]);z[a+4976>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4432>>2])+C(e*h));$=Gc(v[a+4600>>2],v[H>>2],v[a+4616>>2]),aa=C(e-C(h*f)),z[$>>2]=aa;A=C(C(e*C(-.15000000596046448))+C(f*C(-.20000000298023224)));if(t[a+4264|0]&1){e=C(C(C(z[a+4972>>2]-z[Gc(v[a+4576>>2],v[Q>>2],v[a+4596>>2])>>2])*z[a+4428>>2])+z[Gc(v[a+4576>>2],v[Q>>2],v[a+4596>>2])>>2]);z[a+4972>>2]=e;h=z[a+4272>>2];e=C(C(e*z[a+4424>>2])+C(f*h));$=Gc(v[a+4576>>2],v[Q>>2],v[a+4592>>2]),aa=C(f-C(h*e)),z[$>>2]=aa;f=C(C(C(z[a+4968>>2]-z[Gc(v[a+4552>>2],v[R>>2],v[a+4572>>2])>>2])*z[a+4420>>2])+z[Gc(v[a+4552>>2],v[R>>2],v[a+4572>>2])>>2]);z[a+4968>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4416>>2])+C(e*h));$=Gc(v[a+4552>>2],v[R>>2],v[a+4568>>2]),aa=C(e-C(h*f)),z[$>>2]=aa;A=C(C(C(e*C(.3499999940395355))+A)+C(f*C(-.3799999952316284)))}$=Gc(v[a+4912>>2],v[S>>2],v[a+4928>>2]),aa=f,z[$>>2]=aa;e=C(z[Gc(v[a+4912>>2],v[S>>2],v[a+4932>>2])>>2]*z[a+4496>>2]);z[a+5028>>2]=C(C(z[a+5028>>2]-e)*z[a+4500>>2])+e;e=C(C(C(z[a+4964>>2]-z[Gc(v[a+4528>>2],v[I>>2],v[a+4548>>2])>>2])*z[a+4412>>2])+z[Gc(v[a+4528>>2],v[I>>2],v[a+4548>>2])>>2]);z[a+4964>>2]=e;f=z[a+5028>>2];k=z[a+4272>>2];h=C(C(f*k)+C(e*z[a+4408>>2]));$=Gc(v[a+4528>>2],v[I>>2],v[a+4544>>2]),aa=C(f-C(k*h)),z[$>>2]=aa;e=C(C(C(z[a+4960>>2]-z[Gc(v[a+4504>>2],v[J>>2],v[a+4524>>2])>>2])*z[a+4404>>2])+z[Gc(v[a+4504>>2],v[J>>2],v[a+4524>>2])>>2]);z[a+4960>>2]=e;f=C(e*z[a+4400>>2]);e=z[a+4272>>2];k=C(f+C(h*e));$=Gc(v[a+4504>>2],v[J>>2],v[a+4520>>2]),aa=C(h-C(e*k)),z[$>>2]=aa;z[a+5020>>2]=k;e=C(C(C(C(C(Jh(u,v[a+4380>>2])*C(.7070000171661377))+C(Jh(u,v[a+4384>>2])*C(-.6000000238418579)))-C(Jh(u,v[a+4388>>2])*C(.5)))+C(Jh(u,v[a+4392>>2])*C(-.6000000238418579)))-C(Jh(u,v[a+4396>>2])*C(.5)));if(t[a+4264|0]&1){f=e;e=C(z[Gc(v[a+4840>>2],v[U>>2],v[a+4860>>2])>>2]+C(e*C(.6180340051651001)));$=Gc(v[a+4840>>2],v[U>>2],v[a+4856>>2]),aa=C(f-C(e*C(.6180340051651001))),z[$>>2]=aa}Z=z[a+4280>>2];f=C(C(C(z[a+5004>>2]-z[Gc(v[a+4768>>2],v[K>>2],v[a+4788>>2])>>2])*z[a+4492>>2])+z[Gc(v[a+4768>>2],v[K>>2],v[a+4788>>2])>>2]);z[a+5004>>2]=f;_=C(f*z[a+4488>>2]);f=C(i-j);i=z[a+4272>>2];j=C(_+C(f*i));$=Gc(v[a+4768>>2],v[K>>2],v[a+4784>>2]),aa=C(f-C(i*j)),z[$>>2]=aa;f=C(C(C(z[a+5e3>>2]-z[Gc(v[a+4744>>2],v[L>>2],v[a+4764>>2])>>2])*z[a+4484>>2])+z[Gc(v[a+4744>>2],v[L>>2],v[a+4764>>2])>>2]);z[a+5e3>>2]=f;i=z[a+4272>>2];f=C(C(f*z[a+4480>>2])+C(j*i));$=Gc(v[a+4744>>2],v[L>>2],v[a+4760>>2]),aa=C(j-C(i*f)),z[$>>2]=aa;j=C(C(C(h*C(.3799999952316284))+C(j*C(-.15000000596046448)))+C(f*C(-.20000000298023224)));if(t[a+4264|0]&1){h=C(C(C(z[a+4996>>2]-z[Gc(v[a+4720>>2],v[O>>2],v[a+4740>>2])>>2])*z[a+4476>>2])+z[Gc(v[a+4720>>2],v[O>>2],v[a+4740>>2])>>2]);z[a+4996>>2]=h;i=z[a+4272>>2];h=C(C(h*z[a+4472>>2])+C(f*i));$=Gc(v[a+4720>>2],v[O>>2],v[a+4736>>2]),aa=C(f-C(i*h)),z[$>>2]=aa;f=C(C(C(z[a+4992>>2]-z[Gc(v[a+4696>>2],v[P>>2],v[a+4716>>2])>>2])*z[a+4468>>2])+z[Gc(v[a+4696>>2],v[P>>2],v[a+4716>>2])>>2]);z[a+4992>>2]=f;i=z[a+4272>>2];f=C(C(f*z[a+4464>>2])+C(h*i));$=Gc(v[a+4696>>2],v[P>>2],v[a+4712>>2]),aa=C(h-C(i*f)),z[$>>2]=aa;j=C(C(C(h*C(.3499999940395355))+j)+C(f*C(-.3799999952316284)))}n=r+4|0;p=q+4|0;h=C(g*y);A=C(A-C(k*C(.3799999952316284)));k=C(e*Z);$=Gc(v[a+4936>>2],v[T>>2],v[a+4952>>2]),aa=f,z[$>>2]=aa;g=C(z[Gc(v[a+4936>>2],v[T>>2],v[a+4956>>2])>>2]*z[a+4496>>2]);z[a+5032>>2]=C(C(z[a+5032>>2]-g)*z[a+4500>>2])+g;g=C(C(C(z[a+4988>>2]-z[Gc(v[a+4672>>2],v[M>>2],v[a+4692>>2])>>2])*z[a+4460>>2])+z[Gc(v[a+4672>>2],v[M>>2],v[a+4692>>2])>>2]);z[a+4988>>2]=g;e=z[a+5032>>2];f=z[a+4272>>2];g=C(C(e*f)+C(g*z[a+4456>>2]));$=Gc(v[a+4672>>2],v[M>>2],v[a+4688>>2]),aa=C(e-C(f*g)),z[$>>2]=aa;f=z[a+4284>>2];e=C(C(C(z[a+4984>>2]-z[Gc(v[a+4648>>2],v[N>>2],v[a+4668>>2])>>2])*z[a+4452>>2])+z[Gc(v[a+4648>>2],v[N>>2],v[a+4668>>2])>>2]);z[a+4984>>2]=e;y=z[a+4272>>2];e=C(C(e*z[a+4448>>2])+C(g*y));$=Gc(v[a+4648>>2],v[N>>2],v[a+4664>>2]),aa=C(g-C(y*e)),z[$>>2]=aa;z[a+5024>>2]=e;e=C(-e);y=z[a+4288>>2];F=0;e:{f:{while(1){if((F|0)==19){g:{e=C(k+C(C(C(e*C(.3799999952316284))+j)*y));g=C(h+C(C(C(g*C(.3799999952316284))+A)*f));if(!(w[a+4264|0]&2)){break g}break f}}else{o=B(F,24)+W|0;D=v[o+16>>2];E=D-1|0;v[o+16>>2]=E;if((D|0)<=0){v[o+16>>2]=E+v[o+12>>2]}E=v[o+20>>2];D=E-1|0;v[o+20>>2]=D;if((E|0)<=0){v[o+20>>2]=D+v[o+12>>2]}F=F+1|0;continue}break}z[l>>2]=C(g+z[a+5036>>2])*C(.5);z[m>>2]=C(e+z[a+5040>>2])*C(.5);z[a+5040>>2]=e;z[a+5036>>2]=g;if((s|0)==1){break e}s=s-1|0;m=m+4|0;l=l+4|0;n=r+8|0;p=q+8|0}q=p;r=n;z[l>>2]=g;z[m>>2]=e;s=s-1|0;m=m+4|0;l=l+4|0;continue}break}t[a+5044|0]=1}p=a;a=v[a+56>>2];hi(p,b,c,zc(a,0),zc(a,1),d)}}function eda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=fb-288|0;fb=g;e=fb-128|0;fb=e;f=fe(g+104|0,c);v[23220]=0;n=T(161,f+20|0)|0;c=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){v[23220]=0;p=T(161,f+40|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break B}v[23220]=0;q=T(161,f+60|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break A}v[23220]=0;i=T(161,f+80|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break z}v[23220]=0;o=T(161,f+100|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break y}v[23220]=0;k=T(161,f+120|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break x}j=Ib(f+140|0);wc(f);v[f+172>>2]=1873739776;u[f+176>>1]=0;v[23220]=0;d=Q(741,f|0,e+112|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break w}if(!d){break n}d=v[e+112>>2];if((d|0)!=1414744396&(d|0)!=1179011410){break n}c=v[e+120>>2];if((c|0)!=1163280727&(c|0)!=1702257015){break n}t[f+176|0]=(d|0)==1414744396;v[23220]=0;U(742,e+96|0,f|0,2);c=v[23220];v[23220]=0;if((c|0)==1){break v}h=v[e+96>>2];C:{if(oq(h,v[e+100>>2])>>>0<4){break C}c=Sx(h,1);d=v[c+4>>2];c=v[c>>2];wi(e+40|0,c,d);if(v[e+40>>2]!=1635017060){break C}wi(e- -64|0,c,d);if(!(t[e+68|0]&1)){break C}c=Sx(h,2);wi(e+24|0,v[c>>2],v[c+4>>2]);if(v[e+28>>2]){break C}c=Sx(h,3);wi(e+88|0,v[c>>2],v[c+4>>2]);if(v[e+88>>2]){break C}v[23220]=0;Q(142,f|0,12)|0;c=v[23220];v[23220]=0;if((c|0)==1){break u}v[23220]=0;U(742,e+40|0,f|0,1);c=v[23220];v[23220]=0;if((c|0)==1){break t}c=e+40|0;wt(e+96|0,c);Vd(c)}v[23220]=0;U(743,e- -64|0,e+96|0,544501094);c=v[23220];v[23220]=0;if((c|0)==1){break s}v[23220]=0;d=Q(744,e- -64|0,f+156|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break k}if(!d){break o}d=x[f+156>>1];if((d|0)!=1){break q}v[23220]=0;d=T(189,e- -64|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break r}break k}d=P()|0;O()|0;break b}d=P()|0;O()|0;break c}d=P()|0;O()|0;break d}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}d=P()|0;O()|0;break g}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}if((d|0)==4){v[23220]=0;h=T(184,e- -64|0)|0;c=v[23220];v[23220]=0;D:{if((c|0)!=1){v[23220]=0;d=T(184,e- -64|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break D}if((h|0)!=2|(d|0)!=1){break p}t[f+177|0]=1;break p}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=x[f+156>>1]}if((d&65535)!=65534){break p}v[23220]=0;d=Q(745,e- -64|0,e+40|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break l}if(!d){break o}c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;c=v[e+52>>2];v[e+8>>2]=v[e+48>>2];v[e+12>>2]=c;c=e+24|0;v[c>>2]=w[e+8|0]|w[e+9|0]<<8|(w[e+10|0]<<16|w[e+11|0]<<24);u[c+4>>1]=w[e+12|0]|w[e+13|0]<<8;u[c+6>>1]=w[e+14|0]|w[e+15|0]<<8;r=c,s=gA(w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24),w[e+20|0]|w[e+21|0]<<8|(w[e+22|0]<<16|w[e+23|0]<<24)),v[r+8>>2]=s;v[c+12>>2]=ib;u[f+172>>1]=v[c>>2]}v[23220]=0;U(743,e+40|0,e+96|0,1635017060);c=v[23220];v[23220]=0;E:{F:{G:{H:{I:{J:{if((c|0)!=1){c=e+40|0;m=Yc(n,c);wb(c);c=v[m>>2];v[23220]=0;d=T(165,c|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break k}if(!d){v[23220]=0;U(743,e+40|0,e+96|0,544039792);c=v[23220];v[23220]=0;if((c|0)==1){break J}c=e+40|0;Yc(m,c);wb(c)}v[23220]=0;U(743,e+40|0,e+96|0,1952670054);c=v[23220];v[23220]=0;if((c|0)==1){break I}v[23220]=0;d=T(144,e+40|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break H}v[f+152>>2]=d;wb(e+40|0);if(v[f+152>>2]?x[f+156>>1]==17:0){break E}h=x[f+158>>1];d=uL(h,x[f+170>>1]);if(!d){break E}c=x[f+168>>1];if((c>>>0)/(h>>>0)>>>0<d<<1>>>0?c:0){break G}c=v[m>>2];v[23220]=0;d=T(147,c|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break k}c=uL(x[f+158>>1],x[f+170>>1]);break F}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;wb(e+40|0);break j}c=v[m>>2];v[23220]=0;d=T(147,c|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break k}c=x[f+168>>1]}v[f+152>>2]=(d>>>0)/((c&65535)>>>0)}v[23220]=0;d=Q(746,f|0,e+96|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break k}u[f+174>>1]=d;v[23220]=0;R(747,f|0,e+96|0);c=v[23220];v[23220]=0;if((c|0)==1){break k}v[23220]=0;U(743,e+40|0,e+96|0,1886221175);c=v[23220];v[23220]=0;if((c|0)==1){break m}c=e+40|0;Yc(o,c);wb(c)}wb(e- -64|0);Vd(e+96|0)}fb=e+128|0;break a}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0}wb(e- -64|0)}Vd(e+96|0)}Vd(j);wb(k)}wb(o)}wb(i)}wb(q)}wb(p)}wb(n)}wb(f);S(d|0);L()}c=v[f+20>>2];v[23220]=0;d=T(680,c|0)|0;c=v[23220];v[23220]=0;K:{L:{if((c|0)!=1){M:{if(!d|(x[f+158>>1]-3&65535)>>>0<65534){break M}N:{O:{c=x[f+170>>1];P:{if(!c){if((Uj(f)|0)==85){break P}break M}if(c>>>0>31){break O}}if((Uj(f)|0)!=3){break N}break M}if(c>>>0>64){break M}}d=Uj(f);c=30240;while(1){Q:{R:{if((c|0)!=30264){if((d|0)!=v[c>>2]){break R}}else{c=30264}break Q}c=c+4|0;continue}break}if((c|0)==30264){break M}Xs(a,b);v[23220]=0;d=Q(52,g+88|0,21598)|0;c=v[23220];v[23220]=0;S:{T:{U:{V:{W:{if((c|0)!=1){h=yc(((b<<5)+a|0)+946304|0,d);ub(d);v[23220]=0;d=B(b,104)+a|0;i=d+484380|0;R(267,i|0,0);c=v[23220];v[23220]=0;if((c|0)==1){break W}v[i>>2]=v[f+152>>2];v[d+484404>>2]=v[f+160>>2];c=v[a+1298404>>2];v[23220]=0;X(681,f|0,i|0,c|0,h|0);c=v[23220];v[23220]=0;if((c|0)==1){break W}fe(g- -64|0,f+20|0);d=x[f+158>>1];j=Uc(g+56|0,8,d>>>0>1?2:1,0,0);c=Uj(f);if((c|0)!=17|d>>>0>2){break U}uc(i,268435456);c=B(b,104)+a|0;b=c+484414|0;u[b>>1]=x[b>>1]&65470|((d|0)==2)<<6|1;if(wg(i)){break V}break S}l=P()|0;O()|0;break K}l=P()|0;O()|0;break K}j=v[c+484400>>2];h=v[i>>2];k=fe(g+32|0,g- -64|0);d=x[f+158>>1];c=x[f+168>>1];v[23220]=0;b=v[k+12>>2];v[g+16>>2]=v[k+8>>2];v[g+20>>2]=b;v[g+24>>2]=v[k+16>>2];b=v[k+4>>2];v[g+8>>2]=v[k>>2];v[g+12>>2]=b;da(682,j|0,h|0,g+8|0,c|0,d|0);b=v[23220];v[23220]=0;if((b|0)==1){break L}ij(i,a);break T}if((c|0)==85){v[23220]=0;c=W(519,a|0,b|0,g- -64|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break L}if(c){break T}break S}X:{Y:{Z:{if(lP(x[f+156>>1])){break Z}_:{if(!Nd(w[f+177|0])){break _}if((Uj(f)|0)!=1|x[f+170>>1]!=32|x[f+168>>1]!=d<<2){break _}Eh(j,32);b=12;break Y}if((Uj(f)|0)!=1|x[f+170>>1]!=24|x[f+168>>1]!=d<<2){break Z}Eh(j,32);b=13;break Y}if((Uj(f)&65534)!=6){break X}Eh(j,16);b=(Uj(f)|0)==6?17:16}Qf(j,b);v[23220]=0;W(206,j|0,i|0,g- -64|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break T}break L}d=x[f+170>>1];c=(d-1>>>3|0)-1|0;b=c<<3;h=b&31;Eh(j,(c>>>0<7?(b&63)>>>0>=32?4196360>>>h|0:((1<<h)-1&4196360)<<32-h|136321040>>>h:8)&255);if(d>>>0<9){Qf(j,1)}if((Uj(f)|0)==3){Qf(j,3)}v[23220]=0;W(206,j|0,i|0,g- -64|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break L}}oz(i,v[a+480180>>2]);ij(i,a);l=1}wb(g- -64|0)}kP(f);fb=g+288|0;return l|0}l=P()|0;O()|0;break K}l=P()|0;O()|0;wb(g- -64|0)}kP(f);S(l|0);L()}function nI(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=fb-272|0;fb=h;a:{b:{if(g){Ge(h+256|0,f,32);v[23220]=0;W(485,h+240|0,f|0,32)|0;k=v[23220];v[23220]=0;if((k|0)!=1){break b}f=P()|0;O()|0;break a}Gb(h+256|0);Gb(h+240|0)}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if(Xr(c)){k=v[b+24>>2];i=v[k+484344>>2];if(ke(i,v[k+484348>>2],c&65535)){break o}}v[23220]=0;U(1059,a|0,h+256|0,h+240|0);a=v[23220];v[23220]=0;if((a|0)!=1){break n}f=P()|0;O()|0;break c}c=Xb(i,c);if(!(!((e|0)<0|v[c+12>>2]<=(d|0)|(d|0)<0)&x[k+480188>>1]>e>>>0)){v[23220]=0;U(1059,a|0,h+256|0,h+240|0);a=v[23220];v[23220]=0;if((a|0)!=1){break n}f=P()|0;O()|0;break c}c=$c(v[c>>2],v[v[c+48>>2]+12>>2],d,e&65535);Lf(h+256|0);Lf(h+240|0);p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{d=w[c|0];if(!Oc(d)){if(!pp(d)){break F}}e=w[c+1|0];k=v[b+24>>2];v[23220]=0;X(1060,h+208|0,k|0,d|0,e|0);d=v[23220];v[23220]=0;e=1;if((d|0)==1){break D}v[23220]=0;R(981,h+224|0,h+208|0);d=v[23220];v[23220]=0;if((d|0)!=1){break E}f=P()|0;O()|0;break A}e=0;v[23220]=0;Q(52,h+224|0,16709)|0;d=v[23220];v[23220]=0;if((d|0)==1){break C}}v[23220]=0;k=Q(772,h+256|0,h+224|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break B}ub(h+224|0);if(e){vb(h+208|0)}e=9929;d=w[c|0];if(!Oc(d)){e=pp(d)?10239:16709}v[23220]=0;d=Q(52,h+224|0,e|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break z}v[23220]=0;e=Q(772,h+240|0,d|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break y}ub(d);if(f-6>>>0>4294967290){break q}v[23220]=0;d=Q(52,h+192|0,17769)|0;i=v[23220];v[23220]=0;if((i|0)==1){break x}v[23220]=0;i=Q(772,k|0,d|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break w}ub(d);v[23220]=0;d=Q(52,h+176|0,17769)|0;l=v[23220];v[23220]=0;if((l|0)==1){break v}v[23220]=0;l=Q(772,e|0,d|0)|0;j=v[23220];v[23220]=0;if((j|0)==1){break u}ub(d);d=c+1|0;G:{if(w[c+1|0]){v[23220]=0;R(503,h+160|0,d|0);j=v[23220];v[23220]=0;if((j|0)!=1){break G}break d}v[23220]=0;Q(52,h+160|0,16714)|0;j=v[23220];v[23220]=0;if((j|0)==1){break d}}v[23220]=0;j=Q(772,i|0,h+160|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break t}i=h+160|0;ub(i);d=w[d|0];v[23220]=0;d=Q(52,i|0,(d?10729:16714)|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break s}v[23220]=0;l=Q(772,l|0,d|0)|0;i=v[23220];v[23220]=0;if((i|0)!=1){break r}f=P()|0;O()|0;ub(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;ub(h+224|0);if(!e){break c}}vb(h+208|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;ub(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;ub(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;ub(d);break c}f=P()|0;O()|0;ub(h+160|0);break c}f=P()|0;O()|0;break c}ub(d);if(f-9>>>0>4294967287){break q}H:{I:{J:{K:{L:{M:{N:{i=Mg(w[c|0]);O:{if(i){v[23220]=0;m=Q(52,h+128|0,17769)|0;d=v[23220];v[23220]=0;if((d|0)==1){break N}d=w[c+4|0];n=w[c+2|0];v[23220]=0;o=h,p=Rj(n,d)&255,v[o+96>>2]=p;R(502,h+112|0,h+96|0);d=v[23220];v[23220]=0;if((d|0)==1){break M}d=0;v[23220]=0;U(938,h+144|0,m|0,h+112|0);m=v[23220];v[23220]=0;if((m|0)!=1){break O}f=P()|0;O()|0;break f}d=w[c+2|0];if(d){d=mL(v[v[v[b+24>>2]+8>>2]+88>>2],d);v[23220]=0;d=W(485,h+128|0,1,d|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break J}v[23220]=0;R(503,h+112|0,c+4|0);m=v[23220];v[23220]=0;if((m|0)==1){break L}v[23220]=0;U(938,h+144|0,d|0,h+112|0);m=v[23220];v[23220]=0;d=1;if((m|0)!=1){break O}f=P()|0;O()|0;break i}d=0;v[23220]=0;Q(52,h+144|0,16713)|0;m=v[23220];v[23220]=0;if((m|0)==1){break j}}v[23220]=0;j=Q(772,j|0,h+144|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break K}ub(h+144|0);if(d){ub(h+112|0);ub(h+128|0)}if(i){ub(h+112|0);ub(h+128|0)}d=5449;if(!Mg(w[c|0])){d=w[c+2|0]?5445:16713}v[23220]=0;d=Q(52,h+144|0,d|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break I}v[23220]=0;i=Q(772,l|0,d|0)|0;l=v[23220];v[23220]=0;if((l|0)!=1){break H}f=P()|0;O()|0;ub(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break e}f=P()|0;O()|0;break h}f=P()|0;O()|0;ub(h+144|0);if(d){break i}break g}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}ub(d);if(f-13>>>0>4294967283){break q}v[23220]=0;d=Q(52,h+96|0,17769)|0;l=v[23220];v[23220]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((l|0)!=1){v[23220]=0;l=Q(772,j|0,d|0)|0;j=v[23220];v[23220]=0;if((j|0)==1){break Z}ub(d);v[23220]=0;d=Q(52,h+80|0,17769)|0;j=v[23220];v[23220]=0;if((j|0)==1){break Y}v[23220]=0;i=Q(772,i|0,d|0)|0;j=v[23220];v[23220]=0;if((j|0)==1){break X}ub(d);_:{if(Mg(w[c|0])){d=w[c+5|0];j=w[c+3|0];b=0;v[23220]=0;o=h,p=Rj(j,d)&4095,v[o+16>>2]=p;R(1061,h- -64|0,h+16|0);d=v[23220];v[23220]=0;if((d|0)!=1){break _}f=P()|0;O()|0;break c}d=w[c+3|0];if(d){b=lL(v[v[v[b+24>>2]+8>>2]+84>>2],d);v[23220]=0;b=W(485,h+48|0,1,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break W}v[23220]=0;R(503,h+32|0,c+5|0);d=v[23220];v[23220]=0;if((d|0)==1){break V}v[23220]=0;U(938,h- -64|0,b|0,h+32|0);d=v[23220];v[23220]=0;b=1;if((d|0)!=1){break _}f=P()|0;O()|0;break S}b=0;v[23220]=0;Q(52,h- -64|0,16709)|0;d=v[23220];v[23220]=0;if((d|0)==1){break U}}v[23220]=0;Q(772,l|0,h- -64|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break T}ub(h- -64|0);if(b){ub(h+32|0);ub(h+48|0)}b=11072;if(!Mg(w[c|0])){b=w[c+3|0]?11072:16709}v[23220]=0;b=Q(52,h- -64|0,b|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break Q}v[23220]=0;Q(772,i|0,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break P}f=P()|0;O()|0;ub(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;ub(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;ub(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break R}f=P()|0;O()|0;break c}f=P()|0;O()|0;ub(h- -64|0);if(!b){break c}}ub(h+32|0)}ub(h+48|0);break c}f=P()|0;O()|0;break c}ub(b);if(!f){break p}}$:{aa:{ba:{ca:{b=Bb(k);da:{if(b>>>0>f>>>0){v[23220]=0;X(117,h+16|0,k|0,0,f|0);b=v[23220];v[23220]=0;if((b|0)!=1){b=h+16|0;xc(k,b);ub(b);break da}f=P()|0;O()|0;break c}if(!g){break da}v[23220]=0;b=W(485,h+16|0,f-b|0,32)|0;c=v[23220];v[23220]=0;if((c|0)==1){break ca}v[23220]=0;Q(772,k|0,b|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break ba}ub(b)}b=Bb(e);if(b>>>0<=f>>>0){break $}v[23220]=0;X(117,h|0,e|0,0,f|0);b=v[23220];v[23220]=0;if((b|0)==1){break aa}xc(e,h);ub(h);break p}f=P()|0;O()|0;break c}f=P()|0;O()|0;ub(b);break c}f=P()|0;O()|0;break c}if(!g){break p}v[23220]=0;b=W(485,h|0,f-b|0,32)|0;c=v[23220];v[23220]=0;if((c|0)==1){break m}v[23220]=0;Q(772,e|0,b|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break l}ub(b)}v[23220]=0;U(1059,a|0,k|0,e|0);a=v[23220];v[23220]=0;if((a|0)==1){break k}}ub(h+240|0);ub(h+256|0);fb=h+272|0;return}f=P()|0;O()|0;break c}f=P()|0;O()|0;ub(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}ub(h+112|0)}ub(h+128|0)}if(!i){break c}}ub(h+112|0)}ub(h+128|0);break c}f=P()|0;O()|0}ub(h+240|0)}ub(h+256|0);S(f|0);L()}function PZ(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=fb-560|0;fb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+96>>2]=1126;k=l+96|0;s=he(l+136|0,l+144|0,k);b=v[s>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;y=Gb(k);o=Gb(l+80|0);p=Gb(l- -64|0);q=Gb(l+48|0);u=Gb(l+32|0);v[23220]=0;ma(1135,c|0,d|0,l+120|0,l+116|0,l+112|0,y|0,o|0,p|0,q|0,l+28|0);c=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{if((c|0)!=1){v[j>>2]=v[i>>2];z=e&512;A=z>>>9|0;c=v[l+28>>2];while(1){g:{h:{i:{j:{k:{if((r|0)==4){break k}v[23220]=0;d=Q(1109,a|0,l+552|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}if(!d){break k}l:{m:{n:{o:{p:{q:{switch(t[(l+120|0)+r|0]){case 1:if((r|0)==3){break h}d=v[a>>2];v[23220]=0;d=T(1111,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}v[23220]=0;d=W(1136,h|0,8192,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}if(d){v[23220]=0;R(1137,l+16|0,a|0);d=v[23220];v[23220]=0;if((d|0)!=1){v[23220]=0;R(46,u|0,v[l+16>>2]);d=v[23220];v[23220]=0;if((d|0)!=1){break p}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break g;case 4:break m;case 2:break n;case 3:break o;case 0:break q;default:break h}}if((r|0)==3){break h}}while(1){v[23220]=0;d=Q(1109,a|0,l+552|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break b}if(!d){break h}d=v[a>>2];v[23220]=0;d=T(1111,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break b}v[23220]=0;d=W(1136,h|0,8192,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break b}if(!d){break h}v[23220]=0;R(1137,l+16|0,a|0);d=v[23220];v[23220]=0;if((d|0)!=1){v[23220]=0;R(46,u|0,v[l+16>>2]);d=v[23220];v[23220]=0;if((d|0)!=1){continue}}break}a=P()|0;O()|0;break a}d=Bb(p);k=Bb(q);if((d|0)==(0-k|0)){break h}e=v[a>>2];if(!(k?d:0)){if(d){v[23220]=0;d=T(1111,e|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}if((d|0)!=v[pc(p)>>2]){break l}v[23220]=0;T(1113,a|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}n=Bb(p)>>>0>1?p:n;break h}v[23220]=0;d=T(1111,e|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}if((d|0)!=v[pc(q)>>2]){break h}v[23220]=0;T(1113,a|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}t[g|0]=1;n=Bb(q)>>>0>1?q:n;break h}v[23220]=0;d=T(1111,e|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}if((d|0)==v[pc(p)>>2]){v[23220]=0;T(1113,a|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}n=Bb(p)>>>0>1?p:n;break h}d=v[a>>2];v[23220]=0;d=T(1111,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}if((d|0)==v[pc(q)>>2]){v[23220]=0;T(1113,a|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}t[g|0]=1;n=Bb(q)>>>0>1?q:n;break h}v[f>>2]=v[f>>2]|4;a=0;break g}if(!(r>>>0<2|n|((r|0)==2&w[l+123|0]!=0|A))){n=0;break h}e=dc(l+16|0,Td(o));r:{s:{if(!r|w[(l+r|0)+119|0]>1){break s}while(1){t:{d=uk(o);k=v[e>>2];if(!Nb(k,d)){break t}d=v[k>>2];v[23220]=0;d=W(1136,h|0,8192,d|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break r}if(!d){break t}ye(e);continue}break}d=Td(o);d=Gt(v[e>>2],d);if(Bb(u)>>>0>=d>>>0){k=Yl(uk(u),0-d|0);m=uk(u);x=Td(o);d=fb-16|0;fb=d;v[d>>2]=x;v[d+8>>2]=k;while(1){u:{x=Nb(k,m);if(!x){break u}if(!rc(v[k>>2],v[v[d>>2]>>2])){break u}k=ye(d+8|0);ye(d);k=v[k>>2];continue}break}fb=d+16|0;if(x^1){break s}}B=e,C=v[dc(l+8|0,Td(o))>>2],v[B>>2]=C}v[l+8>>2]=v[e>>2];v:{while(1){d=uk(o);if(!Nb(v[l+8>>2],d)){break v}v[23220]=0;d=Q(1109,a|0,l+552|0)|0;e=v[23220];v[23220]=0;w:{if((e|0)==1){break w}if(!d){break v}d=v[a>>2];v[23220]=0;d=T(1111,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break w}if((d|0)!=v[v[l+8>>2]>>2]){break v}v[23220]=0;T(1113,a|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break d}ye(l+8|0);continue}break}break d}if(!z){break h}d=uk(o);if(!Nb(v[l+8>>2],d)){break h}v[f>>2]=v[f>>2]|4;a=0;break g}break d}d=0;m=v[l+112>>2];x:{while(1){y:{v[23220]=0;e=Q(1109,a|0,l+552|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break y}if(!e){break x}e=v[a>>2];v[23220]=0;e=T(1111,e|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break f}v[23220]=0;k=W(1136,h|0,2048,e|0)|0;x=v[23220];v[23220]=0;if((x|0)==1){break f}z:{if(k){k=v[j>>2];if((k|0)==v[l+548>>2]){v[23220]=0;U(1138,i|0,j|0,l+548|0);k=v[23220];v[23220]=0;if((k|0)==1){break f}k=v[j>>2]}v[j>>2]=k+4;v[k>>2]=e;d=d+1|0;break z}if(!Bb(y)|!d|(e|0)!=(m|0)){break x}if(v[l+128>>2]==(b|0)){v[23220]=0;U(1132,s|0,l+132|0,l+128|0);b=v[23220];v[23220]=0;if((b|0)==1){break f}b=v[l+132>>2]}e=b+4|0;v[l+132>>2]=e;v[b>>2]=d;b=e;d=0}v[23220]=0;T(1113,a|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!d|v[s>>2]==(b|0)){break j}if(v[l+128>>2]==(b|0)){v[23220]=0;U(1132,s|0,l+132|0,l+128|0);b=v[23220];v[23220]=0;if((b|0)==1){break e}b=v[l+132>>2]}e=b+4|0;v[l+132>>2]=e;v[b>>2]=d;break i}t[g|0]=1;break h}v[l+28>>2]=c;A:{if(!n){break A}c=1;while(1){if(Bb(n)>>>0<=c>>>0){break A}v[23220]=0;d=Q(1110,a|0,l+552|0)|0;e=v[23220];v[23220]=0;B:{if((e|0)==1){break B}C:{if(!d){d=v[a>>2];v[23220]=0;d=T(1111,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break B}if((d|0)==v[ej(n,c)>>2]){break C}}v[f>>2]=v[f>>2]|4;a=0;break g}v[23220]=0;T(1113,a|0)|0;d=v[23220];v[23220]=0;c=c+1|0;if((d|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;c=v[s>>2];if((c|0)==(b|0)){break g}a=0;v[l+16>>2]=0;pf(y,c,b,l+16|0);if(v[l+16>>2]){v[f>>2]=v[f>>2]|4;break g}a=1;break g}e=b}D:{if((c|0)<=0){break D}v[23220]=0;b=Q(1110,a|0,l+552|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}E:{if(!b){b=v[a>>2];v[23220]=0;b=T(1111,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}if((b|0)==v[l+116>>2]){break E}}v[l+28>>2]=c;v[f>>2]=v[f>>2]|4;a=0;break g}v[23220]=0;b=T(1113,a|0)|0;k=v[23220];v[23220]=0;d=c;if((k|0)==1){break e}while(1){if((d|0)<=0){c=0;break D}v[23220]=0;k=Q(1110,b|0,l+552|0)|0;m=v[23220];v[23220]=0;F:{if((m|0)==1){break F}G:{if(!k){k=v[b>>2];v[23220]=0;k=T(1111,k|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break F}v[23220]=0;k=W(1136,h|0,2048,k|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break F}if(k){break G}}v[l+28>>2]=d;v[f>>2]=v[f>>2]|4;a=0;break g}if(v[j>>2]==v[l+548>>2]){v[23220]=0;U(1138,i|0,j|0,l+548|0);k=v[23220];v[23220]=0;if((k|0)==1){break F}}k=v[b>>2];v[23220]=0;k=T(1111,k|0)|0;m=v[23220];v[23220]=0;if((m|0)==1){break F}m=v[j>>2];v[j>>2]=m+4;v[m>>2]=k;v[23220]=0;T(1113,b|0)|0;k=v[23220];v[23220]=0;d=d-1|0;if((k|0)!=1){continue}}break}break d}if(v[j>>2]!=v[i>>2]){b=e;break h}v[l+28>>2]=c;v[f>>2]=v[f>>2]|4;a=0;break g}r=r+1|0;continue}break}Nc(u);Nc(q);Nc(p);Nc(o);ub(y);Kc(s);fb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;v[l+28>>2]=c;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Nc(u);Nc(q);Nc(p);Nc(o);ub(y);Kc(s);S(a|0);L()}function WZ(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=fb-560|0;fb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+104>>2]=1126;k=l+104|0;r=he(l+136|0,l+144|0,k);b=v[r>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;u=Gb(k);o=Gb(l+88|0);p=Gb(l+72|0);q=Gb(l+56|0);s=Gb(l+40|0);v[23220]=0;ma(1129,c|0,d|0,l+120|0,l+119|0,l+118|0,u|0,o|0,p|0,q|0,l+36|0);c=v[23220];v[23220]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;k=v[l+36>>2];x=h;h=0;while(1){f:{g:{h:{i:{j:{if((h|0)==4){break j}v[23220]=0;c=Q(1093,a|0,l+552|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}if(!c){break j}k:{l:{m:{n:{o:{p:{switch(t[(l+120|0)+h|0]){case 1:if((h|0)==3){break g}c=v[a>>2];v[23220]=0;c=T(1095,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}if(eh(v[x+8>>2],8192,c)){v[23220]=0;R(1130,l+24|0,a|0);c=v[23220];v[23220]=0;if((c|0)!=1){v[23220]=0;R(44,s|0,t[l+24|0]);c=v[23220];v[23220]=0;if((c|0)!=1){break o}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break f;case 4:break l;case 2:break m;case 3:break n;case 0:break p;default:break g}}if((h|0)==3){break g}}while(1){v[23220]=0;c=Q(1093,a|0,l+552|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}if(!c){break g}c=v[a>>2];v[23220]=0;c=T(1095,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}if(!eh(v[x+8>>2],8192,c)){break g}v[23220]=0;R(1130,l+24|0,a|0);c=v[23220];v[23220]=0;if((c|0)!=1){v[23220]=0;R(44,s|0,t[l+24|0]);c=v[23220];v[23220]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}c=Bb(p);e=Bb(q);if((c|0)==(0-e|0)){break g}d=v[a>>2];if(!(e?c:0)){if(c){v[23220]=0;c=T(1095,d|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}if(w[Fc(p,0)|0]!=(c&255)){break k}v[23220]=0;T(1097,a|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break c}m=Bb(p)>>>0>1?p:m;break g}v[23220]=0;c=T(1095,d|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}if(w[Fc(q,0)|0]!=(c&255)){break g}v[23220]=0;T(1097,a|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break c}t[g|0]=1;m=Bb(q)>>>0>1?q:m;break g}v[23220]=0;c=T(1095,d|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}if(w[Fc(p,0)|0]==(c&255)){v[23220]=0;T(1097,a|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break c}m=Bb(p)>>>0>1?p:m;break g}c=v[a>>2];v[23220]=0;c=T(1095,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}if(w[Fc(q,0)|0]==(c&255)){v[23220]=0;T(1097,a|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break c}t[g|0]=1;m=Bb(q)>>>0>1?q:m;break g}v[f>>2]=v[f>>2]|4;a=0;break f}if(!(h>>>0<2|m|((h|0)==2&w[l+123|0]!=0|z))){m=0;break g}B=l,C=Td(o),v[B+16>>2]=C;d=Ef(l+24|0,l+16|0);q:{if(!h|w[(h+l|0)+119|0]>1){break q}while(1){r:{B=l,C=ih(o),v[B+16>>2]=C;if(!Kh(d,l+16|0)){break r}if(!eh(v[x+8>>2],8192,t[v[d>>2]])){break r}xe(d);continue}break}B=l,C=Td(o),v[B+16>>2]=C;c=bk(d,l+16|0);if(Bb(s)>>>0>=c>>>0){B=l,C=ih(s),v[B+16>>2]=C;e=Ei(l+16|0,0-c|0);n=ih(s);A=Td(o);c=fb-32|0;fb=c;v[c+16>>2]=n;v[c+24>>2]=e;v[c+8>>2]=A;while(1){e=Kh(c+24|0,c+16|0);if(!(!e|w[v[c+24>>2]]!=w[v[c+8>>2]])){xe(c+24|0);xe(c+8|0);continue}break}fb=c+32|0;if(e^1){break q}}B=l,C=Td(o),v[B+8>>2]=C;B=d,C=v[Ef(l+16|0,l+8|0)>>2],v[B>>2]=C}v[l+16>>2]=v[d>>2];s:{t:{while(1){B=l,C=ih(o),v[B+8>>2]=C;if(!Kh(l+16|0,l+8|0)){break s}v[23220]=0;c=Q(1093,a|0,l+552|0)|0;d=v[23220];v[23220]=0;u:{if((d|0)==1){break u}if(!c){break s}c=v[a>>2];v[23220]=0;c=T(1095,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break u}if(w[v[l+16>>2]]!=(c&255)){break s}v[23220]=0;T(1097,a|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break t}xe(l+16|0);continue}break}a=P()|0;O()|0;v[l+36>>2]=k;break a}a=P()|0;O()|0;v[l+36>>2]=k;break a}if(!y){break g}B=l,C=ih(o),v[B+8>>2]=C;if(!Kh(l+16|0,l+8|0)){break g}v[f>>2]=v[f>>2]|4;a=0;break f}d=0;n=w[l+118|0];v:{while(1){w:{v[23220]=0;c=Q(1093,a|0,l+552|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break w}if(!c){break v}c=v[a>>2];v[23220]=0;c=T(1095,c|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break e}x:{if(eh(v[x+8>>2],2048,c)){e=v[j>>2];if((e|0)==v[l+548>>2]){v[23220]=0;U(1131,i|0,j|0,l+548|0);e=v[23220];v[23220]=0;if((e|0)==1){break e}e=v[j>>2]}v[j>>2]=e+1;t[e|0]=c;d=d+1|0;break x}if(!Bb(u)|!d|(n|0)!=(c&255)){break v}if(v[l+128>>2]==(b|0)){v[23220]=0;U(1132,r|0,l+132|0,l+128|0);b=v[23220];v[23220]=0;if((b|0)==1){break e}b=v[l+132>>2]}c=b+4|0;v[l+132>>2]=c;v[b>>2]=d;b=c;d=0}v[23220]=0;T(1097,a|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!d|v[r>>2]==(b|0)){break i}if(v[l+128>>2]==(b|0)){v[23220]=0;U(1132,r|0,l+132|0,l+128|0);b=v[23220];v[23220]=0;if((b|0)==1){break d}b=v[l+132>>2]}c=b+4|0;v[l+132>>2]=c;v[b>>2]=d;break h}t[g|0]=1;break g}v[l+36>>2]=k;y:{if(!m){break y}c=1;while(1){if(Bb(m)>>>0<=c>>>0){break y}v[23220]=0;d=Q(1094,a|0,l+552|0)|0;e=v[23220];v[23220]=0;z:{if((e|0)==1){break z}A:{if(!d){d=v[a>>2];v[23220]=0;d=T(1095,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break z}if(w[Vf(m,c)|0]==(d&255)){break A}}v[f>>2]=v[f>>2]|4;a=0;break f}v[23220]=0;T(1097,a|0)|0;d=v[23220];v[23220]=0;c=c+1|0;if((d|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;c=v[r>>2];if((c|0)==(b|0)){break f}a=0;v[l+24>>2]=0;pf(u,c,b,l+24|0);if(v[l+24>>2]){v[f>>2]=v[f>>2]|4;break f}a=1;break f}c=b}B:{if((k|0)<=0){break B}v[23220]=0;b=Q(1094,a|0,l+552|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break d}C:{if(!b){b=v[a>>2];v[23220]=0;b=T(1095,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break d}if(w[l+119|0]==(b&255)){break C}}v[l+36>>2]=k;v[f>>2]=v[f>>2]|4;a=0;break f}v[23220]=0;b=T(1097,a|0)|0;e=v[23220];v[23220]=0;d=k;if((e|0)==1){break d}while(1){if((d|0)<=0){k=0;break B}v[23220]=0;e=Q(1094,b|0,l+552|0)|0;n=v[23220];v[23220]=0;D:{if((n|0)==1){break D}E:{if(!e){e=v[b>>2];v[23220]=0;e=T(1095,e|0)|0;n=v[23220];v[23220]=0;if((n|0)==1){break D}if(eh(v[x+8>>2],2048,e)){break E}}v[l+36>>2]=d;v[f>>2]=v[f>>2]|4;a=0;break f}if(v[j>>2]==v[l+548>>2]){v[23220]=0;U(1131,i|0,j|0,l+548|0);e=v[23220];v[23220]=0;if((e|0)==1){break D}}e=v[b>>2];v[23220]=0;e=T(1095,e|0)|0;n=v[23220];v[23220]=0;if((n|0)==1){break D}n=v[j>>2];v[j>>2]=n+1;t[n|0]=e;v[23220]=0;T(1097,b|0)|0;e=v[23220];v[23220]=0;d=d-1|0;if((e|0)!=1){continue}}break}a=P()|0;O()|0;v[l+36>>2]=k;break a}if(v[j>>2]!=v[i>>2]){b=c;break g}v[l+36>>2]=k;v[f>>2]=v[f>>2]|4;a=0;break f}h=h+1|0;continue}break}ub(s);ub(q);ub(p);ub(o);ub(u);Kc(r);fb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}ub(s);ub(q);ub(p);ub(o);ub(u);Kc(r);S(a|0);L()}function mea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;d=fb-304|0;fb=d;wc(b);a:{b:{c:{d:{if(!xt(b,d+208|0)){break d}if(!NQ(d+208|0)){break d}if(!Lb(v[b>>2],v[b+8>>2],Pc(MQ(d+208|0),ib))){break d}if(!c){g=1;break d}if(!Vc(b,w[d+212|0])){break d}zd(a,268435456);yg(a);v[a+480208>>2]=4;Kb(a+1074312|0,114,1);f=d+88|0;i=Qb(f,15285);Db(a+1298344|0,i);vb(i);i=Qb(f,10243);Db(a+1298356|0,i);vb(i);v[a+1298404>>2]=5;i=d+16|0;_e(i,d+208|6,48,3);Ac(f,i);xc(a+1298308|0,f);ub(f);f=w[d+262|0];u[a+480188>>1]=f+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];while(1){if((e|0)==(f|0)){e:{u[a+480190>>1]=w[d+300|0];i=x[d+302>>1];f=Ib(d+192|0);f:{g:{if(i){v[23220]=0;R(599,f|0,i|0);e=v[23220];v[23220]=0;if((e|0)==1){break g}zA(f,i)}break f}a=P()|0;O()|0;lc(f);S(a|0);L()}v[23220]=0;i=f;U(594,b|0,f|0,x[d+302>>1]);f=v[23220];v[23220]=0;if((f|0)==1){break b}z=Ib(d+176|0);r=Ib(d+160|0);v[23220]=0;W(362,b|0,z|0,w[d+301|0])|0;f=v[23220];v[23220]=0;if((f|0)==1){break c}v[23220]=0;W(362,b|0,r|0,w[d+300|0])|0;f=v[23220];v[23220]=0;if((f|0)==1){break c}s=c&2;p=d+126|0;y=d+88|6;f=0;h:{while(1){e=f;if(e>>>0>=w[d+300|0]){g=1;if(!(c&1)){break e}v[d+68>>2]=0;q=a+484376|0;Bc(Vb(v[a+484360>>2],w[q|0]));E=d,F=Ab(v[i>>2]),v[E+64>>2]=F;j=a+484344|0;A=Ab(v[i+4>>2]);break h}v[23220]=0;f=e+1|0;h=B(f,104)+a|0;k=h+484380|0;R(267,k|0,0);g=v[23220];v[23220]=0;i:{if((g|0)!=1){g=zb(v[r>>2],e);g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);if(!g){continue}v[23220]=0;g=Q(142,b|0,g|0)|0;j=v[23220];v[23220]=0;j:{if((j|0)==1){break j}if(!g){continue}v[23220]=0;g=Q(595,b|0,d+88|0)|0;j=v[23220];v[23220]=0;if((j|0)==1){break j}if(!g){continue}g=d+72|0;Ue(g,2,y);v[23220]=0;R(209,d+16|0,g|0);g=v[23220];v[23220]=0;if((g|0)==1){break c}g=d+16|0;yc(((f<<5)+a|0)+946304|0,g);ub(g);j=d+72|0;ak(j,2,p);v[23220]=0;R(209,g|0,j|0);g=v[23220];v[23220]=0;if((g|0)==1){break c}g=d+16|0;ue(h+484423|0,g);ub(g);g=w[d+138|0];if(g>>>0<=15){u[h+484408>>1]=B(g,17);g=h+484414|0;u[g>>1]=x[g>>1]|32}t[d+16|0]=w[d+139|0];t[d+72|0]=64;E=h+484412|0,F=w[Rb(d+16|0,d+72|0)|0],u[E>>1]=F;v[h+484404>>2]=w[d+141|0]|w[d+142|0]<<8;n=h+484384|0;j=w[d+147|0]|w[d+148|0]<<8|(w[d+149|0]<<16|w[d+150|0]<<24);v[n>>2]=j;m=h+484388|0;g=w[d+151|0]|w[d+152|0]<<8|(w[d+153|0]<<16|w[d+154|0]<<24);v[m>>2]=g;q=w[d+155|0]|w[d+156|0]<<8|(w[d+157|0]<<16|w[d+158|0]<<24);v[k>>2]=q;l=w[d+140|0];if(l&1){j=j>>>1|0;v[n>>2]=j;g=g>>>1|0;v[m>>2]=g;v[k>>2]=q>>>1}k:{if(g>>>0<=j>>>0){break k}h=h+484414|0;g=x[h>>1];u[h>>1]=g|2;if(!(l&2)){break k}u[h>>1]=g|6}hk(k);if(!s){continue}e=zb(v[r>>2],e);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[23220]=0;Q(142,b|0,e+w[d+92|0]|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){break i}}break c}break c}e=Uc(d+16|0,t[d+140|0]&1?16:8,1,0,1);v[23220]=0;W(206,e|0,k|0,b|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){continue}break}break c}while(1){l:{m:{k=v[d+64>>2];if(!Nb(k,A)){b=v[d+68>>2];c=b&63;if(!c){break m}f=w[a+484376|0];e=v[a+484360>>2];v[23220]=0;b=b>>>6|0;f=Q(300,Vb(e,f)|0,b&65535)|0;e=v[23220];v[23220]=0;if((e|0)!=1){if(!f){break m}b=x[ac(v[Vb(v[a+484360>>2],w[a+484376|0])>>2],b&65535)>>1];f=v[a+484344>>2];v[23220]=0;R(596,Xb(f,b)|0,c|0);b=v[23220];v[23220]=0;if((b|0)!=1){break m}}break c}c=w[k+3|0];if(w[k+2|0]>w[d+262|0]|c>>>0>=w[d+301|0]){break l}c=zb(v[z>>2],c);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23220]=0;c=Q(142,b|0,c|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break c}if(!c){break l}v[23220]=0;R(597,b|0,d+88|0);c=v[23220];v[23220]=0;if((c|0)==1){break c}e=w[d+92|0];if(!e){break l}f=w[k|0]|w[k+1|0]<<8;t[d+16|0]=w[d+93|0];t[d+72|0]=w[d+262|0]-w[k+2|0];s=w[Rb(d+16|0,d+72|0)|0];v[d+60>>2]=e+f;E=d,F=v[Sc(d+68|0,d+60|0)>>2],v[E+68>>2]=F;v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;c=f&63;p=f>>>6|0;y=0;while(1){if((e&255)>>>0<=y>>>0){break l}e=Vb(v[a+484360>>2],w[q|0]);h=c>>>0>63;p=h+p|0;f=p&65535;if(Ic(v[e>>2],v[e+4>>2])>>>0<=f>>>0){v[23220]=0;R(315,e|0,p+1&65535);e=v[23220];v[23220]=0;if((e|0)==1){break c}v[23220]=0;n=Q(352,j|0,64)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}e=Vb(v[a+484360>>2],w[q|0]);E=ac(v[e>>2],f),F=n,u[E>>1]=F}m=v[j>>2];o=v[j+4>>2];n=x[ac(v[e>>2],f)>>1];if(!ke(m,o,n)){break l}f=0;e=Xb(m,n);m=h?0:c;e=$c(v[e>>2],v[v[e+48>>2]+12>>2],m,w[k+2|0]);n:{while(1){if((f|0)==(s|0)){c=w[d+93|0];if(c>>>0<=s>>>0){break n}v[23220]=0;Q(175,b|0,B(c-s|0,5)|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break n}break c}v[23220]=0;R(598,d+72|0,b|0);c=v[23220];v[23220]=0;if((c|0)!=1){c=d+72|0;h=gd(c);C=Qe(c);l=zi(c);D=fc(c);c=w[d+72|0];o=c-1&255;o:{if(o>>>0<=142){c=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[e|0]=c;t[(d+16|0)+f|0]=c;break o}t[e|0]=0}c=w[h|0];t[e+2|0]=1;t[e+1|0]=c;c=w[C|0];p:{if((c|0)!=255){t[e+4|0]=c;break p}t[e+2|0]=0}c=w[l|0];q:{if(c>>>0>22){break q}t[e+3|0]=w[c+26992|0];h=w[D|0];t[e+5|0]=h;c=e+5|0;r:{switch(w[l|0]-4|0){case 3:t[c|0]=h&3|64;break q;case 4:t[c|0]=h&3|48;break q;case 7:l=v[i>>2];if(sc(l,v[i+4>>2])>>>0<=h>>>0){break q}o=c;c=zb(l,h);c=w[c|0]|w[c+1|0]<<8;t[o|0]=c>>>6;h=Xb(v[a+484344>>2],n);h=$c(v[h>>2],v[v[h+48>>2]+12>>2],m,x[a+480188>>1]-1&65535);t[h+5|0]=c&63;t[h+3|0]=14;break q;case 8:o=c;c=v[d+60>>2];t[o|0]=c>>>6;h=Xb(v[a+484344>>2],n);h=$c(v[h>>2],v[v[h+48>>2]+12>>2],m,x[a+480188>>1]-1&65535);t[h+5|0]=c&63;t[h+3|0]=14;break q;case 10:t[c|0]=h&15|128;break q;case 12:t[d+15|0]=15;E=c,F=w[Rb(c,d+15|0)|0]|208,t[E|0]=F;break q;case 13:t[d+15|0]=15;E=c,F=w[Rb(c,d+15|0)|0]|192,t[E|0]=F;break q;case 14:t[d+15|0]=15;E=c,F=w[Rb(c,d+15|0)|0]|224,t[E|0]=F;break q;case 0:case 16:case 17:if(!(h&15)){break q}l=h&240;if(!l|(l|0)==240){break q}t[c|0]=h|15;break q;case 9:case 18:break r;default:break q}}if(o>>>0<143){break q}t[e|0]=w[(d+16|0)+f|0]}e=e+6|0;f=f+1|0;continue}break}break c}c=m+1|0;y=y+1|0;e=w[d+92|0];continue}}a=Vb(v[a+484360>>2],w[a+484376|0]);E=d,F=Ab(v[a>>2]),v[E+88>>2]=F;b=Ab(v[a+4>>2]);c=65535;while(1){a=v[d+88>>2];if(!Nb(a,b)){break e}if(x[a>>1]==65535){s:{if((c&65535)!=65535){break s}v[23220]=0;c=Q(352,j|0,64)|0;f=v[23220];v[23220]=0;if((f|0)!=1){break s}break c}u[a>>1]=c}Oe(d+88|0);continue}}ye(d- -64|0);continue}}}else{u[((e<<5)+a|0)+480284>>1]=B(w[(d+e|0)+268|0],17);e=e+1|0;continue}break}lc(r);lc(z);lc(i)}fb=d+304|0;return g|0}a=P()|0;O()|0;lc(r);lc(z);break a}a=P()|0;O()|0}lc(i);S(a|0);L()}function oha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;g=fb-1344|0;fb=g;wc(b);d=fb-16|0;fb=d;j=g+768|0;$S(d+8|0,j);h=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],h);i=v[d+4>>2];if((i|0)==(h|0)){Yb(b,v[d+12>>2])}fb=d+16|0;d=(h|0)==(i|0);if(!d){_S(j)}a:{if(!d){break a}if(!bT(g+768|0)){break a}if(!Lb(v[b>>2],v[b+8>>2],Pc(aT(x[g+802>>1],x[g+804>>1]),ib))){break a}if(!c){f=1;break a}q=lh(g+760|0);b:{while(1){if((f|0)!=32){d=(f<<5)+a|0;h=d+480280|0;Pe(h);j=(g+768|0)+(f<<4)|0;u[d+480284>>1]=((w[j+78|0]<<8&65280)>>>0)/255;l=g+496|0;ak(l,1,j- -64|0);i=g+112|0;Ac(i,l);mm(d+480289|0,i);ub(i);c:{d:{switch(w[j+79|0]){case 0:k=e+1|0;break c;case 1:v[h>>2]=1024;k=f+1|0;break c;case 2:break d;default:break b}}v[h>>2]=1024;d=g+112|0;sk(d,q,f);dm(d)}e=e+1|0;f=f+1|0;continue}break}zd(a,33554432);u[a+480188>>1]=k&255;d=g+112|0;e=Qb(d,6734);Db(a+1298344|0,e);vb(e);d=Qb(d,11048);Db(a+1298356|0,d);vb(d);v[a+1298404>>2]=5;e:{if(w[g+847|0]){break e}f=1;i=1;while(1){if((f|0)==16){while(1){if((i|0)==16){break e}d=((i<<5)+a|0)+480280|0;v[d>>2]=v[d>>2]&-1025;i=i+1|0;continue}}d=f<<4;f=f+1|0;if(w[(g+d|0)+847|0]==1){continue}break}}d=g+496|0;Ue(d,1,g+768|0);e=g+112|0;Ac(e,d);xc(a+1298308|0,e);ub(e);v[a+480208>>2]=v[a+480208>>2]&-17|x[g+806>>1]<<4&16;v[a+480196>>2]=w[g+816|0];v[a+480204>>2]=B(w[g+817|0],1e4);v[a+480200>>2]=w[g+818|0]<<2;v[a+480228>>2]=w[g+819|0];e=x[g+804>>1];u[a+480190>>1]=0;u[a+480192>>1]=e;Ku(b,d);Cq(Vb(v[a+484360>>2],w[a+484376|0]),d,x[g+800>>1],65535,255);r=c&1;if(r){ig(a+484344|0,x[g+802>>1])}o=a+484344|0;z=a+480188|0;f:{while(1){g:{if(x[g+802>>1]<=m>>>0){l=c&2;m=g+108|0;q=a+480192|0;d=1;i=0;h:while(1){if(x[q>>1]<=(i&65535)>>>0){f=32;break b}i=i+1|0;c=NB(a,i&65535,0);h=!c;e=fb-16|0;fb=e;j=g+112|0;ec(e+8|0,j,384);f=v[e+12>>2];jc(e,v[b>>2],v[b+8>>2],v[e+8>>2],f);k=v[e+4>>2];if((k|0)==(f|0)){Yb(b,v[e+12>>2])}fb=e+16|0;e=(f|0)==(k|0);if(!e){Sb(j,0,384)}if(!e|h){continue}j=d&65535;f=fb-32|0;fb=f;h=g+112|0;Ue(f,1,h);e=f+16|0;Ac(e,f);yc(c+492|0,e);ub(e);i:{if(!(w[h+378|0]|w[h+379|0]<<8)){break i}k=c+236|0;e=0;while(1){v[f+16>>2]=120;v[f>>2]=116;if(y[Eb(f+16|0,f)>>2]<=e>>>0){break i}A=ac(k,e+12|0),C=j+w[(e+h|0)+32|0]|0,u[A>>1]=C;e=e+1|0;continue}}e=w[h+376|0]|w[h+377|0]<<8;t[c+33|0]=1;v[c>>2]=e;RA(h,c+48|0,0);RA(h,c+68|0,1);RA(h,c+88|0,2);e=w[c+100|0];if(e&1){t[c+100|0]=e|16}if(!(v[c>>2]|t[c+60|0]&1)){v[c>>2]=32767}fb=f+32|0;f=0;while(1){c=x[g+490>>1];if(c>>>0<=f>>>0){d=c+d|0;continue h}FT(b,g+48|0);j:{k:{if(Mb(m,15481,4)){break k}c=f+d|0;j=c&65535;if(j>>>0>3999){break k}u[a+480190>>1]=c;h=fb-32|0;fb=h;k=B(j,104)+a|0;c=k+484380|0;kd(c,0);Sh(h,1,g+48|0);e=h+16|0;Ac(e,h);ue(c+43|0,e);ub(e);o=w[g+64|0]|w[g+65|0]<<8|(w[g+66|0]<<16|w[g+67|0]<<24);v[c>>2]=o;p=w[g+68|0]|w[g+69|0]<<8|(w[g+70|0]<<16|w[g+71|0]<<24);v[c+4>>2]=p;n=w[g+72|0]|w[g+73|0]<<8|(w[g+74|0]<<16|w[g+75|0]<<24);v[c+8>>2]=n;v[c+24>>2]=w[g+76|0]|w[g+77|0]<<8|(w[g+78|0]<<16|w[g+79|0]<<24);u[c+30>>1]=w[g+80|0]<<2;u[c+28>>1]=w[g+81|0];e=w[g+96|0];if(e&1){u[c+34>>1]=x[c+34>>1]|2;e=w[g+96|0]}if(e&2){u[c+34>>1]=x[c+34>>1]|4;e=w[g+96|0]}if(e&4){v[c+8>>2]=n>>>1;v[c+4>>2]=p>>>1;v[c>>2]=o>>>1;u[c+34>>1]=x[c+34>>1]|1;e=w[g+96|0]}if(e&8){u[c+34>>1]=x[c+34>>1]|32}fb=h+32|0;e=fb-16|0;fb=e;Uu(e+8|0,k+484423|0);h=g+24|0;Jq(h,v[e+8>>2],v[e+12>>2]);fb=e+16|0;yc(((j<<5)+a|0)+946304|0,h);ub(h);e=v[g+64>>2];if(!e){break k}Qd(g,b,e);e=gc(g+24|0,g);wb(g);if(l){h=Uc(g,u[k+484414>>1]&1?16:8,1,0,0);v[23220]=0;W(206,h|0,c|0,e|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break j}}wb(e)}f=f+1|0;continue}break}break}a=P()|0;O()|0;wb(e);break f}e=Ag(b);p=Ag(b);d=g+48|0;Qd(d,b,e-4|0);l=gc(g+112|0,d);wb(d);l:{m:{if(!r){break m}v[23220]=0;d=W(213,o|0,m&65535,p|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break l}if(!d){break m}k=0;j=Rh(g+24|0);while(1){if(k>>>0>=p>>>0){break m}v[23220]=0;h=T(193,l|0)|0;d=v[23220];v[23220]=0;n:{if((d|0)!=1){if(h){break n}k=k+1|0;continue}break g}f=j;n=h&31;if(n>>>0<x[z>>1]){d=Xb(v[o>>2],m);f=$c(v[d>>2],v[v[d+48>>2]+12>>2],k,n)}if(h&32){v[23220]=0;R(250,g+48|0,l|0);d=v[23220];v[23220]=0;if((d|0)==1){break g}d=w[g+48|0];t[f|0]=d;A=f,C=w[gd(g+48|0)|0],t[A+1|0]=C;o:{p:{if((d|0)==160){e=255;break p}if((d|0)==255){e=0;break p}e=0;d=(B(d>>>4|0,12)+(d&15)|0)+13|0;if(ZS(d)){break o}}d=e}t[f|0]=d}d=h&192;q:{if(!d){break q}if((d|0)==192){v[23220]=0;R(342,g+48|0,l|0);d=v[23220];v[23220]=0;if((d|0)!=1){d=g+48|0;h=gd(d);i=Qe(d);d=zi(d);s=w[g+48|0];r:{s:{if((s|0)==12){t[g|0]=64;A=f,C=w[Rb(h,g)|0],t[A+4|0]=C;e=1;break s}e=w[i|0];t:{if((e|0)==12){t[g|0]=64;A=f,C=w[Rb(d,g)|0],t[A+4|0]=C;i=g+48|0;e=1;break t}if((s|0)==10){t[f+4|0]=(w[h|0]<<6>>>0)/255;e=2;break s}if((e|0)!=10){break r}t[f+4|0]=(w[d|0]<<6>>>0)/255;i=g+48|0;e=2}d=h}t[f+2|0]=e;e=w[i|0]}t[f+3|0]=e;t[f+5|0]=w[d|0];break q}break g}v[23220]=0;R(250,g+48|0,l|0);d=v[23220];v[23220]=0;if((d|0)==1){break g}t[f+3|0]=w[g+48|0];A=f,C=w[gd(g+48|0)|0],t[A+5|0]=C}if(w[f+3|0]){d=f+3|0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{h=w[f+3|0];switch(h-14|0){case 19:break A;case 17:break B;case 9:break C;case 8:break D;case 6:case 7:break E;case 1:break F;case 0:break G;default:break z}}d=w[f+5|0];if(!d){d=14;break w}if((d|0)==15){break y}if((d|0)==240){t[f+5|0]=239;break x}if(d>>>0>=16){t[f+5|0]=d|15;break x}t[f+5|0]=d|240;break x}t[f+5|0]=w[f+5|0]^128;break x}d=w[f+5|0];if(d>>>0>=16){t[f+5|0]=d>>>4|240;break x}t[f+5|0]=d|224;break x}t[f+5|0]=((w[f+5|0]^-1)&254)>>>1;break x}t[f+5|0]=w[f+5|0]&15|128;break x}A=f,C=vi(w[f+5|0]<<1),t[A+5|0]=C;break x}e=32;d=0;H:{I:{J:{K:{L:{M:{N:{i=w[f+5|0];switch(i>>>4|0){case 0:break x;case 3:break H;case 5:break I;case 14:break J;case 12:case 13:break K;case 11:break L;case 10:break M;case 8:break N;default:break w}}e=64;break H}e=176;break H}e=224;break H}if(i){break x}break w}O:{switch(i&15){case 0:t[f+5|0]=119;break x;case 1:t[f+5|0]=119;break x;case 2:t[f+5|0]=121;break x;case 3:break O;default:break x}}t[f+5|0]=123;break x}e=48}t[f+5|0]=i&15|e;break x}if(h>>>0<=35){break x}break v}t[f+5|0]=254}d=h}t[f+3|0]=w[d+26608|0];if(w[f+2|0]|(d|0)!=12){break u}t[f+2|0]=1;t[f+3|0]=0;t[f+4|0]=w[f+5|0];d=f+5|0}t[d|0]=0}}sk(g+48|0,q,n);if(!yb(v[v[g+48>>2]>>2],v[g+52>>2])){continue}if(!vB(w[f+3|0],w[f+5|0])){continue}t[f+3|0]=0;continue}}wb(l);m=m+1|0;continue}}break}a=P()|0;O()|0;wb(l)}S(a|0);L()}f=f>>>0>31}fb=g+1344|0;return f|0}function bN(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=C(0),r=0,s=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=C(0),S=C(0),T=0,U=0,V=0,W=C(0),X=0;o=fb-48|0;fb=o;t[o+40|0]=0;m=o+40|0;Ji(b+223848|0,oi(e,mi(e,Rn(e),m))+1|0);ge(m,v[b+223848>>2],v[b+223852>>2]);g=fb-16|0;fb=g;t[g+15|0]=0;cc(o+32|0,e,oi(e,mi(e,Rn(e),g+15|0)));fb=g+16|0;H=v[o+32>>2];I=v[o+36>>2];k=fb-16|0;fb=k;D=a+1074312|0;i=B(c,872)+b|0;J=i+1415|0;K=i+1304|0;L=i+1392|0;E=i+1368|0;F=i+1364|0;M=i+1336|0;N=i+1308|0;O=i+1300|0;P=i+1280|0;Q=i+1402|0;j=i+1466|0;R=C(w[j|0]);S=C(f>>>0);G=i+616|0;l=v[i+1272>>2];T=a+480188|0;h=1;n=255;while(1){if((s|0)!=(I|0)&y[m+4>>2]>p>>>0){e=w[Hb(H,s)|0];g=e-48|0;a:{b:{c:{if((g&255)>>>0<=9){break c}if((e-65&255)>>>0<=5){g=e-55|0;break c}d:{e:{f:{switch(e-97|0){case 2:g:{e=ml(a,b,c,3,0);if((e-1&255)>>>0>249){break g}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break g}e=zy(e,47600,44700);if(!e){break g}g=jb[v[v[e>>2]+188>>2]](e,G,c)|0;e=(g|0)!=255;g=e?g:0;if(e|!l){break c}break d}if(l){break d}g=0;break c;case 21:xb(k+8|0,D,28);h:{if(!yb(v[v[k+8>>2]>>2],v[k+12>>2])){xb(k,D,1);e=0;if(!yb(v[v[k>>2]>>2],v[k+4>>2])){break h}}e=u[L>>1]}g=B(v[E>>2],v[F>>2]);e=B(v[a+1074456>>2],e+v[K>>2]|0);e=Ub((Dc(Cia(Bia(g,g>>31,e,e>>31),ib,1048576,0),ib)|0)/2|0,1,127);break e;case 20:e=B(v[E>>2],v[F>>2]);g=e;A=e>>31;e=B(v[a+1074456>>2],v[M>>2]);e=Ub((Dc(Cia(Bia(g,A,e,e>>31),ib,67108864,0),ib)|0)/2|0,1,127);break e;case 23:v[k+8>>2]=v[N>>2]/2;v[k>>2]=127;e=v[nd(k+8|0,k)>>2];break e;case 24:v[k+8>>2]=v[O>>2]/2;v[k>>2]=127;e=v[nd(k+8|0,k)>>2];break e;case 0:e=0;if(!l){break e}g=x[l+28>>1];if(!g){break e}e=g-1>>>7&127;break e;case 1:e=0;if(!l){break e}g=x[l+28>>1];if(!g){break e}e=g-1&127;break e;case 14:e=v[P>>2]>>>8|0;break e;case 7:e=(x[T>>1]<=c>>>0?w[Q|0]-1|0:c)&127;break e;case 12:e=w[i+704|0]>>>7|0;break e;case 15:e=0;if(!l){break e}g=w[l+30|0];if(!g){break e}e=g-1&127;break e;case 25:i:{if(!d|t[j|0]<0){break i}j:{if(p>>>0<3){break j}e=v[m>>2];if(w[Hb(e,p-3|0)|0]!=240){break j}if(w[Hb(e,p-2|0)|0]>239){break i}}q=tp(b,R,S);k:{if(q<C(4294967296)&q>=C(0)){e=~~q>>>0;break k}e=0}t[j|0]=e;n=128;break e}n=(n&255)==255?f:n;e=f;break e;case 18:l:{if(!p){g=0;break l}e=v[m>>2];g=p;while(1){g=g-1|0;A=Hb(e,g);if(!g){break l}if(w[A|0]!=240){continue}break}}if(p-g>>>0<5){break a}A=v[m>>2];if(w[Hb(A,g)|0]!=240){break a}g=g+5|0;e=0;while(1){if((g|0)!=(p|0)){e=w[Hb(A,g)|0]+e|0;g=g+1|0;continue}break};e=0-e&127;break e;case 13:break f;default:break a}}e=w[J|0];e=Oc(e)?e-1|0:0}g=((h^-1)&1)+p|0;U=Hb(v[m>>2],g),V=e,t[U|0]=V;p=g+1|0;h=1;break b}e=x[G+786>>1];g=(e?e-1|0:c)&15;e=w[l+31|0];if((e|0)!=17){g=jj(e)?e-1&15:0}}e=Hb(v[m>>2],p);m:{if(h){t[e|0]=g;break m}t[e|0]=w[e|0]<<4|g;p=p+1|0}h=(h^-1)&1}}s=s+1|0;continue}else{if(n<<24>>24>=0){t[j|0]=n}ec(k+8|0,v[m>>2],((h^-1)&1)+p|0);e=v[k+12>>2];v[m>>2]=v[k+8>>2];v[m+4>>2]=e;fb=k+16|0}break}p=v[o+44>>2];n:while(1){k=0;while(1){e=r;o:{p:{q:{r:{while(1){if(y[o+44>>2]<=e>>>0){break o}f=v[o+40>>2];h=Hb(f,e);g=t[h|0];if((g|0)==-16){g=e;if(p-e>>>0>=4){r=4;if((w[Hb(f,e+1|0)|0]&254)==240){break p}}s:{while(1){g=g+1|0;if(p>>>0<=g>>>0){break s}if(w[Hb(f,g)|0]!=247){continue}break}r=(g-e|0)+1|0;if(r){break p}}U=Hb(f,p),V=247,t[U|0]=V;p=p+1|0;r=p-e|0;break q}if((g|0)<0){break r}if(k&255){e=e-1|0;U=Hb(f,e),V=k,t[U|0]=V;continue}break}r=r+1|0;continue n}U=o,V=cP(g&255),v[U+16>>2]=V;v[o+28>>2]=p-e;r=v[Eb(o+16|0,o+28|0)>>2]}if(!r){break o}f=v[o+40>>2];h=Hb(f,e)}s=w[h|0];dq(o+16|0,f,v[o+44>>2],e,r);f=v[cc(o+8|0,v[o+16>>2],v[o+20>>2])>>2];h=0;g=fb-32|0;fb=g;j=v[o+12>>2];t:{if(!j){break t}i=Nd(w[b+223884|0]);u:{m=Hb(f,0);l=w[m|0]-250|0;if(l>>>0>5|!(1<<l&37)){break u}l=x[a+480188>>1];while(1){if((h|0)==(l|0)){break u}n=(B(h,872)+b|0)+1453|0;t[n|0]=127;t[n+1|0]=0;h=h+1|0;continue}}v:{if((j|0)!=4|w[m|0]!=240){break v}h=w[Hb(f,1)|0];if((h&254)!=240){break v}m=b+223860|0;j=(B(c,872)+b|0)+616|0;l=Hb(f,2);n=w[Hb(f,3)|0];f=n<<24>>24;w:{x:{y:{z:{A:{B:{l=w[l|0];switch(l|0){case 3:break y;case 2:break z;case 1:break A;case 0:break B;default:break x}}if((h|0)==241|(f|0)<0){break x}h=B(c,872)+b|0;m=h+1453|0;if(d){f=Og(tp(b,C(w[m|0]),C((f&255)>>>0)))}t[m|0]=f;t[h+1412|0]=0;f=yp(a,j,!(v[h+704>>2]&32768),256);if((f|0)<0|!(w[h+705|0]&2)){break t}h=v[a+1298300>>2];if(i|sd(h)^1){break t}Dp(h,c,f>>>2&255,1);break t}if((h|0)==241|(f|0)<0){break x}h=B(c,872)+b|0;i=h+1454|0;if(d){f=Og(tp(b,C(w[i|0]),C((f&255)>>>0)))}t[i|0]=f;t[h+1411|0]=0;yp(a,j,!(v[h+704>>2]&32768),256);break t}if((h|0)==241){break w}if(f>>>0>31){break t}h=B(c,872)+b|0;t[h+1461|0]=(f&240)>>>4;yp(a,j,!(v[h+704>>2]&32768),256);break t}if((h|0)==241){break w}h=(f|0)<0;f=ml(a,b,c,3,0)-1|0;if(h|(f&255)>>>0>249){break t}t[g+24|0]=f;h=f&255;f=v[(B(h,160)+a|0)+906300>>2];if(!f){break t}q=C(C(127-n|0)/C(127));if(i){j=0;h=fb-16|0;fb=h;U=h,V=Zj(g+24|0),v[U>>2]=V;f=fb-16|0;fb=f;l=yy(m,f+12|0,w[g+24|0]);n=v[l>>2];if(!n){j=fb-16|0;fb=j;i=fc(m);n=oh(f,tc(24),ph(j+8|0,i));i=v[n>>2];D=w[v[h>>2]];v[i+20>>2]=0;t[i+16|0]=D;U=fc(n),V=1,t[U+4|0]=V;fb=j+16|0;Tg(m,v[f+12>>2],l,v[f>>2]);n=Ud(f);_k(f);j=1}Sg(h+8|0,v[dc(f,n)>>2],j);fb=f+16|0;f=pd(v[h+8>>2]);fb=h+16|0;z[f+4>>2]=q;break t}if(!d){Ms(v[f+20>>2],q);break t}Ms(v[f+20>>2],tp(b,z[(B(h,160)+a|0)+906444>>2],q));break t}if(l&128){break w}if((h|0)!=241){break t}}n=ml(a,b,c,3,0)-1|0;if((f|0)<0|(n&255)>>>0>249){break t}j=v[(B(n&255,160)+a|0)+906300>>2];if(!j){break t}h=(h|0)==241?l+128|0:l&127;q=C(C((f&255)>>>0)/C(127));if(i){U=qN(m+12|0,LM(g+24|0,n,h)),W=q,z[U>>2]=W;break t}f=v[j>>2];if(!d){jb[v[f+44>>2]](j,h,q);break t}V=j,X=h,W=tp(b,C(jb[v[f+48>>2]](j,h)),q),U=v[v[j>>2]+44>>2],jb[U](V|0,X|0,C(W));break t}if(i){break t}i=x[a+480188>>1];C:{if(i>>>0>c>>>0){h=c+1|0;break C}h=x[(B(c,872)+b|0)+1402>>1];if(!h){break t}}if(w[(B(c,872)+b|0)+707|0]&4|i>>>0<(h&65535)>>>0){break t}h=ml(a,b,c,3,0);if((h-1&255)>>>0>249){break t}h=v[(B(h,160)+a|0)+906140>>2];if(!h){break t}i=w[m|0];if((i|0)==240){Hg(g+16|0,f,j);f=v[v[h>>2]+72>>2];j=v[g+20>>2];v[g>>2]=v[g+16>>2];v[g+4>>2]=j;jb[f|0](h,g)|0;break t}U=g,X=cP(i),v[U+24>>2]=X;v[g+12>>2]=j;j=g+24|0;i=v[Eb(j,g+12|0)>>2];v[g+24>>2]=0;nc(j,f,i);jb[v[v[h>>2]+68>>2]](h,v[g+24>>2])|0}fb=g+32|0;k=s>>>0<240?s:k;r=e+r|0;continue}break}break}fb=o+48|0}function oV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=fb-224|0;fb=e;wc(b);a:{b:{c:{d:{if(!nC(b,e+176|0)){break d}if(!qC(e+176|0)){break d}if(!c){n=1;break d}zd(a,2048);yg(a);d=fb-16|0;fb=d;f=e+8|0;h=Qb(d,3927);Mc(f,h);vb(h);fb=d+16|0;v[23220]=0;U(200,e+80|0,f|0,w[e+179|0]);d=v[23220];v[23220]=0;e:{f:{g:{h:{i:{j:{k:{if((d|0)!=1){d=e+80|0;Db(a+1298344|0,d);vb(d);f=e+8|0;bc(f);h=Qb(d,11056);Db(a+1298356|0,h);vb(h);v[a+1298404>>2]=5;u[a+480188>>1]=w[e+216|0];u[a+480190>>1]=w[e+212|0];Ue(f,2,e+176|4);Ac(d,f);xc(a+1298308|0,d);ub(d);d=w[e+179|0];l:{if(d>>>0>=9){if(d>>>0>=11){f=(d|0)==11?16:32;d=0;while(1){if((d|0)==(f|0)){break l}h=Pu(b);m:{if((h|0)==100){v[((d<<5)+a|0)+480280>>2]=256;break m}v[e+80>>2]=(h<<1)+128;v[e+8>>2]=0;v[e+160>>2]=256;s=((d<<5)+a|0)+480284|0,y=v[uj(e+80|0,e+8|0,e+160|0)>>2],u[s>>1]=y}d=d+1|0;continue}}f=e+80|0;d=fb-16|0;fb=d;n:{if(!Lb(v[b>>2],v[b+8>>2],16)){cC(f);break n}Fu(d+8|0,f);md(d,b,v[d+8>>2],v[d+12>>2])}fb=d+16|0;d=0;while(1){if((d|0)==16){break l}u[((d<<5)+a|0)+480284>>1]=t[(e+80|0)+d|0]&1?64:192;d=d+1|0;continue}}u[a+480188>>1]=4;jg(b,1);th(a,1)}o:{if(w[e+179|0]>=13){d=e+80|0;Ju(d,b);f=gd(d);d=w[e+80|0];if(d>>>0<=31){t[e+80|0]=125;d=125}v[a+480204>>2]=B(d,1e4);v[a+480196>>2]=w[f|0];break o}v[a+480196>>2]=6;v[a+480204>>2]=125e4}gg(Vb(v[a+484360>>2],w[a+484376|0]),w[e+213|0]);l=Ib(e+160|0);f=w[e+179|0];q=v[b+8>>2]+((f>>>0>13)<<1)|0;d=0;p:{if(f>>>0<14){break p}v[23220]=0;R(201,l|0,w[e+213|0]);f=v[23220];v[23220]=0;if((f|0)!=1){break p}d=P()|0;O()|0;break b}q:{r:{s:{while(1){t:{if(w[e+213|0]<=d>>>0){d=0;if(w[e+179|0]!=10){break s}m=v[b+8>>2];k=a+480190|0;d=1;while(1){j=x[k>>1];if(j>>>0<(d&65535)>>>0){break t}v[23220]=0;f=Q(202,b|0,e+80|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break r}if(f){f=0;u:{if(w[e+212|0]<(w[e+126|0]|w[e+127|0]<<8|(w[e+128|0]<<16|w[e+129|0]<<24))>>>0|w[e+80|0]>1){break u}h=w[e+130|0]|w[e+131|0]<<8|(w[e+132|0]<<16|w[e+133|0]<<24);if(h>>>0>1048576|w[e+136|0]>64|h>>>0<(w[e+137|0]|w[e+138|0]<<8|(w[e+139|0]<<16|w[e+140|0]<<24))>>>0){break u}f=h>>>0>=(w[e+141|0]|w[e+142|0]<<8|(w[e+143|0]<<16|w[e+144|0]<<24))>>>0}if(!f){break t}}d=d+1|0;continue}}s=ac(v[Vb(v[a+484360>>2],w[a+484376|0])>>2],d),y=d,u[s>>1]=y;if(w[e+179|0]>=14){v[23220]=0;f=T(181,b|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break q}s=ac(v[l>>2],d),y=f,u[s>>1]=y}f=x[a+480188>>1];v[23220]=0;Q(175,b|0,f<<1)|0;f=v[23220];v[23220]=0;if((f|0)==1){break q}d=d+1|0;continue}break}v[23220]=0;Q(142,b|0,m|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break c}d=j>>>0>=(d&65535)>>>0}j=a+480190|0;f=x[j>>1];v[23220]=0;v[e+80>>2]=0;m=W(203,e- -64|0,f|0,e+80|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break k}n=d?59:65;k=e+80|1;f=1;v:{while(1){h=f&65535;if(h>>>0>x[j>>1]){h=Ib(e+48|0);v[23220]=0;n=W(204,b|0,h|0,x[e+214>>1])|0;d=v[23220];v[23220]=0;w:{if((d|0)!=1){if(!n){break e}d=0;k=0;f=v[h>>2];if(!rc(f,v[h+4>>2])){f=Ab(f);g=Ab(v[h+4>>2]);k=fb-16|0;fb=k;x:{if(!Nb(f,g)){break x}v[k+8>>2]=f;while(1){j=v[Oe(k+8|0)>>2];if(!Nb(j,g)){break x}f=ll(w[f|0]|w[f+1|0]<<8,w[j|0]|w[j+1|0]<<8)?j:f;continue}}fb=k+16|0;k=w[f|0]|w[f+1|0]<<8}v[23220]=0;j=Q(205,e+32|0,k|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break w}y:{while(1){if((d|0)==(k|0)){if(!(c&2)){break j}i=Uc(e+80|0,8,1,0,1);o=a+480190|0;f=x[o>>1];g=1;z:{A:while(1){p=g&65535;if(p>>>0>(f&65535)>>>0){break j}d=v[b+8>>2];f=v[b>>2];v[23220]=0;d=W(143,f|0,d|0,1)|0;f=v[23220];v[23220]=0;if((f|0)==1){break z}if(!d){break j}r=v[b+8>>2];d=0;while(1){f=x[o>>1];if(f>>>0<=d>>>0){g=g+1|0;continue A}if((p|0)!=v[zb(v[m>>2],d)>>2]){d=d+1|0;continue}v[23220]=0;Q(142,b|0,r|0)|0;f=v[23220];v[23220]=0;if((f|0)!=1){v[23220]=0;d=d+1|0;W(206,i|0,(B(d,104)+a|0)+484380|0,b|0)|0;f=v[23220];v[23220]=0;if((f|0)!=1){continue}}break}break}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}v[23220]=0;f=T(181,b|0)|0;g=v[23220];v[23220]=0;B:{if((g|0)==1){break B}v[23220]=0;Q(175,b|0,1)|0;g=v[23220];v[23220]=0;if((g|0)==1){break B}if(f){v[23220]=0;U(177,e+8|0,b|0,B(f,3)+(w[e+179|0]==1?3:0)|0);f=v[23220];v[23220]=0;if((f|0)==1){break y}g=e+8|0;f=gc(e+80|0,g);Yc(xg(v[j>>2],d),f);wb(f);wb(g)}d=d+1|0;continue}break}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}C:{D:{if(w[e+179|0]<=9){v[23220]=0;R(207,b|0,e+80|0);g=v[23220];v[23220]=0;E:{F:{if((g|0)==1){break F}v[23220]=0;R(208,e+80|0,(B(h,104)+a|0)+484380|0);g=v[23220];v[23220]=0;if((g|0)==1){break F}g=e+48|0;Ue(g,2,k);v[23220]=0;R(209,e+8|0,g|0);g=v[23220];v[23220]=0;if((g|0)==1){break E}break D}d=P()|0;O()|0;break g}d=P()|0;O()|0;break g}v[23220]=0;U(210,b|0,e+80|0,n|0);g=v[23220];v[23220]=0;if((g|0)==1){break C}v[23220]=0;U(211,e+80|0,(B(h,104)+a|0)+484380|0,d|0);g=v[23220];v[23220]=0;if((g|0)==1){break C}g=e+48|0;Ue(g,2,k);v[23220]=0;R(209,e+8|0,g|0);g=v[23220];v[23220]=0;if((g|0)==1){break v}}g=e+8|0;yc(((h<<5)+a|0)+946304|0,g);ub(g);s=zb(v[m>>2],h-1|0),y=x[e+126>>1]|x[e+128>>1]<<16,v[s>>2]=y;f=f+1|0;continue}break}d=P()|0;O()|0;break g}d=P()|0;O()|0;break g}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;bc(e+8|0);break a}d=P()|0;O()|0;break b}if(!(c&1)){break f}v[23220]=0;g=a+484344|0;R(212,g|0,w[e+213|0]);c=v[23220];v[23220]=0;G:{if((c|0)!=1){f=a+480188|0;a=0;while(1){H:{if(w[e+213|0]<=a>>>0){break f}d=64;c=v[l>>2];if(Ic(c,v[l+4>>2])>>>0>a>>>0){d=x[ac(c,a)>>1]}v[23220]=0;c=W(213,g|0,a&65535,d&65535)|0;d=v[23220];v[23220]=0;if((d|0)==1){break G}I:{if(c){c=x[f>>1];v[23220]=0;Q(142,b|0,B(((w[e+179|0]>13)<<1)+(c<<1)|0,a)+q|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break G}c=Ib(e+80|0);d=x[f>>1];v[23220]=0;i=W(204,b|0,c|0,d|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break I}d=0;J:{if(!i){break J}while(1){if(x[f>>1]<=d>>>0){break J}K:{i=ac(v[c>>2],d);i=w[i|0]|w[i+1|0]<<8;if(!i|i>>>0>x[e+214>>1]){break K}i=ac(v[h>>2],i-1|0);i=(w[i|0]|w[i+1|0]<<8)-1&65535;if(i>>>0>=k>>>0){break K}o=v[g>>2];p=v[j>>2];v[23220]=0;U(214,Xb(o,a)|0,d&65535,xg(p,i)|0);i=v[23220];v[23220]=0;if((i|0)!=1){break K}break H}d=d+1|0;continue}}ld(c)}a=a+1|0;continue}}break}d=P()|0;O()|0;ld(c);break i}d=P()|0;O()|0;break i}d=P()|0;O()|0}fd(j)}ld(h)}lc(m);break b}fd(j)}ld(h);lc(m);ld(l)}fb=e+224|0;return n|0}d=P()|0;O()|0}ld(l)}S(d|0);L()}function wp(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;g=fb-16|0;fb=g;i=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:i;s=v[b+752>>2];k=w[b+802|0];a:{if(!k){xb(g+8|0,a+1074312|0,11);if(yb(v[v[g+8>>2]>>2],v[g+12>>2])){break a}}b:{c:{if(!i){break c}if(!Oc(k)){break c}d:{l=k-1|0;k=ac(i+236|0,l);if(x[k>>1]){break d}xb(g+8|0,a+1074312|0,43);if(!yb(v[v[g+8>>2]>>2],v[g+12>>2])){break d}if(jj(w[i+31|0])){break d}v[b+656>>2]=i;break a}if(w[Hb(i+108|0,l)|0]>120){break a}k=x[k>>1];l=(k-1&65535)>>>0<3999?(B(k,104)+a|0)+484380|0:0;break b}l=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(k>>>0>250){break a}xb(g+8|0,a+1074312|0,43);if(yb(v[v[g+8>>2]>>2],v[g+12>>2])){if(i){l=0;if(jj(w[i+31|0])){break b}}t[b+803|0]=0;v[b+656>>2]=0;break a}l=0}k=v[b+104>>2];n=(k|0)!=0&(k|0)!=(l|0);j=v[b+656>>2];p=!i|v[a+480180>>2]!=16777216?p:v[i+44>>2]!=0;q=d^1;h=(j|0)!=(i|0);if((q|h|n)==1){u[b+774>>1]=0}r=!n;if(!(r|(h|!(d&p)))){break a}e:{if(!(d&n)){break e}k=a+1074312|0;xb(g+8|0,k,32);if(!(!yb(v[v[g+8>>2]>>2],v[g+12>>2])|!(w[a+480208|0]&8))){l=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:l}m=v[a+480180>>2];f:{if(!(i?h|!(m&1048580):1)|(m|0)==268435456){break f}if((m|0)==1){if(ni(v[b+8>>2],v[b+12>>2])){break f}}xb(g+8|0,k,79);if(!yb(v[v[g+8>>2]>>2],v[g+12>>2])){break e}if(!ni(v[b+8>>2],v[b+12>>2])){break e}}o=1}g:{if(!v[b+16>>2]|(!n|(h|!x[a+480192>>1]))){break g}xb(g+8|0,a+1074312|0,87);if(!yb(v[v[g+8>>2]>>2],v[g+12>>2])){break g}o=Oc(w[b+788|0])^1|o}h:{i:{j:{k:{l:{if(ni(v[b+8>>2],v[b+12>>2])|!(v[a+480180>>2]&16777248)){break l}if(i){if(jj(w[i+31|0])){break l}}k=1;break k}if(!(h|n)){break j}k=(j|0)!=(i|0)}if(!d){break i}xb(g+8|0,a+1074312|0,61);if(!yb(v[v[g+8>>2]>>2],v[g+12>>2])){break i}j=v[b+656>>2];if(!j){j=0;m=0;h=v[b+104>>2];if(!h){break i}break h}h=v[b+104>>2];m=0;break h}k=0}v[b+656>>2]=i;j=i;m=k;h=l}m:{n:{o:{if(!e){break o}p:{if(w[a+480180|0]&3){if(h){if(Md(v[h>>2],v[h+20>>2])){break p}}if(!Qj(j)){break o}}if(!h){break n}}if(u[h+34>>1]<0){break o}v[b+688>>2]=x[h+30>>1]}i=(h|0)!=0;if(!(n&o)|!h){break m}xb(g+8|0,a+1074312|0,85);if(yb(v[v[g+8>>2]>>2],v[g+12>>2])){u[b+772>>1]=t[h+37|0]}i=1;if(v[a+480180>>2]!=2){break m}if(!Md(v[h>>2],v[h+20>>2])){break m}v[b+704>>2]=v[h+24>>2];break m}if(!(!j|!w[j+34|0])){k=v[b+688>>2];if(j){k=v[j+4>>2]<<2}v[b+688>>2]=k;i=0;break m}i=0;v[b+688>>2]=0}if(o){break a}t[b+803|0]=0;q:{if(!j){break q}xb(g+8|0,a+1074312|0,29);if(!(z=1,A=(yb(v[v[g+8>>2]>>2],v[g+12>>2])^-1)&i,C=w[j+34|0]|m,C?z:A)){break q}t[b+798|0]=w[j+16|0]}l=64;v[b+752>>2]=64;if(h){l=x[h+32>>1];v[b+752>>2]=l}if(j){v[b+752>>2]=B(v[j+4>>2],l)>>>6}r:{if(!(v[a+480180>>2]&1048580?e:1)){break r}xb(g+8|0,a+1074312|0,48);if(yb(v[v[g+8>>2]>>2],v[g+12>>2])){break r}XM(a,b,j,h)}s:{t:{u:{if(!f){break u}f=a+1074312|0;xb(g+8|0,f,19);v:{w:{x:{y:{z:{A:{B:{C:{if(yb(v[v[g+8>>2]>>2],v[g+12>>2])){if(!v[b+76>>2]){e=1;break B}if(!(!c|q)){e=(w[a+480208|0]&8)>>>3|0;if(e){break B}break C}e=0;if(c){break C}break B}c=v[a+480180>>2]&17301536;e=1;D:{if(!d|!c){break D}c=1;e=1;if(w[a+480208|0]&8){break D}e=1;if(!v[b+76>>2]){break D}e=0;if(!(w[b+89|0]&16)){break D}e=!v[b+696>>2]}if(!j|(!c|m)){break z}if(!e){break y}c=v[b+88>>2];e=c&6144;break A}if(d){break B}if(!(w[b+89|0]&24)){e=0;break B}e=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|m){break z}if(!e){break y}c=v[b+88>>2];e=c&2048}v[b+88>>2]=c|2097152;if(!j){break v}if(e){break w}if(!(w[j+60|0]&8)){dj(b+724|0)}if(!(w[j+80|0]&8)){dj(b+732|0)}if(w[j+100|0]&8){break v}dj(b+740|0);break v}if(e){break x}}if(j){if(t[j+60|0]&1){break u}xb(g+8|0,f,32);if(yb(v[v[g+8>>2]>>2],v[g+12>>2])){dj(b+724|0);break u}Ol(b);break u}c=0;if(!h){break t}break s}v[b+88>>2]=v[b+88>>2]|2097152;if(!j){break v}}Ol(b)}xb(g+8|0,f,21);if(yb(v[v[g+8>>2]>>2],v[g+12>>2])){break u}t[b+818|0]=0;v[b+756>>2]=0}c=0;if(h){break s}if(!j){break t}c=1;if(jj(w[j+31|0])){break s}}v[b+752>>2]=0;v[b+104>>2]=0;break a}E:{F:{G:{H:{I:{if(!(!d|(i^1|v[b+104>>2]!=(h|0)))){d=v[a+480180>>2];if(v[b+76>>2]?d&16777250:0){break a}if((d|0)!=4){break I}xb(g+8|0,a+1074312|0,40);if(!yb(v[v[g+8>>2]>>2],v[g+12>>2])|w[b+789|0]){break I}d=v[b+88>>2];break H}v[b+88>>2]=v[b+88>>2]&-6145;e=a+1074312|0;xb(g+8|0,e,18);J:{if(z=yb(v[v[g+8>>2]>>2],v[g+12>>2]),A=1,C=v[a+480180>>2]&16777248,C?z:A){f=-640;if(!(v[b+104>>2]!=(h|0)|m)){break J}}f=-768}v[b+88>>2]=f&v[b+88>>2];K:{if(!j){break K}t[b+730|0]=w[j+60|0];t[b+738|0]=w[j+80|0];t[b+746|0]=w[j+100|0];L:{if((w[j+100|0]&17)!=17){break L}xb(g+8|0,e,36);if(yb(v[v[g+8>>2]>>2],v[g+12>>2])|w[b+837|0]){break L}t[b+837|0]=127}e=w[j+21|0];if(nf(e)){z=b,A=Iq(e),t[z+837|0]=A}e=w[j+22|0];if(!nf(e)){break K}z=b,A=Iq(e),t[z+838|0]=A}if(c){break G}if(!d){break E}break F}d=v[b+88>>2]&-6145}v[b+88>>2]=d&-640;if(!c){break F}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break E}c=a+1074312|0;xb(g+8|0,c,54);if(!yb(v[v[g+8>>2]>>2],v[g+12>>2])){xb(g,c,39);if(!yb(v[v[g>>2]>>2],v[g+4>>2])){break E}}v[b+8>>2]=0;v[b+12>>2]=0}M:{if(w[b+788|0]!=255){break M}xb(g+8|0,a+1074312|0,100);if(!yb(v[v[g+8>>2]>>2],v[g+12>>2])|(!(v[a+480208>>2]&4)|r)){break M}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+752>>2]=s;v[b+688>>2]=x[h+30>>1];if(!(w[h+34|0]&32)){break a}Fp(b,x[h+28>>1],a);break a}v[b+104>>2]=h;v[b+76>>2]=v[h>>2];v[b+80>>2]=v[h+4>>2];v[b+84>>2]=v[h+8>>2];e=a+1074312|0;xb(g+8|0,e,83);if(!(!yb(v[v[g+8>>2]>>2],v[g+12>>2])|v[b+80>>2])){v[b+84>>2]=v[h>>2]}v[b+88>>2]=v[b+88>>2]|x[h+34>>1]&1023;xb(g+8|0,e,21);if(yb(v[v[g+8>>2]>>2],v[g+12>>2])){t[b+818|0]=0;v[b+756>>2]=0}N:{O:{if(p){v[b+704>>2]=v[h+24>>2];t[b+851|0]=w[b+851|0]|64;c=0;break O}if(!(n|q)){d=v[a+480180>>2];if(d&5){break N}}v[b+704>>2]=v[h+24>>2];c=t[h+37|0]}u[b+772>>1]=c;d=v[a+480180>>2]}if(em(d)){c=t[h+36|0]}else{c=0}u[b+770>>1]=c;xb(g+8|0,e,69);if(!(yb(v[v[g+8>>2]>>2],v[g+12>>2])|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+852>>2]=0;i=v[b+88>>2];if(i&8){v[b+80>>2]=v[h+12>>2];v[b+84>>2]=v[h+16>>2];i=i>>>2&4|i|2;v[b+88>>2]=i}P:{if(!(i&2)){i=v[b+76>>2];break P}i=v[b+76>>2];c=v[b+84>>2];if(i>>>0<=c>>>0){break P}v[b+76>>2]=c;i=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<i>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}fb=g+16|0}function rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=fb-272|0;fb=e;wc(b);d=fb-16|0;fb=d;i=e+112|0;eT(d+8|0,i);g=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],g);h=v[d+4>>2];if((h|0)==(g|0)){Yb(b,v[d+12>>2])}fb=d+16|0;d=(g|0)==(h|0);if(!d){dT(i)}a:{if(!d){break a}if(!fT(e+112|0)){break a}if(!c){f=1;break a}zd(a,v[(x[e+228>>1]<<2)+26400>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;d=e+48|0;f=Qb(d,13077);Db(a+1298344|0,f);vb(f);f=Qb(d,10274);Db(a+1298356|0,f);vb(f);f=fb-16|0;fb=f;g=e+8|0;i=Qb(f,4350);Mc(g,i);vb(i);fb=f+16|0;v[23220]=0;X(219,d|0,g|0,w[e+191|0],e+188|0);d=v[23220];v[23220]=0;b:{if((d|0)!=1){d=e+48|0;Db(a+1298368|0,d);vb(d);f=e+8|0;bc(f);ql(a+1298392|0,(x[e+228>>1]<<2)+26448|0);ql(a+1298380|0,v[(x[e+228>>1]<<2)+26496>>2]);v[a+1298404>>2]=5;Ue(f,2,e+112|4);Ac(d,f);xc(a+1298308|0,d);ub(d);Ue(f,2,e+148|0);Ac(d,f);c:{if(_p(d,9711)){v[23220]=0;U(11,e+8|0,5,e+48|0);d=v[23220];v[23220]=0;if((d|0)==1){break c}d=e+8|0;Db(a+1298320|0,d);vb(d)}ub(e+48|0);u[a+480188>>1]=32;d=0;d:{while(1){if((d|0)!=32){g=(d<<5)+a|0;i=g+480280|0;Pe(i);f=w[(d+e|0)+193|0];e:{if(f>>>0<=15){v[e+48>>2]=f<<4|8;v[e+8>>2]=256;r=g+480284|0,s=v[nd(e+48|0,e+8|0)>>2],u[r>>1]=s;break e}if((f|0)!=16){if((f|0)!=255){break e}u[a+480188>>1]=d;break d}u[g+480284>>1]=128;v[i>>2]=256}d=d+1|0;continue}break}d=x[a+480188>>1]}f=0;if(!(d&65535)){break a}v[e+48>>2]=w[e+225|0]<<2;v[e+8>>2]=256;r=a,s=v[Eb(e+48|0,e+8|0)>>2],v[r+480200>>2]=s;v[a+480196>>2]=w[e+226|0];v[a+480204>>2]=B(w[e+227|0],1e4);if(Vc(b,x[e+230>>1]|x[e+232>>1]<<16)){fo(Vb(v[a+484360>>2],w[a+484376|0]),b,w[e+234|0]+1|0,255,254)}if(!Vc(b,v[e+240>>2])){break a}d=w[e+248|0]+1|0;u[a+480190>>1]=d;l=e+80|0;m=a+480180|0;i=1;while(1){f:{g:{j=i&65535;if(j>>>0>(d&65535)>>>0){break g}d=fb-16|0;fb=d;g=e+48|0;ec(d+8|0,g,62);f=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],f);h=v[d+4>>2];if((h|0)==(f|0)){Yb(b,v[d+12>>2])}fb=d+16|0;d=(f|0)==(h|0);if(!d){Sb(g,0,62)}if(!d){break g}d=0;f=B(j,104)+a|0;k=f+484380|0;kd(k,0);h=e+32|0;Ue(h,2,e+48|0);g=e+8|0;Ac(g,h);yc(((j<<5)+a|0)+946304|0,g);ub(g);ak(h,2,l);Ac(g,h);ue(f+484423|0,g);ub(g);g=x[e+106>>1];v[f+484404>>2]=g;if(!em(v[m>>2])){break f}while(1){if((d|0)==16){break f}if((g|0)==x[(d<<1)+26544>>1]){t[f+484417|0]=d<<4;break f}else{d=d+1|0;continue}}}h:{if(!(c&2)){break h}if(!Vc(b,v[e+244>>2])){break h}f=a+480190|0;d=1;while(1){g=d&65535;if(g>>>0>x[f>>1]){break h}g=B(g,104)+a|0;hg(Uc(e+48|0,u[g+484414>>1]&1?16:8,1,0,1),g+484380|0,b);d=d+1|0;continue}}n=a+484344|0;ig(n,w[e+239|0]+1|0);f=Zp(a);d=fb-16|0;fb=d;v[d+12>>2]=0;Gs(d+12|0,f);k=v[d+12>>2];fb=d+16|0;Vc(b,w[e+235|0]|w[e+236|0]<<8|(w[e+237|0]<<16|w[e+238|0]<<24));p=c&1;j=0;m=1;i:{j:{k:{while(1){if(w[e+239|0]<j>>>0){if(v[a+480180>>2]==1){break k}c=v[a+480208>>2]&-8454145;break j}l:{d=Ag(b);if(d>>>0>=3){c=e+8|0;Qd(c,b,d-2|0);h=gc(e+48|0,c);wb(c);m:{if(!p){break m}c=v[h>>2];v[23220]=0;c=T(165,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break l}if(!c){break m}v[23220]=0;c=W(213,n|0,j&65535,64)|0;d=v[23220];v[23220]=0;if((d|0)==1){break l}l=0;if(!c){break m}while(1){if((l|0)==64){break m}c=Xb(v[n>>2],j);q=Of(v[c>>2],v[v[c+48>>2]+12>>2],l);n:{o:while(1){v[23220]=0;c=T(193,h|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break i}if(!c){break n}d=c&31;if(d>>>0>=x[a+480188>>1]){break n}f=B(d,6)+q|0;if(c&32){v[23220]=0;R(250,e+8|0,h|0);d=v[23220];v[23220]=0;if((d|0)==1){break i}g=gd(e+8|0);d=w[e+8|0];if(d){d=(d&127)-1|0;t[e+8|0]=d;d=(B((d&240)>>>4|0,12)+(d&15)|0)+13|0;t[f|0]=d;m=SA(d)&m}t[f+1|0]=w[g|0]}if(!(c&64)){continue}t[f+2|0]=0;t[f+3|0]=0;g=f+5|0;while(1){c=v[h>>2];v[23220]=0;c=W(143,c|0,v[e+56>>2],2)|0;d=v[23220];v[23220]=0;if((d|0)==1){break i}if(!c){continue o}o=w[f+5|0];c=w[f+3|0];v[23220]=0;R(250,e+8|0,h|0);d=v[23220];v[23220]=0;if((d|0)!=1){i=w[gd(e+8|0)|0];t[g|0]=i;d=w[(w[e+8|0]&31)+26576|0];t[f+3|0]=d;p:{q:{r:{s:{t:{switch(d-2|0){case 0:case 1:if(i>>>0<224){break r}d=223;if(v[a+480180>>2]!=1){break s}break r;case 11:t[e+32|0]=64;r=g,s=w[Rb(g,e+32|0)|0],t[r|0]=s;if(!cT(v[k+88>>2])){break r}t[f+2|0]=1;t[f+4|0]=w[g|0];t[f+3|0]=c;t[g|0]=o;d=c;break q;case 17:u:{switch(((i&240)>>>4|0)-8|0){case 0:t[f+3|0]=2;t[g|0]=i&15|224;break p;case 1:t[f+3|0]=3;t[g|0]=i&15|224;break p;default:break u}}if(Wt(v[k+84>>2],19)){break r}zu(f);break r;case 13:d=v[k+84>>2];if(Wt(d,15)){break r}if(!Wt(d,19)){break r}t[f+3|0]=19;t[g|0]=i&15|144;break p;case 18:d=145;if((i|0)==1){break s}if((i&240)==128){if(Wt(v[k+84>>2],20)){break r}t[f+3|0]=19;break p}t[f+3|0]=0;break p;case 4:case 5:break t;default:break q}}d=i&240;if(!d){break r}}t[g|0]=d}d=w[f+3|0]}if((d&255)!=20){break p}d=w[g|0];if(w[f+2|0]|(d&240)!=128){break p}t[f+2|0]=2;t[f+4|0]=(((d&15)<<6|8)>>>0)/15;t[f+3|0]=c;t[g|0]=o}if(!(w[e+8|0]&32)){continue o}continue}break}break}break i}l=l+1|0;continue}}wb(h)}j=j+1|0;continue}break}break i}c=v[a+480208>>2]&-8454145|(x[a+480188>>1]==4?m&1?8454144:0:0)}v[a+480208>>2]=c;f=1;if(!(w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24))){break a}if(!Vc(b,w[e+249|0]|w[e+250|0]<<8|(w[e+251|0]<<16|w[e+252|0]<<24))){break a}cB(a+1298332|0,b,w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24),4);break a}d=P()|0;O()|0;wb(h);break b}u[f+484412>>1]=64;g=w[e+93|0]|w[e+94|0]<<8|(w[e+95|0]<<16|w[e+96|0]<<24);v[k>>2]=g;d=w[e+105|0];if(d&2){h=f+484414|0;u[h>>1]=x[h>>1]|1;v[k>>2]=g>>>1}v[f+484384>>2]=w[e+97|0]|w[e+98|0]<<8|(w[e+99|0]<<16|w[e+100|0]<<24);v[f+484388>>2]=(w[e+101|0]|w[e+102|0]<<8|(w[e+103|0]<<16|w[e+104|0]<<24))-1;if(d&1){g=f+484414|0;u[g>>1]=x[g>>1]|2}v:{w:{if(!(d&4)){break w}g=w[e+108|0];if((g|0)==255){break w}t[e+8|0]=g;t[e+32|0]=64;r=f+484410|0,s=w[Rb(e+8|0,e+32|0)|0]<<2,u[r>>1]=s;break v}g=f+484414|0;u[g>>1]=x[g>>1]|32768}x:{if(d&8){d=f+484414|0;g=x[d>>1]|32;u[d>>1]=g;j=f+484408|0;f=w[e+109|0];if(f>>>0<=15){v[e+32>>2]=256;v[e+8>>2]=f<<4|8;h=v[nd(e+8|0,e+32|0)>>2]}else{h=128}u[j>>1]=h;u[d>>1]=g&65279|((f|0)==16)<<8;break x}u[f+484408>>1]=128}i=i+1|0;d=x[a+480190>>1];continue}}d=P()|0;O()|0;ub(e+48|0);break b}d=P()|0;O()|0;bc(e+8|0)}S(d|0);L()}fb=e+272|0;return f|0}function o9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=fb+-64|0;fb=i;d=v[b>>2];v[23220]=0;d=T(165,d|0)|0;h=v[23220];v[23220]=0;a:{b:{c:{d:{if((h|0)==1){break d}e:{f:{if(d){h=Ib(i+48|0);g:{h:{i:{if(c&16){break i}v[23220]=0;g=(c|0)!=0;f=W(794,h|0,b|0,g|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}d=4;j:{if(f){break j}v[23220]=0;f=W(795,h|0,b|0,g|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}d=5;if(f){break j}v[23220]=0;f=W(796,h|0,b|0,g|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}d=6;if(f){break j}f=0;v[23220]=0;g=W(797,h|0,b|0,g|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}d=3;if(!g){break i}}if(!c){d=1;break h}f=v[h>>2];if(!rc(f,v[h+4>>2])){$u(b,f+12|0)}f=d}d=0;if(c&32){break h}d=31552;k:{while(1){e=d;if((d|0)!=32068){j=v[e+8>>2];g=(j>>1)+a|0;d=v[e+4>>2];d=j&1?v[v[g>>2]+d>>2]:d;v[23220]=0;g=W(d|0,g|0,b|0,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}d=e+12|0;if(!g){continue}break k}break}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){d=(e|0)!=32068;e=0;break h}if(!(v[a+480184>>2]|!f)){v[a+480184>>2]=f}v[23220]=0;e=1;R(737,a+1298264|0,1);f=v[23220];v[23220]=0;d=1;if((f|0)==1){break g}}WL(h);if(e){break f}break a}break c}v[23220]=0;R(236,a|0,0);d=v[23220];v[23220]=0;if((d|0)==1){break d}v[23220]=0;R(737,a+1298264|0,1);d=v[23220];v[23220]=0;if((d|0)==1){break d}v[a+1074304>>2]=19923968}d=0;while(1){if((d|0)==127){d=1;while(1){e=d&65535;if(e>>>0>x[a+480190>>1]){e=0;h=a+480180|0;d=0;l:{while(1){f=d&65535;if(f>>>0>x[a+480192>>1]){m:{u[a+480192>>1]=e;d=a+480204|0;if(y[a+480204>>2]>=1e4){break m}v[d>>2]=125e4;break l}}else{f=v[((f<<2)+a|0)+900380>>2];if(f){g=v[h>>2];uc(f,65536);uc(f+4|0,64);uc(f+8|0,256);qg(f+28|0,16384);hf(f+30|0,128);hf(f+31|0,17);if(w[f+16|0]>=4){t[f+16|0]=0}if(w[f+17|0]>=5){t[f+17|0]=0}if(w[f+18|0]>=3){t[f+18|0]=0}hf(f+19|0,64);hf(f+20|0,100);e=224;j=t[f+26|0];n:{if((j|0)>=-32){e=32;if((j|0)<33){break n}}t[f+26|0]=e}hf(f+23|0,64);hf(f+24|0,64);qz(f+48|0,64);qz(f+68|0,64);qz(f+88|0,(g|0)==4096?255:64);g=f+108|0;e=0;while(1){o:{if((e|0)==128){if(!qo(w[f+14|0])){t[f+14|0]=5}if(w[f+34|0]>=251){t[f+34|0]=0}break o}j=Hb(g,e);if((w[j|0]-121&255)>>>0<=135){t[j|0]=e+1}e=e+1|0;continue}break}e=d}d=d+1|0;continue}break}uc(d,65535e4)}if(!v[a+480196>>2]){v[a+480196>>2]=6}d=a+480220|0;e=v[a+480216>>2];if(e>>>0>y[a+480220>>2]){v[d>>2]=e}e=a+480216|0;uc(e,65536);uc(d,65536);uc(a+480200|0,256);p:{if(!rc(v[a+480248>>2],v[a+480252>>2])){d=v[e>>2];v[23220]=0;R(798,a+480248|0,d|0);d=v[23220];v[23220]=0;if((d|0)==1){break p}}v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];e=v[a+480220>>2];d=a+1074408|0;v[d>>2]=v[a+480216>>2];v[d+4>>2]=e;v[a+1074456>>2]=v[a+480200>>2];Fy(a+1074376|0);d=a+1074446|0;u[d>>1]=0;u[d+2>>1]=0;u[d+4>>1]=0;u[d+6>>1]=65535;v[a+1074392>>2]=-2;d=a+1074384|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074380>>2]=0;d=a+1074424|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074432>>2]=0;d=a+1074396|0;v[d>>2]=0;v[d+4>>2]=0;if(em(v[a+480180>>2])){v[23220]=0;Q(255,a+1074312|0,7)|0;d=v[23220];v[23220]=0;if((d|0)==1){break p}}u[a+480276>>1]=0;qp(a);n=i,o=Ab(v[a+484360>>2]),v[n+48>>2]=o;e=Ab(v[a+484364>>2]);while(1){d=v[i+48>>2];if(!Nb(d,e)){q:{r:{j=v[a+480180>>2];if(j){Gs(a+8|0,Zp(a));if(v[a+1074308>>2]){v[23220]=0;Y(799,a|0);d=v[23220];v[23220]=0;if((d|0)==1){break p}}h=Ib(i+48|0);s:{if((c&12)!=12){break s}l=a+1298464|0;d=0;t:{u:{v:{w:{x:{y:{while(1){if((d|0)==250){break s}z:{c=B(d,160)+a|0;k=c+906316|0;A:{if(!(v[k>>2]|v[c+906320>>2])){break A}v[23220]=0;e=c+906300|0;R(800,e|0,a|0);f=v[23220];v[23220]=0;B:{if((f|0)!=1){f=v[e>>2];if(!f){break B}c=v[c+906448>>2];e=v[v[f>>2]+56>>2];v[23220]=0;R(e|0,f|0,c|0);c=v[23220];v[23220]=0;if((c|0)!=1){break A}}a=P()|0;O()|0;break q}f=Ab(v[h>>2]);m=Ab(v[h+4>>2]);g=fb-16|0;fb=g;v[g+8>>2]=f;while(1){C:{if(!Nb(f,m)){break C}c=v[f>>2];if((w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))==(w[e+20|0]|w[e+21|0]<<8|(w[e+22|0]<<16|w[e+23|0]<<24))){c=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))==(w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24))}else{c=0}if(c){break C}f=v[ye(g+8|0)>>2];continue}break}fb=g+16|0;if(Nb(f,Ab(v[h+4>>2]))){break A}v[23220]=0;v[i+32>>2]=k;R(801,h|0,i+32|0);c=v[23220];v[23220]=0;if((c|0)==1){break z}v[23220]=0;c=Q(1,i+16|0,17645)|0;f=v[23220];v[23220]=0;if((f|0)==1){break y}v[23220]=0;R(802,i|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){break x}v[23220]=0;U(2,i+32|0,c|0,i|0);e=v[23220];v[23220]=0;if((e|0)==1){break w}e=v[l>>2];v[23220]=0;U(360,e|0,2,i+32|0);e=v[23220];v[23220]=0;if((e|0)==1){break v}vb(i+32|0);vb(i);vb(c)}d=d+1|0;continue}break}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;break u}a=P()|0;O()|0;vb(i+32|0)}vb(i)}vb(c);break q}c=w[a+1074368|0];v[23220]=0;R(803,a|0,c|0);a=v[23220];v[23220]=0;if((a|0)==1){break r}lc(h)}d=(j|0)!=0;break a}a=P()|0;O()|0}lc(h);break b}v[23220]=0;Y(804,d|0);f=v[23220];v[23220]=0;if((f|0)!=1){if(Ic(v[d>>2],v[d+4>>2])>>>0<=x[d+28>>1]){Ve(d,0)}lz(i+48|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}f=B(e,104)+a|0;e=f+484380|0;D:{if(Md(v[e>>2],v[f+484400>>2])){ij(e,a);break D}h=f+484414|0;g=x[h>>1];if(g&16384){break D}v[e>>2]=0;v[e+4>>2]=0;v[e+16>>2]=0;v[e+8>>2]=0;v[e+12>>2]=0;u[h>>1]=g&65505}e=f+484412|0;if(x[e>>1]>=65){u[e>>1]=64}E:{F:{if(!(w[f+484415|0]&2)){break F}if(!Tj(v[a+1298300>>2])){break F}v[23220]=0;Y(805,a|0);e=v[23220];v[23220]=0;if((e|0)==1){break E}}d=d+1|0;continue}break}a=P()|0;O()|0;break b}e=(d<<5)+a|0;qg(e+480286|0,64);f=e+480284|0;if(x[f>>1]>=257){u[f>>1]=128}e=e+480288|0;if(w[e|0]>=251){t[e|0]=0}Qn((B(d,872)+a|0)+1074992|0,a,d&65535,134217728);d=d+1|0;continue}}break c}a=P()|0;O()|0;break b}a=P()|0;O()|0;WL(h)}wb(b);S(a|0);L()}wb(b);fb=i- -64|0;return d|0}function $$(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0;n=fb-560|0;fb=n;v[n+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){x=1;A=5257;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){x=1;A=5260;break a}x=e&1;A=x?5263:5258;F=!x}b:{if((g&2146435072)==2146435072){d=x+3|0;qf(a,32,c,d,e&-65537);cf(a,A,x);f=f&32;cf(a,b!=b?f?9939:13768:f?11044:14130,3);qf(a,32,c,d,e^8192);i=(c|0)<(d|0)?d:c;break b}z=n+16|0;c:{d:{e:{b=iH(b,n+44|0);b=b+b;if(b!=0){g=v[n+44>>2];v[n+44>>2]=g-1;u=f|32;if((u|0)!=97){break e}break c}u=f|32;if((u|0)==97){break c}l=v[n+44>>2];m=(d|0)<0?6:d;break d}l=g-29|0;v[n+44>>2]=l;b=b*268435456;m=(d|0)<0?6:d}r=(n+48|0)+((l|0)<0?0:288)|0;h=r;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}v[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;k=r;break f}k=r;d=l;while(1){d=(d|0)<29?d:29;g=h-4|0;g:{if(k>>>0>g>>>0){break g}i=0;while(1){q=v[g>>2];p=d&31;C=i;if((d&63)>>>0>=32){i=q<<p;q=0}else{i=(1<<p)-1&q>>>32-p;q=q<<p}p=C+q|0;i=i+E|0;i=p>>>0<q>>>0?i+1|0:i;i=Eia(p,i,1e9,0);q=Bia(i,ib,-1e9,0)+p|0;v[g>>2]=q;g=g-4|0;if(k>>>0<=g>>>0){continue}break}if(!i){break g}k=k-4|0;v[k>>2]=i}while(1){g=h;if(k>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[n+44>>2]-d|0;v[n+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){y=((m+25>>>0)/9|0)+1|0;p=(u|0)==102;while(1){d=0-d|0;i=(d|0)<9?d:9;h:{if(g>>>0<=k>>>0){h=v[k>>2];break h}q=1e9>>>i|0;E=-1<<i^-1;d=0;h=k;while(1){C=d;d=v[h>>2];v[h>>2]=C+(d>>>i|0);d=B(q,d&E);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=v[k>>2];if(!d){break h}v[g>>2]=d;g=g+4|0}d=i+v[n+44>>2]|0;v[n+44>>2]=d;k=(!h<<2)+k|0;h=p?r:k;g=g-h>>2>(y|0)?h+(y<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=k>>>0){break i}d=B(r-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break i}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=(m-((u|0)==102?0:d)|0)-((u|0)==103&(m|0)!=0)|0;if((h|0)<(B(g-r>>2,9)-9|0)){i=h+9216|0;p=(i|0)/9|0;l=((((l|0)<0?4:292)+n|0)+(p<<2)|0)-4048|0;h=10;i=i+B(p,-9)|0;if((i|0)<=7){while(1){h=B(h,10);i=i+1|0;if((i|0)!=8){continue}break}}p=v[l>>2];y=(p>>>0)/(h>>>0)|0;i=B(y,h);q=l+4|0;j:{if((i|0)==(p|0)&(q|0)==(g|0)){break j}p=p-i|0;k:{if(!(y&1)){b=9007199254740992;if(!(t[l-4|0]&1)|((h|0)!=1e9|k>>>0>=l>>>0)){break k}}b=9007199254740994}s=(g|0)==(q|0)?1:1.5;q=h>>>1|0;s=p>>>0<q>>>0?.5:(q|0)==(p|0)?s:1.5;if(!(w[A|0]!=45|F)){s=-s;b=-b}v[l>>2]=i;if(b+s==b){break j}d=h+i|0;v[l>>2]=d;if(d>>>0>=1e9){while(1){v[l>>2]=0;l=l-4|0;if(l>>>0<k>>>0){k=k-4|0;v[k>>2]=0}d=v[l>>2]+1|0;v[l>>2]=d;if(d>>>0>999999999){continue}break}}d=B(r-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break j}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){h=g;i=g>>>0<=k>>>0;if(!i){g=h-4|0;if(!v[g>>2]){continue}}break}l:{if((u|0)!=103){l=e&8;break l}g=m?m:1;l=(g|0)>(d|0)&(d|0)>-5;m=(l?d^-1:-1)+g|0;f=(l?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(i){break m}p=v[h-4>>2];if(!p){break m}i=10;g=0;if((p>>>0)%10|0){break m}while(1){l=g;g=g+1|0;i=B(i,10);if(!((p>>>0)%(i>>>0)|0)){continue}break}g=l^-1}i=B(h-r>>2,9);if((f&-33)==70){l=0;g=(g+i|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g;break l}l=0;g=((d+i|0)+g|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g}i=-1;u=l|m;if(((u?2147483645:2147483646)|0)<(m|0)){break b}p=(((u|0)!=0)+m|0)+1|0;q=f&-33;n:{if((q|0)==70){if((2147483647-p|0)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=gn((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((z-g|0)<2){continue}break}}y=g-2|0;t[y|0]=f;t[g-1|0]=(d|0)<0?45:43;g=z-y|0;if((g|0)>(2147483647-p|0)){break b}}d=g+p|0;if((d|0)>(x^2147483647)){break b}f=d+x|0;qf(a,32,c,f,e);cf(a,A,x);qf(a,48,c,f,e^65536);o:{p:{q:{if((q|0)==70){g=n+16|0;d=g|8;l=g|9;i=k>>>0>r>>>0?r:k;k=i;while(1){g=gn(v[k>>2],0,l);r:{if((i|0)!=(k|0)){if(n+16>>>0>=g>>>0){break r}while(1){g=g-1|0;t[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}t[n+24|0]=48;g=d}cf(a,g,l-g|0);k=k+4|0;if(r>>>0>=k>>>0){continue}break}if(u){cf(a,16715,1)}if((m|0)<=0|h>>>0<=k>>>0){break q}while(1){g=gn(v[k>>2],0,l);if(g>>>0>n+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(n+16>>>0<g>>>0){continue}break}}cf(a,g,(m|0)<9?m:9);g=m-9|0;k=k+4|0;if(h>>>0<=k>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}i=h>>>0>k>>>0?h:k+4|0;g=n+16|0;d=g|8;r=g|9;h=k;while(1){g=gn(v[h>>2],0,r);if((r|0)==(g|0)){t[n+24|0]=48;g=d}t:{if((h|0)!=(k|0)){if(n+16>>>0>=g>>>0){break t}while(1){g=g-1|0;t[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break t}cf(a,g,1);g=g+1|0;if(!(l|m)){break t}cf(a,16715,1)}C=g;g=r-g|0;cf(a,C,(g|0)>(m|0)?m:g);m=m-g|0;h=h+4|0;if(i>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}qf(a,48,m+18|0,18,0);cf(a,y,z-y|0);break o}g=m}qf(a,48,g+9|0,9,0)}qf(a,32,c,f,e^8192);i=(c|0)<(f|0)?f:c;break b}m=(f<<26>>31&9)+A|0;u:{if(d>>>0>11){break u}g=12-d|0;s=16;while(1){s=s*16;g=g-1|0;if(g){continue}break}if(w[m|0]==45){b=-(s+(-b-s));break u}b=b+s-s}l=x|2;k=f&32;h=v[n+44>>2];g=h>>31;g=gn((g^h)-g|0,0,z);if((z|0)==(g|0)){t[n+15|0]=48;g=n+15|0}r=g-2|0;t[r|0]=f+15;t[g-1|0]=(h|0)<0?45:43;i=e&8;h=n+16|0;while(1){f=h;if(D(b)<2147483648){g=~~b}else{g=-2147483648}t[h|0]=k|w[g+76160|0];b=(b-+(g|0))*16;h=f+1|0;if(!(!(i|(d|0)>0)&b==0|(h-(n+16|0)|0)!=1)){t[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}i=-1;p=z-r|0;f=p+l|0;if((2147483645-f|0)<(d|0)){break b}v:{w:{if(!d){break w}k=h-(n+16|0)|0;if((k-2|0)>=(d|0)){break w}g=d+2|0;break v}k=h-(n+16|0)|0;g=k}d=g+f|0;qf(a,32,c,d,e);cf(a,m,l);qf(a,48,c,d,e^65536);cf(a,n+16|0,k);qf(a,48,g-k|0,0,0);cf(a,r,p);qf(a,32,c,d,e^8192);i=(c|0)<(d|0)?d:c}fb=n+560|0;return i|0}function Wda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-272|0;fb=e;wc(b);d=fb-16|0;fb=d;f=e+120|0;xQ(d+8|0,f);g=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],g);h=v[d+4>>2];if((h|0)==(g|0)){Yb(b,v[d+12>>2])}fb=d+16|0;d=(g|0)==(h|0);if(!d){wQ(f)}a:{b:{if(!d){break b}if(!yQ(e+120|0)){break b}if(!c){i=1;break b}zd(a,4194304);d=e+32|0;g=Qb(d,16982);Db(a+1298344|0,g);vb(g);g=Qb(d,10098);Db(a+1298356|0,g);vb(g);v[a+1298404>>2]=5;n=a,o=Pd(x[e+198>>1],x[e+200>>1],127),u[n+480188>>1]=o;g=w[e+189|0];v[a+480228>>2]=(g|0)==255?48:g;v[a+480196>>2]=w[e+187|0];v[a+480204>>2]=B(w[e+188|0],1e4);g=e+96|0;_e(g,e+120|4,59,3);Ac(d,g);xc(a+1298308|0,d);ub(d);d=x[e+202>>1]|x[e+204>>1]<<16;c:{if(d>>>0<5){break c}if(!Vc(b,d-4|0)){break c}if(!wh(b,14230)){break c}fo(Vb(v[a+484360>>2],w[a+484376|0]),b,x[e+192>>1],65535,65535)}d:{d=x[e+206>>1]|x[e+208>>1]<<16;if(d>>>0<5){break d}if(!Vc(b,d-4|0)){break d}if(!wh(b,13763)){break d}d=0;while(1){if((d|0)==32){break d}g=(d<<5)+a|0;Pe(g+480280|0);n=g+480284|0,o=((((Ae(b)^-1)&15)<<8|8)>>>0)/15|0,u[n>>1]=o;d=d+1|0;continue}}d=x[e+214>>1]|x[e+216>>1]<<16;e:{if(d>>>0<5){break e}if(!Vc(b,d-4|0)){break e}if(!wh(b,14087)){break e}d=e+32|0;Qd(d,b,x[e+196>>1]<<6);k=c&2;h=a+480190|0;g=gc(e+96|0,d);wb(d);j=e+45|0;d=0;f:{while(1){if(x[e+196>>1]<=(d&65535)>>>0){break f}v[23220]=0;f=Q(625,g|0,e+32|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break a}if(!f){break f}f=w[e+77|0]|w[e+78|0]<<8;u[e+30>>1]=f;g:{h:{if((f-1&65535)>>>0>3998){break h}f=B(f,104)+a|0;i=f+484380|0;if(Md(v[i>>2],v[f+484400>>2])){break h}n=h,o=x[Re(h,e+30|0)>>1],u[n>>1]=o;v[23220]=0;R(626,e+32|0,i|0);f=v[23220];v[23220]=0;if((f|0)==1){break g}_e(e,j,24,1);v[23220]=0;R(209,e+16|0,e|0);f=v[23220];v[23220]=0;if((f|0)==1){break a}f=e+16|0;yc(((x[e+30>>1]<<5)+a|0)+946304|0,f);ub(f);if(!k){break h}v[23220]=0;Q(142,b|0,w[e+69|0]|w[e+70|0]<<8|(w[e+71|0]<<16|w[e+72|0]<<24))|0;f=v[23220];v[23220]=0;if((f|0)==1){break g}i=1;l=e+16|0;f=w[e+79|0];m=Uc(l,f&4?16:8,1,0,0);i:{j:{if(f&8){break j}i=2;if(f&16){break j}if(f&127){break i}}Qf(m,i)}v[23220]=0;W(206,l|0,(B(x[e+30>>1],104)+a|0)+484380|0,b|0)|0;f=v[23220];v[23220]=0;if((f|0)!=1){break h}break a}d=d+1|0;continue}break}break a}wb(g)}i=1;if(!(c&1)){break b}k:{c=x[e+210>>1]|x[e+212>>1]<<16;if(c>>>0<5){break k}if(!Vc(b,c-4|0)){break k}if(!wh(b,13613)){break k}k=a+484344|0;ig(k,x[e+194>>1]);f=0;while(1){if(x[e+194>>1]<=f>>>0){break k}if(!sA(b,e+16|0)){break k}l:{d=x[e+16>>1];if(d>>>0>3){c=e+96|0;Qd(c,b,(d+15&131056)-4|0);g=gc(e+32|0,c);wb(c);v[23220]=0;c=W(213,k|0,f&65535,w[e+18|0])|0;d=v[23220];v[23220]=0;if((d|0)==1){break l}h=0;m:{if(!c){break m}while(1){n:{c=v[g>>2];v[23220]=0;d=W(143,c|0,v[e+40>>2],1)|0;c=v[23220];v[23220]=0;o:{if((c|0)!=1){c=w[e+18|0];if(!(d&c>>>0>(h&255)>>>0)){break n}v[23220]=0;d=T(193,g|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}if(d){break o}h=h+1|0;continue}break a}c=v[a+484344>>2];u[e+96>>1]=d&31;u[e>>1]=x[a+480188>>1]-1;c=Xb(c,f);c=$c(v[c>>2],v[v[c+48>>2]+12>>2],h,x[Tc(e+96|0,e)>>1]);if(d&128){v[23220]=0;R(250,e+96|0,g|0);j=v[23220];v[23220]=0;if((j|0)==1){break a}t[c|0]=w[e+96|0]+36;n=c,o=w[gd(e+96|0)|0],t[n+1|0]=o}if(d&64){t[c+2|0]=1;v[23220]=0;j=T(193,g|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break a}t[e+96|0]=j;t[e|0]=64;n=c,o=w[Rb(e+96|0,e)|0],t[n+4|0]=o}if(!(d&32)){continue}v[23220]=0;R(250,e+96|0,g|0);d=v[23220];v[23220]=0;p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{if((d|0)!=1){d=w[gd(e+96|0)|0];t[c+5|0]=d;switch(w[e+96|0]-1|0){case 71:break q;case 70:break r;case 69:break s;case 60:break t;case 59:break u;case 52:break v;case 51:break w;case 50:break x;case 49:break y;case 42:break z;case 41:break A;case 40:break B;case 39:break C;case 30:break D;case 29:break E;case 22:break F;case 21:break G;case 20:break H;case 19:break I;case 16:break J;case 15:break K;case 14:break L;case 13:break M;case 12:break N;case 11:break O;case 10:break P;case 9:break Q;case 3:break R;case 2:break S;case 1:break T;case 0:break U;default:break p}}break a}t[c+3|0]=11;t[c+5|0]=d<<4|15;continue}t[c+3|0]=11;t[c+5|0]=d<<4;continue}t[c+3|0]=11;t[c+5|0]=d|240;continue}t[c+3|0]=11;t[c+5|0]=d&15;continue}t[c+3|0]=2;t[c+5|0]=d|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=d|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=d|16;continue}t[c+3|0]=6;t[c+5|0]=d<<4;continue}t[c+3|0]=6;t[c+5|0]=d&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=d|48;continue}t[c+3|0]=7;t[c+5|0]=d<<4;continue}t[c+3|0]=7;t[c+5|0]=d&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=d|64;continue}t[c+3|0]=10;v[23220]=0;d=T(193,g|0)|0;j=v[23220];v[23220]=0;if((j|0)!=1){t[c+5|0]=d;v[23220]=0;Q(175,g|0,1)|0;c=v[23220];v[23220]=0;if((c|0)!=1){continue}}break a}t[c+3|0]=15;t[c+5|0]=d&15;continue}t[c+3|0]=20;t[c+5|0]=d|192;continue}t[c+3|0]=20;t[c+5|0]=d|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=d|176;continue}t[c+3|0]=20;t[c+5|0]=d|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=d&15|32;continue}t[c+3|0]=20;t[c+5|0]=d&15|128;continue}t[c+3|0]=0;continue}break}if((c|0)==64){break m}me(Xb(v[k>>2],f),uh(He(Be(e+96|0,14,0),c-1|0)))}wb(g)}f=f+1|0;continue}break}break a}c=x[e+218>>1]|x[e+220>>1]<<16;if(!c){break b}Vc(b,c);cB(a+1298332|0,b,Ag(b),4)}fb=e+272|0;return i|0}a=P()|0;O()|0;wb(g);S(a|0);L()}function dda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=fb-208|0;fb=d;wc(c);a:{if(!go(c,d+192|0)){break a}if(Mb(d+192|0,13794,4)){break a}f=d+200|0;if(Mb(f,14163,4)){if(Mb(f,14267,4)){break a}}e=fb-32|0;fb=e;i=d+176|0;g=Ib(i);b:{c:{d:{e:{f:{while(1){h=v[c+8>>2];j=v[c>>2];v[23220]=0;h=W(143,j|0,h|0,8)|0;j=v[23220];v[23220]=0;if((j|0)==1){break d}if(!h){break e}v[23220]=0;R(759,e|0,c|0);h=v[23220];v[23220]=0;if((h|0)!=1){v[23220]=0;R(760,g|0,e|0);h=v[23220];v[23220]=0;if((h|0)==1){break f}Id(e);continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;Id(e);break c}fb=e+32|0;break b}a=P()|0;O()|0}Vd(g);S(a|0);L()}v[23220]=0;U(683,d+152|0,i|0,1129270605);c=v[23220];v[23220]=0;g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){v[23220]=0;c=Q(684,d+152|0,d+128|0)|0;e=v[23220];v[23220]=0;n:{o:{if((e|0)!=1){if(!c){break g}if(!_b(x[d+130>>1]|x[d+132>>1]<<16)){break g}if((Jb(x[d+128>>1])-3&65535)>>>0<65534){break g}if((Jb(x[d+134>>1])-65&65535)>>>0<65472){break g}v[d+124>>2]=1162760014;c=1;if(!Mb(f,14267,4)){v[23220]=0;c=Q(568,d+152|0,d+124|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break o}if(!c){break g}c=v[d+124>>2]!=1936684916}v[23220]=0;U(683,d+104|0,d+176|0,1397968452);e=v[23220];v[23220]=0;p:{q:{if((e|0)!=1){v[23220]=0;k=Q(685,d+104|0,d+96|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break p}if(k){break q}break h}c=P()|0;O()|0;break j}f=((Jb(x[d+134>>1])-1|0)/8|0)-1|0;g=f<<3;e=g&31;g=Uc(d+88|0,(f>>>0<7?(g&63)>>>0>=32?4196360>>>e|0:((1<<e)-1&4196360)<<32-e|136321040>>>e:8)&255,(Jb(x[d+128>>1])|0)==2?2:1,c,0);c=v[d+124>>2];r:{if((c|0)!=544694642){s:{t:{if(!((c|0)==842222662|(c|0)==842230886|(c|0)==875973702)){if((c|0)==2002873461){break s}if((c|0)==1463897153){break t}if((c|0)==1463897173){break s}if((c|0)==2002873441){break t}if((c|0)!=875981926){break r}}Qf(g,3);break r}Qf(g,17);Eh(g,16);break r}Qf(g,16);Eh(g,16);break r}Qf(g,1)}c=v[d+96>>2];v[23220]=0;c=W(143,v[d+104>>2],v[d+112>>2],_b(c)|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break l}if(c){c=v[d+96>>2];v[23220]=0;Q(175,d+104|0,_b(c)|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break l}}Xs(a,b);v[23220]=0;c=B(b,104)+a|0;i=c+484380|0;R(267,i|0,0);e=v[23220];v[23220]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((e|0)==1){break D}r=i,s=_b(x[d+130>>1]|x[d+132>>1]<<16),v[r>>2]=s;j=c+484404|0;c=w[d+138|0]|w[d+139|0]<<8|(w[d+140|0]<<16|w[d+141|0]<<24);f=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);h=30-w[d+137|0]|0;e=0;while(1){c=f;if(h&255){f=c>>>1|0;h=h-1|0;e=c;continue}break}v[j>>2]=c+(e&1);v[23220]=0;W(206,g|0,i|0,d+104|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break D}v[23220]=0;U(683,d- -64|0,d+176|0,1296126539);c=v[23220];v[23220]=0;if((c|0)==1){break C}v[23220]=0;c=T(165,v[d+64>>2])|0;e=v[23220];v[23220]=0;if((e|0)==1){break B}if(!c){break u}v[23220]=0;U(683,d+16|0,d+176|0,1229869908);c=v[23220];v[23220]=0;if((c|0)==1){break A}v[23220]=0;c=Q(686,d+16|0,d+40|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break z}wb(d+16|0);if(!c){break u}v[23220]=0;f=T(261,d- -64|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break y}e=Ib(d+16|0);v[23220]=0;R(687,e|0,f|0);c=v[23220];v[23220]=0;if((c|0)==1){break w}c=0;while(1){if((c|0)==(f|0)){break x}v[23220]=0;g=Q(688,d- -64|0,d|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break w}if(!g){break x}v[23220]=0;R(689,e|0,d|0);g=v[23220];v[23220]=0;if((g|0)==1){break w}v[23220]=0;g=w[d+6|0];Q(175,d- -64|0,((g^-1)&1)+g|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break w}c=c+1|0;continue}}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break m}c=P()|0;O()|0;break m}c=P()|0;O()|0;wb(d+16|0);break m}c=P()|0;O()|0;break m}c=Jb(x[d+48>>1]);if(c){f=(B(b,104)+a|0)+484414|0;u[f>>1]=x[f>>1]&65511|((c|0)==2)<<4|8}c=Jb(x[d+54>>1]);if(c){f=(B(b,104)+a|0)+484414|0;u[f>>1]=x[f>>1]&65529|((c|0)==2?4:2)|2}r=d,s=Ab(v[e>>2]),v[r>>2]=s;c=B(b,104)+a|0;g=c+484388|0;h=c+484384|0;j=c+484396|0;l=c+484392|0;m=Ab(v[e+4>>2]);n=x[d+50>>1];o=x[d+52>>1];p=x[d+56>>1];q=x[d+58>>1];while(1){c=v[d>>2];if(!Nb(c,m)){break v}f=Jb(w[c|0]|w[c+1|0]<<8);if((f|0)==(Jb(n)|0)){r=l,s=_b(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s;f=Jb(w[c|0]|w[c+1|0]<<8)}if((Jb(o)|0)==(f|0)){r=j,s=_b(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s;f=Jb(w[c|0]|w[c+1|0]<<8)}if((Jb(p)|0)==(f|0)){r=h,s=_b(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s;f=Jb(w[c|0]|w[c+1|0]<<8)}if((f|0)==(Jb(q)|0)){r=g,s=_b(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s}v[d>>2]=v[d>>2]+7;continue}}c=P()|0;O()|0;BN(e);break m}hk(i);BN(e)}v[23220]=0;U(683,d+16|0,d+176|0,1312902469);c=v[23220];v[23220]=0;if((c|0)==1){break n}v[23220]=0;c=T(165,v[d+16>>2])|0;e=v[23220];v[23220]=0;E:{if((e|0)==1){break E}F:{if(c){v[23220]=0;c=T(147,v[d+16>>2])|0;e=v[23220];v[23220]=0;if((e|0)==1){break E}v[23220]=0;U(303,d+16|0,((b<<5)+a|0)+946304|0,c|0);b=v[23220];v[23220]=0;if((b|0)!=1){break F}break E}v[23220]=0;c=Q(52,d|0,21598)|0;e=v[23220];v[23220]=0;if((e|0)==1){break E}yc(((b<<5)+a|0)+946304|0,c);ub(c)}oz(i,v[a+480180>>2]);ij(i,a);wb(d+16|0);wb(d- -64|0);break h}c=P()|0;O()|0;wb(d+16|0);break m}c=P()|0;O()|0;break k}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break m}c=P()|0;O()|0;break i}wb(d- -64|0);break k}c=P()|0;O()|0}wb(d+104|0)}wb(d+152|0)}Vd(d+176|0);S(c|0);L()}wb(d+104|0)}wb(d+152|0);Vd(d+176|0)}fb=d+208|0;return k|0}function Gda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;e=fb-224|0;fb=e;wc(b);a:{if(!At(b,e+160|0)){break a}if(!$P(e+160|0)){break a}if(!Lb(v[b>>2],v[b+8>>2],Pc(_P(e+160|0),ib))){break a}if(!c){d=1;break a}zd(a,256);f=e+144|0;rj(f,2,e+160|0);d=e+48|0;Ac(d,f);xc(a+1298308|0,d);ub(d);f=x[e+210>>1];v[a+480260>>2]=64;v[a+480264>>2]=32767;u[a+480188>>1]=4;u[a+480190>>1]=f;Kb(a+1074312|0,107,1);f=w[e+203|0];f=f?f:96;k=Lz(f);v[a+480196>>2]=f>>>4;v[a+480204>>2]=k;t[e+48|0]=64;C=a,D=w[Rb(e+202|0,d)|0]<<2,v[C+480200>>2]=D;d=0;b:{c:{d:{e:{f:{g:{while(1){if((d|0)==4){h:{k=Ib(e+144|0);m=Ib(e+128|0);v[23220]=0;Q(142,b|0,x[e+192>>1]<<4)|0;d=v[23220];v[23220]=0;i:{if((d|0)==1){break i}v[23220]=0;W(204,b|0,k|0,x[e+208>>1])|0;d=v[23220];v[23220]=0;if((d|0)==1){break i}v[23220]=0;Q(142,b|0,x[e+194>>1]<<4)|0;d=v[23220];v[23220]=0;if((d|0)==1){break i}v[23220]=0;W(204,b|0,m|0,x[e+210>>1])|0;d=v[23220];v[23220]=0;if((d|0)==1){break i}v[23220]=0;Q(142,b|0,(x[e+196>>1]<<4)+32|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break i}d=a+484376|0;f=w[d|0];i=v[a+484360>>2];v[23220]=0;R(315,Vb(i,f)|0,x[e+212>>1]);f=v[23220];v[23220]=0;if((f|0)==1){break i}d=Vb(v[a+484360>>2],w[d|0]);C=e,D=Ab(v[d>>2]),v[C+48>>2]=D;d=Ab(v[d+4>>2]);j:{while(1){f=v[e+48>>2];if(!Nb(f,d)){d=0;if(!bQ(Vb(v[a+484360>>2],w[a+484376|0]))){break b}i=c&2;j=e+48|1;d=1;break j}v[23220]=0;i=T(193,b|0)|0;j=v[23220];v[23220]=0;k:{if((j|0)==1){break k}u[f>>1]=i;v[23220]=0;Q(175,b|0,4)|0;f=v[23220];v[23220]=0;if((f|0)==1){break k}Oe(e+48|0);continue}break}d=P()|0;O()|0;break c}l:{m:{n:{o:{while(1){f=d&65535;if(f>>>0>x[e+210>>1]){break l}g=ac(v[m>>2],f-1|0);g=w[g|0]|w[g+1|0]<<8;v[23220]=0;g=Q(142,b|0,g<<4)|0;h=v[23220];v[23220]=0;p:{if((h|0)!=1){if(g){break p}d=0;break b}d=P()|0;O()|0;break c}v[23220]=0;Q(634,b|0,e+48|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break o}v[23220]=0;g=(B(f,104)+a|0)+484380|0;U(635,e+48|0,g|0,0);h=v[23220];v[23220]=0;if((h|0)==1){break o}h=e+16|0;ak(h,2,j);v[23220]=0;R(209,e+32|0,h|0);h=v[23220];v[23220]=0;if((h|0)==1){break n}h=((f<<5)+a|0)+946304|0;f=e+32|0;yc(h,f);ub(f);q:{r:{if(!i|!v[e+64>>2]){break r}f=oQ(e+48|0);v[23220]=0;f=Q(142,b|0,f|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break m}if(!f){break r}f=e+32|0;nQ(f,w[e+78|0],w[e+79|0],1);v[23220]=0;W(206,f|0,g|0,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break q}}d=d+1|0;continue}break}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}t[e+15|0]=1;d=v[k>>2];s:{if(rc(d,v[k+4>>2])|x[e+188>>1]==26){break s}f=w[d|0]|w[d+1|0]<<8;d=0;v[23220]=0;f=Q(142,b|0,f<<4)|0;i=v[23220];v[23220]=0;if((i|0)==1){break h}if(!f){break b}v[23220]=0;d=T(181,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break h}if((d|0)!=x[e+188>>1]){break s}t[e+15|0]=0}n=c&1;if(n){v[23220]=0;R(212,a+484344|0,x[e+208>>1]);c=v[23220];v[23220]=0;if((c|0)==1){break h}}h=a+484344|0;c=e+48|0;p=c|5;q=c|3;r=c|4;s=c|2;y=c|1;z=a+480188|0;f=0;while(1){t:{if(!n|x[e+208>>1]<=f>>>0){break t}v[23220]=0;c=W(213,h|0,f&65535,64)|0;d=v[23220];v[23220]=0;if((d|0)==1){break g}if(!c){break t}c=ac(v[k>>2],f);c=w[c|0]|w[c+1|0]<<8;v[23220]=0;c=Q(142,b|0,c<<4)|0;d=v[23220];v[23220]=0;if((d|0)==1){break g}d=0;if(!c){break b}if(!w[e+15|0]){v[23220]=0;c=T(181,b|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break g}if(c>>>0>2112){break b}}u[e+16>>1]=65535;v[e+32>>2]=63;u:while(1){c=Xb(v[h>>2],f);A=Of(v[c>>2],v[v[c+48>>2]+12>>2],d);v:while(1){c=d;while(1){if(c>>>0<=63){v[23220]=0;i=T(193,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break f}if(!i){d=64;if(c>>>0>62){continue v}d=c+1|0;continue u}d=i&31;j=B(d,6)+A|0;l=Rh(e+48|0);g=d>>>0<x[z>>1];o=g?j:l;if(i&32){v[23220]=0;R(250,e|0,b|0);d=v[23220];v[23220]=0;w:{x:{y:{if((d|0)!=1){l=gd(e);d=w[e|0];if(d>>>0>239){break y}d=mQ((B(d>>>4|0,12)+(d&15)|0)+37|0);break x}d=P()|0;O()|0;break c}z:{switch(d-254|0){case 0:break x;case 1:break z;default:break w}}d=0}t[o|0]=d}t[(g?j+1|0:y)|0]=w[l|0]}if(i&64){v[23220]=0;d=T(193,b|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break e}t[e|0]=d;t[(g?j+2|0:s)|0]=1;t[e+14|0]=64;C=g?j+4|0:r,D=w[Rb(e,e+14|0)|0],t[C|0]=D}if(!(i&128)){continue}v[23220]=0;R(250,e|0,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break d}t[(g?j+3|0:q)|0]=w[e|0];C=g?j+5|0:p,D=w[gd(e)|0],t[C|0]=D;aQ(o,c,255,e+16|0,e+32|0);continue}break}break}break}c=x[e+16>>1];if((c|0)!=65535){me(Xb(v[h>>2],f),im(He(Be(e+48|0,12,c&255),v[e+32>>2])))}f=f+1|0;continue}break}v[23220]=0;b=Q(1,e+48|0,6049)|0;c=v[23220];v[23220]=0;A:{B:{C:{if((c|0)!=1){Db(a+1298344|0,b);vb(b);v[23220]=0;b=Q(1,e+32|0,5235)|0;c=v[23220];v[23220]=0;if((c|0)==1){break C}Db(a+1298356|0,b);vb(b);v[a+1298404>>2]=5;v[23220]=0;R(637,e|0,4366);b=v[23220];v[23220]=0;if((b|0)==1){break B}v[23220]=0;U(294,e+16|0,e|0,e+15|0);b=v[23220];v[23220]=0;if((b|0)==1){break A}b=a+1298368|0;a=e+16|0;Db(b,a);vb(a);bc(e);d=1;break b}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;bc(e);break c}d=P()|0;O()|0;break c}}else{f=(d<<5)+a|0;Pe(f+480280|0);u[f+480284>>1]=d&1?64:192;d=d+1|0;continue}break}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0}ld(m);ld(k);S(d|0);L()}ld(m);ld(k)}fb=e+224|0;return d|0}function gH(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0,D=0,E=0,F=0;i=fb-80|0;fb=i;v[i+76>>2]=b;D=i+55|0;s=i+56|0;b=0;a:{b:{c:{d:{e:while(1){if((2147483647-o|0)<(b|0)){break d}o=b+o|0;f:{g:{h:{k=v[i+76>>2];b=k;h=w[b|0];if(h){while(1){i:{h=h&255;j:{if(!h){h=b;break j}if((h|0)!=37){break i}h=b;while(1){if(w[b+1|0]!=37){break j}j=b+2|0;v[i+76>>2]=j;h=h+1|0;l=w[b+2|0];b=j;if((l|0)==37){continue}break}}b=h-k|0;C=2147483647-o|0;if((b|0)>(C|0)){break d}if(a){cf(a,k,b)}if(b){continue e}r=-1;h=1;b=v[i+76>>2];j=t[b+1|0];if(!(!Jj(j)|w[b+2|0]!=36)){r=j-48|0;y=1;h=3}b=h+b|0;v[i+76>>2]=b;p=0;m=t[b|0];j=m-32|0;k:{if(j>>>0>31){h=b;break k}h=b;j=1<<j;if(!(j&75913)){break k}while(1){h=b+1|0;v[i+76>>2]=h;p=j|p;m=t[b+1|0];j=m-32|0;if(j>>>0>=32){break k}b=h;j=1<<j;if(j&75913){continue}break}}l:{if((m|0)==42){b=t[h+1|0];m:{if(!(!Jj(b)|w[h+2|0]!=36)){v[((b<<2)+e|0)-192>>2]=10;m=h+3|0;q=v[((t[h+1|0]<<3)+d|0)-384>>2];y=1;break m}if(y){break h}m=h+1|0;if(!a){v[i+76>>2]=m;y=0;q=0;break l}b=v[c>>2];v[c>>2]=b+4;q=v[b>>2];y=0}v[i+76>>2]=m;if((q|0)>=0){break l}q=0-q|0;p=p|8192;break l}q=fH(i+76|0);if((q|0)<0){break d}m=v[i+76>>2]}b=0;l=-1;n:{if(w[m|0]!=46){j=m;h=0;break n}if(w[m+1|0]==42){h=t[m+2|0];o:{if(!(!Jj(h)|w[m+3|0]!=36)){v[((h<<2)+e|0)-192>>2]=10;j=m+4|0;l=v[((t[m+2|0]<<3)+d|0)-384>>2];break o}if(y){break h}j=m+2|0;l=0;if(!a){break o}h=v[c>>2];v[c>>2]=h+4;l=v[h>>2]}v[i+76>>2]=j;h=(l^-1)>>>31|0;break n}v[i+76>>2]=m+1;l=fH(i+76|0);j=v[i+76>>2];h=1}z=h;while(1){n=b;h=28;x=j;if(t[j|0]-123>>>0<4294967238){break c}j=x+1|0;v[i+76>>2]=j;b=w[(t[x|0]+B(n,58)|0)+75631|0];if(b-1>>>0<8){continue}break}p:{q:{if((b|0)!=27){if(!b){break c}if((r|0)>=0){v[(r<<2)+e>>2]=b;b=(r<<3)+d|0;h=v[b+4>>2];v[i+64>>2]=v[b>>2];v[i+68>>2]=h;break q}if(!a){break f}eH(i- -64|0,b,c,g);break p}if((r|0)>=0){break c}}b=0;if(!a){continue e}}m=p&-65537;j=p&8192?m:p;p=0;r=5247;h=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{b=t[x|0];b=n?(b&15)==3?b&-33:b:b;switch(b-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(b-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((b|0)==83){break w}break g}n=v[i+64>>2];k=v[i+68>>2];r=5247;break z}b=0;I:{switch(n&255){case 0:v[v[i+64>>2]>>2]=o;continue e;case 1:v[v[i+64>>2]>>2]=o;continue e;case 2:h=v[i+64>>2];v[h>>2]=o;v[h+4>>2]=o>>31;continue e;case 3:u[v[i+64>>2]>>1]=o;continue e;case 4:t[v[i+64>>2]]=o;continue e;case 6:v[v[i+64>>2]>>2]=o;continue e;case 7:break I;default:continue e}}h=v[i+64>>2];v[h>>2]=o;v[h+4>>2]=o>>31;continue e}l=l>>>0>8?l:8;j=j|8;b=120}m=s;E=b&32;n=v[i+64>>2];k=v[i+68>>2];if(n|k){while(1){m=m-1|0;t[m|0]=E|w[(n&15)+76160|0];F=!k&n>>>0>15|(k|0)!=0;x=k;k=k>>>4|0;n=(x&15)<<28|n>>>4;if(F){continue}break}}k=m;if(!(j&8)|!(v[i+64>>2]|v[i+68>>2])){break y}r=(b>>>4|0)+5247|0;p=2;break y}b=s;n=v[i+64>>2];k=v[i+68>>2];if(n|k){while(1){b=b-1|0;t[b|0]=n&7|48;x=!k&n>>>0>7|(k|0)!=0;m=k;k=m>>>3|0;n=(m&7)<<29|n>>>3;if(x){continue}break}}k=b;if(!(j&8)){break y}b=s-k|0;l=(b|0)<(l|0)?l:b+1|0;break y}b=v[i+68>>2];k=b;n=v[i+64>>2];if((b|0)<0){k=0-(k+((n|0)!=0)|0)|0;n=0-n|0;v[i+64>>2]=n;v[i+68>>2]=k;p=1;r=5247;break z}if(j&2048){p=1;r=5248;break z}p=j&1;r=p?5249:5247}k=gn(n,k,s)}if((l|0)<0?z:0){break d}j=z?j&-65537:j;m=v[i+64>>2];b=v[i+68>>2];if(!((m|b)!=0|l)){k=s;h=k;l=0;break g}b=!(b|m)+(s-k|0)|0;l=(b|0)<(l|0)?l:b;break g}b=v[i+64>>2];k=b?b:17016;b=k;h=l>>>0<2147483647?l:2147483647;j=Vt(b,0,h);b=j?j-b|0:h;h=b+k|0;if((l|0)>=0){j=m;l=b;break g}j=m;l=b;if(w[h|0]){break d}break g}if(l){h=v[i+64>>2];break u}b=0;qf(a,32,q,0,j);break t}v[i+12>>2]=0;v[i+8>>2]=v[i+64>>2];h=i+8|0;v[i+64>>2]=h;l=-1}b=0;J:{while(1){k=v[h>>2];if(!k){break J}k=dH(i+4|0,k);m=(k|0)<0;if(!(m|k>>>0>l-b>>>0)){h=h+4|0;b=b+k|0;if(l>>>0>b>>>0){continue}break J}break}if(m){break b}}h=61;if((b|0)<0){break c}qf(a,32,q,b,j);if(!b){b=0;break t}k=0;h=v[i+64>>2];while(1){l=v[h>>2];if(!l){break t}l=dH(i+4|0,l);k=l+k|0;if(k>>>0>b>>>0){break t}cf(a,i+4|0,l);h=h+4|0;if(b>>>0>k>>>0){continue}break}}qf(a,32,q,b,j^8192);b=(b|0)<(q|0)?q:b;continue e}if((l|0)<0?z:0){break d}h=61;b=jb[f|0](a,A[i+64>>3],q,l,j,b)|0;if((b|0)>=0){continue e}break c}t[i+55|0]=v[i+64>>2];l=1;k=D;j=m;break g}j=b+1|0;v[i+76>>2]=j;h=w[b+1|0];b=j;continue}}if(a){break a}if(!y){break f}b=1;while(1){a=v[(b<<2)+e>>2];if(a){eH((b<<3)+d|0,a,c,g);o=1;b=b+1|0;if((b|0)!=10){continue}break a}break}o=1;if(b>>>0>=10){break a}h=0;while(1){if(h){break h}b=b+1|0;if((b|0)==10){break a}h=v[(b<<2)+e>>2];continue}}h=28;break c}m=h-k|0;n=(l|0)>(m|0)?l:m;if((n|0)>(2147483647-p|0)){break d}h=61;l=n+p|0;b=(l|0)<(q|0)?q:l;if((C|0)<(b|0)){break c}qf(a,32,b,l,j);cf(a,r,p);qf(a,48,b,l,j^65536);qf(a,48,n,m,0);cf(a,k,m);qf(a,32,b,l,j^8192);continue}break}o=0;break a}h=61}v[115696]=h}o=-1}fb=i+80|0;return o}function Vga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=fb-224|0;fb=f;if(wh(b,13809)){if(d){t[d|0]=1}k=a+480204|0;n=a+480216|0;o=a+480220|0;p=a+480224|0;l=a+1074368|0;s=a+480228|0;z=a+480232|0;q=a+480200|0;m=a+480268|0;A=a+1298320|0;C=a+480248|0;D=Ut(a+1074312|0);E=a+480180|0;F=a+484376|0;G=a+480190|0;a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Lb(v[b>>2],v[b+8>>2],7)){break a}e=mg(b);g=Ag(b);if((e|0)==(w[21574]|w[21575]<<8|(w[21576]<<16|w[21577]<<24))){jg(b,6);break a}if(!(e&1616928864)|e&-2139062144){break a}if(!Lb(v[b>>2],v[b+8>>2],g)){break a}d=f+176|0;Qd(d,b,g);h=gc(f+200|0,d);wb(d);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((e|0)!=1127099950){if((e|0)==1129797166){break v}if((e|0)==1130917459){break o}if((e|0)==1145525806){break t}d=z;if((e|0)==1448301654){break s}if((e|0)==1196316499){break m}if((e|0)==1213486401){break p}if((e|0)==1280530262){break u}if((e|0)==1297303086){break l}if((e|0)==1347243310){break w}if((e|0)==1347244882){break q}if((e|0)!=1380340804){if((e|0)==1380986414){break r}d=n;if((e|0)==1380991534){break s}d=o;if((e|0)==1380994350){break s}if((e|0)==1397052739){break n}d=s;if((e|0)==1397768494){break s}if((e|0)==1414344238){break k}if((e|0)!=1146367534){break j}v[23220]=0;U(394,h|0,g|0,f+176|0);d=v[23220];v[23220]=0;if((d|0)==1){break i}v[k>>2]=B(v[f+176>>2],1e4)+(y[k>>2]%1e4|0);break j}v[23220]=0;U(394,h|0,g|0,f+176|0);d=v[23220];v[23220]=0;if((d|0)!=1){d=v[k>>2];v[k>>2]=d-((d>>>0)%1e4|0)+y[f+176>>2]%1e4;break j}e=P()|0;O()|0;break b}if(c){break j}v[23220]=0;u[f+176>>1]=0;U(395,h|0,g|0,f+176|0);d=v[23220];v[23220]=0;if((d|0)!=1){H=a,I=Pd(x[f+176>>1],x[a+480188>>1],127),u[H+480188>>1]=I;break j}e=P()|0;O()|0;break b}v[23220]=0;U(396,h|0,g|0,l|0);d=v[23220];v[23220]=0;if((d|0)!=1){break j}break c}v[23220]=0;v[f+176>>2]=0;U(394,h|0,g|0,f+176|0);d=v[23220];v[23220]=0;if((d|0)!=1){v[a+1074304>>2]=v[f+176>>2];break j}e=P()|0;O()|0;break b}v[23220]=0;v[f+176>>2]=0;U(394,h|0,g|0,f+176|0);d=v[23220];v[23220]=0;if((d|0)==1){break h}d=v[f+176>>2];if(!d){break j}v[a+1074308>>2]=d;break j}d=q}v[23220]=0;U(394,h|0,g|0,d|0);d=v[23220];v[23220]=0;if((d|0)==1){break c}break j}if(v[E>>2]==4){break j}v[23220]=0;U(395,h|0,g|0,f+176|0);d=v[23220];v[23220]=0;if((d|0)!=1){Ve(Vb(v[a+484360>>2],w[F|0]),x[f+176>>1]);break j}e=P()|0;O()|0;break b}v[23220]=0;U(397,h|0,g|0,m|0);d=v[23220];v[23220]=0;if((d|0)==1){break c}if(qo(w[m|0])){break j}t[m|0]=5;break j}d=Gb(f+176|0);e=v[h>>2];v[23220]=0;e=T(147,e|0)|0;g=v[23220];v[23220]=0;x:{if((g|0)==1){break x}v[23220]=0;U(398,h|0,d|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){break x}v[23220]=0;U(11,f+160|0,0,d|0);e=v[23220];v[23220]=0;if((e|0)==1){break x}e=f+160|0;Db(A,e);vb(e);ub(d);break j}e=P()|0;O()|0;ub(d);break b}if(g&1|g>>>0>126){break j}d=64;u[f+176>>1]=(g>>>1|0)- -64;u[f+160>>1]=127;e=x[Tc(f+176|0,f+160|0)>>1];i=e>>>0>64?e:64;while(1){if((d|0)==(i|0)){break j}v[23220]=0;R(250,f+176|0,h|0);e=v[23220];v[23220]=0;if((e|0)==1){break g}e=w[f+176|0];y:{if((e|0)==255){break y}j=w[gd(f+176|0)|0];g=(d<<5)+a|0;r=g+480284|0;u[r>>1]=128;u[g+480286>>1]=j;g=g+480280|0;j=(e&128)<<3;v[g>>2]=j;e=e&127;if(e>>>0<65){u[r>>1]=e<<2;break y}if((e|0)!=100){break y}v[g>>2]=j|256}d=d+1|0;continue}}if(g>>>0<3){break j}v[23220]=0;d=T(181,h|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break f}if(!d|d>>>0>x[G>>1]){break j}d=(B(d,104)+a|0)+484448|0;g=SS(d);while(1){if((d|0)==(g|0)){break j}e=v[h>>2];v[23220]=0;i=W(143,e|0,v[f+208>>2],4)|0;e=v[23220];v[23220]=0;z:{if((e|0)!=1){e=268435456;if(!i){break z}v[23220]=0;e=T(144,h|0)|0;i=v[23220];v[23220]=0;if((i|0)!=1){break z}}e=P()|0;O()|0;break b}v[d>>2]=e;d=d+4|0;continue}}if(g>>>0<3){break j}v[23220]=0;R(399,f|0,h|0);d=v[23220];v[23220]=0;A:{B:{C:{D:{if((d|0)!=1){v[23220]=0;U(400,f+176|0,v[f>>2],v[f+4>>2]);d=v[23220];v[23220]=0;if((d|0)==1){break D}v[23220]=0;d=Q(76,f+16|0,f+176|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break C}ub(f+176|0);$b(f);e=v[h>>2];v[23220]=0;e=T(147,e|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break A}v[23220]=0;U(401,d|0,C|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){break A}df(d);break j}e=P()|0;O()|0;break b}e=P()|0;O()|0;break B}e=P()|0;O()|0;ub(f+176|0)}$b(f);break b}e=P()|0;O()|0;df(d);break b}e=0;g=Ut(D);E:while(1){d=v[h>>2];v[23220]=0;d=W(143,d|0,v[f+208>>2],1)|0;i=v[23220];v[23220]=0;if((i|0)==1){break d}if(!(d&e>>>0<117)){break j}v[23220]=0;i=T(193,h|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue E}F:{if(!(i>>>d&1)|e>>>0>116){break F}v[23220]=0;W(254,g|0,e|0,1)|0;j=v[23220];v[23220]=0;if((j|0)!=1){break F}e=P()|0;O()|0;break b}e=e+1|0;d=d+1|0;continue}}}v[23220]=0;U(402,h|0,g|0,p|0);d=v[23220];v[23220]=0;if((d|0)==1){break c}}wb(h);continue}break}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}wb(h);S(e|0);L()}b=v[a+8>>2];xo(k,B(v[b+20>>2],1e4),B(v[b+24>>2],1e4));if(w[a+480224|0]>=3){t[p|0]=0}if(w[l|0]>=6){t[l|0]=0}uc(q,256);uc(n,65536);uc(o,65536)}fb=f+224|0}function Xea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;d=fb-1824|0;fb=d;wc(b);e=fb-16|0;fb=e;h=d+1224|0;kR(e+8|0,h);j=b;i=v[b+8>>2];b=v[e+12>>2];jc(e,v[j>>2],i,v[e+8>>2],b);i=v[e+4>>2];if((i|0)==(b|0)){Yb(j,v[e+12>>2])}fb=e+16|0;b=(b|0)==(i|0);if(!b){jR(h)}a:{if(!b){break a}if(!mR(d+1224|0)){break a}if(!aA(j,16,0)){break a}v[d+1216>>2]=v[d+1240>>2];b=v[d+1228>>2];v[d+1200>>2]=v[d+1224>>2];v[d+1204>>2]=b;b=d+1232|0;e=v[b+4>>2];v[d+1208>>2]=v[b>>2];v[d+1212>>2]=e;zd(a,1);Kb(Kb(zf(a+1074312|0,83),84,1),85,1);u[a+480188>>1]=4;v[d+1196>>2]=0;u[a+480190>>1]=15;Vc(j,20);k=a+480188|0;f=1;i=1;while(1){b:{if((f|0)==16){b=d+1064|0;uR(j,b);e=a+484376|0;kq(Vb(v[a+484360>>2],w[e|0]),b|2,128);f=0;m=tR(j,Vb(v[a+484360>>2],w[e|0]),w[d+1064|0],g,k,0,1);if(!(w[d+1064|0]?1:w[d+1065|0]|m>>>0>1)){break a}if(Ze(j)+65536>>>0<(m<<10)+g>>>0){break a}if(c){break b}f=1;break a}e=B(f,104)+a|0;h=e+484380|0;b=((f<<5)+a|0)+946304|0;bA(j,d+24|0,h,b,1);m=v[h>>2];c:{if(!w[Hb(b,0)|0]){break c}d:{if(Mb(b,16717,3)){if(Mb(b,16721,3)){break d}}if(w[Hb(b,5)|0]==58){break c}}i=0}b=Jb(x[d+52>>1]);if(b>>>0>=2){l=b<<1;b=Jb(x[d+50>>1]);v[e+484388>>2]=l+b;v[e+484384>>2]=b;hk(h)}e:{if(Jb(x[d+46>>1])>>>0<=4999){if(Jb(x[d+50>>1])>>>0<1e4){break e}}v[d+1064>>2]=5;z=d,A=v[Ke(d+1196|0,d+1064|0)>>2],v[z+1196>>2]=A}g=g+m|0;f=f+1|0;continue}break}f=w[d+1065|0];if(!f){t[d+1065|0]=120;f=120}f:{if(!Mb(d+1200|0,14904,6)){t[d+1065|0]=120;v[a+480204>>2]=125e4;break f}v[a+480204>>2]=125e4;if((f|0)==120){break f}z=a,A=Ee(1773447.5/(+(240-f|0)*122)*1e4),v[z+480204>>2]=A;if(v[d+1196>>2]>=2){v[d+24>>2]=i?4:5;z=d,A=v[Ke(d+1196|0,d+24|0)>>2],v[z+1196>>2]=A;break f}v[d+24>>2]=i?1:2;z=d,A=v[Ke(d+1196|0,d+24|0)>>2],v[z+1196>>2]=A}v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|2097152;g=d+1048|0;rj(g,3,d+1200|0);b=d+24|0;Ac(b,g);xc(a+1298308|0,b);ub(b);th(a,0);q=v[j+8>>2];r=a+484376|0;while(1){g:{h:{if(m>>>0>(p&65535)>>>0){b=Vb(v[a+484360>>2],w[r|0]);b=Nb(Wz(Ab(v[b>>2]),Ab(v[b+4>>2]),p),Ab(v[b+4>>2]));iR(j,d+24|0);if(b){s=Zz(d+24|0,0)+s|0;if(s>>>0>512){break h}}k=0;b=0;g=0;i:while(1){if((g|0)==64){break g}f=0;y=_c(d+24|0,g);while(1){e=b;if((f|0)==4){g=g+1|0;continue i}else{o=zb(y,f);l=w[Hb(o,2)|0]&15;h=w[Hb(o,3)|0];b=0;j:{if(!(e&255)){break j}if(Mb(o,26884,4)){break j}b=e+1|0;if((b&255)>>>0<33){break j}v[d+1196>>2]=6}k:{l:{m:{switch(l-1|0){case 0:case 1:e=v[d+1196>>2];if((e|0)==1&h>>>0>=32){break l}l=(l|0)!=1;if(!(l|!h|h>>>0>2)){v[d+1048>>2]=2;z=d,A=v[Ke(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;break k}if(l|(h|0)!=55&(h|0)!=71){break k}if((e|0)<=2){break l}break k;case 10:v[d+1196>>2]=6;break k;case 11:case 12:case 13:v[d+1048>>2]=2;z=d,A=v[Ke(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;if((l|0)!=13){break k}k=((g|h)!=0)+k|0;b=1;break k;case 14:break m;default:break k}}v[d+1048>>2]=3;z=d,A=v[Ke(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;break k}v[d+1196>>2]=i}f=f+1|0;continue}}}}if(!(v[d+1196>>2]!=6|m+32>>>0>=n>>>0)){v[d+1196>>2]=5}Vc(j,q);o=c&1;if(o){ig(a+484344|0,m)}l=a+484344|0;n=0;while(1){if((m|0)==(n|0)){f=21598;b=v[d+1196>>2];if(b>>>0<7){f=v[(b<<2)+26896>>2]}b=d+24|0;g=Qb(b,8291);Db(a+1298344|0,g);vb(g);b=Qb(b,10717);Db(a+1298356|0,b);vb(b);ql(a+1298368|0,f);v[a+1298404>>2]=13;if(!(c&2)){break h}f=1;while(1){if((f|0)==16){break h}b=B(f,104)+a|0;c=b+484384|0;Yb(j,v[c>>2]);g=v[c>>2];v[c>>2]=0;c=b+484380|0;v[c>>2]=v[c>>2]-g;b=b+484388|0;v[b>>2]=v[b>>2]-g;b=d+24|0;Uc(b,8,1,1,0);hg(b,c,j);f=f+1|0;continue}}iR(j,d+24|0);n:{if(!o){break n}if(!Xg(l,n&65535,64)){break n}i=0;v[d+1048>>2]=0;o:while(1){if((i|0)==64){break n}f=0;b=Xb(v[l>>2],n);q=$c(v[b>>2],v[v[b+48>>2]+12>>2],i,0);r=_c(d+24|0,i);while(1)if((f|0)==4){i=i+1|0;continue o}else{b=zb(r,f);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+12>>2]=b;v[d+16>>2]=b;e=q+B(f,6)|0;Yt(d+12|0,e);h=w[e+3|0];b=h;p:{q:{r:{g=w[e+5|0];if(g){b=14;if((h|0)!=14){break r}}t[(d+1048|0)+f|0]=0;if((b|g)&255){break q}break p}b=h;k=w[(d+1048|0)+f|0];if(!k){break q}s:{if(k>>>0>=16){t[e+2|0]=3;k=k>>>4|0;break s}t[e+2|0]=4}t[e+4|0]=k}t:{u:{v:{w:{x:{y:{switch((b&255)-12|0){case 1:b=v[d+1196>>2];if((b|0)==6){break u}h=10;t[e+3|0]=10;break v;case 0:g=g&127;break x;case 2:if(g>>>0<=1&v[d+1196>>2]>3){break t}h=10;t[e+3|0]=10;t[(d+1048|0)+f|0]=g;break w;case 3:break y;default:break w}}g=g&15}t[e+5|0]=g}b=v[d+1196>>2]}if((b|0)>1){break t}z:{A:{B:{switch(h|0){case 0:if(g>>>0>2){break A}break;case 2:break z;case 1:break A;default:break B}}t[e+3|0]=0;break p}t[e+3|0]=1;break p}b=g&15;if(b){t[e+3|0]=2;t[e+5|0]=b;break p}if(g>>>0<16){break p}t[e+3|0]=3;t[e+5|0]=g>>>4;break p}t[e+5|0]=0}Mf(e)}f=f+1|0;continue}}}n=n+1|0;continue}}f=m>>>0<=(p&65535)>>>0;break a}if((k-1&255)>>>0<2){v[d+1196>>2]=6}p=p+1|0;n=(k&255)+n|0;continue}}fb=d+1824|0;return f|0}function Kda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=fb-352|0;fb=d;Vc(b,60);h=15;a:{if(!wh(b,14115)){Vc(b,124);h=31;if(!wh(b,15336)){break a}}zd(a,536870912);u[a+480190>>1]=h;wc(b);b:{while(1){if(x[a+480190>>1]>f>>>0){e=km(b);v[(d+224|0)+(f<<2)>>2]=e;f=f+1|0;if(e>>>0<=131072){continue}break b}break}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;f=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;th(a,1);Yb(b,4);e=qq(b);if(e>>>0<178){break a}p=a,q=Ee(1776930/+(e>>>0)*1e4),v[p+480204>>2]=q;Yb(b,14);h=0;l=1;c:while(1){n=l&65535;if(n>>>0<=x[a+480190>>1]){pR(b,d+56|0);e=v[((n<<2)+d|0)+220>>2];g=fb-16|0;fb=g;i=(B(n,104)+a|0)+484380|0;kd(i,1);v[i>>2]=e;t[i+37|0]=w[d+80|0]<<4;t[g+15|0]=w[d+81|0];t[g+14|0]=64;p=i,q=w[Rb(g+15|0,g+14|0)|0]<<2,u[p+30>>1]=q;d:{if(!e){break d}f=Jb(w[d+84|0]|w[d+85|0]<<8);k=Jb(w[d+82|0]|w[d+83|0]<<8);v[i+4>>2]=k;f=(f<<1)+k|0;v[i+8>>2]=f;if(e>>>0<=k>>>0){k=e-1|0;v[i+4>>2]=k}if(e>>>0<f>>>0){v[i+8>>2]=e;f=e}if(!(!(f>>>0<4|f>>>0<k>>>0)&f-k>>>0>3)){v[i+4>>2]=0;v[i+8>>2]=0;break d}if(f>>>0<=k>>>0){break d}u[i+34>>1]=x[i+34>>1]|2}fb=g+16|0;f=0;while(1)if((f|0)==22){if(h>>>0>127){break b}e=d+192|0;dl(e,3,d+56|0);f=d+208|0;Ac(f,e);yc(((n<<5)+a|0)+946304|0,f);l=l+1|0;ub(f);continue c}else{e=(d+56|0)+f|0;if((w[e|0]-1&255)>>>0<=30){t[e|0]=32;h=h+1|0}f=f+1|0;continue}}break}i=1;e:{f:{g:{h=a+946336|0;f=Qb(d+56|0,13982);if(!hQ(h,f)){v[23220]=0;e=Q(52,d+208|0,13993)|0;i=v[23220];v[23220]=0;if((i|0)==1){break g}i=hQ(h,e);ub(e)}ub(f);f=0;e=d+56|0;h=oR(b,e);if(!h){Xz(e)}if(!h){break a}e=w[d+56|0];if(!kQ(e)){break a}if(!c){break e}u[d+54>>1]=0;while(1)if((e|0)==(f|0)){f=a+484376|0;g=Vb(v[a+484360>>2],w[f|0]);h=w[d+57|0];Ve(g,e>>>0>h>>>0?h:0);kq(Vb(v[a+484360>>2],w[f|0]),d+56|2,w[d+56|0]);if(x[a+480190>>1]==31){Yb(b,4)}v[d+48>>2]=0;v[d+44>>2]=0;v[d+40>>2]=0;t[d+39|0]=0;n=c&1;if(n){ig(a+484344|0,x[d+54>>1])}k=a+484344|0;l=0;while(1){h:{i:{j:{if(x[d+54>>1]<=l>>>0){if(!(c&2)){break j}f=1;while(1){h=x[a+480190>>1];c=f&65535;if(h>>>0<c>>>0){break i}c=(B(c,104)+a|0)+484380|0;if(v[c>>2]){hg(Uc(d+192|0,8,1,0,0),c,b)}f=f+1|0;continue}}k:{if(n){h=0;if(Xg(k,l&65535,64)){break k}}Yb(b,1024);break h}l:while(1){if((h|0)==64){break h}f=0;e=Xb(v[k>>2],l);o=$c(v[e>>2],v[v[e+48>>2]+12>>2],h,0);while(1)if((f|0)==4){h=h+1|0;continue l}else{g=d+192|0;pm(g,b);e=B(f,6)+o|0;m:{n:{o:{p:{if(w[Hb(g,0)|0]!=255){break p}t[(d+48|0)+f|0]=0;t[(d+40|0)+f|0]=0;g=Hb(d+192|0,1);j=w[g|0];if((j|0)==252&i){t[g|0]=254;break n}switch(j-252|0){case 1:break m;case 2:break n;case 0:break o;default:break p}}g=v[d+192>>2];v[d+32>>2]=g;v[d+12>>2]=g;Yt(d+12|0,e);g=w[e|0];q:{if(!g){break q}t[(d+40|0)+f|0]=0;t[(d+48|0)+f|0]=g;if(g>>>0>48){break q}t[d+16|0]=8;p=d,q=w[$e(d+39|0,d+16|0)|0],t[p+39|0]=q}r:{s:{t:{u:{v:{w:{switch(w[e+3|0]){case 1:t[e+3|0]=1;break m;case 2:g=w[e+5|0];if(g&240){t[e+3|0]=3;t[e+5|0]=g>>>4;break m}g=g&15;if(g){t[e+3|0]=2;t[e+5|0]=g;break m}t[e+5|0]=0;break s;case 3:if(w[(d+40|0)+f|0]){break t}t[e+3|0]=19;t[e+5|0]=0;break m;case 4:if(w[(d+40|0)+f|0]){break t}t[e+3|0]=19;t[e+5|0]=1;break m;case 5:if(!w[e+1|0]){break t}t[e+3|0]=13;t[d+16|0]=63;t[d+31|0]=w[e+5|0]+(x[(B(w[e+1|0],104)+a|0)+484410>>1]>>>2|0);p=e,q=w[Rb(d+16|0,d+31|0)|0],t[p+5|0]=q;if(!w[(d+40|0)+f|0]){break v}t[e+2|0]=1;t[e+4|0]=w[e+5|0];t[e+5|0]=0;break s;case 6:g=w[e+1|0];if(!g){break t}t[e+3|0]=13;g=x[(B(g,104)+a|0)+484410>>1]>>>2|0;j=w[e+5|0];g=g>>>0<j>>>0?0:g-j|0;t[e+5|0]=g;if(!w[(d+40|0)+f|0]){break m}t[e+4|0]=g;t[e+2|0]=1;t[e+5|0]=0;break s;case 7:g=w[(d+48|0)+f|0];j=w[e+5|0];m=g-(j>>>4|0)|0;t[(d+44|0)+f|0]=m;t[e+3|0]=3;j=j&15;t[(d+40|0)+f|0]=j;p=e,q=gQ(j,m&255,g),t[p+5|0]=q;break m;case 8:j=w[(d+48|0)+f|0];g=w[e+5|0];m=j+(g>>>4|0)|0;t[(d+44|0)+f|0]=m;t[e+3|0]=2;g=g&15;t[(d+40|0)+f|0]=g;p=e,q=gQ(g,j,m&255),t[p+5|0]=q;break m;case 0:break u;case 9:break w;default:break s}}t[d+16|0]=8;p=d,q=w[$e(d+39|0,d+16|0)|0],t[p+39|0]=q;break s}if(!w[e+3|0]){break r}break m}if(!w[e+5|0]){break r}break s}t[e+5|0]=0}t[e+3|0]=0}j=w[(d+40|0)+f|0];if(!j){break m}m=(d+44|0)+f|0;g=w[m|0];if(g){t[(d+48|0)+f|0]=g;t[e|0]=g;t[e+5|0]=j;t[m|0]=0}t[e+3|0]=4;break m}t[e+3|0]=14;t[d+39|0]=9;break m}t[e+3|0]=13}f=f+1|0;continue}}}h=x[a+480190>>1]}x:{y:{if((h&65535)==15){b=d+16|0;og(b,4379);v[23220]=0;U(294,d+192|0,b|0,d+39|0);b=v[23220];v[23220]=0;if((b|0)!=1){break y}h=P()|0;O()|0;bc(d+16|0);break f}v[23220]=0;Q(1,d+192|0,12296)|0;b=v[23220];v[23220]=0;if((b|0)==1){break x}}b=d+192|0;Db(a+1298344|0,b);vb(b);if((h&65535)==15){bc(d+16|0)}ql(a+1298356|0,x[a+480190>>1]==15?5243:15153);v[a+1298404>>2]=13;break e}h=P()|0;O()|0;break f}l=l+1|0;continue}}else{u[d+192>>1]=w[(d+f|0)+58|0]+1;p=d,q=x[Re(d+54|0,d+192|0)>>1],u[p+54>>1]=q;f=f+1|0;continue}}h=P()|0;O()|0;ub(f)}S(h|0);L()}f=1;break a}f=0}fb=d+352|0;return f|0}function MH(a,b,c,d,e,f){var g=0,h=C(0),i=0,j=0,k=C(0),l=C(0),m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,A=C(0),D=C(0),E=0,F=0,G=0,H=C(0),I=C(0),J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0),P=0,Q=0;F=(d|0)>0?d:0;while(1){if((s|0)!=(F|0)){G=B(s,2304)+b|0;v=0;q=(c|0)>0?c:0;n=fb-128|0;x=n+96|0;y=n- -64|0;E=n+32|0;while(1){if((q|0)!=(v|0)){o=G+(v<<2)|0;w=0;i=n;p=i;j=0;while(1){if((j|0)!=8){k=z[B(15-j|0,72)+o>>2];g=B(j,72)+o|0;h=z[g+1152>>2];l=C(k+h);m=z[g>>2];A=z[B(31-j|0,72)+o>>2];D=C(m+A);z[p>>2]=l+D;g=B(j,12);k=C(C(k-h)*z[g+70352>>2]);h=C(C(m-A)*z[g+70356>>2]);z[p+64>>2]=k+h;m=C(D-l);l=z[g+70360>>2];z[p+32>>2]=m*l;z[p+96>>2]=C(h-k)*l;p=p+4|0;j=j+1|0;continue}break}while(1){if((w|0)!=4){l=z[i+8>>2];m=z[i+20>>2];h=C(l+m);A=z[i+4>>2];D=z[i+24>>2];H=C(A+D);k=C(h+H);I=z[i+12>>2];J=z[i+16>>2];K=C(I+J);L=z[i>>2];M=z[i+28>>2];N=C(L+M);O=C(K+N);z[i>>2]=k+O;z[i+16>>2]=C(O-k)*C(.7071067690849304);k=C(N-K);h=C(C(k+C(H-h))*C(.7071067690849304));z[i+24>>2]=C(k-h)*C(1.3065630197525024);z[i+8>>2]=C(k+h)*C(.5411961078643799);k=C(L-M);h=C(l-m);l=C(A-D);m=C(C(h+l)*C(.7071067690849304));A=C(k+m);D=C(C(I-J)+h);h=C(l+k);l=C(D-C(h*C(.1989123672246933)));h=C(C(l*C(.3826834261417389))+h);z[i+28>>2]=C(A-h)*C(2.562915563583374);z[i+4>>2]=C(A+h)*C(.509795606136322);k=C(k-m);h=C(l-C(h*C(.1989123672246933)));z[i+20>>2]=C(k+h)*C(.8999761939048767);z[i+12>>2]=C(k-h)*C(.601344883441925);i=i+32|0;w=w+1|0;continue}break}i=0;while(1){if((i|0)!=7){p=i<<2;z[o>>2]=z[p+n>>2];k=z[p+x>>2];i=i+1|0;j=i<<2;h=z[j+x>>2];z[o+72>>2]=C(z[p+y>>2]+k)+h;z[o+144>>2]=z[p+E>>2]+z[j+E>>2];z[o+216>>2]=h+C(k+z[j+y>>2]);o=o+288|0;continue}break}z[o>>2]=z[n+28>>2];k=z[n+124>>2];z[o+72>>2]=z[n+92>>2]+k;h=z[n+60>>2];z[o+216>>2]=k;z[o+144>>2]=h;v=v+1|0;continue}break}s=s+1|0;continue}break}E=nc(f,a,3840);G=d<<5;s=0;while(1){if((c|0)>(s|0)){i=fb-32|0;fb=i;o=E+(s<<8)|0;v=(s<<2)+b|0;z[o+4080>>2]=z[v+1152>>2];f=d-1|0;w=v+B(f,2304)|0;z[o+4084>>2]=z[w+1152>>2];z[o+4088>>2]=z[v>>2];z[o+4092>>2]=z[w>>2];z[o+4336>>2]=z[v+1156>>2];z[o+4340>>2]=z[w+1156>>2];z[o+4344>>2]=z[v+4>>2];z[o+4348>>2]=z[w+4>>2];x=(B(s,G)<<1)+e|0;y=x+(f<<1)|0;Vr(y,d,o+244|0);f=d<<6;Vr(f+y|0,d,o+500|0);Vr(x,d,o+240|0);Vr(f+x|0,d,o+496|0);F=o+3840|0;p=14;n=70448;while(1){if((p|0)>=0){g=p<<4;j=g+F|0;f=B(31-p|0,72);z[j>>2]=z[f+v>>2];z[j+4>>2]=z[f+w>>2];f=f|4;z[j+8>>2]=z[f+v>>2];z[j+12>>2]=z[f+w>>2];f=B(p,72);q=f+76|0;z[j+256>>2]=z[q+v>>2];z[j+260>>2]=z[q+w>>2];f=f+72|0;z[j-248>>2]=z[f+v>>2];z[j-244>>2]=z[f+w>>2];q=p<<2;t=g+o|0;k=z[n+4>>2];h=z[n>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=z[g+j>>2];m=z[g+t>>2];z[g+(i+16|0)>>2]=C(l*h)-C(k*m);z[i+g>>2]=C(l*k)+C(h*m);f=f+1|0;continue}break}j=F+(q<<2)|0;q=j-3584|0;t=j-256|0;k=z[n+12>>2];h=z[n+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-3328|0;t=j-512|0;k=z[n+20>>2];h=z[n+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}q=j-3072|0;t=j-768|0;k=z[n+28>>2];h=z[n+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-2816|0;t=j-1024|0;k=z[n+36>>2];h=z[n+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}q=j-2560|0;t=j-1280|0;k=z[n+44>>2];h=z[n+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-2304|0;t=j-1536|0;k=z[n+52>>2];h=z[n+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}g=j-2048|0;q=j-1792|0;k=z[n+60>>2];h=z[n+56>>2];f=0;while(1){if((f|0)!=4){j=f<<2;t=j+i|0;l=z[j+q>>2];m=z[g+j>>2];z[t>>2]=z[t>>2]+C(C(l*k)+C(h*m));j=j+(i+16|0)|0;z[j>>2]=C(C(m*k)-C(h*l))+z[j>>2];f=f+1|0;continue}break}f=B(15-p|0,d)<<1;P=f+y|0,Q=Yi(z[i+20>>2]),u[P>>1]=Q;j=B(p+17|0,d)<<1;P=j+y|0,Q=Yi(z[i+4>>2]),u[P>>1]=Q;P=f+x|0,Q=Yi(z[i+16>>2]),u[P>>1]=Q;P=j+x|0,Q=Yi(z[i>>2]),u[P>>1]=Q;f=B(47-p|0,d)<<1;P=f+y|0,Q=Yi(z[i+28>>2]),u[P>>1]=Q;j=B(p+49|0,d)<<1;P=j+y|0,Q=Yi(z[i+12>>2]),u[P>>1]=Q;P=f+x|0,Q=Yi(z[i+24>>2]),u[P>>1]=Q;P=j+x|0,Q=Yi(z[i+8>>2]),u[P>>1]=Q;p=p-1|0;n=n- -64|0;continue}break}fb=i+32|0;s=s+2|0;continue}break}b=c<<6;a:{if((d|0)==1){s=0;while(1){if(s>>>0>959){break a}z[(s<<2)+a>>2]=z[E+(b+s<<2)>>2];s=s+2|0;continue}}nc(a,E+(b<<2)|0,3840)}}function Tca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;i=fb-208|0;fb=i;wc(b);a:{if(!VA(b,i+160|0)){break a}if(!rP(i+160|0)){break a}b:{if(!c){break b}if(!Lb(v[b>>2],v[b+8>>2],Pc(qP(w[i+207|0]),ib))){break a}zd(a,128);e=i+144|0;Ue(e,2,i+175|0);d=i+72|0;Ac(d,e);xc(a+1298308|0,d);ub(d);h=Qb(d,8440);Db(a+1298344|0,h);vb(h);h=Qb(d,6017);Db(a+1298356|0,h);vb(h);h=Qb(e,17484);v[23220]=0;U(692,d|0,h|0,v[(w[i+174|0]<<2)+26860>>2]);d=v[23220];v[23220]=0;c:{if((d|0)!=1){d=i+72|0;Db(a+1298368|0,d);vb(d);vb(h);v[a+480208>>2]=12;v[a+1298404>>2]=5;lB(a+1298332|0,b,w[i+207|0]<<5,32,0);e=Ae(b);u[a+480190>>1]=e;n=a+480190|0;h=1;while(1){m=h&65535;if(m>>>0>(e&65535)>>>0){fo(Vb(v[a+484360>>2],w[a+484376|0]),b,256,255,254);h=0;d=Ae(b);if(d>>>0>=127){break a}u[a+480188>>1]=d+1;d=Ae(b);e=a+480188|0;while(1)if(x[e>>1]<=h>>>0){n=a+484344|0;q=d+1|0;ig(n,q);e=0;while(1){d:{f=e&65535;if(f>>>0>d>>>0){l=0;s=a+480188|0;e:while(1){r=l&65535;e=x[a+480188>>1];if(r>>>0>=e>>>0){d=Sn(i+8|0);t[d+16|0]=0;u[d+14>>1]=0;u[d+12>>1]=e;v[23220]=0;R(694,d|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){a=P()|0;O()|0;Ie(d);S(a|0);L()}v[23220]=0;U(693,i+32|0,n|0,d|0);e=v[23220];v[23220]=0;h=1;if((e|0)==1){break d}Ie(i+32|0);Ie(d);if(!(c&2)){break a}c=a+480190|0;while(1){d=h&65535;if(d>>>0>x[c>>1]){break b}d=B(d,104)+a|0;hg(Uc(i+72|0,u[d+484414>>1]&1?16:8,1,0,0),d+484380|0,b);h=h+1|0;continue}}m=0;f=Rh(i+72|0);f:while(1){g:{if((m|0)!=(q|0)){if(Lb(v[b>>2],v[b+8>>2],5)){break g}}l=l+1|0;continue e}e=0;d=Xb(v[n>>2],m);h=$c(v[d>>2],v[v[d+48>>2]+12>>2],0,r);while(1){h:{i:{if(e>>>0>63){break i}j=w[i+174|0];d=fb-16|0;fb=d;p=1;g=Ae(b);if((g|0)==252){p=Ae(b);g=Ae(b)}t[f|0]=(g-1&255)>>>0<60?g+36|0:0;g=d+8|0;pm(g,b);t[f+1|0]=w[d+8|0];k=w[gd(g)|0];t[d+7|0]=k&15;t[d+6|0]=k>>>4;y=d,z=w[Qe(g)|0],t[y+5|0]=z;y=d,z=w[zi(g)|0],t[y+4|0]=z;nP(d+7|0,d+5|0,j);nP(d+6|0,d+4|0,j);j=w[d+7|0];k=(j|0)!=10;g=w[d+6|0];j:{if(!(k|(g|0)!=10)){j=w[d+5|0];g=w[d+4|0];t[f+3|0]=10;j=j|g<<8;t[f+5|0]=j>>>6;if(j>>>0<16384){break j}t[f+2|0]=15;t[f+4|0]=g>>>6;break j}k:{l:{m:{n:{if(!k){k=w[d+5|0];o=k<<2;y=d,z=sm(o),t[y+5|0]=z;if(k>>>0<64){break n}if(yi(g)>>>0>=xz(10)>>>0){break n}t[f+5|0]=o;t[f+2|0]=15;t[f+3|0]=10;t[f+4|0]=k>>>6;break j}if((g|0)==10){g=w[d+4|0];k=g<<2;y=d,z=sm(k),t[y+4|0]=z;if(g>>>0<64){break k}if(yi(j)>>>0>=xz(10)>>>0){break k}t[f+5|0]=k;t[f+2|0]=15;t[f+3|0]=10;t[f+4|0]=g>>>6;break j}if((g|0)!=(j|0)){break n}g=0;t[d+6|0]=0;break m}if((g|0)==13){break l}}if((j|0)==13|g){break k}}Wg(d+7|0,d+6|0);Wg(d+5|0,d+4|0)}g=d+6|0;j=d+4|0;k=d+7|0;o=d+5|0;yu(g,j,k,o);lo(d,k,o,g,j);t[f+2|0]=w[d+7|0];t[f+4|0]=w[d+5|0];t[f+3|0]=w[d+6|0];t[f+5|0]=w[d+4|0]}fb=d+16|0;g=e+p|0;e=g>>>0>64?64-e|0:p;if(!e){break i}while(1){if(!e){break h}d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[h|0]=d;t[h+1|0]=d>>>8;t[h+2|0]=d>>>16;t[h+3|0]=d>>>24;d=w[f+4|0]|w[f+5|0]<<8;t[h+4|0]=d;t[h+5|0]=d>>>8;e=e-1|0;h=B(x[s>>1],6)+h|0;continue}}m=m+1|0;continue f}e=g>>>0<64?g:64;continue}}}}e=e+1|0;h=0;if(Xg(n,f,64)){continue}break a}break}e=P()|0;O()|0;Ie(d);break c}else{f=(h<<5)+a|0;Pe(f+480280|0);g=f+480284|0;o:{if(w[i+174|0]>=51){f=(Ae(b)<<4|8)&248;break o}f=h&1?192:64}u[g>>1]=f;h=h+1|0;continue}}else{p:{if(w[i+174|0]>=52){d=i+72|0;if(!JT(b,d)){nB(d)}break p}d=fb-32|0;fb=d;v[d+28>>2]=64;v[d+8>>2]=66;f=v[b>>2];g=v[b+8>>2];e=v[Eb(d+28|0,d+8|0)>>2];if(!Lb(f,g,e)){e=Ze(b)}g=d+8|0;l=i+72|0;gu(g,l);f=cc(d+16|0,v[d+8>>2],e);jc(d,v[b>>2],v[b+8>>2],v[f>>2],v[f+4>>2]);gu(g,l);Sb(v[d+8>>2]+e|0,0,66-e|0);Yb(b,v[d+28>>2]);fb=d+32|0;u[i+136>>1]=x[i+134>>1];u[i+134>>1]=8363}g=fb-32|0;fb=g;f=(B(m,104)+a|0)+484380|0;kd(f,0);dB(f);d=i+72|0;ak(g,2,d+32|0);e=g+16|0;Ac(e,g);ue(f+43|0,e);ub(e);e=w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24);l=w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24);q:{if(e>>>0<=l>>>0){break q}v[f>>2]=e-l;v[f+12>>2]=w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24);v[g+16>>2]=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);y=f,z=v[Eb(g+16|0,f)>>2],v[y+16>>2]=z;u[f+30>>1]=w[d+60|0];v[f+24>>2]=w[d+62|0]|w[d+63|0]<<8;e=w[d+64|0]|w[d+65|0]<<8;if(e){aq(f,+(e<<16>>16)/393216)}e=w[d+61|0];if(e&8){u[f+34>>1]=x[f+34>>1]|8;e=w[d+61|0]}if(e&16){u[f+34>>1]=x[f+34>>1]|16;e=w[d+61|0]}if(!(e&4)){break q}u[f+34>>1]=x[f+34>>1]|1;v[f+12>>2]=v[f+12>>2]>>>1;v[f+16>>2]=v[f+16>>2]>>>1}fb=g+32|0;e=i+56|0;Ue(e,2,d);d=i+144|0;Ac(d,e);yc(((m<<5)+a|0)+946304|0,d);h=h+1|0;ub(d);e=x[n>>1];continue}}}e=P()|0;O()|0;vb(h)}S(e|0);L()}h=1}fb=i+208|0;return h|0}function DM(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;f=fb-16|0;fb=f;a:{if(!Oc(d&255)){break a}n=a+1074376|0;i=(n+B(b,872)|0)+616|0;b:{g=x[a+480192>>1];if(!(e?1:!(v[a+480180>>2]&17825824)|!g)){break b}if(Qj(v[i+656>>2])){break b}c=B(b,872)+a|0;d=c+1075068|0;if(!v[d>>2]){break a}c=v[c+1075080>>2];if(c&1024){break a}e=B(b,872)+a|0;g=e+1075012|0;e=e+1075016|0;if(!(v[g>>2]|v[e>>2])){break a}c:{if(!(c&512)){break c}c=v[a+1298300>>2];if(!sd(c)){break c}fj(c,b,0);break a}c=wy(a,b);if((c|0)==65535){break a}k=B(c,872);c=a+1074992|0;a=k+c|0;up(a,i);t[a+831|0]=0;t[a+805|0]=0;u[a+786>>1]=b+1;v[a+88>>2]=v[a+88>>2]&-918529;Vn(a+788|0);v[a+696>>2]=0;v[a+88>>2]=v[a+88>>2]|2101248;v[d>>2]=0;v[i>>2]=0;v[i+4>>2]=0;a=c+B(b,872)|0;v[a+92>>2]=0;v[a+96>>2]=0;v[g>>2]=0;v[e>>2]=0;break a}e=B(b,872)+a|0;m=v[e+1075096>>2];c=c>>>0>g>>>0?0:c;g=v[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!g){break d}l=d-1|0;c=x[ac(g+236|0,l)>>1];h=a+1074312|0;xb(f+8|0,h,104);e:{if(yb(v[v[f+8>>2]>>2],v[f+12>>2])){xb(f,h,34);if(yb(v[v[f>>2]>>2],v[f+4>>2])){break e}}d=w[Hb(g+108|0,l)|0]}if((c-1&65535)>>>0<=3998){m=(B(c,104)+a|0)+484380|0;break d}xb(f+8|0,h,43);if(!yb(v[v[f+8>>2]>>2],v[f+12>>2])){break d}if(!jj(w[g+31|0])){break a}}if(w[e+1075081|0]&4){break a}p=b>>>0>256?b:256;l=a+1074312|0;q=b+1|0;c=b;f:{while(1){if((c|0)==(p|0)){g:{e=0;c=0;if(!Qj(v[i+656>>2])){break f}c=0;if(!Oc(w[(B(b,872)+a|0)+1075789|0])){break f}d=ml(a,n,b,2,1);c=0;if((d-1&255)>>>0>249){break f}e=v[(B(d,160)+a|0)+906140>>2];if(e){break g}e=0;c=0;break f}}else{h:{if((b|0)!=(c|0)&x[a+480188>>1]>c>>>0){break h}e=B(c,872)+a|0;if(x[e+1075778>>1]!=(q|0)&(b|0)!=(c|0)){break h}o=e+1075648|0;h=v[o>>2];if(!h){break h}j=e+1074992|0;i:{j:{k:{l:{m:{n:{o:{switch(w[h+17|0]-1|0){case 0:if(!d){break h}k=w[e+1075789|0]==(d|0)&(g|0)==(h|0);if(!g){break n}if(k){break k}break h;case 1:if(!m|v[e+1075096>>2]!=(m|0)){break h}if((g|0)==(h|0)){break i}xb(f+8|0,l,104);if(!yb(v[v[f+8>>2]>>2],v[f+12>>2])){break i}break h;case 3:break m;case 2:break o;default:break h}}if(g){break l}k=(g|0)==(h|0)}if(k){break i}break h}if(!g){break h}k=w[g+34|0];if(!k){break h}if((k|0)==w[h+34|0]){break j}break h}if((g|0)!=(h|0)){break h}}if(!w[g+34|0]){break i}}if(!w[e+1075789|0]|w[h+18|0]>2){break i}xb(f+8|0,l,34);Nl(a,c&65535,RO(j,yb(v[v[f+8>>2]>>2],v[f+12>>2]))+255|0,0);t[e+1075792|0]=0}p:{q:{switch(w[v[o>>2]+18|0]){case 0:Fn(a,j);v[e+1075680>>2]=0;if(!(w[e+1075081|0]&2)){break p}h=v[a+1298300>>2];if(!sd(h)){break p}fj(h,c&65535,1);break p;case 1:Fn(a,j);if(!(w[e+1075081|0]&2)){break p}h=v[a+1298300>>2];if(!sd(h)){break p}Sj(h,c&65535);break p;case 2:break q;default:break p}}j=e+1075080|0;h=v[j>>2];v[j>>2]=h|4096;if(!(h&512)){break p}if(!sd(v[a+1298300>>2])){break p}xb(f+8|0,l,105);if(yb(v[v[f+8>>2]>>2],v[f+12>>2])){break p}Sj(v[a+1298300>>2],c&65535)}if(v[e+1075680>>2]){break h}v[e+1075688>>2]=0;e=e+1075080|0;v[e>>2]=v[e>>2]|2101248}c=c+1|0;continue}break}xb(f+8|0,l,34);c=(s=e,y=RO(i,yb(v[v[f+8>>2]>>2],v[f+12>>2])),z=b,r=v[v[e>>2]+100>>2],jb[r](s|0,y|0,z|0)|0)}if(!(ni(v[i+8>>2],v[i+12>>2])?1:c)){break a}g=wy(a,b);if((g|0)==65535){break a}h=B(g,872)+a|0;d=h+1075080|0;m=h+1074992|0;r:{if(!(w[h+1075081|0]&2)){break r}j=v[a+1298300>>2];if(!sd(j)){break r}fj(j,g,1)}m=up(m,i);v[d>>2]=v[d>>2]&-917505;t[h+1075823|0]=0;j=x[a+480188>>1];t[h+1075797|0]=0;u[h+1075778>>1]=b>>>0<j>>>0?b+1|0:0;s:{if(!(c&(e|0)!=0)){break s}c=w[(B(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break s}Nl(a,b,255,0);t[(B(b,872)+a|0)+1075792|0]=0}t:{u:{switch(w[(B(b,872)+a|0)+1075790|0]){case 2:Fn(a,m);if(!(w[d+1|0]&2)){break t}c=v[a+1298300>>2];if(!sd(c)){break t}Sj(c,b);xb(f+8|0,l,105);if(!yb(v[v[f+8>>2]>>2],v[f+12>>2])){break t}ez(v[a+1298300>>2],b,g);break t;case 0:v[(B(g,872)+a|0)+1075688>>2]=0;c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break t}c=v[a+1298300>>2];if(!sd(c)){break t}fj(c,b,1);break t;case 3:c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break t}if(!sd(v[a+1298300>>2])){break t}xb(f+8|0,l,105);c=v[a+1298300>>2];if(yb(v[v[f+8>>2]>>2],v[f+12>>2])){ez(c,b,g);break t}Sj(c,b);break t;case 1:break u;default:break t}}if(!(w[d+1|0]&2)){break t}c=v[a+1298300>>2];if(!sd(c)){break t}ez(c,b,g)}if(!v[(B(g,872)+a|0)+1075680>>2]){v[(B(g,872)+a|0)+1075688>>2]=0;v[d>>2]=v[d>>2]|2101248}a=B(b,872)+a|0;v[a+1075068>>2]=0;v[i>>2]=0;v[i+4>>2]=0;a=a+1075084|0;v[a>>2]=0;v[a+4>>2]=0}fb=f+16|0}function fda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=fb-144|0;fb=d;wc(c);a:{b:{c:{d:{if(!go(c,d+128|0)){break d}if(Mb(d+128|0,13794,4)){break d}k=d+136|0;e:{if(!Mb(k,13485,4)){break e}if(!Mb(k,13543,4)){break e}if(Mb(k,14225,4)){break d}}j=fb-32|0;fb=j;g=Ib(d+112|0);f:{g:{h:{i:{j:{while(1){f=v[c+8>>2];e=v[c>>2];v[23220]=0;f=W(143,e|0,f|0,8)|0;e=v[23220];v[23220]=0;if((e|0)==1){break h}if(!f){break i}v[23220]=0;R(763,j|0,c|0);e=v[23220];v[23220]=0;if((e|0)!=1){v[23220]=0;R(764,g|0,j|0);e=v[23220];v[23220]=0;if((e|0)==1){break j}Id(j);continue}break}a=P()|0;O()|0;break g}a=P()|0;O()|0;Id(j);break g}fb=j+32|0;break f}a=P()|0;O()|0}Vd(g);S(a|0);L()}v[23220]=0;j=T(161,d+88|0)|0;c=v[23220];v[23220]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if((c|0)!=1){l=Uc(d+80|0,8,1,1,0);if(Mb(k,14225,4)){break t}v[23220]=0;U(677,d+56|0,d+112|0,1296581714);c=v[23220];v[23220]=0;if((c|0)==1){break q}v[23220]=0;U(677,d+32|0,d+112|0,1296318804);c=v[23220];v[23220]=0;if((c|0)==1){break c}c=d+32|0;f=Yc(j,c);wb(c);c=0;v[23220]=0;i=T(678,d+56|0)|0;e=v[23220];v[23220]=0;h=1;if((e|0)==1){break c}if(!i){break u}e=v[f>>2];v[23220]=0;i=T(165,e|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}if(!i){break u}v[23220]=0;m=T(269,d+56|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break c}v[23220]=0;g=T(261,d+56|0)|0;c=v[23220];v[23220]=0;w:{if((c|0)==1){break w}v[23220]=0;Q(175,d+56|0,2)|0;c=v[23220];v[23220]=0;if((c|0)==1){break w}v[23220]=0;c=T(269,d+56|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){break v}}break c}h=P()|0;O()|0;break a}v[23220]=0;R(590,d+32|0,d+56|0);e=v[23220];v[23220]=0;if((e|0)==1){break c}e=Jb(x[d+32>>1]);if(!e){break u}c=(c>>>0)/(e>>>0)|0;e=d+32|0;f=fc(e);i=Qe(e);e=Jb(w[f|0]|w[f+1|0]<<8);if((e|0)!=(Jb(w[i|0]|w[i+1|0]<<8)+1|0)){break u}if((e|0)==2){so(l,2)}x:{if((g|0)!=16){if((g|0)!=8){break u}y:{switch(Jb(w[d+38|0]|w[d+39|0]<<8)|0){case 0:Qf(l,1);break x;case 2:Qf(l,17);break x;case 3:break y;default:break u}}Qf(l,16);break x}if(Jb(w[d+38|0]|w[d+39|0]<<8)){break u}Eh(l,16)}h=0}wb(d+56|0);if(!h){break s}h=0;break k}v[23220]=0;U(677,d+56|0,d+112|0,1447576658);c=v[23220];v[23220]=0;z:{A:{if((c|0)!=1){v[23220]=0;U(677,d+32|0,d+112|0,1128808782);c=v[23220];v[23220]=0;if((c|0)==1){break A}v[23220]=0;U(677,d+8|0,d+112|0,1112491097);c=v[23220];v[23220]=0;if((c|0)==1){break m}c=d+8|0;g=Yc(j,c);wb(c);c=v[g>>2];v[23220]=0;f=T(165,c|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break z}c=0;e=0;B:{if(!f){break B}v[23220]=0;f=T(165,v[d+56>>2])|0;c=v[23220];v[23220]=0;if((c|0)==1){break z}c=0;e=0;if(!f){break B}v[23220]=0;f=Q(679,d+56|0,d+8|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break z}c=0;e=0;if(!f){break B}m=Mb(k,13485,4);v[23220]=0;k=T(269,d+32|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break m}if(m){p=l,q=v[Uc(d,16,1,0,0)>>2],v[p>>2]=q}if((k|0)==6){so(l,3)}c=v[g>>2];v[23220]=0;n=v[d+24>>2];g=x[d+20>>1];o=v[d+12>>2];f=v[d+8>>2];e=T(147,c|0)|0;c=v[23220];v[23220]=0;i=1;if((c|0)==1){break m}c=e;e=B((k|0)==6?2:1,m?2:1);m=(c>>>0)/(e>>>0)|0;n=_b(n);c=Jb(g);o=(_b(o)>>>0)/(e>>>0)|0;e=(_b(f)>>>0)/(e>>>0)|0}wb(d+32|0);wb(d+56|0);if(i){break r}break k}h=P()|0;O()|0;break b}h=P()|0;O()|0;break l}break m}e=0}Xs(a,b);v[23220]=0;f=B(b,104)+a|0;g=f+484380|0;R(267,g|0,0);i=v[23220];v[23220]=0;if((i|0)==1){break p}v[g>>2]=m;i=e+o|0;v[f+484388>>2]=i;v[f+484384>>2]=e;if(!(i>>>0<=e+4>>>0|i>>>0>m>>>0)){e=(B(b,104)+a|0)+484414|0;u[e>>1]=x[e>>1]|2}e=B(b,104)+a|0;v[e+484404>>2]=c?c:22050;c=n>>>8|0;u[e+484410>>1]=(n&16776960)>>>0>65536?256:c&65535?c:256;oz(g,v[a+480180>>2]);v[23220]=0;U(677,d+56|0,d+112|0,1312902469);c=v[23220];v[23220]=0;if((c|0)==1){break o}v[23220]=0;e=T(165,v[d+56>>2])|0;c=v[23220];v[23220]=0;if((c|0)==1){break n}C:{D:{if(e){v[23220]=0;e=T(147,v[d+56>>2])|0;c=v[23220];v[23220]=0;if((c|0)==1){break n}v[23220]=0;U(316,d+56|0,((b<<5)+a|0)+946304|0,e|0);b=v[23220];v[23220]=0;if((b|0)!=1){break D}break n}v[23220]=0;e=Q(52,d+32|0,21598)|0;c=v[23220];v[23220]=0;if((c|0)==1){break C}yc(((b<<5)+a|0)+946304|0,e);ub(e)}v[23220]=0;W(206,l|0,g|0,j|0)|0;b=v[23220];v[23220]=0;h=1;if((b|0)==1){break n}ij(g,a);wb(d+56|0);break k}break n}h=P()|0;O()|0;break b}h=P()|0;O()|0;break b}h=P()|0;O()|0;break b}h=P()|0;O()|0;wb(d+56|0);break b}h=P()|0;O()|0;wb(d+32|0)}wb(d+56|0);break b}wb(j);Vd(d+112|0)}fb=d+144|0;return h|0}h=P()|0;O()|0;wb(d+56|0)}wb(j)}Vd(d+112|0);S(h|0);L()}function Ad(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=fb-96|0;fb=k;t=h;u=i&65535;m=(e^i)&-2147483648;l=e&65535;p=l;A=l;K=i>>>16&32767;L=e>>>16&32767;a:{b:{if(K-32767>>>0>4294934529&L-32767>>>0>=4294934530){break b}l=e&2147483647;j=d;if(!(!d&(l|0)==2147418112?!(b|c):l>>>0<2147418112)){o=d;m=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){o=h;m=i|32768;b=f;c=g;break a}if(!(b|j|(l^2147418112|c))){if(!(f|h|(e|g))){m=2147450880;b=0;c=0;break a}m=m|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){d=b|j;e=c|l;b=0;c=0;if(!(d|e)){m=2147450880;break a}m=m|2147418112;break a}if(!(b|j|(c|l))){b=0;c=0;break a}if(!(f|h|(e|g))){b=0;c=0;break a}if((l|0)==65535|l>>>0<65535){j=b;h=!(d|p);i=h<<6;l=E(h?b:d)+32|0;b=E(h?c:p);b=i+((b|0)==32?l:b)|0;vf(k+80|0,j,c,d,p,b-15|0);s=16-b|0;d=v[k+88>>2];A=v[k+92>>2];c=v[k+84>>2];b=v[k+80>>2]}if(e>>>0>65535){break b}e=!(t|u);h=e<<6;i=E(e?f:t)+32|0;e=E(e?g:u);e=h+((e|0)==32?i:e)|0;vf(k- -64|0,f,g,t,u,e-15|0);s=(s-e|0)+16|0;t=v[k+72>>2];u=v[k+76>>2];f=v[k+64>>2];g=v[k+68>>2]}e=f;j=g<<15|e>>>17;h=e<<15;e=j;p=h&-32768;q=c;B=Bia(p,0,c,0);c=ib;x=c;C=e;i=0;j=Bia(e,0,b,i);e=j+B|0;h=ib+c|0;h=e>>>0<j>>>0?h+1|0:h;c=e;j=e;n=Bia(b,i,p,i);l=0+n|0;e=ib+e|0;e=l>>>0<n>>>0?e+1|0:e;y=l;n=l;l=e;D=(j|0)==(e|0)&r>>>0>n>>>0|e>>>0<j>>>0;r=d;M=Bia(p,i,d,0);H=ib;e=Bia(q,i,C,i);d=e+M|0;j=ib+H|0;n=d;d=d>>>0<e>>>0?j+1|0:j;e=t;j=u<<15|e>>>17;z=e<<15|g>>>17;g=j;j=Bia(z,0,b,i);e=j+n|0;f=ib+d|0;I=e;f=e>>>0<j>>>0?f+1|0:f;u=f;e=f;f=(h|0)==(x|0)&c>>>0<B>>>0|h>>>0<x>>>0;c=h+I|0;f=e+f|0;B=c;f=c>>>0<h>>>0?f+1|0:f;t=f;c=f;F=A|65536;A=w;N=Bia(p,i,F,w);J=ib;h=Bia(r,o,C,i);f=h+N|0;e=ib+J|0;O=f;e=f>>>0<h>>>0?e+1|0:e;w=e;G=g|-2147483648;x=0;g=Bia(G,x,b,i);b=g+f|0;f=ib+e|0;f=b>>>0<g>>>0?f+1|0:f;P=b;e=Bia(z,o,q,i);b=b+e|0;p=f;j=f+ib|0;Q=b;g=b>>>0<e>>>0?j+1|0:j;f=0;b=f+B|0;e=c+Q|0;e=b>>>0<f>>>0?e+1|0:e;R=b;c=b;b=b+D|0;D=e;f=b>>>0<c>>>0?e+1|0:e;c=f;s=((L+K|0)+s|0)-16383|0;j=Bia(G,x,q,i);h=ib;i=Bia(F,A,C,i);e=i+j|0;f=ib+h|0;f=e>>>0<i>>>0?f+1|0:f;i=(f|0)==(h|0)&e>>>0<j>>>0|f>>>0<h>>>0;h=e;q=i;i=Bia(z,o,r,o);e=i+e|0;j=ib+f|0;j=e>>>0<i>>>0?j+1|0:j;i=(f|0)==(j|0)&e>>>0<h>>>0|f>>>0>j>>>0;f=q+i|0;h=0;h=f>>>0<i>>>0?1:h;q=Bia(G,x,F,A);i=q+f|0;f=ib+h|0;f=i>>>0<q>>>0?f+1|0:f;q=e;h=j;C=i;e=(d|0)==(u|0)&n>>>0>I>>>0|d>>>0>u>>>0;d=e+((d|0)==(H|0)&n>>>0<M>>>0|d>>>0<H>>>0)|0;j=0;j=d>>>0<e>>>0?1:j;i=d;d=q+d|0;e=h+j|0;e=d>>>0<i>>>0?e+1|0:e;n=d;i=e;e=(e|0)==(h|0)&d>>>0<q>>>0|e>>>0<h>>>0;d=C+e|0;h=d>>>0<e>>>0?f+1|0:f;q=d;j=Bia(z,o,F,A);e=ib;r=Bia(G,x,r,o);d=r+j|0;f=ib+e|0;f=d>>>0<r>>>0?f+1|0:f;r=d;d=f;f=(e|0)==(f|0)&j>>>0>r>>>0|e>>>0>f>>>0;z=d+q|0;e=f+h|0;e=d>>>0>z>>>0?e+1|0:e;h=0;d=h+n|0;f=i+r|0;f=d>>>0<h>>>0?f+1|0:f;h=f;j=(i|0)==(f|0)&d>>>0<n>>>0|f>>>0<i>>>0;i=j+z|0;n=i;i=i>>>0<j>>>0?e+1|0:e;r=d;e=d;d=h;j=(p|0)==(w|0)&O>>>0>P>>>0|p>>>0<w>>>0;f=j+((w|0)==(J|0)&O>>>0<N>>>0|w>>>0<J>>>0)|0;h=0;j=f+((g|0)==(p|0)&P>>>0>Q>>>0|g>>>0<p>>>0)|0;f=g+e|0;e=d+j|0;e=f>>>0<g>>>0?e+1|0:e;g=f;h=(d|0)==(e|0)&f>>>0<r>>>0|d>>>0>e>>>0;d=h+n|0;f=i;f=d>>>0<h>>>0?f+1|0:f;h=e;n=d;i=(t|0)==(D|0)&B>>>0>R>>>0|t>>>0>D>>>0;d=i+((t|0)==(u|0)&B>>>0<I>>>0|t>>>0<u>>>0)|0;j=0;j=d>>>0<i>>>0?1:j;i=d;d=d+g|0;e=e+j|0;e=d>>>0<i>>>0?e+1|0:e;h=(e|0)==(h|0)&d>>>0<g>>>0|e>>>0<h>>>0;g=n+h|0;f=g>>>0<h>>>0?f+1|0:f;h=g;i=f;c:{if(f&65536){s=s+1|0;break c}w=l>>>31|0;f=i<<1|h>>>31;h=g<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;g=y;f=l<<1|g>>>31;y=g<<1;l=f;f=c<<1|b>>>31;b=b<<1|w;c=f}if((s|0)>=32767){m=m|2147418112;b=0;c=0;break a}d:{if((s|0)<=0){f=1-s|0;if(f>>>0>=128){b=0;c=0;break a}g=s+127|0;vf(k+48|0,y,l,b,c,g);vf(k+32|0,d,e,h,i,g);cm(k+16|0,y,l,b,c,f);cm(k,d,e,h,i,f);y=v[k+32>>2]|v[k+16>>2]|(v[k+48>>2]|v[k+56>>2]|(v[k+52>>2]|v[k+60>>2]))!=0;l=v[k+36>>2]|v[k+20>>2];b=v[k+40>>2]|v[k+24>>2];c=v[k+44>>2]|v[k+28>>2];d=v[k>>2];e=v[k+4>>2];f=v[k+8>>2];g=v[k+12>>2];break d}f=h;g=i&65535|s<<16}o=f|o;m=g|m;if(!(!b&(c|0)==-2147483648?!(l|y):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;c=j;f=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;d=f+o|0;e=m;o=d;m=d>>>0<f>>>0?e+1|0:e;break a}if(b|y|(c^-2147483648|l)){b=d;c=e;break a}j=m;c=d&1;b=c+d|0;f=b>>>0<c>>>0?e+1|0:e;c=f;e=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;d=e+o|0;o=d;m=d>>>0<e>>>0?j+1|0:j}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=o;v[a+12>>2]=m;fb=k+96|0}function sea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=fb-144|0;fb=g;wc(b);a:{b:{c:{d:{e:{if(!QQ(b,14111)){break e}k=Ib(g+128|0);j=Ib(g+112|0);v[23220]=0;v[g+104>>2]=0;v[g+108>>2]=0;R(236,a|0,32768);d=v[23220];v[23220]=0;if((d|0)==1){break b}v[23220]=0;d=Q(1,g+88|0,8156)|0;i=v[23220];v[23220]=0;if((i|0)==1){break c}Db(a+1298344|0,d);vb(d);v[23220]=0;d=Q(1,g+72|0,6021)|0;i=v[23220];v[23220]=0;if((i|0)==1){break d}Db(a+1298356|0,d);vb(d);v[a+1298404>>2]=13;m=a+484376|0;i=a+480280|0;while(1){d=v[b+8>>2];f=v[b>>2];v[23220]=0;d=W(143,f|0,d|0,8)|0;f=v[23220];v[23220]=0;f:{g:{h:{if((f|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}v[23220]=0;d=Q(589,b|0,g- -64|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break m}if(!d){break n}d=v[g+68>>2];v[23220]=0;U(177,g+16|0,b|0,_b(d)|0);d=v[23220];v[23220]=0;if((d|0)==1){break l}d=g+16|0;f=gc(g+40|0,d);wb(d);d=v[f>>2];v[23220]=0;d=T(165,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break j}if(d){break k}wb(f)}if(x[a+480188>>1]){break i}i=0;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}o:{p:{q:{r:{s:{t:{u:{d=_b(v[g+64>>2]);if((d|0)!=1397769541){if((d|0)==1346458708){break t}if((d|0)==1346522948){break s}if((d|0)==1347175758){break u}if((d|0)!=1396788560){if((d|0)==1396854596){break r}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(x[a+480188>>1]){break f}d=v[f>>2];v[23220]=0;d=T(147,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break j}if(d>>>0<8){break f}d=0;v[23220]=0;R(590,g+16|0,f|0);e=v[23220];v[23220]=0;if((e|0)==1){break j}while(1)if((d|0)==4){if(c){break f}i=1;break o}else{e=x[a+480188>>1];h=ac(g+16|0,d);v:{if(!Jb(w[h|0]|w[h+1|0]<<8)){h=(d&3)-1|0;break v}h=g+104|0;o=Hb(h,e),p=1,t[o|0]=p;o=Hb(h,x[a+480188>>1]+1|0),p=255,t[o|0]=p;Pe(i+(x[a+480188>>1]<<5)|0);h=x[a+480188>>1];e=h+1|0;u[a+480188>>1]=e;l=i+(h<<5)|0;h=(d&3)-1|0;u[l+4>>1]=h>>>0<2?192:64}Pe(i+((e&65535)<<5)|0);e=x[a+480188>>1];u[a+480188>>1]=e+1;u[(i+(e<<5)|0)+4>>1]=h>>>0<2?192:64;d=d+1|0;continue}}if(x[a+480190>>1]){break f}v[23220]=0;R(591,f|0,a|0);d=v[23220];v[23220]=0;if((d|0)!=1){break f}break j}d=v[f>>2];v[23220]=0;d=T(147,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break j}if(d>>>0<2){break f}v[23220]=0;d=T(261,f|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break j}o=a,p=Pd(d,1,255),v[o+480196>>2]=p;break f}d=v[f>>2];v[23220]=0;d=T(147,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break j}if(d>>>0<2){break f}v[23220]=0;n=T(261,f|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break f}break j}d=w[m|0];e=v[a+484360>>2];h=v[f>>2];v[23220]=0;h=T(147,h|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break j}v[23220]=0;da(333,Vb(e,d)|0,f|0,h|0,255,254);d=v[23220];v[23220]=0;if((d|0)==1){break j}break f}d=k;if(Bf(v[d>>2],v[d+4>>2])>>>0>=256){break f}break q}if(Bf(v[j>>2],v[j+4>>2])>>>0>3998){break f}d=v[f>>2];v[23220]=0;e=T(147,d|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break j}d=j;if(!e){break f}}v[23220]=0;R(592,d|0,f|0);d=v[23220];v[23220]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}i=0}wb(f);break g}a=P()|0;O()|0;wb(f);break a}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=w[a+484376|0];d=v[a+484360>>2];v[23220]=0;R(315,Vb(d,b)|0,n&65535);b=v[23220];v[23220]=0;if((b|0)==1){break b}w:{if(!(c&1)){break w}b=v[k+4>>2];i=v[k>>2];d=0;v[23220]=0;R(212,a+484344|0,Bf(i,b)&65535);b=v[23220];v[23220]=0;if((b|0)==1){break b}while(1){f=v[k>>2];b=d&65535;if(Bf(f,v[k+4>>2])>>>0<=b>>>0){break w}v[23220]=0;i=v[g+108>>2];e=v[g+104>>2];v[g+8>>2]=e;v[g+12>>2]=i;v[g>>2]=e;v[g+4>>2]=i;X(593,xg(f,b)|0,b|0,a|0,g|0);b=v[23220];v[23220]=0;if((b|0)!=1){d=d+1|0;continue}break}a=P()|0;O()|0;break a}f=c&2;i=1;d=1;b=0;while(1){if(x[a+480190>>1]<=d>>>0){break g}if(!f|Bf(v[j>>2],v[j+4>>2])>>>0<=b>>>0){break g}c=(B(d,104)+a|0)+484380|0;to(c);x:{if(v[c>>2]){e=v[xg(v[j>>2],b)>>2];v[23220]=0;e=T(147,e|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break h}uc(c,e);e=Uc(g+40|0,8,1,1,0);h=v[j>>2];v[23220]=0;W(206,e|0,c|0,xg(h,b)|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break x}b=b+1|0}d=d+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}fd(j);fd(k);break e}wb(f);continue}}fb=g+144|0;return i|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}fd(j);fd(k);S(a|0);L()}function aV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-112|0;fb=e;wc(b);a:{if(!zq(b,11748)){break a}if(!Du(b,e+96|0)){break a}if(!aC(w[e+97|0])){break a}if(!Lb(v[b>>2],v[b+8>>2],Pc($B(e+96|0),ib))){break a}if(!Yb(b,w[e+105|0]|w[e+106|0]<<8)){break a}b:{if(!c){break b}zd(a,4096);v[a+480208>>2]=12;u[a+480188>>1]=(w[e+98|0]&31)+1;u[a+480190>>1]=w[e+99|0];th(a,1);d=e+24|0;j=Qb(d,8463);Db(a+1298344|0,j);vb(j);j=Qb(d,7011);Db(a+1298356|0,j);vb(j);j=fb-16|0;fb=j;f=Qb(j,4208);Mc(e,f);vb(f);fb=j+16|0;v[23220]=0;X(219,d|0,e|0,w[e+97|0],e+96|0);d=v[23220];v[23220]=0;c:{if((d|0)!=1){d=e+24|0;Db(a+1298368|0,d);vb(d);bc(e);v[a+1298404>>2]=5;d=w[e+99|0];j=e+80|0;v[j>>2]=0;v[j+4>>2]=0;mj(j+8|0,0);if(d){Hq(j,d);LC(j,d,0)}i=a+480190|0;d=1;d:{while(1){f=d&65535;if(f>>>0>x[i>>1]){v[23220]=0;Q(220,b|0,a+1298308|0)|0;f=v[23220];v[23220]=0;d=1;e:{if((f|0)==1){break e}f=a+480190|0;while(1){i=d&65535;if(i>>>0>x[f>>1]){f=a+480188|0;d=0;f:{while(1){if(x[f>>1]<=d>>>0){d=0;v[23220]=0;i=a+484344|0;R(212,i|0,x[e+100>>1]);f=v[23220];v[23220]=0;if((f|0)==1){break e}break f}i=(d<<5)+a|0;Pe(i+480280|0);v[23220]=0;R(221,b|0,i+480289|0);i=v[23220];v[23220]=0;if((i|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}g:{h:{i:{j:{while(1){if(x[e+100>>1]<=d>>>0){v[23220]=0;g=T(181,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break h}if(!g){break i}d=v[b+8>>2];f=v[b>>2];v[23220]=0;d=W(143,f|0,d|0,g|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break h}if(d){break j}break i}v[23220]=0;f=Q(222,b|0,e+24|0)|0;g=v[23220];v[23220]=0;k:{if((g|0)==1){break k}v[23220]=0;g=W(213,i|0,d&65535,64)|0;h=v[23220];v[23220]=0;if((h|0)==1){break k}if((f&g)==1){f=v[i>>2];v[23220]=0;R(223,Xb(f,d)|0,e+24|0);f=v[23220];v[23220]=0;if((f|0)==1){break k}}d=d+1|0;continue}break}b=P()|0;O()|0;break d}f=Ib(e+24|0);v[23220]=0;U(224,b|0,f|0,g|0);d=v[23220];v[23220]=0;l:{if((d|0)!=1){d=Gb(e);v[23220]=0;R(43,d|0,g|0);g=v[23220];v[23220]=0;m:{if((g|0)==1){break m}l=e,m=Ab(v[f>>2]),v[l+48>>2]=m;h=Ab(v[f+4>>2]);while(1){n:{g=v[e+48>>2];if(!Nb(g,h)){v[23220]=0;X(225,e+48|0,5,6,d|0);g=v[23220];v[23220]=0;if((g|0)==1){break n}h=e+48|0;g=xc(d,h);ub(h);h=Ec(g);k=Bb(g);v[23220]=0;da(226,a+1298332|0,h|0,k|0,76,0);h=v[23220];v[23220]=0;if((h|0)==1){break m}ub(g);$b(f);break i}o:{g=w[g|0];if(g&128){l=e,m=ih(d),v[l+64>>2]=m;k=v[Ef(e+72|0,e- -64|0)>>2];v[23220]=0;X(227,d|0,k|0,g&127,32);g=v[23220];v[23220]=0;if((g|0)!=1){break o}break m}v[23220]=0;R(44,d|0,g<<24>>24);g=v[23220];v[23220]=0;if((g|0)!=1){break o}break m}xe(e+48|0);continue}break}}b=P()|0;O()|0;ub(d);break l}b=P()|0;O()|0}$b(f);break d}d=w[a+484376|0];f=v[a+484360>>2];v[23220]=0;U(228,Vb(f,d)|0,b|0,x[e+102>>1]);d=v[23220];v[23220]=0;if((d|0)==1){break h}g=c&1;d=0;while(1){p:{q:{if(x[e+100>>1]>d>>>0){f=v[b+8>>2];h=v[b>>2];v[23220]=0;f=W(143,h|0,f|0,4)|0;h=v[23220];v[23220]=0;if((h|0)==1){break p}if(f){break q}}if(!(c&2)){break g}f=a+480190|0;d=1;while(1){c=d&65535;if(c>>>0>x[f>>1]){break g}i=B(c,104)+a|0;g=x[i+484414>>1];xb(e+24|0,v[j>>2],c-1|0);c=Uc(e,g&1?16:8,1,0,yb(v[v[e+24>>2]>>2],v[e+28>>2])?6:0);v[23220]=0;W(206,c|0,i+484380|0,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}v[23220]=0;f=T(144,b|0)|0;h=v[23220];v[23220]=0;r:{s:{if((h|0)!=1){v[23220]=0;U(177,e|0,b|0,f|0);f=v[23220];v[23220]=0;if((f|0)==1){break s}f=gc(e+24|0,e);wb(e);if(!g){break r}h=v[i>>2];if(!ke(h,v[i+4>>2],d&65535)){break r}v[23220]=0;U(229,Xb(h,d)|0,0,f|0);h=v[23220];v[23220]=0;if((h|0)!=1){break r}b=P()|0;O()|0;wb(f);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}wb(f);d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}Ie(j);break b}v[23220]=0;Q(230,b|0,((i<<5)+a|0)+946304|0)|0;i=v[23220];v[23220]=0;if((i|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[23220]=0;R(231,b|0,e+24|0);g=v[23220];v[23220]=0;t:{if((g|0)==1){break t}v[23220]=0;R(232,e+24|0,(B(f,104)+a|0)+484380|0);g=v[23220];v[23220]=0;if((g|0)==1){break t}g=w[e+40|0];xb(e,v[j>>2],f-1|0);sg(e,(g&3)!=0);d=d+1|0;continue}break}b=P()|0;O()|0}Ie(j);break c}b=P()|0;O()|0;bc(e)}S(b|0);L()}d=1}fb=e+112|0;return d|0}function i8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0;e=fb-320|0;fb=e;f=-1;a:{b:{c:{if(!Ek(v[(v[v[b>>2]-12>>2]+b|0)+16>>2])){b=yl(e+216|0,b);v[23220]=0;d=Q(404,e+200|0,13942)|0;f=v[23220];v[23220]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){v[23220]=0;v[e+184>>2]=83886084;v[e+188>>2]=0;U(405,b|0,d|0,e+184|0);f=v[23220];v[23220]=0;if((f|0)==1){break A}Pb(d);t[e+199|0]=0;v[23220]=0;d=Q(404,e+184|0,14720)|0;f=v[23220];v[23220]=0;if((f|0)==1){break z}v[23220]=0;U(406,b|0,e+199|0,d|0);f=v[23220];v[23220]=0;if((f|0)==1){break y}Pb(d);v[23220]=0;f=w[e+199|0];d=Q(404,e+168|0,15750)|0;h=v[23220];v[23220]=0;if((h|0)==1){break x}v[23220]=0;f=f?0:c;X(852,b|0,a+40|0,d|0,f|0);c=v[23220];v[23220]=0;if((c|0)==1){break w}Pb(d);u[e+166>>1]=65535;v[23220]=0;c=Q(404,e+152|0,15420)|0;d=v[23220];v[23220]=0;if((d|0)==1){break v}v[23220]=0;W(434,b|0,e+166|0,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break u}Pb(c);u[e+150>>1]=0;v[23220]=0;c=Q(404,e+136|0,15319)|0;d=v[23220];v[23220]=0;if((d|0)==1){break t}v[23220]=0;W(434,b|0,e+150|0,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break s}Pb(c);u[a>>1]=x[e+150>>1];v[23220]=0;c=Q(404,e+120|0,15084)|0;d=v[23220];v[23220]=0;if((d|0)==1){break r}v[23220]=0;X(853,b|0,a+52|0,c|0,f|0);d=v[23220];v[23220]=0;if((d|0)==1){break q}Pb(c);v[23220]=0;c=Q(404,e+104|0,14966)|0;d=v[23220];v[23220]=0;if((d|0)==1){break p}v[23220]=0;U(844,b|0,a+36|0,c|0);d=v[23220];v[23220]=0;if((d|0)==1){break o}Pb(c);v[23220]=0;d=Q(404,e+88|0,15427)|0;c=v[23220];v[23220]=0;if((c|0)==1){break n}v[23220]=0;c=a+4|0;U(854,b|0,c|0,d|0);f=v[23220];v[23220]=0;if((f|0)==1){break m}Pb(d);v[23220]=0;d=Q(404,e+72|0,15321)|0;f=v[23220];v[23220]=0;if((f|0)==1){break l}v[23220]=0;h=a+28|0;U(855,b|0,h|0,d|0);f=v[23220];v[23220]=0;if((f|0)==1){break k}Pb(d);v[23220]=0;d=Q(404,e+56|0,15198)|0;f=v[23220];v[23220]=0;if((f|0)==1){break j}v[23220]=0;U(855,b|0,a+30|0,d|0);f=v[23220];v[23220]=0;if((f|0)==1){break i}Pb(d);v[23220]=0;d=Q(404,e+40|0,14995)|0;f=v[23220];v[23220]=0;if((f|0)==1){break h}v[23220]=0;U(856,b|0,a+32|0,d|0);f=v[23220];v[23220]=0;if((f|0)==1){break g}Pb(d);u[e+38>>1]=0;v[23220]=0;d=Q(404,e+24|0,14939)|0;f=v[23220];v[23220]=0;if((f|0)==1){break c}v[23220]=0;W(434,b|0,e+38|0,d|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break f}Pb(d);i=UK(z[a+32>>2]);z[a+32>>2]=i;f=-1;if(!Il(i)){break d}k=e,l=Ab(v[c>>2]),v[k+16>>2]=l;d=Ab(v[c+4>>2]);while(1){g=v[e+16>>2];if(!Nb(g,d)){break e}if(!Il(z[g>>2])){break d}ye(e+16|0);continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;Pb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Pb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Pb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Pb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Pb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Pb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Pb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Pb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Pb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Pb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Pb(d);break a}a=P()|0;O()|0;Pb(d);break a}if(w[b+3|0]&64){break d}d=x[h>>1];if((d+300&65535)>>>0>600){break d}g=x[a>>1];if(g>>>0>3|(g|0)==2){break d}j=u[a+30>>1];if((j|0)<0){break d}k=e,l=ui(v[a+36>>2]),v[k+16>>2]=l;v[e+8>>2]=0;k=a,l=v[uj(e+16|0,e+8|0,43984)>>2],v[k+36>>2]=l;if(sc(v[c>>2],v[c+4>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:c=u[e+38>>1];if((c|0)<=0){break d}u[e+6>>1]=j;z[e+16>>2]=z[a+32>>2];v[23220]=0;u[e+8>>1]=d;u[e+10>>1]=(c+d|0)-1;a=fa(857,a|0,e+6|0,e+16|0,e+8|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;O()|0;break a;case 0:g=u[e+38>>1];if((g|0)<=0){break d}z[e+16>>2]=z[a+32>>2];v[23220]=0;u[e+8>>1]=d;u[e+10>>1]=(d+g|0)-1;a=ga(858,a|0,c|0,e+16|0,e+8|0,h|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;O()|0;break a;default:break C}}v[23220]=0;Y(859,a|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}}f=1}Ug(b)}fb=e+320|0;return f|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}Ug(b);S(a|0);L()}function nx(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;l=fb-48|0;fb=l;v[l+44>>2]=0;if(i?1:d|g|h){j=g?l+44|0:0;a:{if(!j){break a}k=v[j>>2];if(!k){break a}Fb(k);v[j>>2]=0}v[23220]=0;Z(91);k=v[23220];v[23220]=0;b:{c:{if((k|0)==1){m=Ta(91480,49056,49112,61832,91656,91760,91708,91600,91588,91904,91872,91840,91828,92052,0)|0;d:{e:{n=O()|0;if((n|0)==(ea(91480)|0)){k=_(m|0)|0;v[23220]=0;R(1019,j|0,k|0);j=v[23220];v[23220]=0;k=277;if((j|0)==1){break e}break b}if((ea(49056)|0)==(n|0)){k=_(m|0)|0;v[23220]=0;R(1019,j|0,k|0);j=v[23220];v[23220]=0;k=358;if((j|0)!=1){break b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break c}break d}if((ea(49112)|0)==(n|0)){k=_(m|0)|0;v[23220]=0;R(1019,j|0,k|0);j=v[23220];v[23220]=0;k=359;if((j|0)!=1){break b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break c}break d}if((ea(61832)|0)==(n|0)){k=_(m|0)|0;v[23220]=0;R(1019,j|0,k|0);j=v[23220];v[23220]=0;k=357;if((j|0)!=1){break b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break c}break d}if((ea(91656)|0)==(n|0)){k=_(m|0)|0;v[23220]=0;R(1019,j|0,k|0);j=v[23220];v[23220]=0;k=300;if((j|0)!=1){break b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break c}break d}if((ea(91760)|0)==(n|0)){k=_(m|0)|0;v[23220]=0;R(1019,j|0,k|0);j=v[23220];v[23220]=0;k=299;if((j|0)!=1){break b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break c}break d}if((ea(91708)|0)==(n|0)){k=_(m|0)|0;v[23220]=0;R(1019,j|0,k|0);j=v[23220];v[23220]=0;k=298;if((j|0)!=1){break b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break c}break d}if((ea(91600)|0)==(n|0)){k=_(m|0)|0;v[23220]=0;R(1019,j|0,k|0);j=v[23220];v[23220]=0;k=297;if((j|0)!=1){break b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break c}break d}if((ea(91588)|0)==(n|0)){k=_(m|0)|0;v[23220]=0;R(1019,j|0,k|0);j=v[23220];v[23220]=0;k=296;if((j|0)!=1){break b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break c}break d}if((ea(91904)|0)==(n|0)){k=_(m|0)|0;v[23220]=0;R(1019,j|0,k|0);j=v[23220];v[23220]=0;k=289;if((j|0)!=1){break b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break c}break d}if((ea(91872)|0)==(n|0)){k=_(m|0)|0;v[23220]=0;R(1019,j|0,k|0);j=v[23220];v[23220]=0;k=288;if((j|0)!=1){break b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break c}break d}if((ea(91840)|0)==(n|0)){k=_(m|0)|0;v[23220]=0;R(1019,j|0,k|0);j=v[23220];v[23220]=0;k=287;if((j|0)!=1){break b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break c}break d}if((ea(91828)|0)==(n|0)){k=_(m|0)|0;v[23220]=0;R(1019,j|0,k|0);j=v[23220];v[23220]=0;k=286;if((j|0)!=1){break b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break c}break d}o=ea(92052)|0;k=257;m=_(m|0)|0;if((n|0)!=(o|0)){break b}v[23220]=0;R(1019,j|0,m|0);j=v[23220];v[23220]=0;k=267;if((j|0)!=1){break b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)==1){break d}break c}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break c}}V(0)|0;O()|0;Tb()}L()}S(a|0);L()}$()}m=!g;if(d){j=jb[d|0](k,e)|0}else{j=3}if(!(m|!(j&2))){v[g+16>>2]=k;m=g;g=v[l+44>>2];p=m,q=Uf(g?g:21598),v[p+20>>2]=q}if(h){v[h>>2]=k}if(i){g=v[l+44>>2];p=i,q=Uf(g?g:21598),v[p>>2]=q}g=v[l+44>>2];if(g){Fb(g);v[l+44>>2]=0}f:{if(!(j&1)){break f}v[23220]=0;R(1017,l+32|0,a|0);g=v[23220];v[23220]=0;g:{h:{if((g|0)!=1){i:{if(f){g=v[f+24>>2];v[23220]=0;R(1018,g|0,l+32|0);g=v[23220];v[23220]=0;if((g|0)!=1){break i}break h}g=Ec(l+32|0);if(b){v[23220]=0;R(b|0,g|0,c|0);g=v[23220];v[23220]=0;if((g|0)==1){break h}break i}rs(g,l)}ub(l+32|0);break f}g=V(0)|0;O()|0;break g}g=V(0)|0;O()|0;ub(l+32|0)}_(g|0)|0;v[l+28>>2]=f;v[l+24>>2]=e;v[l+20>>2]=d;v[l+16>>2]=c;v[l+12>>2]=b;v[l+8>>2]=a?a:21598;v[l+4>>2]=250;v[l>>2]=9145;FJ(17814,l);ps(92408);$()}fb=l+48|0}function uha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;e=fb-352|0;fb=e;wc(b);f=fb-16|0;fb=f;hT(f+8|0,e+128|0);h=v[f+12>>2];jc(f,v[b>>2],v[b+8>>2],v[f+8>>2],h);i=v[f+4>>2];if((i|0)==(h|0)){Yb(b,v[f+12>>2])}fb=f+16|0;a:{b:{c:{d:{e:{f:{g:{if((h|0)!=(i|0)){break g}if(!jT(e+128|0)){break g}if(!Lb(v[b>>2],v[b+8>>2],Pc(iT(w[e+344|0],w[e+345|0]),ib))){break g}if(!c){d=1;break g}zd(a,2);yg(a);v[a+480188>>2]=524296;s=a,z=Ee(455e3),v[s+480204>>2]=z;Kb(a+1074312|0,110,1);v[a+480208>>2]=v[a+480208>>2]|16777216;f=e+96|0;Ue(f,2,e+159|0);d=e+112|0;Ac(d,f);xc(a+1298308|0,d);ub(d);d=0;h:{i:{while(1){if((d|0)==8){j:{d=Vb(v[a+484360>>2],w[a+484376|0]);o=w[e+344|0];n=o+1|0;fo(d,b,n,65535,65535);f=Ib(e+112|0);v[23220]=0;U(224,b|0,f|0,n|0);d=v[23220];v[23220]=0;if((d|0)==1){break j}s=e,z=Ab(v[f>>2]),v[s+96>>2]=z;d=Ab(v[f+4>>2]);while(1){h=v[e+96>>2];p=Nb(h,d);if(p){if((w[h|0]-9&255)>>>0<248){break h}xe(e+96|0);continue}break}s=a,z=w[Hb(v[f>>2],0)|0],v[s+480196>>2]=z;d=w[e+343|0];i=w[e+345|0];h=Ib(e+96|0);v[23220]=0;m=i+1|0;U(224,b|0,h|0,m|0);i=v[23220];v[23220]=0;k:{if((i|0)==1){break k}v[23220]=0;i=a+484344|0;R(212,i|0,m|0);g=v[23220];v[23220]=0;if((g|0)==1){break k}q=d+1|0;if(!(c&1)){break i}c=0;while(1){if((c|0)==(m|0)){break i}d=w[Hb(v[h>>2],c)|0];v[23220]=0;d=W(213,i|0,d|0,q|0)|0;g=v[23220];v[23220]=0;l:{if((g|0)!=1){if(!d){break i}j=0;k=Xb(v[i>>2],w[Hb(v[h>>2],c)|0]);m:while(1){r=j&65535;if(r>>>0>7){break l}j=j+1|0;d=0;while(1){if(y[k+12>>2]<=d>>>0){continue m}v[23220]=0;g=T(193,b|0)|0;l=v[23220];v[23220]=0;n:{o:{if((l|0)!=1){if(!(g&128)){break o}d=(g&127)+d|0;break n}d=P()|0;O()|0;break b}l=$c(v[k>>2],v[v[k+48>>2]+12>>2],d,r);if((g|0)==1){t[l|0]=254;break n}if((g-1&255)>>>0>96){break n}t[l+1|0]=j;t[l|0]=g+12}d=d+1|0;continue}}}d=P()|0;O()|0;break b}c=c+1|0;continue}}d=P()|0;O()|0;break b}}else{i=e+112|0;f=(e+128|0)+B(d,19)|0;UA(i,f+63|0);h=e+96|0;Ac(h,i);mm(((d<<5)+a|0)+480289|0,h);ub(h);d=d+1|0;g=B(d,104)+a|0;j=g+484380|0;kd(j,2);t[e+107|0]=0;h=w[f+78|0]|w[f+79|0]<<8|(w[f+80|0]<<16|w[f+81|0]<<24);t[e+103|0]=h;t[e+104|0]=h>>>8;t[e+105|0]=h>>>16;t[e+106|0]=h>>>24;h=w[f+75|0]|w[f+76|0]<<8|(w[f+77|0]<<16|w[f+78|0]<<24);f=w[f+71|0]|w[f+72|0]<<8|(w[f+73|0]<<16|w[f+74|0]<<24);v[e+8>>2]=v[e+104>>2];v[e+96>>2]=f;v[e+100>>2]=h;f=v[e+100>>2];v[e>>2]=v[e+96>>2];v[e+4>>2]=f;cl(j,1,e);v[g+484404>>2]=8215;f=e+80|0;Ac(f,i);yc(((d<<5)+a|0)+946304|0,f);ub(f);continue}break}d=P()|0;O()|0;break a}j=o+1|0;c=a+484376|0;d=0;p:{q:{while(1){if((d|0)==(j|0)){v[23220]=0;b=Q(1,e+80|0,8587)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break p}d=P()|0;O()|0;break b}b=w[c|0];g=v[a+484360>>2];v[23220]=0;k=d&65535;b=Q(300,Vb(g,b)|0,k|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){r:{s:{if(b){b=Vb(v[a+484360>>2],w[c|0]);break s}v[23220]=0;g=Q(352,i|0,q|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break q}if((g|0)==65535){break r}b=Vb(v[a+484360>>2],w[c|0]);s=ac(v[b>>2],d),z=g,u[s>>1]=z}b=TA(Ab(v[Xb(v[i>>2],x[ac(v[b>>2],d)>>1])+4>>2]),1);g=w[b+5|0];l=w[Hb(v[f>>2],(d+1>>>0)%(n>>>0)|0)|0];if((g|0)==(l|0)){break r}t:{if(w[b+3|0]!=16){break t}g=w[c|0];m=v[a+484360>>2];v[23220]=0;g=Q(353,Vb(m,g)|0,k|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break c}if((g|0)==65535){break t}b=TA(Ab(v[Xb(v[i>>2],g)+4>>2]),1)}t[b+5|0]=l;t[b+3|0]=16}d=d+1|0;continue}break}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}Db(a+1298344|0,b);vb(b);v[23220]=0;b=Q(1,e- -64|0,6010)|0;c=v[23220];v[23220]=0;if((c|0)==1){break f}Db(a+1298356|0,b);vb(b);b=e+16|0;rj(b,2,e+139|0);v[23220]=0;R(209,e+32|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break e}v[23220]=0;U(11,e+48|0,5,e+32|0);b=v[23220];v[23220]=0;if((b|0)==1){break d}b=e+48|0;Db(a+1298368|0,b);vb(b);ub(e+32|0);v[a+1298404>>2]=5;$b(h)}$b(f);d=p^1}fb=e+352|0;return d|0}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;ub(e+32|0);break b}d=P()|0;O()|0}$b(h)}$b(f);S(d|0);L()}function kH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,C=0;i=fb-560|0;fb=i;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;k=g+B(s,-24)|0;o=v[(e<<2)+72848>>2];j=d-1|0;if((o+j|0)>=0){g=d+o|0;c=s-j|0;while(1){A[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+v[(c<<2)+72864>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=k-24|0;g=0;t=(o|0)>0?o:0;h=(d|0)<=0;while(1){a:{if(h){f=0;break a}n=g+j|0;c=0;f=0;while(1){f=A[(c<<3)+a>>3]*A[(i+320|0)+(n-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;c=(g|0)==(t|0);g=g+1|0;if(!c){continue}break}z=47-k|0;u=48-k|0;C=k-25|0;g=o;b:{while(1){f=A[(g<<3)+i>>3];c=0;h=g;l=(g|0)<=0;if(!l){while(1){n=(i+480|0)+(c<<2)|0;m=f*5.960464477539063e-8;c:{if(D(m)<2147483648){j=~~m;break c}j=-2147483648}m=+(j|0);f=m*-16777216+f;d:{if(D(f)<2147483648){j=~~f;break d}j=-2147483648}v[n>>2]=j;h=h-1|0;f=A[(h<<3)+i>>3]+m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=Cj(f,q);f=f+H(f*.125)*-8;e:{if(D(f)<2147483648){n=~~f;break e}n=-2147483648}f=f-+(n|0);f:{g:{h:{w=(q|0)<=0;i:{if(!w){h=(g<<2)+i|0;j=v[h+476>>2];c=j>>u;r=h;h=j-(c<<u)|0;v[r+476>>2]=h;n=c+n|0;j=h>>z;break i}if(q){break h}j=v[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break f}break g}j=2;if(f>=.5){break g}j=0;break f}c=0;h=0;if(!l){while(1){r=(i+480|0)+(c<<2)|0;x=v[r>>2];l=16777215;j:{k:{if(h){break k}l=16777216;if(x){break k}h=0;break j}v[r>>2]=l-x;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(w){break l}c=8388607;m:{switch(C|0){case 1:c=4194303;break;case 0:break m;default:break l}}l=(g<<2)+i|0;v[l+476>>2]=v[l+476>>2]&c}n=n+1|0;if((j|0)!=2){break f}f=1-f;j=2;if(!h){break f}f=f-Cj(1,q)}if(f==0){c=1;l=0;h=g;n:{if((g|0)<=(o|0)){break n}while(1){h=h-1|0;l=v[(i+480|0)+(h<<2)>>2]|l;if((h|0)>(o|0)){continue}break}if(!l){break n}k=q;while(1){k=k-24|0;g=g-1|0;if(!v[(i+480|0)+(g<<2)>>2]){continue}break}break b}while(1){h=c;c=c+1|0;if(!v[(i+480|0)+(o-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;A[(i+320|0)+(j<<3)>>3]=v[(s+g<<2)+72864>>2];c=0;f=0;if((d|0)>0){while(1){f=A[(c<<3)+a>>3]*A[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}break}f=Cj(f,24-k|0);o:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;m=f*5.960464477539063e-8;p:{if(D(m)<2147483648){c=~~m;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(D(f)<2147483648){a=~~f;break q}a=-2147483648}v[d>>2]=a;g=g+1|0;break o}if(D(f)<2147483648){c=~~f}else{c=-2147483648}k=q}v[(i+480|0)+(g<<2)>>2]=c}f=Cj(1,k);if((g|0)>=0){d=g;while(1){a=d;A[(a<<3)+i>>3]=f*+v[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}a=0;h=g;while(1){d=a>>>0<t>>>0?a:t;c=0;f=0;while(1){f=A[(c<<3)+75632>>3]*A[(c+h<<3)+i>>3]+f;k=(c|0)!=(d|0);c=c+1|0;if(k){continue}break}A[(i+160|0)+(g-h<<3)>>3]=f;h=h-1|0;c=(a|0)!=(g|0);a=a+1|0;if(c){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<=0){break u}d=(i+160|0)+(g<<3)|0;f=A[d>>3];c=g;while(1){m=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;y=A[h>>3];f=y+f;A[e+(c<<3)>>3]=m+(y-f);A[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=A[d>>3];c=g;while(1){m=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=A[e>>3];f=p+f;A[d+(c<<3)>>3]=m+(p-f);A[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+A[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[i+160>>3];if(j){break s}A[b>>3]=f;f=A[i+168>>3];A[b+16>>3]=p;A[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+A[(i+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+A[(i+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;f=A[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+A[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break r}A[b>>3]=-f;f=A[i+168>>3];A[b+16>>3]=-p;A[b+8>>3]=-f}fb=i+560|0;return n&7}function _Z(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;h=fb+-64|0;fb=h;v[h+56>>2]=b;v[e>>2]=0;Xc(h,d);v[23220]=0;b=T(1104,h|0)|0;i=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((i|0)!=1){Wb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Wb(h);S(a|0);L()}IF(a,f+24|0,h+56|0,c,e,b);break b}HF(a,f+16|0,h+56|0,c,e,b);break b}b=jb[v[v[a+8>>2]+12>>2]](a+8|0)|0;g=a;i=v[h+56>>2];a=pc(b);j=h,k=Fj(g,i,c,d,e,f,a,a+(Bb(b)<<2)|0),v[j+56>>2]=k;break b}a=Mi(h+56|0,c,e,b,2);b=v[e>>2];B:{if(!(b&4|a-1>>>0>30)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}b=v[20727];v[h+24>>2]=v[20726];v[h+28>>2]=b;b=v[20725];v[h+16>>2]=v[20724];v[h+20>>2]=b;b=v[20723];v[h+8>>2]=v[20722];v[h+12>>2]=b;b=v[20721];v[h>>2]=v[20720];v[h+4>>2]=b;j=h,k=Fj(a,v[h+56>>2],c,d,e,f,h,h+32|0),v[j+56>>2]=k;break b}b=v[20735];v[h+24>>2]=v[20734];v[h+28>>2]=b;b=v[20733];v[h+16>>2]=v[20732];v[h+20>>2]=b;b=v[20731];v[h+8>>2]=v[20730];v[h+12>>2]=b;b=v[20729];v[h>>2]=v[20728];v[h+4>>2]=b;j=h,k=Fj(a,v[h+56>>2],c,d,e,f,h,h+32|0),v[j+56>>2]=k;break b}a=Mi(h+56|0,c,e,b,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=Mi(h+56|0,c,e,b,2);b=v[e>>2];D:{if(!(b&4|a-1>>>0>11)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=Mi(h+56|0,c,e,b,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=Mi(h+56|0,c,e,b,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=Mi(h+56|0,c,e,b,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+56|0;d=fb-16|0;fb=d;v[d+8>>2]=c;while(1){H:{if(!Ir(a,d+8|0)){break H}if(!yk(b,8192,zk(v[a>>2]))){break H}bn(a);continue}break}if(xk(a,d+8|0)){v[e>>2]=v[e>>2]|2}fb=d+16|0;break b}d=h+56|0;a=jb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Bb(a)|0)==(0-Bb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}c=tr(d,c,a,a+24|0,b,e,0);b=v[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}b=nc(h,82944,44);j=b,k=Fj(a,v[b+56>>2],c,d,e,f,b,b+44|0),v[j+56>>2]=k;break b}v[h+16>>2]=v[20752];b=v[20751];v[h+8>>2]=v[20750];v[h+12>>2]=b;b=v[20749];v[h>>2]=v[20748];v[h+4>>2]=b;j=h,k=Fj(a,v[h+56>>2],c,d,e,f,h,h+20|0),v[j+56>>2]=k;break b}a=Mi(h+56|0,c,e,b,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}b=v[20763];v[h+24>>2]=v[20762];v[h+28>>2]=b;b=v[20761];v[h+16>>2]=v[20760];v[h+20>>2]=b;b=v[20759];v[h+8>>2]=v[20758];v[h+12>>2]=b;b=v[20757];v[h>>2]=v[20756];v[h+4>>2]=b;j=h,k=Fj(a,v[h+56>>2],c,d,e,f,h,h+32|0),v[j+56>>2]=k;break b}a=Mi(h+56|0,c,e,b,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=jb[v[v[a>>2]+20>>2]](a,v[h+56>>2],c,d,e,f)|0;break a}b=jb[v[v[a+8>>2]+24>>2]](a+8|0)|0;g=a;i=v[h+56>>2];a=pc(b);j=h,k=Fj(g,i,c,d,e,f,a,a+(Bb(b)<<2)|0),v[j+56>>2]=k;break b}GF(f+20|0,h+56|0,c,e,b);break b}a=Mi(h+56|0,c,e,b,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=fb-16|0;fb=a;v[a+8>>2]=c;c=6;d=h+56|0;L:{M:{if(xk(d,a+8|0)){break M}c=4;if((Tm(b,zk(v[d>>2]))|0)!=37){break M}c=2;if(!xk(bn(d),a+8|0)){break L}}v[e>>2]=v[e>>2]|c}fb=a+16|0}a=v[h+56>>2]}fb=h- -64|0;return a|0}function oI(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0;g=fb-48|0;fb=g;a:{b:{if(Xr(c)){j=v[b+484344>>2];if(ke(j,v[b+484348>>2],c&65535)){break b}}c=a;a=Gb(g+32|0);b=Gb(g+16|0);di(c,a,b);ub(b);ub(a);break a}c=Xb(j,c);if(!(v[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Gb(g+32|0);b=Gb(g+16|0);di(c,a,b);ub(b);ub(a);break a}if(!(x[b+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Gb(g+32|0);b=Gb(g+16|0);di(c,a,b);ub(b);ub(a);break a}if(f>>>0>=6){c=a;a=Gb(g+32|0);b=Gb(g+16|0);di(c,a,b);ub(b);ub(a);break a}c=$c(v[c>>2],v[v[c+48>>2]+12>>2],d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{d=w[c|0];if(!Oc(d)){if(!pp(d)){break k}}e=g+16|0;ML(e,b,d,w[c+1|0]);v[23220]=0;R(981,g+32|0,e|0);b=v[23220];v[23220]=0;d=1;if((b|0)!=1){break j}c=P()|0;O()|0;break g}d=0;v[23220]=0;Q(52,g+32|0,16709)|0;b=v[23220];v[23220]=0;if((b|0)==1){break i}}b=9929;c=w[c|0];if(!Oc(c)){b=pp(c)?10239:16709}v[23220]=0;b=Q(52,g|0,b|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break h}c=a;a=g+32|0;di(c,a,b);ub(b);ub(a);if(!d){break a}vb(g+16|0);break a}c=P()|0;O()|0;break d}c=P()|0;O()|0;ub(g+32|0);if(!d){break d}}vb(g+16|0);break d;case 1:b=c+1|0;l:{if(w[c+1|0]){Dt(g+32|0,b);break l}Qb(g+32|0,16714)}b=w[b|0];v[23220]=0;b=Q(52,g+16|0,(b?10729:16714)|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break e}c=a;a=g+32|0;di(c,a,b);ub(b);ub(a);break a;case 2:m:{if(Mg(w[c|0])){Qb(g+32|0,17769);break m}d=w[c+2|0];if(d){Ge(g+32|0,1,mL(v[v[b+8>>2]+88>>2],d));break m}Qb(g+32|0,17769)}b=17769;if(!Mg(w[c|0])){b=w[c+2|0]?5466:17769}v[23220]=0;b=Q(52,g+16|0,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){c=a;a=g+32|0;di(c,a,b);ub(b);ub(a);break a}c=P()|0;O()|0;ub(g+32|0);break d;case 4:n:{if(Mg(w[c|0])){k=g,l=Rj(w[c+2|0],w[c+4|0])&255,v[k>>2]=l;kA(g+32|0,g);break n}if(w[c+2|0]){Dt(g+32|0,c+4|0);break n}Qb(g+32|0,16714)}b=5450;if(!Mg(w[c|0])){b=w[c+2|0]?5450:16714}v[23220]=0;b=Q(52,g+16|0,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){c=a;a=g+32|0;di(c,a,b);ub(b);ub(a);break a}c=P()|0;O()|0;ub(g+32|0);break d;case 3:o:{if(Mg(w[c|0])){k=g,l=(Rj(w[c+3|0],w[c+5|0])&3840)!=0,t[k|0]=l;d=fb-32|0;fb=d;t[d+24|0]=44;v[d+16>>2]=-1;v[d+20>>2]=0;v[d+8>>2]=1058;v[d+12>>2]=1;j=g+32|0;b=fb+-64|0;fb=b;h=v[d+8>>2]&2?16:10;f=fb-32|0;fb=f;e=Ge(f+16|0,1,0);p:{q:{r:{while(1){i=pc(e);lx(f+8|0,i,Bb(e)+i|0,w[g|0],h);if(!v[f+12>>2]){break r}i=Ff(Bb(e));v[23220]=0;R(56,e|0,i|0);i=v[23220];v[23220]=0;if((i|0)!=1){continue}break}break q}h=v[f+8>>2];i=pc(e);v[23220]=0;R(57,e|0,h-i|0);h=v[23220];v[23220]=0;s:{if((h|0)!=1){v[23220]=0;R(58,b|0,e|0);h=v[23220];v[23220]=0;if((h|0)!=1){break s}break q}break q}ub(e);fb=f+32|0;break p}a=P()|0;O()|0;ub(e);S(a|0);L()}e=b+16|0;is(e,b,v[d+8>>2]);f=v[d+12>>2];h=v[d+8>>2];v[23220]=0;X(71,b+32|0,e|0,h|0,f|0);e=v[23220];v[23220]=0;t:{u:{v:{w:{x:{if((e|0)!=1){e=w[d+24|0];f=v[d+20>>2];v[23220]=0;X(72,b+48|0,b+32|0,f|0,e|0);e=v[23220];v[23220]=0;if((e|0)==1){break x}v[23220]=0;R(55,j|0,b+48|0);e=v[23220];v[23220]=0;if((e|0)==1){break w}ub(b+48|0);ub(b+32|0);ub(b+16|0);ub(b);fb=b- -64|0;break t}a=P()|0;O()|0;break u}a=P()|0;O()|0;break v}a=P()|0;O()|0;ub(b+48|0)}ub(b+32|0)}ub(b+16|0);ub(b);S(a|0);L()}fb=d+32|0;break o}d=w[c+3|0];if(d){Ge(g+32|0,1,lL(v[v[b+8>>2]+84>>2],d));break o}Qb(g+32|0,16715)}b=12281;if(!Mg(w[c|0])){b=w[c+3|0]?12281:16715}v[23220]=0;b=Q(52,g+16|0,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){c=a;a=g+32|0;di(c,a,b);ub(b);ub(a);break a}c=P()|0;O()|0;ub(g+32|0);break d;case 5:break f;default:break c}}y:{if(Mg(w[c|0])){k=g,l=Rj(w[c+3|0],w[c+5|0])&255,v[k>>2]=l;kA(g+32|0,g);break y}if(w[c+3|0]){Dt(g+32|0,c+5|0);break y}Qb(g+32|0,16714)}b=11073;if(!Mg(w[c|0])){b=w[c+3|0]?11073:16714}v[23220]=0;b=Q(52,g+16|0,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){c=a;a=g+32|0;di(c,a,b);ub(b);ub(a);break a}c=P()|0;O()|0;ub(g+32|0);break d}c=P()|0;O()|0;ub(g+32|0)}S(c|0);L()}c=a;a=Gb(g+32|0);b=Gb(g+16|0);di(c,a,b);ub(b);ub(a)}fb=g+48|0}function ML(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;k=fb-16|0;fb=k;a:{b:{c:{if(!Oc(c)|!d|v[b+480180>>2]!=16777216|x[b+480192>>1]<d>>>0){break c}d=v[((d<<2)+b|0)+900380>>2];if(!d){break c}e=v[d+44>>2];if(!e){break c}u[k+14>>1]=c-61;c=fb+-64|0;fb=c;d:{e:{d=u[e+28>>1];h=k+14|0;b=u[h>>1];if((d|0)<=(b|0)){if((b|0)<=(sc(v[e+4>>2],v[e+8>>2])+d<<16)-65536>>16){break e}}Gb(a);break d}f:{d=x[e+30>>1];if(!d){b=e+52|0;d=Lx(b,h);if(!vg(d,wf(b))){break f}Km(a,pd(d)+4|0);break d}b=xn(b,d<<16>>16);u[c+62>>1]=b;d=Gb(a);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{a=e+52|0;f=Lx(a,c+62|0);t:{if(vg(f,wf(a))){v[23220]=0;R(122,d|0,pd(f)+4|0);a=v[23220];v[23220]=0;if((a|0)==1){break t}a=u[e+30>>1];b=u[h>>1];v[23220]=0;l=c,m=Kx(b,a)+5|0,v[l+32>>2]=m;R(119,c+48|0,c+32|0);a=v[23220];v[23220]=0;u:{if((a|0)!=1){v[23220]=0;Q(85,d|0,c+48|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break u}vb(c+48|0);break d}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(c+48|0);break g}if(u[e+30>>1]>26){break q}v[23220]=0;b=W(485,c+32|0,1,(b<<24)+1090519040>>24)|0;a=v[23220];v[23220]=0;if((a|0)==1){break s}v[23220]=0;U(11,c+48|0,0,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break r}a=c+48|0;f=Db(d,a);vb(a);ub(b);v[23220]=0;Q(120,f|0,14621)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break p}}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;ub(b);break g}v[23220]=0;a=b<<16>>16;v[c+28>>2]=(a|0)%16;R(812,c+32|0,c+28|0);f=v[23220];v[23220]=0;if((f|0)==1){break o}v[23220]=0;v[c+12>>2]=((a|0)/16<<16>>16)%16;R(812,c+16|0,c+12|0);a=v[23220];v[23220]=0;if((a|0)==1){break n}v[23220]=0;U(2,c+48|0,c+32|0,c+16|0);a=v[23220];v[23220]=0;if((a|0)==1){break m}a=c+48|0;f=Db(d,a);vb(a);vb(c+16|0);vb(c+32|0);if(b<<16>>16<256){break p}v[23220]=0;U(8,c|0,0,f|0);a=v[23220];v[23220]=0;if((a|0)==1){break k}b=c+32|0;g=Td(c);j=ih(c);i=Td(c);a=fb-32|0;fb=a;v[a+16>>2]=j;v[a+24>>2]=g;v[a+8>>2]=i;while(1){if(Kh(a+24|0,a+16|0)){g=a+24|0;j=sp(t[v[g>>2]]);i=a+8|0;t[v[i>>2]]=j;xe(g);xe(i);continue}break}fb=a+32|0;Mc(b,c);v[23220]=0;U(11,c+48|0,0,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break j}a=c+48|0;Db(f,a);vb(a);ub(c+32|0);ub(c)}a=u[e+30>>1];b=u[h>>1];v[23220]=0;l=c,m=Kx(b,a)+5|0,v[l+16>>2]=m;R(119,c+48|0,c+16|0);a=v[23220];v[23220]=0;if((a|0)==1){break i}v[23220]=0;Q(85,d|0,c+48|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break h}vb(c+48|0);break d}a=P()|0;O()|0;break g}a=P()|0;O()|0;break l}a=P()|0;O()|0;vb(c+16|0)}vb(c+32|0);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;ub(c+32|0);ub(c);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(c+48|0)}break a}d=fb-16|0;fb=d;f=fb-32|0;fb=f;e=Ge(f+16|0,1,0);v:{w:{x:{while(1){j=f+8|0;b=pc(e);i=Bb(e)+b|0;g=u[h>>1];if(!((b|0)==(i|0)|(g|0)>=0)){t[b|0]=45;g=0-(g&65535)&65535;b=b+1|0}ox(j,b,i,g&65535);if(!v[f+12>>2]){break x}b=Ff(Bb(e));v[23220]=0;R(56,e|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){continue}break}break w}b=v[f+8>>2];h=pc(e);v[23220]=0;R(57,e|0,b-h|0);b=v[23220];v[23220]=0;y:{if((b|0)!=1){v[23220]=0;R(69,d|0,e|0);b=v[23220];v[23220]=0;if((b|0)!=1){break y}break w}break w}ub(e);fb=f+32|0;break v}a=P()|0;O()|0;ub(e);S(a|0);L()}v[23220]=0;R(68,a|0,d|0);a=v[23220];v[23220]=0;z:{if((a|0)!=1){vb(d);fb=d+16|0;break z}a=P()|0;O()|0;break a}}fb=c- -64|0;break b}e=v[b>>2];b=fb-32|0;fb=b;A:{if(pp(c)){v[b+16>>2]=v[8024];d=v[8023];v[b+8>>2]=v[8022];v[b+12>>2]=d;d=v[8021];v[b>>2]=v[8020];v[b+4>>2]=d;Qb(a,(b+(c<<2)|0)-1004|0);break A}if(Oc(c)){d=Gb(b);v[23220]=0;c=c-1|0;f=(c|0)/12|0;c=Q(813,d|0,e+(B(f,-12)+c<<16>>16<<2)|0)|0;e=v[23220];v[23220]=0;B:{if((e|0)==1){break B}v[23220]=0;c=Q(814,c|0,(f<<24)+805306368>>24)|0;e=v[23220];v[23220]=0;if((e|0)==1){break B}v[23220]=0;Q(3,a|0,c|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break B}vb(c);break A}a=P()|0;O()|0;break a}if(!c){Qb(a,16709);break A}Qb(a,14592)}fb=b+32|0}fb=k+16|0;return}vb(d);S(a|0);L()}function c8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=0;d=fb-128|0;fb=d;g=-1;a:{b:{c:{d:{if(!Ch(v[v[b>>2]-12>>2]+b|0)){break d}e=d+112|0;Yd(e,b);f=v[e+8>>2];j=v[e+12>>2];e=d+104|0;ol(e);b=Bk(b,e,8);e:{f:{g:{h:{i:{j:{k:{if(Mb(e,16685,8)){a=ch(d+88|0,f,j);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;Ej(b,d+8|0);break k}u[d+86>>1]=0;If(b,d+86|0);j=x[d+86>>1];if((j&65534)!=2){break d}f=d+78|0;ol(f);e=Bk(b,f,8);if(Mb(f,14272,8)){break d}u[d+76>>1]=0;If(e,d+76|0);f=u[d+76>>1];if((f-5&65535)>>>0<65534){break d}l:{if(f>>>0<=3){b=Gb(d+112|0);v[23220]=0;h=W(438,e|0,b|0,65535)|0;l=v[23220];v[23220]=0;if((l|0)==1){break b}if(!h){break i}v[23220]=0;U(11,d- -64|0,c|0,b|0);h=v[23220];v[23220]=0;if((h|0)!=1){break l}break b}b=Gb(d+112|0);v[23220]=0;h=Q(440,e|0,b|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break c}if(!h){break h}v[23220]=0;U(11,d- -64|0,c|0,b|0);h=v[23220];v[23220]=0;if((h|0)==1){break c}}h=d- -64|0;Db(a+40|0,h);vb(h);ub(b);u[d+62>>1]=0;If(e,d+62|0);u[d+60>>1]=0;If(e,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;m:{if((f|0)<=3){v[d+112>>2]=0;_j(e,d+112|0);b=v[d+112>>2];if(b>>>0>65535){break d}b=fu(b);u[d+58>>1]=b;break m}If(e,d+58|0);b=x[d+58>>1]}h=a+52|0;l=b&65535;n=(f|0)>3;f=0;n:{o:{while(1){if(l>>>0<=(f&65535)>>>0){break n}b=Gb(d+112|0);v[23220]=0;u[d+40>>1]=0;R(863,e|0,d+40|0);i=v[23220];v[23220]=0;if((i|0)==1){break g}p:{if(!n){v[23220]=0;i=W(438,e|0,b|0,65535)|0;k=v[23220];v[23220]=0;if((k|0)==1){break g}if(i){break p}break e}v[23220]=0;i=Q(440,e|0,b|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break g}if(!i){break e}}v[23220]=0;U(11,d- -64|0,c|0,b|0);i=v[23220];v[23220]=0;if((i|0)!=1){v[23220]=0;i=Q(860,h|0,d+40|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break o}k=i;i=d- -64|0;Db(k,i);vb(i);ub(b);f=f+1|0;continue}break}g=P()|0;O()|0;break f}g=P()|0;O()|0;vb(d- -64|0);break f}c=d- -64|0;ol(c);b=Bk(e,c,8);if(Mb(c,14216,8)){break d}c=x[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;f=j<<16>>16;q:{if((f|0)<=2){if(SK(b,c)){break q}break d}if(!RK(b,c)){break d}}o=d,p=Ab(v[c>>2]),v[o+112>>2]=p;e=Ab(v[c+4>>2]);while(1){j=v[d+112>>2];if(Nb(j,e)){if(!Il(z[j>>2])){break d}ye(d+112|0);continue}break}e=a+16|0;r:{if((f|0)<=2){if(SK(b,e)){break r}break d}if(!RK(b,e)){break d}}o=d,p=Ab(v[e>>2]),v[o+112>>2]=p;e=Ab(v[e+4>>2]);while(1){f=v[d+112>>2];if(Nb(f,e)){if(!Il(z[f>>2])){break d}ye(d+112|0);continue}break}o=a,p=sc(v[a+16>>2],v[a+20>>2]),v[o+36>>2]=p;u[d+56>>1]=0;If(b,d+56|0);e=x[d+56>>1];u[a+28>>1]=e;if((e-201&65535)>>>0<65135){break d}u[d+54>>1]=0;If(b,d+54|0);g=u[d+54>>1];u[a+30>>1]=g;if((g|0)>=0){break j}}g=-1;break d}v[d+48>>2]=0;jp(b,d+48|0);m=UK(z[d+48>>2]);z[a+32>>2]=m;g=-1;if(!Il(m)){break d}e=d+40|0;ol(e);Bk(b,e,8);if(Mb(e,16676,8)){break d}b=sc(v[c>>2],v[c+4>>2]);if(b>>>0>32767){break d}c=u[a+30>>1];e=x[a>>1];if(!(e?!(z[a+32>>2]<=C(0))&(c|0)>0:1)){break d}s:{switch(e-1|0){case 0:case 2:if(b>>>0<c>>>0){break d}break;default:break s}}b=0;c=v[a+36>>2];if(c){b=c-1|0;v[a+36>>2]=b}o=d,p=ui(b),v[o+112>>2]=p;v[d+32>>2]=0;o=a,p=v[uj(d+112|0,d+32|0,43984)>>2],v[o+36>>2]=p;kp(a);g=1;if(x[a>>1]!=3){break d}c=u[a+30>>1];if((c-u[a+28>>1]|0)>($K(sc(v[a+4>>2],v[a+8>>2]))|0)){break d}g=a+32|0;e=Ib(d+112|0);b=0;while(1){t:{if(c<<16>>16<=(b|0)){b=x[a+28>>1];u[d+32>>1]=b;o=d,p=(sc(v[a+4>>2],v[a+8>>2])+b|0)-1|0,u[o+34>>1]=p;v[23220]=0;u[d+30>>1]=0;ga(858,a|0,e|0,g|0,d+32|0,d+30|0)|0;a=v[23220];v[23220]=0;g=1;if((a|0)==1){break t}lc(e);break d}c=u[a+28>>1];f=v[a+4>>2];v[23220]=0;R(864,e|0,zb(f,b-c|0)|0);c=v[23220];v[23220]=0;if((c|0)!=1){b=b+1|0;c=x[a+30>>1];continue}}break}g=P()|0;O()|0;lc(e);break a}ub(b);break d}ub(b);break d}g=P()|0;O()|0}ub(b);break a}ub(b)}fb=d+128|0;return g|0}g=P()|0;O()|0;ub(b);break a}g=P()|0;O()|0;ub(b)}S(g|0);L()}function Tda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;e=fb-752|0;fb=e;wc(b);d=fb-16|0;fb=d;g=e+144|0;tQ(d+8|0,g);f=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],f);i=v[d+4>>2];if((i|0)==(f|0)){Yb(b,v[d+12>>2])}fb=d+16|0;d=(f|0)==(i|0);if(!d){sQ(g)}a:{if(!d){break a}if(!vQ(e+144|0)){break a}if(!Lb(v[b>>2],v[b+8>>2],Pc(uQ(x[e+178>>1]),ib))){break a}if(!c){p=1;break a}zd(a,262144);f=e+104|0;$k(f,2,e+144|0);d=e+24|0;Ac(d,f);xc(a+1298308|0,d);ub(d);g=Qb(d,8304);Db(a+1298344|0,g);vb(g);d=Qb(d,10086);Db(a+1298356|0,d);vb(d);d=fb-16|0;fb=d;h=f;f=Qb(d,4154);Mc(h,f);vb(f);fb=d+16|0;t[e+8|0]=w[e+174|0];v[23220]=0;t[e+127|0]=w[e+173|0];R(627,e+128|0,e+127|0);d=v[23220];v[23220]=0;b:{c:{d:{if((d|0)!=1){v[23220]=0;X(240,e+24|0,e+104|0,e+8|0,e+128|0);d=v[23220];v[23220]=0;if((d|0)!=1){d=e+24|0;Db(a+1298368|0,d);vb(d);vb(e+128|0);f=e+104|0;bc(f);v[a+480208>>2]=12;v[a+1298404>>2]=5;u[a+480188>>1]=x[e+182>>1];u[e+24>>1]=x[e+178>>1];u[e+104>>1]=3999;C=a,D=x[Tc(d,f)>>1],u[C+480190>>1]=D;mT(Vb(v[a+484360>>2],w[a+484376|0]),e+240|0,x[e+176>>1]);d=0;while(1)if(x[a+480188>>1]<=d>>>0){d=e+24|0;Qd(d,b,B(x[e+178>>1],80));g=c&2;l=gc(e+104|0,d);wb(d);i=e+72|0;d=0;e:{f:{while(1){if(x[a+480190>>1]<=d>>>0){p=1;if(c&1){break f}break b}v[23220]=0;R(628,l|0,e+24|0);f=v[23220];v[23220]=0;if((f|0)==1){break e}f=e+8|0;$k(f,2,i);v[23220]=0;R(209,e+128|0,f|0);f=v[23220];v[23220]=0;if((f|0)==1){break e}d=d+1|0;f=e+128|0;yc(((d<<5)+a|0)+946304|0,f);ub(f);v[23220]=0;h=f;f=(B(d,104)+a|0)+484380|0;U(629,h|0,e+24|0,f|0);h=v[23220];v[23220]=0;g:{if((h|0)==1){break g}if(!g|!v[f>>2]){continue}v[23220]=0;h=Q(142,b|0,x[e+42>>1]|x[e+44>>1]<<16)|0;j=v[23220];v[23220]=0;if((j|0)==1){break g}if(!h){continue}v[23220]=0;W(206,e+128|0,f|0,b|0)|0;f=v[23220];v[23220]=0;if((f|0)!=1){continue}}break}break e}v[23220]=0;m=a+484344|0;R(212,m|0,x[e+180>>1]);c=v[23220];v[23220]=0;if((c|0)==1){break e}c=e+24|0;q=c|4;r=c|2;s=c|5;y=c|3;z=c|1;A=a+480188|0;f=0;while(1){if(x[e+180>>1]<=f>>>0){break b}v[23220]=0;c=W(213,m|0,f&65535,64)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}h:{if(!c){break h}c=(f<<1)+e|0;c=w[c+496|0]|w[c+497|0]<<8;if(!c){break h}v[23220]=0;c=Q(142,b|0,c<<4)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}if(!c){break h}c=0;d=Xb(v[m>>2],f);n=$c(v[d>>2],v[v[d+48>>2]+12>>2],0,0);while(1){if(c>>>0>63){break h}d=v[b+8>>2];g=v[b>>2];v[23220]=0;d=W(143,g|0,d|0,1)|0;g=v[23220];v[23220]=0;i:{if((g|0)!=1){if(!d){break h}v[23220]=0;g=T(193,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}if(g){break i}c=c+1|0;n=B(x[a+480188>>1],6)+n|0;continue}break e}u[e+28>>1]=0;v[e+24>>2]=0;d=g&31;i=B(d,6)+n|0;j=Rh(e+24|0);h=d>>>0<x[A>>1];o=h?i:j;j:{if(!(g&32)){break j}v[23220]=0;R(250,e+128|0,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break e}d=w[e+128|0];t[o|0]=d;C=h?i+1|0:z,D=w[gd(e+128|0)|0],t[C|0]=D;k:{if(d){if((d|0)==254){break k}if(d>>>0<121){break j}}d=0}t[o|0]=d}l:{if(!(g&64)){break l}v[23220]=0;R(250,e+128|0,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break e}j=h?i+3|0:y;d=w[e+128|0];t[j|0]=d;k=h?i+5|0:s;C=k,D=w[gd(e+128|0)|0],t[C|0]=D;m:{if(d>>>0>=16){if(d>>>0<=23){d=w[d+26999|0];t[j|0]=d;break m}t[j|0]=0;break l}Mf(o);d=w[j|0]}if((d|0)!=23){if((d|0)!=9){break l}t[j|0]=20;t[e+8|0]=w[k|0]>>>3;t[e+127|0]=1;C=k,D=w[$e(e+8|0,e+127|0)|0]-1&15|128,t[C|0]=D;break l}t[e+8|0]=64;C=k,D=w[Rb(k,e+8|0)|0]<<1,t[C|0]=D}if(!(g&128)){continue}t[(h?i+2|0:r)|0]=1;v[23220]=0;d=T(193,b|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break e}t[(h?i+4|0:q)|0]=d;continue}}f=f+1|0;continue}}d=P()|0;O()|0;wb(l);break c}else{f=(d<<5)+a|0;Pe(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+208|0]<<4|4)&244;d=d+1|0;continue}}d=P()|0;O()|0;vb(e+128|0);break d}d=P()|0;O()|0}bc(e+104|0)}S(d|0);L()}wb(l)}fb=e+752|0;return p|0}function Sea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-224|0;fb=d;wc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!go(b,d+208|0)){break l}if(!gR(d+208|0)){break l}g=xh(d+184|0);h=Gb(d+168|0);$t(d+104|0);v[23220]=0;f=Q(557,b|0,d+96|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break h}m:{if(!f){break m}f=_b(_b(v[d+100>>2])-4|0);while(1){f=_b(_b(f)-8|0);v[d+100>>2]=f;n:{if(c){break n}if((_b(v[d+96>>2])|0)!=1347699796){break n}j=1;break m}v[23220]=0;U(177,d+72|0,b|0,_b(f)|0);f=v[23220];v[23220]=0;if((f|0)==1){break d}e=d+72|0;f=gc(d+8|0,e);wb(e);e=v[f>>2];v[23220]=0;i=T(165,e|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break b}o:{if(!i){break o}p:{e=_b(v[d+96>>2]);if((e|0)!=1129139796){if((e|0)!=1229866575){if((e|0)==1347699796){break p}if((e|0)!=1447383635){break o}v[23220]=0;Q(175,f|0,4)|0;e=v[23220];v[23220]=0;if((e|0)==1){break b}v[23220]=0;e=T(558,f|0)|0;k=v[23220];v[23220]=0;if((k|0)==1){break b}if(!e){break o}e=_b(v[d+100>>2]);if(e>>>0<7){break o}v[23220]=0;U(559,f|0,h|0,e-6|0);e=v[23220];v[23220]=0;if((e|0)==1){break b}break o}v[23220]=0;l=Q(560,f|0,d+104|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){break o}break b}$u(g,f);break o}v[23220]=0;j=W(561,a|0,f|0,c|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break b}}wb(f);q:{if(!i){break q}v[23220]=0;f=Q(557,b|0,d+96|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break i}if(!f){break q}f=v[d+100>>2];continue}break}if(ah(v[h+4>>2],w[h+11|0])){v[23220]=0;b=Q(1,d+72|0,14856)|0;c=v[23220];v[23220]=0;if((c|0)==1){break g}Db(h,b);vb(b)}r:{if(!(j&l&1)){break r}b=x[d+146>>1];v[23220]=0;b=Jb(b)&256;W(254,a+1074312|0,5,!b|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break f}c=Jb(x[d+142>>1]);if(c){u[d+8>>1]=64;u[d+56>>1]=c;m=a,n=x[Tc(d+8|0,d+56|0)>>1],v[m+480228>>2]=n}c=!b;b=Jb(x[d+144>>1]);if(!(c|!b)){v[a+480204>>2]=B(b,1e4)}if(w[d+104|0]){b=d+56|0;Ue(b,2,d+104|0);v[23220]=0;R(209,d+8|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break e}b=d+8|0;xc(a+1298308|0,b);ub(b)}c=x[d+150>>1];if(!Mp(c,1,12)){break r}f=x[d+148>>1];if(!Mp(f,1,31)){break r}e=x[d+154>>1];if(!Mp(e,0,23)){break r}i=x[d+156>>1];if(!Mp(i,0,59)){break r}k=x[d+158>>1];if(!Mp(k,0,59)){break r}b=jq(d+8|0);m=b,n=Jb(x[d+152>>1]),v[m+20>>2]=n;m=b,n=Jb(c)-1|0,v[m+16>>2]=n;m=b,n=Jb(f),v[m+12>>2]=n;m=b,n=Jb(e),v[m+8>>2]=n;m=b,n=Jb(i),v[m+4>>2]=n;m=b,n=Jb(k),v[m>>2]=n;v[23220]=0;R(388,a+1298408|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break r}a=P()|0;O()|0;break a}if(j&1){b=v[g>>2];v[23220]=0;b=T(165,b|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break h}if(b){b=Gb(d+8|0);v[23220]=0;U(258,g|0,b|0,32);c=v[23220];v[23220]=0;if((c|0)==1){break c}if(_p(b,13712)){v[23220]=0;U(11,d+56|0,13,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break c}c=d+56|0;Db(a+1298320|0,c);vb(c)}c=v[g+8>>2];f=v[g>>2];v[23220]=0;c=Q(562,f|0,c|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break c}if(!c){v[23220]=0;c=T(189,g|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break c}v[23220]=0;da(302,a+1298332|0,g|0,c|0,40,0);c=v[23220];v[23220]=0;if((c|0)==1){break c}}ub(b)}v[23220]=0;b=Q(1,d+56|0,17472)|0;c=v[23220];v[23220]=0;if((c|0)==1){break k}v[23220]=0;U(432,d+8|0,b|0,h|0);c=v[23220];v[23220]=0;if((c|0)==1){break j}c=d+8|0;Db(a+1298368|0,c);vb(c);vb(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[23220]=0;a=W(254,a+1074312|0,84,1)|0;b=v[23220];v[23220]=0;if((b|0)==1){break h}v[23220]=0;a=W(254,a|0,83,1)|0;b=v[23220];v[23220]=0;if((b|0)==1){break h}v[23220]=0;Q(255,a|0,85)|0;a=v[23220];v[23220]=0;if((a|0)==1){break h}}vb(h);wb(g)}fb=d+224|0;return j&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;ub(b);break a}a=P()|0;O()|0;wb(f)}vb(h);wb(g);S(a|0);L()}function Aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=fb-256|0;fb=e;wc(b);a:{if(!aU(b,e+184|0)){break a}if(!XQ(e+184|0)){break a}if(!Lb(v[b>>2],v[b+8>>2],Pc(WQ(e+184|0),ib))){break a}b:{if(!c){break b}zd(a,16);f=e+24|0;rj(f,2,e+184|4);d=e+48|0;Ac(d,f);xc(a+1298308|0,d);ub(d);u[a+480190>>1]=w[e+214|0];u[a+480188>>1]=w[e+217|0];g=Qb(d,8352);Db(a+1298344|0,g);vb(g);g=Qb(d,10090);Db(a+1298356|0,g);vb(g);og(f,4172);g=w[e+187|0];v[e>>2]=g>>>4;v[23220]=0;v[e+180>>2]=g&15;X(291,d|0,f|0,e|0,e+180|0);d=v[23220];v[23220]=0;c:{d:{e:{if((d|0)!=1){d=e+48|0;Db(a+1298368|0,d);vb(d);bc(e+24|0);v[a+1298404>>2]=5;l=a+480190|0;g=1;while(1){j=g&65535;if(j>>>0>x[l>>1]){g=0;d=a+480188|0;while(1)if(x[d>>1]<=g>>>0){f=e+48|0;d=fb-16|0;fb=d;h=b;f:{if(!Lb(v[b>>2],v[b+8>>2],128)){b=0;while(1){if((b|0)!=128){rg(b+f|0);b=b+1|0;continue}break}break f}sS(d+8|0,f);md(d,h,v[d+8>>2],v[d+12>>2])}fb=d+16|0;Mu(Vb(v[a+484360>>2],w[a+484376|0]),f,w[e+211|0]+1|0);b=w[e+216|0];Qd(e,h,B(x[e+208>>1],192));i=gc(e+24|0,e);wb(e);n=c&1;if(n){v[23220]=0;R(212,a+484344|0,w[e+210|0]+1|0);d=v[23220];v[23220]=0;if((d|0)==1){break d}}o=b?b:64;p=a+484344|0;q=a+480188|0;while(1){if(w[e+210|0]<m>>>0){b=x[e+212>>1];if(b){v[23220]=0;da(302,a+1298332|0,h|0,b|0,39,1);b=v[23220];v[23220]=0;if((b|0)==1){break d}}if(!(c&2)){break e}g=1;b=a+480190|0;while(1){c=g&65535;if(c>>>0>x[b>>1]){break e}c=B(c,104)+a|0;d=Uc(e,u[c+484414>>1]&1?16:8,1,0,1);v[23220]=0;W(206,d|0,c+484380|0,h|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){g=g+1|0;continue}break}break d}g:{h:{if(n){v[23220]=0;b=W(213,p|0,m&65535,o|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break d}k=0;if(b){break h}}v[23220]=0;Q(175,h|0,64)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break g}break d}while(1){d=k&65535;if(d>>>0>31){break g}v[23220]=0;b=T(181,h|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break d}i:{if(!b|b>>>0>x[e+208>>1]|d>>>0>=x[q>>1]){break i}v[23220]=0;Q(142,i|0,B(b,192)-192|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break d}l=0;b=Xb(v[p>>2],m);g=$c(v[b>>2],v[v[b+48>>2]+12>>2],0,d);while(1){if((l|0)==(o|0)){break i}v[23220]=0;R(492,e|0,i|0);b=v[23220];v[23220]=0;if((b|0)!=1){j=gd(e);d=Qe(e);b=w[e|0];if(b>>>0>=4){t[g|0]=(b>>>2|0)+37;b=w[e|0]}t[g+1|0]=b<<4&48|w[j|0]>>>4;b=w[d|0];d=0;f=0;j:{k:{l:{m:{n:{o:{j=w[j|0]&15;switch(j-8|0){case 0:break l;case 6:break n;case 2:break o;default:break m}}b=(b&240?-16:15)&b;j=10;break k}j=14;r=(b+16&240)>>>4|0;if(r>>>0>8){break k}if(1<<r&435){break l}break k}d=j;f=b}j=d;b=f;if(!((d|b)&255)){break j}}t[g+5|0]=b;t[g+3|0]=j;Mf(g)}l=l+1|0;g=B(x[q>>1],6)+g|0;continue}break}break d}k=k+1|0;continue}}m=m+1|0;continue}}else{f=(g<<5)+a|0;Pe(f+480280|0);u[f+480284>>1]=(w[(e+g|0)+218|0]<<4|8)&248;g=g+1|0;continue}}else{f=e+48|0;rC(b,f);h=fb-16|0;fb=h;d=(B(j,104)+a|0)+484380|0;kd(d,0);u[h+14>>1]=w[f+35|0]<<2;u[h+12>>1]=256;s=d,y=x[Tc(h+14|0,h+12|0)>>1],u[s+30>>1]=y;i=w[f+22|0]|w[f+23|0]<<8|(w[f+24|0]<<16|w[f+25|0]<<24);p:{if(i>>>0<3){break p}v[d>>2]=i;v[d+4>>2]=w[f+26|0]|w[f+27|0]<<8|(w[f+28|0]<<16|w[f+29|0]<<24);v[h+8>>2]=w[f+30|0]|w[f+31|0]<<8|(w[f+32|0]<<16|w[f+33|0]<<24);v[h+4>>2]=1;s=d,y=v[Sc(h+8|0,h+4|0)>>2]-1|0,v[s+8>>2]=y;uc(d+8|0,i);k=v[d+8>>2];i=v[d+4>>2];q:{if(k>>>0<=i+4>>>0){v[d+4>>2]=0;v[d+8>>2]=0;k=0;i=0;break q}u[d+34>>1]=x[d+34>>1]|2;k=k>>>1|0;i=i>>>1|0}t[d+37|0]=w[f+34|0];s=d,y=Bu(0,t[f+34|0]<<4),v[s+24>>2]=y;if(!(t[f+36|0]&1)){break p}v[d+8>>2]=k;v[d+4>>2]=i;u[d+34>>1]=x[d+34>>1]|1;v[d>>2]=v[d>>2]>>>1}fb=h+16|0;dl(e,2,f);d=e+24|0;Ac(d,e);yc(((j<<5)+a|0)+946304|0,d);g=g+1|0;ub(d);continue}}}g=P()|0;O()|0;bc(e+24|0);break c}v[a+480260>>2]=64;v[a+480264>>2]=32767;wb(i);break b}g=P()|0;O()|0;wb(i)}S(g|0);L()}g=1}fb=e+256|0;return g|0}function GU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=fb-3056|0;fb=e;wc(b);g=fb-16|0;fb=g;i=e+1096|0;EB(g+8|0,i);j=b;h=v[b+8>>2];b=v[g+12>>2];jc(g,v[j>>2],h,v[g+8>>2],b);h=v[g+4>>2];if((h|0)==(b|0)){Yb(j,v[g+12>>2])}fb=g+16|0;b=(b|0)==(h|0);if(!b){DB(i)}a:{if(!b){break a}if(!FB(e+1096|0)){break a}b:{if(!c){break b}if(!Lb(v[j>>2],v[j+8>>2],Pc(1024,0))){break a}CB(j,e+576|0);CB(j,e- -64|0);while(1){if((f|0)!=128){b=f<<2;g=v[b+(e+576|0)>>2];if(g>>>0>16777215){break a}b=v[b+(e- -64|0)>>2];if(b-4097>>>0<4294963202){break a}f=f+1|0;if(_q(v[j>>2],(b+g|0)+2978|0)){continue}break a}break}zd(a,2);yg(a);b=e+40|0;d=Qb(b,13819);Db(a+1298344|0,d);vb(d);d=Qb(b,14737);Db(a+1298356|0,d);vb(d);b=Qb(b,15443);Db(a+1298368|0,b);vb(b);v[a+1298404>>2]=5;b=w[e+1096|0];v[a+480204>>2]=143e4;v[a+480196>>2]=b;Ve(Vb(v[a+484360>>2],w[a+484376|0]),w[e+1097|0]);v[a+480188>>2]=4194317;Kb(a+1074312|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;f=0;while(1){if((f|0)==4){c:{while(1){d:{if((d|0)==32){f=0;break d}b=d+1|0;f=B(b,104)+a|0;i=f+484380|0;kd(i,2);h=e+16|0;Sh(h,1,(B(d,13)+e|0)+1098|0);g=e+40|0;Ac(g,h);yc(((b<<5)+a|0)+946304|0,g);ub(g);d=(e+1096|0)+(d<<4)|0;g=w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24);v[i>>2]=g;h=g;g=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);if(h>>>0>=g>>>0){d=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);u[f+484414>>1]=2;v[f+484388>>2]=g;v[f+484384>>2]=d}v[f+484404>>2]=8287;d=b;continue}break}while(1){if((f|0)!=32){d=f+33|0;g=(B(d,104)+a|0)+484380|0;kd(g,2);i=e+16|0;Sh(i,1,(B(f,13)+e|0)+2026|0);b=e+40|0;Ac(b,i);yc(((d<<5)+a|0)+946304|0,b);ub(b);v[e+48>>2]=0;v[e+40>>2]=0;v[e+44>>2]=0;d=(e+1096|0)+B(f,11)|0;o=Hb(b,0),p=w[d+1347|0],t[o|0]=p;o=Hb(b,1),p=w[d+1352|0],t[o|0]=p;o=Hb(b,2),p=w[d+1348|0],t[o|0]=p;o=Hb(b,3),p=w[d+1353|0],t[o|0]=p;o=Hb(b,4),p=w[d+1349|0],t[o|0]=p;o=Hb(b,5),p=w[d+1354|0],t[o|0]=p;o=Hb(b,6),p=w[d+1350|0],t[o|0]=p;o=Hb(b,7),p=w[d+1355|0],t[o|0]=p;o=Hb(b,8),p=w[d+1351|0],t[o|0]=p;o=Hb(b,9),p=w[d+1356|0],t[o|0]=p;o=Hb(b,10),p=w[d+1346|0],t[o|0]=p;v[e+8>>2]=v[e+48>>2];b=v[e+44>>2];v[e>>2]=v[e+40>>2];v[e+4>>2]=b;cl(g,1,e);f=f+1|0;continue}break}Cq(Vb(v[a+484360>>2],w[a+484376|0]),e+2794|0,256,255,65535);l=a+484344|0;ig(l,128);m=c&1;g=0;while(1){e:{f:{if((g|0)!=128){b=g<<2;Vc(j,v[b+(e+576|0)>>2]+2978|0);d=e+16|0;Qd(d,j,v[b+(e- -64|0)>>2]);b=gc(e+40|0,d);wb(d);if(!m){break e}v[23220]=0;d=W(213,l|0,g&65535,64)|0;f=v[23220];v[23220]=0;if((f|0)==1){break c}if(!d){break e}f=0;i=Xb(v[l>>2],g);while(1){if(f>>>0>63){break e}d=v[b>>2];v[23220]=0;d=W(143,d|0,v[e+48>>2],1)|0;h=v[23220];v[23220]=0;g:{if((h|0)!=1){if(!d){break e}v[23220]=0;d=T(193,b|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break c}if(d>>>0>12){break g}h=$c(v[i>>2],v[v[i+48>>2]+12>>2],f,d);v[23220]=0;R(250,e+16|0,b|0);k=v[23220];v[23220]=0;if((k|0)==1){break c}k=w[e+16|0];d=d>>>0>3;t[h|0]=((k&15)+(d?13:37)|0)+B(k>>>4&7,12);k=gd(e+16|0);t[h+1|0]=((w[k|0]>>>4|0)+(d?33:1)|0)+(w[e+16|0]>>>3&16);BB(h,w[k|0],d);continue}break c}h=d-32|0;if((h&255)>>>0<=12){h=$c(v[i>>2],v[v[i+48>>2]+12>>2],f,h&65535);v[23220]=0;k=T(193,b|0)|0;n=v[23220];v[23220]=0;if((n|0)==1){break c}BB(h,k,d>>>0>35);continue}if((d|0)!=64){if((d|0)!=96){break f}if(!f){break e}o=$c(v[i>>2],v[v[i+48>>2]+12>>2],f-1|0,0),p=14,t[o+3|0]=p;break e}v[23220]=0;d=T(193,b|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break c}f=d+f|0;continue}}d=1;if(!(c&2)){break a}while(1){if((d|0)==33){break b}hg(Uc(e+40|0,8,1,0,1),(B(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}wb(b);d=0;break a}wb(b);g=g+1|0;continue}}}else{u[((f<<5)+a|0)+480284>>1]=f&1?192:64;f=f+1|0;continue}break}a=P()|0;O()|0;wb(b);S(a|0);L()}d=1}fb=e+3056|0;return d|0}function e_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;h=fb-32|0;fb=h;v[h+24>>2]=b;v[e>>2]=0;b=h+8|0;Xc(b,d);v[23220]=0;b=T(18,b|0)|0;i=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((i|0)!=1){Wb(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Wb(h+8|0);S(a|0);L()}LF(a,f+24|0,h+24|0,c,e,b);break b}KF(a,f+16|0,h+24|0,c,e,b);break b}b=jb[v[v[a+8>>2]+12>>2]](a+8|0)|0;g=a;i=v[h+24>>2];a=Ec(b);j=h,k=Gj(g,i,c,d,e,f,a,Bb(b)+a|0),v[j+24>>2]=k;break b}a=Ni(h+24|0,c,e,b,2);b=v[e>>2];B:{if(!(b&4|a-1>>>0>30)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;j=h,k=Gj(a,v[h+24>>2],c,d,e,f,h+8|0,h+16|0),v[j+24>>2]=k;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;j=h,k=Gj(a,v[h+24>>2],c,d,e,f,h+8|0,h+16|0),v[j+24>>2]=k;break b}a=Ni(h+24|0,c,e,b,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=Ni(h+24|0,c,e,b,2);b=v[e>>2];D:{if(!(b&4|a-1>>>0>11)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=Ni(h+24|0,c,e,b,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=Ni(h+24|0,c,e,b,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=Ni(h+24|0,c,e,b,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+24|0;d=fb-16|0;fb=d;v[d+8>>2]=c;while(1){H:{if(!Zo(a,d+8|0)){break H}c=Ak(v[a>>2]);if(!eh(v[b+8>>2],8192,c)){break H}Al(a);continue}break}if(Ij(a,d+8|0)){v[e>>2]=v[e>>2]|2}fb=d+16|0;break b}d=h+24|0;a=jb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Bb(a)|0)==(0-Bb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}c=vr(d,c,a,a+24|0,b,e,0);b=v[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}b=w[82868]|w[82869]<<8|(w[82870]<<16|w[82871]<<24);t[h+15|0]=b;t[h+16|0]=b>>>8;t[h+17|0]=b>>>16;t[h+18|0]=b>>>24;b=w[82865]|w[82866]<<8|(w[82867]<<16|w[82868]<<24);v[h+8>>2]=w[82861]|w[82862]<<8|(w[82863]<<16|w[82864]<<24);v[h+12>>2]=b;j=h,k=Gj(a,v[h+24>>2],c,d,e,f,h+8|0,h+19|0),v[j+24>>2]=k;break b}t[h+12|0]=w[82876];v[h+8>>2]=w[82872]|w[82873]<<8|(w[82874]<<16|w[82875]<<24);j=h,k=Gj(a,v[h+24>>2],c,d,e,f,h+8|0,h+13|0),v[j+24>>2]=k;break b}a=Ni(h+24|0,c,e,b,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;j=h,k=Gj(a,v[h+24>>2],c,d,e,f,h+8|0,h+16|0),v[j+24>>2]=k;break b}a=Ni(h+24|0,c,e,b,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=jb[v[v[a>>2]+20>>2]](a,v[h+24>>2],c,d,e,f)|0;break a}b=jb[v[v[a+8>>2]+24>>2]](a+8|0)|0;g=a;i=v[h+24>>2];a=Ec(b);j=h,k=Gj(g,i,c,d,e,f,a,Bb(b)+a|0),v[j+24>>2]=k;break b}JF(f+20|0,h+24|0,c,e,b);break b}a=Ni(h+24|0,c,e,b,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=fb-16|0;fb=a;v[a+8>>2]=c;c=6;d=h+24|0;L:{M:{if(Ij(d,a+8|0)){break M}c=4;if((Um(b,Ak(v[d>>2]))|0)!=37){break M}c=2;if(!Ij(Al(d),a+8|0)){break L}}v[e>>2]=v[e>>2]|c}fb=a+16|0}a=v[h+24>>2]}fb=h+32|0;return a|0}function nha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=fb-736|0;fb=h;a:{b:{if(d>>>0<=511){a=fb-16|0;fb=a;e=h+56|0;ec(a+8|0,e,554);d=v[a+12>>2];jc(a,v[b>>2],v[b+8>>2],v[a+8>>2],d);f=v[a+4>>2];if((f|0)==(d|0)){Yb(b,v[a+12>>2])}fb=a+16|0;a=(d|0)==(f|0);if(!a){Sb(e,0,554)}if(!a){break b}d=fb-32|0;fb=d;c:{a=h+56|0;if(Mb(a,13972,4)){break c}Kq(d,a+32|0);b=d+16|0;Ac(b,d);yc(c+492|0,b);ub(b);Sh(d,1,a+4|0);Ac(b,d);yc(c+524|0,b);ub(b);b=w[a+24|0]|w[a+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=b<<6;t[c+16|0]=w[a+26|0];t[c+17|0]=w[a+27|0];f=c+108|0;g=c+236|0;b=0;while(1)if((b|0)==120){b=w[c+60|0]&-2|t[a+17|0]&1;t[c+60|0]=b;b=b&-3|w[a+17|0]&2;t[c+60|0]=b;t[c+60|0]=b&251|w[a+17|0]&4;g=c+61|0;t[g|0]=w[a+18|0];i=c+62|0;t[i|0]=w[a+19|0];j=c+63|0;t[j|0]=w[a+20|0];k=c- -64|0;t[k|0]=w[a+21|0];e=c+48|0;Zg(e,25);f=v[c+48>>2];b=0;while(1){d:{if((b|0)!=25){l=zb(f,b);m=b<<1;n=w[(a+m|0)+504|0];u[l>>1]=n;if((n|0)!=255){break d}Zg(e,b);f=v[e>>2]}b=$e(g,i);a=ne(f,v[e+4>>2]);if(a>>>0<=w[b|0]){t[c+60|0]=w[c+60|0]&253}if(a>>>0>w[$e(j,k)|0]){break c}t[c+60|0]=w[c+60|0]&251;break c}t[l+2|0]=w[(a+(m|1)|0)+504|0];b=b+1|0;continue}}else{i=a+(b<<1)|0;e=w[i- -64|0];o=ac(g,b),p=w[i+65|0],u[o>>1]=p;o=Hb(f,b),p=(e>>>0<120?e:b)+1|0,t[o|0]=p;b=b+1|0;continue}}fb=d+32|0;break b}i=v[b+8>>2];d=fb-32|0;fb=d;v[d+28>>2]=674;v[d+8>>2]=674;e=v[b>>2];g=v[b+8>>2];f=v[Eb(d+28|0,d+8|0)>>2];if(!Lb(e,g,f)){f=Ze(b)}j=d+8|0;e=h+56|0;YS(j,e);g=cc(d+16|0,v[d+8>>2],f);jc(d,v[b>>2],v[b+8>>2],v[g>>2],v[g+4>>2]);YS(j,e);Sb(v[d+8>>2]+f|0,0,674-f|0);Yb(b,v[d+28>>2]);fb=d+32|0;f=v[a+480180>>2];a=0;d=fb-32|0;fb=d;if(!Mb(e,13972,4)){Kq(d,e+32|0);a=d+16|0;Ac(a,d);yc(c+492|0,a);ub(a);Sh(d,1,e+4|0);Ac(a,d);yc(c+524|0,a);ub(a);v[c>>2]=(w[e+20|0]|w[e+21|0]<<8)<<5;v[c+4>>2]=w[e+24|0]>>>1;uc(c+4|0,64);g=w[e+25|0]&127;v[c+8>>2]=g>>>0>64?128:g<<2;t[c+15|0]=w[c+15|0]&254|((w[e+25|0]^-1)&128)>>>7;t[d+16|0]=w[e+26|0];t[d|0]=100;o=c,p=w[Rb(a,d)|0],t[o+20|0]=p;t[d+16|0]=w[e+27|0];t[d|0]=64;o=c,p=w[Rb(a,d)|0],t[o+19|0]=p;t[c+16|0]=w[e+17|0];t[c+17|0]=w[e+18|0];t[c+18|0]=w[e+19|0];t[c+26|0]=w[e+22|0];t[c+27|0]=w[e+23|0];a=w[e+58|0];um(c,a&127,a>>>7|0);a=w[e+59|0];tm(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{j:{a=w[e+28|0]|w[e+29|0]<<8;switch(a-529|0){case 1:case 2:break h;case 0:case 3:break i;default:break j}}if((a|0)==544){break i}if((a|0)!=514){break h}}a=w[e+61|0];if((a|0)==255){break g}if(a>>>0<=128){t[c+30|0]=a}a=w[e+62|0]|w[e+63|0]<<8;if(a>>>0<129){break f}break e}a=t[e+61|0];if((a|0)<0){break g}t[c+30|0]=a+1}a=w[e+62|0];a=a<<24>>24>=0?a+1|0:0;g=t[e+63|0];if((g|0)<0){break f}a=((g&255)<<7)+a|0}u[c+28>>1]=a}a=t[e+60|0];t[c+31|0]=a;if((a|0)<0){t[c+31|0]=0;t[c+34|0]=a^128}a=0;f=f&16777216?240:25;Xu(e+304|0,c+48|0,0,f);Xu(e+386|0,c+68|0,32,f);Xu(e+468|0,c+88|0,32,f);t[c+100|0]=w[c+100|0]&239|w[e+468|0]>>>3&16;g=c+108|0;j=c+236|0;while(1){if((a|0)!=120){k=e+(a<<1)|0;f=w[k- -64|0];o=ac(j,a),p=w[k+65|0],u[o>>1]=p;o=Hb(g,a),p=(f>>>0<120?f:a)+1|0,t[o|0]=p;a=a+1|0;continue}break}a=554}fb=d+32|0;d=0;k:{if(!a){break k}d=e+550|0;l:{if(Mb(d,13490,4)){if(Mb(d,13804,4)){break l}}d=c+236|0;a=0;while(1){if((a|0)!=120){f=ac(d,a);u[f>>1]=x[f>>1]|w[(a+e|0)+554|0]<<8;a=a+1|0;continue}break}a=674}d=a}Vc(b,d+i|0);if(!wh(b,13977)){break b}d=h+8|0;Qd(d,b,mg(b));a=gc(h+32|0,d);wb(d);b=v[a>>2];v[23220]=0;T(147,b|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break a}v[23220]=0;b=Q(355,a|0,13727)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}if(b){v[23220]=0;b=T(193,a|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}t[c+34|0]=b>>>0>250?0:b}wb(a)}fb=h+736|0;return}b=P()|0;O()|0;wb(a);S(b|0);L()}function xM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-16|0;fb=f;g=a+1074376|0;h=B(b,872);e=(g+h|0)+616|0;d=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+h|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}if(lj(v[e+656>>2])){a=B(b,872)+a|0;u[a+1075764>>1]=d-8;a=a+1075843|0;t[a|0]=w[a|0]|64;break a}if(v[a+480180>>2]!=64){b=B(b,872)+a|0;u[b+1075764>>1]=d<<28>>24;c=x[(d<<1)+33440>>1];v[b+1075696>>2]=c;e=b+1075692|0;if(!v[e>>2]){break a}k=e,l=Lg(a,w[b+1075789|0],d<<28>>24,c),v[k>>2]=l;break a}a=B(b,872)+a|0;b=v[a+1075096>>2];if(!b){break a}v[a+1075696>>2]=v[b+24>>2]+B(d,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075814|0]=c&3;break a}xb(f+8|0,a+1074312|0,21);if(yb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075814|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075817|0]=c&3;break a}xb(f+8|0,a+1074312|0,21);if(yb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075817|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075817|0]=c&7;break a;case 4:xb(f+8|0,a+1074312|0,21);if(yb(v[v[f+8>>2]>>2],v[f+12>>2])){a=B(b,872)+a|0;t[a+1075813|0]=0;t[a+1075820|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(v[a+1074392>>2]|!(w[a+480209|0]&16)){break a}a=a+1074400|0;v[a>>2]=v[a>>2]+d;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(d>>>0<=2){d=x[a+480188>>1];h=d>>>0>256?d:256;i=b+1|0;j=(c&15)-1|0;while(1){if((d|0)==(h|0)){break a}c=B(d,872)+a|0;c:{if(x[c+1075778>>1]!=(i|0)){break c}d:{e:{switch(j|0){case 0:Fn(a,c+1074992|0);if(!(w[c+1075081|0]&2)){break d}e=v[a+1298300>>2];if(!sd(e)){break d}Sj(e,d&65535);break d;case 1:g=c+1075080|0;e=v[g>>2];v[g>>2]=e|4096;if(!(e&512)){break d}e=v[a+1298300>>2];if(!sd(e)){break d}Sj(e,d&65535);break d;default:break e}}v[c+1075688>>2]=0;g=c+1075080|0;e=v[g>>2];v[g>>2]=e|4096;if(!(e&512)){break d}e=v[a+1298300>>2];if(!sd(e)){break d}fj(e,d&65535,1)}e=v[c+1075648>>2];if(!e){break c}g=w[e+34|0];if(!g){break c}g=v[(B(g,160)+a|0)+906140>>2];if(!g){break c}jb[v[v[g>>2]+92>>2]](g,e,w[c+1075789|0]+255|0,0,b)}d=d+1|0;continue}}OO(e,d,v[a+480180>>2]);break a;case 7:if(!(w[a+480209|0]&16)){break a}Pl(a,e,d,4);break a;case 8:b=e;c=v[a+480208>>2];f:{if(!(c&4096)){break f}g:{switch(d&15){case 0:v[b+88>>2]=v[b+88>>2]&-257;break f;case 1:v[b+692>>2]=128;v[b+88>>2]=v[b+88>>2]|256;break f;case 8:v[b+88>>2]=v[b+88>>2]&-25165825|16777216;break f;case 9:v[b+88>>2]=v[b+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=c&-16385;break f;case 11:v[a+480208>>2]=c|16384;break f;case 12:v[a+480208>>2]=c&-8193;break f;case 13:v[a+480208>>2]=c|8192;break f;case 14:v[b+88>>2]=v[b+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(v[b>>2]|v[b+4>>2]){break h}a=v[b+76>>2];if(!a){break h}if(!(k=Oc(w[b+788|0]),l=1,m=w[b+88|0]&2,m?k:l)){break h}v[b>>2]=-1;v[b+4>>2]=a-1}v[b+88>>2]=v[b+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,872)+a|0;t[c+1075828|0]=d;xb(f+8|0,a+1074312|0,35);if(yb(v[v[f+8>>2]>>2],v[f+12>>2])){break a}if(!Oc(w[c+1075780|0])){break a}b=v[(B(b,872)+a|0)+1075068>>2];a=d<<16;if(b>>>0<=a>>>0){break a}v[e+4>>2]=a;break a;case 10:if(!(w[a+480209|0]&16)){break a}Hy(a,g,e,d);break a;case 11:i:{if(d){break i}d=1;c=v[a+480180>>2];if(c&16777248){break i}d=0;if((c|0)==2){break a}}xb(f+8|0,a+1074312|0,30);vy(a,b,d,yb(v[v[f+8>>2]>>2],v[f+12>>2])|v[a+480180>>2]==2);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,872)+a|0)+1075836|0]=d}fb=f+16|0}function Mj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=1;o(+b);f=j(1)|0;e=j(0)|0;a:{b:{m=f&2147483647;g=e;c:{if(!(m|e)){break c}o(+a);e=j(1)|0;t=j(0)|0;if(!t&(e|0)==1072693248){break c}q=e&2147483647;if(!(!(q>>>0>2146435072|(q|0)==2146435072&(t|0)!=0|m>>>0>2146435072)&(!g|(m|0)!=2146435072))){return a+b}d:{e:{f:{r=0;g:{if((e|0)>0|(e|0)>=0){break g}r=2;if(m>>>0>1128267775){break g}r=0;if(m>>>0<1072693248){break g}h=m>>>20|0;if(m>>>0<1094713344){break f}d=1075-h|0;h=g>>>d|0;r=0;if((g|0)!=h<<d){break g}r=2-(h&1)|0}d=r;if(!g){break e}break d}if(g){break d}g=1043-h|0;h=m>>>g|0;d=0;if((m|0)!=h<<g){break e}d=2-(h&1)|0}if((m|0)==2146435072){if(!(q-1072693248|t)){break c}if(q>>>0>=1072693248){return(f|0)>0|(f|0)>=0?b:0}return(f|0)>0|(f|0)>=0?0:-b}if((m|0)==1072693248){if((f|0)>0|(f|0)>=0){return a}return 1/a}if((f|0)==1073741824){return a*a}if((f|0)!=1071644672|(e|0)<0){break d}return K(a)}c=D(a);if(!((q?(e&1073741823)!=1072693248:0)|t)){k=(f|0)<0?1/c:c;if((e|0)>0|(e|0)>=0){break c}if(!(q-1072693248|d)){a=k-k;return a/a}return(d|0)==1?-k:k}h:{if((e|0)>0|(e|0)>=0){break h}i:{switch(d|0){case 0:a=a-a;return a/a;case 1:break i;default:break h}}k=-1}j:{if(m>>>0>=1105199105){if(m>>>0>=1139802113){if(q>>>0<=1072693247){return(f|0)<0?N:0}return(f|0)>0?N:0}if(q>>>0<=1072693246){return(f|0)<0?k*1e300*1e300:k*1e-300*1e-300}if(q>>>0>=1072693249){return(f|0)>0?k*1e300*1e300:k*1e-300*1e-300}a=c+-1;c=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;i=c;c=a*1.4426950216293335;o(+(i+c));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();c=i-(a-c);break j}a=c*9007199254740992;g=q>>>0<1048576;c=g?a:c;o(+a);d=j(1)|0;j(0)|0;h=g?d:q;e=h&1048575;d=e|1072693248;h=(h>>20)+(g?-1076:-1023)|0;g=0;k:{if(e>>>0<235663){break k}if(e>>>0<767610){g=1;break k}d=e|1071644672;h=h+1|0}e=g<<3;w=A[e+3536>>3];o(+c);j(1)|0;q=0;l(0,j(0)|q);l(1,d|0);p=+n();s=A[e+3520>>3];i=p-s;u=1/(s+p);c=i*u;o(+c);m=j(1)|0;j(0)|0;l(0,0);l(1,m|0);a=+n();x=a;l(0,q|0);l(1,((g<<18)+(d>>>1|0)|0)+537395200|0);v=a*a;y=i;i=+n();p=u*(y-a*i-a*(p-(i-s)));i=p*(c+a);a=c*c;s=i+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();i=x*a;c=p*a+c*(s-(a+-3-v));o(+(i+c));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();c=w+(a*-7.028461650952758e-9+(c-(a-i))*.9617966939259756);i=c;p=A[e+3552>>3];c=a*.9617967009544373;s=+(h|0);o(+(p+(i+c)+s));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();c=i-(a-s-p-c)}l(0,0);l(1,f|0);p=+n();c=(b-p)*a+c*b;b=a*p;a=c+b;o(+a);e=j(1)|0;d=j(0)|0;l:{f=e;if((e|0)>=1083179008){if(d|f-1083179008){break b}if(!(c+8.008566259537294e-17>a-b)){break l}break b}if((f&2147482624)>>>0<1083231232){break l}if(d|f+1064252416){break a}if(!(c<=a-b)){break l}break a}g=0;h=f&2147483647;if(h>>>0>=1071644673){d=f+(1048576>>>(h>>>20|0)-1022|0)|0;f=d>>>20&2047;g=(d&1048575|1048576)>>>1043-f|0;g=(e|0)<0?0-g|0:g;l(0,0);l(1,d&-1048576>>f-1023);b=b-+n();o(+(c+b));e=j(1)|0;j(0)|0}l(0,0);l(1,e|0);a=+n();p=a*.6931471824645996;c=(c-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=p+c;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);i=a*b/(b+-2);b=a;a=c-(a-p);a=b-(i-(b*a+a))+1;o(+a);d=j(1)|0;e=j(0)|0;d=(g<<20)+d|0;m:{if((d|0)<=1048575){a=Cj(a,g);break m}l(0,e|0);l(1,d|0);a=+n()}k=k*a}return k}return k*1e300*1e300}return k*1e-300*1e-300}function vJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=fb-192|0;fb=g;v[g+188>>2]=c;v[g+184>>2]=b;a:{if(!c){break a}h=w[Hk(b,c)|0];if((h|0)==33){f=1}else{if((h|0)!=63){break a}f=0}Qk(g+8|0,b,c,c-1|0);b=v[g+12>>2];v[g+184>>2]=v[g+8>>2];v[g+188>>2]=b}c=g+8|0;Kd(c);b=v[g+8>>2];Kd(g+160|0);b=Gk(b,v[g+164>>2],g+184|0);Kd(c);h=v[g+188>>2];c=v[g+184>>2];b:{c:{d:{e:{if((b|0)==v[g+12>>2]){a=oc(g+176|0,21598);if(Hc(c,h,v[a>>2],v[a+4>>2])){f=aa(8)|0;v[23220]=0;b=Bh(g+160|0,d,e);a=v[23220];v[23220]=0;f:{g:{h:{if((a|0)!=1){v[23220]=0;U(934,g+8|0,17577,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}d=0;a=qc(f,g+8|0);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(g+8|0);break g}c=P()|0;O()|0;break f}c=P()|0;d=1;O()|0}ub(b);if(!d){break c}}ba(f|0);break c}if(!f){break e}i=aa(8)|0;v[23220]=0;h=Bh(g+128|0,v[g+184>>2],v[g+188>>2]);a=v[23220];v[23220]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[23220]=0;U(934,g+144|0,17613,h|0);a=v[23220];v[23220]=0;if((a|0)==1){break q}v[23220]=0;R(936,g+160|0,g+144|0);a=v[23220];v[23220]=0;f=1;if((a|0)==1){break p}v[23220]=0;b=Bh(g+112|0,d,e);a=v[23220];v[23220]=0;if((a|0)==1){break o}v[23220]=0;U(938,g+8|0,g+160|0,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break n}a=qc(i,g+8|0);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(g+8|0);f=0;break m}c=P()|0;O()|0;break i}c=P()|0;f=1;O()|0;break j}c=P()|0;O()|0;break k}c=P()|0;O()|0;break l}c=P()|0;O()|0}ub(b)}ub(g+160|0)}ub(g+144|0)}ub(h);if(!f){break c}}ba(i|0);break c}b=oc(g+104|0,21598);if(Hc(c,h,v[b>>2],v[b+4>>2])){f=aa(8)|0;v[23220]=0;b=Bh(g+160|0,d,e);a=v[23220];v[23220]=0;r:{s:{t:{if((a|0)!=1){v[23220]=0;U(934,g+8|0,17577,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break t}d=0;a=qc(f,g+8|0);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(g+8|0);break s}c=P()|0;O()|0;break r}c=P()|0;d=1;O()|0}ub(b);if(!d){break c}}ba(f|0);break c}b=oc(g+96|0,12327);if(Hc(c,h,v[b>>2],v[b+4>>2])){b=oc(g+88|0,5562);if(Hc(d,e,v[b>>2],v[b+4>>2])){v[a+52>>2]=0;break e}b=oc(g+80|0,11259);if(Hc(d,e,v[b>>2],v[b+4>>2])){v[a+52>>2]=1;break e}b=oc(g+72|0,9177);if(Hc(d,e,v[b>>2],v[b+4>>2])){v[a+52>>2]=2;break e}f=aa(8)|0;v[23220]=0;b=Bh(g+160|0,d,e);a=v[23220];v[23220]=0;u:{v:{w:{if((a|0)!=1){v[23220]=0;U(934,g+8|0,14598,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break w}d=0;a=qc(f,g+8|0);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(g+8|0);break v}c=P()|0;O()|0;break u}c=P()|0;d=1;O()|0}ub(b);if(!d){break c}}ba(f|0);break c}b=oc(g- -64|0,11496);if(!Hc(c,h,v[b>>2],v[b+4>>2])){break e}c=0;x:{b=oc(g+56|0,15540);if(Hc(d,e,v[b>>2],v[b+4>>2])){break x}c=1;b=oc(g+48|0,15545);if(Hc(d,e,v[b>>2],v[b+4>>2])){break x}c=2;b=oc(g+40|0,12601);if(Hc(d,e,v[b>>2],v[b+4>>2])){break x}c=3;b=oc(g+32|0,9241);if(Hc(d,e,v[b>>2],v[b+4>>2])){break x}d=aa(8)|0;v[23220]=0;b=Q(52,g+8|0,11532)|0;a=v[23220];v[23220]=0;if((a|0)==1){break d}a=qc(d,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(b);break c}v[a+56>>2]=c;b=v[a+24>>2];if(!v[b+24668>>2]){break e}d=b+24648|0;a=v[d+20>>2];v[g+24>>2]=v[d+16>>2];v[g+28>>2]=a;a=v[d+12>>2];v[g+16>>2]=v[d+8>>2];v[g+20>>2]=a;a=v[d+4>>2];v[g+8>>2]=v[d>>2];v[g+12>>2]=a;j=g,k=$I(c),v[j+28>>2]=k;if(!jx(g+8|0,d)){break e}ey(b,g+8|0)}fb=g+192|0;return}c=P()|0;O()|0;ba(d|0)}S(c|0)}L()}function wha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=fb-976|0;fb=e;wc(b);d=fb-16|0;fb=d;h=e+872|0;pT(d+8|0,h);f=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],f);g=v[d+4>>2];if((g|0)==(f|0)){Yb(b,v[d+12>>2])}fb=d+16|0;d=(f|0)==(g|0);if(!d){oT(h)}a:{if(!d){break a}if(!rT(e+872|0)){break a}if(!Lb(v[b>>2],v[b+8>>2],Pc(qT(w[e+919|0]|w[e+920|0]<<8),ib))){break a}if(!c){l=1;break a}zd(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[e+947|0];v[a+480208>>2]=16;v[a+480200>>2]=256;v[a+480204>>2]=8e5;Kb(a+1074312|0,7,1);d=e+96|0;f=Qb(d,8211);Db(a+1298344|0,f);vb(f);f=Qb(d,8883);Db(a+1298356|0,f);vb(f);v[a+1298404>>2]=5;f=e+16|0;nT(f,e+872|4);Ac(d,f);xc(a+1298308|0,d);ub(d);d=0;while(1){if((d|0)==16){b:{d=x[e+968>>1];if(d){lB(a+1298332|0,b,d,132,0)}d=fb-16|0;fb=d;h=e+96|0;ec(d+8|0,h,771);f=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],f);g=v[d+4>>2];if((g|0)==(f|0)){Yb(b,v[d+12>>2])}fb=d+16|0;l=(f|0)==(g|0);if(!l){Sb(h,0,771)}if(!l){break a}d=a+484376|0;mT(Vb(v[a+484360>>2],w[d|0]),e+96|0,w[e+353|0]);Ve(Vb(v[a+484360>>2],w[d|0]),w[e+354|0]);Vc(b,w[e+919|0]|w[e+920|0]<<8);o=a+484344|0;p=c&1;h=0;while(1){c:{if((h|0)==256){if(!(c&2)){break a}uB(b,e- -64|0);d=0;while(1){if((d|0)==64){break a}if(!(w[e- -64+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;continue}if(!VA(b,e+16|0)){break a}d=d+1|0;u[a+480190>>1]=d;Ue(e,1,e+16|0);h=e+72|0;Ac(h,e);yc(((x[a+480190>>1]<<5)+a|0)+946304|0,h);ub(h);c=(B(d,104)+a|0)+484380|0;kd(c,0);i=w[e+48|0]|w[e+49|0]<<8|(w[e+50|0]<<16|w[e+51|0]<<24);v[c>>2]=i;f=w[e+54|0]|w[e+55|0]<<8|(w[e+56|0]<<16|w[e+57|0]<<24);v[c+4>>2]=f;g=w[e+58|0]|w[e+59|0]<<8|(w[e+60|0]<<16|w[e+61|0]<<24);v[c+24>>2]=16726;v[c+8>>2]=g;u[c+30>>1]=w[e+53|0]<<4;if(t[e+62|0]&1){g=g>>>1|0;v[c+8>>2]=g;f=f>>>1|0;v[c+4>>2]=f;v[c>>2]=i>>>1}if(!(!(w[e+63|0]&8)|f>>>0>=g>>>0)){u[c+34>>1]=x[c+34>>1]|2}Uc(h,t[e+62|0]&1?16:8,1,0,0);hg(h,c,b);continue}}d:{d=(h<<1)+e|0;g=w[d+355|0]|w[d+356|0]<<8;if(g){f=e+72|0;Qd(f,b,g);i=gc(e+16|0,f);wb(f);n=((w[d+355|0]|w[d+356|0]<<8)-2|0)/64|0;e:{if(!p){break e}v[23220]=0;d=W(213,o|0,h&65535,n|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break d}if(!d){break e}v[23220]=0;d=T(193,i|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break b}v[23220]=0;Q(175,i|0,1)|0;f=v[23220];v[23220]=0;if((f|0)==1){break b}q=d?d>>>0<n-2>>>0?d+1|0:-1:-1;f=0;f:while(1){g:{d=Xb(v[o>>2],h);if((f|0)==(n|0)){break g}m=0;r=Of(v[d>>2],v[v[d+48>>2]+12>>2],f);while(1){if((m|0)==16){f=f+1|0;continue f}v[23220]=0;R(342,e+72|0,i|0);d=v[23220];v[23220]=0;if((d|0)==1){break c}d=B(m,6)+r|0;j=e+72|0;g=Qe(j);j=zi(j);k=w[e+72|0];if((k-1&255)>>>0<=71){t[d|0]=k+36;s=d,y=w[gd(e+72|0)|0]+1|0,t[s+1|0]=y}if((w[g|0]-1&255)>>>0<=15){t[d+2|0]=1;t[d+4|0]=((w[g|0]<<6)+-64>>>0)/15}k=w[j|0];g=k&15;t[d+5|0]=g;h:{i:{switch((w[j|0]>>>4|0)-1|0){case 0:case 1:t[d+5|0]=k|240;break h;case 2:t[d+5|0]=g<<2;break h;case 3:t[d+5|0]=(6/(g+1>>>0)|0)+1;break h;case 5:case 6:t[d+5|0]=g<<3;break h;case 9:t[d+4|0]=(g<<2)+4;t[d+2|0]=1;break h;case 10:t[d+5|0]=g|128;break h;case 11:break i;default:break h}}t[d+5|0]=(6/(g+1>>>0)|0)+1|13}t[d+3|0]=w[(w[j|0]>>>4|0)+26384|0];m=m+1|0;continue}}break}me(d,uh(He(Be(e+72|0,14,0),q)))}wb(i)}h=h+1|0;continue}}break}}}else{f=(d<<5)+a|0;h=f+480280|0;Pe(h);g=h;h=(e+872|0)+d|0;v[g>>2]=!w[h+50|0]<<10;u[f+480284>>1]=(w[h+76|0]<<4|8)&248;d=d+1|0;continue}break}a=P()|0;O()|0;wb(i);S(a|0);L()}fb=e+976|0;return l|0}function S4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=fb-96|0;fb=f;a:{if(ze(b)){break a}e=w[cJ(b)|0];if((e|0)==33){d=1}else{if((e|0)!=63){break a}d=0}e=f+80|0;vv(e,b,0,Bb(b)-1|0);xc(b,e);ub(e)}g=f+80|0;Kd(g);e=v[f+80>>2];Kd(f- -64|0);e=bJ(e,v[f+68>>2],b);Kd(g);b:{c:{d:{e:{if((e|0)==v[f+84>>2]){if(je(b,21598)){a=aa(8)|0;v[23220]=0;U(925,f+80|0,17577,c|0);b=v[23220];v[23220]=0;if((b|0)==1){break d}a=qc(a,f+80|0);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}b=P()|0;O()|0;ub(f+80|0);break c}if(!d){break e}a=aa(8)|0;v[23220]=0;U(925,f+48|0,17613,b|0);b=v[23220];v[23220]=0;f:{g:{h:{i:{j:{if((b|0)!=1){v[23220]=0;R(936,f- -64|0,f+48|0);b=v[23220];v[23220]=0;if((b|0)==1){break j}v[23220]=0;U(487,f+80|0,f- -64|0,c|0);b=v[23220];v[23220]=0;d=1;if((b|0)==1){break i}b=qc(a,f+80|0);v[23220]=0;U(106,b|0,61832,923);b=v[23220];v[23220]=0;if((b|0)!=1){break b}b=P()|0;O()|0;ub(f+80|0);d=0;break h}b=P()|0;O()|0;break f}b=P()|0;d=1;O()|0;break g}b=P()|0;O()|0}ub(f- -64|0)}ub(f+48|0);if(!d){break c}}ba(a|0);break c}k:{switch(v[e+4>>2]){case 0:re(f+40|0,b);b=fb-192|0;fb=b;e=b+16|0;ei(e,c);v[23220]=0;R(75,b+32|0,e|0);c=v[23220];v[23220]=0;l:{m:{n:{o:{p:{if((c|0)!=1){v[23220]=0;c=Q(76,b+48|0,b+32|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break p}ub(b+32|0);ub(b+16|0);e=v[v[c>>2]-12>>2];v[23220]=0;g=ha(59)|0;h=v[23220];v[23220]=0;if((h|0)==1){break n}v[23220]=0;U(60,b+8|0,c+e|0,g|0);e=v[23220];v[23220]=0;if((e|0)==1){break n}Wb(b+8|0);v[23220]=0;e=Q(1036,c|0,b+32|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break n}c=Ek(v[(e+v[v[e>>2]-12>>2]|0)+16>>2]);g=w[b+32|0];df(e);fb=b+192|0;b=(c^-1)&(g|0)!=0;break l}a=P()|0;O()|0;break o}a=P()|0;O()|0;ub(b+32|0)}ub(b+16|0);break m}a=P()|0;O()|0;df(c)}S(a|0);L()}zJ(a,v[f+40>>2],v[f+44>>2],b,d);break e;case 1:re(f+32|0,b);b=fb-192|0;fb=b;e=b+16|0;ei(e,c);v[23220]=0;R(75,b+32|0,e|0);c=v[23220];v[23220]=0;q:{r:{s:{t:{u:{if((c|0)!=1){v[23220]=0;c=Q(76,b+48|0,b+32|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break u}ub(b+32|0);ub(b+16|0);e=v[v[c>>2]-12>>2];v[23220]=0;g=ha(59)|0;h=v[23220];v[23220]=0;if((h|0)==1){break s}v[23220]=0;U(60,b+8|0,c+e|0,g|0);e=v[23220];v[23220]=0;if((e|0)==1){break s}Wb(b+8|0);v[23220]=0;e=Q(82,c|0,b+32|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break s}c=Ek(v[(e+v[v[e>>2]-12>>2]|0)+16>>2]);g=v[b+32>>2];h=v[b+36>>2];df(e);fb=b+192|0;b=c?0:g;c=c?0:h;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;ub(b+32|0)}ub(b+16|0);break r}a=P()|0;O()|0;df(c)}S(a|0);L()}xJ(a,v[f+32>>2],v[f+36>>2],b,c,d);break e;case 2:re(f+24|0,b);b=fb-192|0;fb=b;e=b+16|0;ei(e,c);v[23220]=0;R(75,b+32|0,e|0);c=v[23220];v[23220]=0;v:{w:{x:{y:{z:{if((c|0)!=1){v[23220]=0;c=Q(76,b+48|0,b+32|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break z}ub(b+32|0);ub(b+16|0);e=v[v[c>>2]-12>>2];v[23220]=0;g=ha(59)|0;h=v[23220];v[23220]=0;if((h|0)==1){break x}v[23220]=0;U(60,b+8|0,c+e|0,g|0);e=v[23220];v[23220]=0;if((e|0)==1){break x}Wb(b+8|0);v[23220]=0;e=Q(83,c|0,b+32|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break x}c=Ek(v[(e+v[v[e>>2]-12>>2]|0)+16>>2]);i=A[b+32>>3];df(e);fb=b+192|0;i=c?0:i;break v}a=P()|0;O()|0;break y}a=P()|0;O()|0;ub(b+32|0)}ub(b+16|0);break w}a=P()|0;O()|0;df(c)}S(a|0);L()}yJ(a,v[f+24>>2],v[f+28>>2],i,d);break e;case 3:break k;default:break e}}re(f+16|0,b);re(f+8|0,c);vJ(a,v[f+16>>2],v[f+20>>2],v[f+8>>2],v[f+12>>2],d)}fb=f+96|0;return}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function uV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-576|0;fb=e;wc(b);d=fb-16|0;fb=d;f=e+72|0;BC(d+8|0,f);g=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],g);j=v[d+4>>2];if((j|0)==(g|0)){Yb(b,v[d+12>>2])}fb=d+16|0;d=(g|0)==(j|0);if(!d){AC(f)}a:{if(!d){break a}if(!DC(e+72|0)){break a}b:{if(!c){break b}if(!Lb(v[b>>2],v[b+8>>2],Pc(CC(w[e+182|0],w[e+183|0]),ib))){break a}zd(a,64);v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480204>>2]=78e4;v[a+480196>>2]=4;u[a+480188>>1]=8;Kb(a+1074312|0,7,1);d=e+40|0;g=Qb(d,14634);Db(a+1298344|0,g);vb(g);d=Qb(d,14667);Db(a+1298356|0,d);vb(d);ql(a+1298368|0,Mb(e+72|0,11060,2)?14662:14634);v[a+1298404>>2]=5;f=w[e+182|0];u[a+480190>>1]=f;g=1;while(1){j=g&65535;if(j>>>0<=f>>>0){f=fb-16|0;fb=f;d=e+40|0;ec(f+8|0,d,25);k=v[f+12>>2];jc(f,v[b>>2],v[b+8>>2],v[f+8>>2],k);i=v[f+4>>2];if((i|0)==(k|0)){Yb(b,v[f+12>>2])}fb=f+16|0;if((i|0)!=(k|0)){t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;t[d+24|0]=0;t[d+16|0]=0;t[d+17|0]=0;t[d+18|0]=0;t[d+19|0]=0;t[d+20|0]=0;t[d+21|0]=0;t[d+22|0]=0;t[d+23|0]=0;t[d+8|0]=0;t[d+9|0]=0;t[d+10|0]=0;t[d+11|0]=0;t[d+12|0]=0;t[d+13|0]=0;t[d+14|0]=0;t[d+15|0]=0}if((w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24))>>>0>67108863){break a}f=(B(j,104)+a|0)+484380|0;kd(f,0);v[f+24>>2]=8363;k=e+40|0;d=k;i=w[d+13|0]|w[d+14|0]<<8|(w[d+15|0]<<16|w[d+16|0]<<24);v[f>>2]=i;l=w[d+17|0]|w[d+18|0]<<8|(w[d+19|0]<<16|w[d+20|0]<<24);v[f+4>>2]=l;d=w[d+21|0]|w[d+22|0]<<8|(w[d+23|0]<<16|w[d+24|0]<<24);d=d>>>0>i>>>0?l?d:0:d;v[f+8>>2]=d;if(d){u[f+34>>1]=2;hk(f)}f=e+8|0;Sh(f,2,k);d=e+24|0;Ac(d,f);yc(((j<<5)+a|0)+946304|0,d);g=g+1|0;ub(d);f=x[a+480190>>1];continue}break}g=e+24|0;h=e+72|2;Pf(g,3,h,36);d=e+40|0;Ac(d,g);xc(a+1298308|0,d);ub(d);g=0;zC(a+1298332|0,h,108,36,0);d=a+484376|0;Mu(Vb(v[a+484360>>2],w[d|0]),e+185|0,128);d=Vb(v[a+484360>>2],w[d|0]);h=w[e+184|0];if(x[ac(v[d>>2],h)>>1]<w[e+183|0]){Ve(d,h)}while(1)if((g|0)==8){j=a+484344|0;ig(j,w[e+183|0]);n=c&1;f=0;while(1){if(w[e+183|0]<=f>>>0){h=1;if(!(c&2)){break a}c=Uc(e+40|0,8,1,0,1);g=1;while(1){d=g&65535;if(d>>>0>x[a+480190>>1]){break b}hg(c,(B(d,104)+a|0)+484380|0,b);g=g+1|0;continue}}c:{d:{if(n){if(Xg(j,f&65535,64)){break d}}Yb(b,1536);break c}v[e+24>>2]=-1;v[e+28>>2]=-1;k=0;e:while(1){if((k|0)==64){d=(e+72|0)+f|0;g=w[d+369|0];if(g>>>0<63){me(Xb(v[j>>2],f),uh(He(Be(e+40|0,14,0),g)))}me(Xb(v[j>>2],f),uh(Be(e+40|0,16,w[d+241|0])));break c}g=0;d=Xb(v[j>>2],f);h=Of(v[d>>2],v[v[d+48>>2]+12>>2],k);while(1){if((g|0)==8){k=k+1|0;continue e}d=e+40|0;Dq(d,b);i=gd(d);l=Qe(d);i=w[i|0];d=w[e+40|0];if(d>>>0<=253){t[h|0]=(d>>>2|0)+37;t[h+1|0]=(d<<4&48|i>>>4)+1;t[(e+24|0)+g|0]=255;d=w[e+40|0]}if((d&255)!=255){t[h+2|0]=1;t[h+4|0]=(((i&15)<<6|8)>>>0)/15}d=w[l|0];if((d|0)!=255){t[(e+24|0)+g|0]=d}i=(e+24|0)+g|0;f:{g:{if(d&15?0:(d|0)!=48){break g}l=w[i|0];if((l|0)==255){break f}m=l<<24>>24;d=m&15;t[h+5|0]=d;h:{if((m|0)<0){break h}l=l>>>4|0;t[h+3|0]=w[l+26168|0];i:{switch(l-3|0){case 0:t[h+5|0]=d|32;break g;case 1:t[h+5|0]=d|m<<4;break f;case 2:break g;case 3:break i;default:break f}}j:{switch(d|0){case 0:t[h+5|0]=79;break f;case 1:break j;default:break h}}t[h+5|0]=244;break f}t[h+3|0]=0;break f}t[i|0]=255}h=h+6|0;g=g+1|0;continue}}}f=f+1|0;continue}}else{d=(g<<5)+a|0;Pe(d+480280|0);u[d+480284>>1]=g&1?208:48;g=g+1|0;continue}}h=1}fb=e+576|0;return h|0}function hK(){var a=0,b=0,c=0,d=0,e=0,f=0;if(w[466720]){return v[116679]}b=Rd(468328);v[b>>2]=83064;c=b+8|0;v[c>>2]=0;v[c+4>>2]=0;e=lh(c+8|0),f=0,t[e+128|0]=f;v[23220]=0;Y(1176,c|0);a=v[23220];v[23220]=0;if((a|0)==1){b=P()|0;O()|0;bw(c);S(b|0);L()}it(c,30);v[23220]=0;d=Q(52,b+152|0,14270)|0;a=v[23220];v[23220]=0;a:{b:{c:{if((a|0)!=1){Bc(c);Rd(468016);v[117004]=84388;v[23220]=0;Y(1145,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468024);v[117006]=84420;v[23220]=0;Y(1146,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}a=Rd(468032);t[a+12|0]=0;v[a+8>>2]=0;v[a>>2]=83084;v[a+8>>2]=79024;v[23220]=0;Y(1147,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468048);v[117012]=83568;v[23220]=0;Y(1148,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468056);v[117014]=83716;v[23220]=0;Y(1149,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}v[23220]=0;Z(1150);a=v[23220];v[23220]=0;if((a|0)==1){break c}v[23220]=0;Y(1151,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468080);v[117020]=83864;v[23220]=0;Y(1152,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468088);v[117022]=83980;v[23220]=0;Y(1153,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}a=Rd(468096);u[a+8>>1]=11310;v[a>>2]=83184;Gb(a+12|0);v[23220]=0;Y(1154,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}a=Rd(468120);v[a+8>>2]=46;v[a+12>>2]=44;v[a>>2]=83224;Gb(a+16|0);v[23220]=0;Y(1155,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468152);v[117038]=84452;v[23220]=0;Y(1156,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468160);v[117040]=84696;v[23220]=0;Y(1157,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468168);v[117042]=84908;v[23220]=0;Y(1158,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468176);v[117044]=85140;v[23220]=0;Y(1159,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468184);v[117046]=86124;v[23220]=0;Y(1160,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468192);v[117048]=86272;v[23220]=0;Y(1161,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468200);v[117050]=86388;v[23220]=0;Y(1162,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468208);v[117052]=86504;v[23220]=0;Y(1163,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468216);v[117054]=86620;v[23220]=0;Y(1164,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468224);v[117056]=86784;v[23220]=0;Y(1165,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468232);v[117058]=86948;v[23220]=0;Y(1166,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468240);v[117060]=87112;v[23220]=0;Y(1167,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468248);v[117064]=88368;v[117064]=85388;v[117062]=85340;v[23220]=0;Y(1168,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468264);v[117068]=88404;v[117068]=85652;v[117066]=85604;v[23220]=0;Y(1169,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}v[23220]=0;Z(1170);a=v[23220];v[23220]=0;if((a|0)==1){break c}v[23220]=0;Y(1171,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}v[23220]=0;Z(1172);a=v[23220];v[23220]=0;if((a|0)==1){break c}v[23220]=0;Y(1173,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468312);v[117078]=87276;v[23220]=0;Y(1174,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rd(468320);v[117080]=87396;v[23220]=0;Y(1175,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break c}break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;ub(d)}bw(c);S(b|0);L()}v[116678]=468328;t[466720]=1;v[116679]=466712;return 466712}function Zha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;d=fb-336|0;fb=d;wc(b);a:{if(!go(b,d+320|0)){break a}if(!HT(d+320|0)){break a}if(!Mb(d+320|0,14139,4)){Yb(b,4)}if(!Xh(b,d+312|0)){break a}if(Mb(d+312|0,14115,4)){break a}if(!c){m=1;break a}JB(b,d+120|0,v[d+316>>2]);if(x[d+156>>1]>128|x[d+162>>1]>16|(x[d+160>>1]>256|x[d+154>>1]>128)){break a}zd(a,8192);i=d+32|0;e=Qb(i,6500);Db(a+1298344|0,e);vb(e);e=Qb(i,10102);Db(a+1298356|0,e);vb(e);v[a+1298404>>2]=5;e=d+96|0;$k(e,2,d+120|0);Ac(i,e);xc(a+1298308|0,i);ub(i);u[d+32>>1]=x[d+162>>1];u[d+96>>1]=1;g=x[Re(i,e)>>1];u[a+480188>>1]=g;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+32|0]=w[d+164|0];t[d+96|0]=64;e=w[Rb(i,e)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}e=w[d+165|0];b:{if((e|0)==128){v[d+32>>2]=256/(g>>>0);v[d+96>>2]=128;l=v[Eb(d+32|0,d+96|0)>>2];break b}l=e&127}v[a+480228>>2]=l;while(1){if((f|0)==16){g=a+484376|0;Mu(Vb(v[a+484360>>2],w[g|0]),d+184|0,x[d+156>>1]);e=x[d+154>>1];if(e>>>0<x[d+156>>1]){Ve(Vb(v[a+484360>>2],w[g|0]),e)}p=c&2;n=a+484344|0;m=1;q=c&1;r=d+68|0;l=a+480190|0;i=a+480188|0;while(1){if(!Xh(b,d+312|0)){break a}c=d+32|0;Qd(c,b,v[d+316>>2]);h=gc(d+96|0,c);wb(c);c:{d:{if(!(Mb(d+312|0,13553,4)|!q)){v[23220]=0;g=o&65535;e=W(213,n|0,g|0,64)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}if(!e){break c}v[23220]=0;Q(175,h|0,2)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}sh(d+32|0);j=0;e:{while(1){c=v[h>>2];v[23220]=0;e=W(143,c|0,v[d+104>>2],1)|0;c=v[23220];v[23220]=0;f:{if((c|0)!=1){if(!(e&j>>>0<64)){break e}v[23220]=0;k=T(193,h|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}if(k){break f}j=j+1|0;continue}break d}f=d+32|0;e=k&15;if(e>>>0<x[i>>1]){c=Xb(v[n>>2],g);f=$c(v[c>>2],v[v[c+48>>2]+12>>2],j,e)}g:{if(!(k&128)){break g}v[23220]=0;e=T(193,h|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}if(!e){break g}t[f|0]=e>>>0<109?e+12|0:e}if(k&64){v[23220]=0;e=T(193,h|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}t[f+1|0]=e}if(k&32){t[f+2|0]=1;v[23220]=0;e=T(193,h|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}t[d+16|0]=e;t[d|0]=64;s=f,y=w[Rb(d+16|0,d)|0],t[s+4|0]=y}if(!(k&16)){continue}v[23220]=0;R(250,d+16|0,h|0);c=v[23220];v[23220]=0;if((c|0)!=1){e=gd(d+16|0);h:{i:{j:{k:{l:{c=w[d+16|0];switch(c-17|0){case 2:break k;case 0:case 1:break l;default:break j}}c=c&15;break i}t[d+16|0]=33;t[e|0]=145;c=w[d+16|0];break h}if(c>>>0<17){break h}c=(c&240)==32?9:-1}t[d+16|0]=c}t[f+3|0]=c;t[f+5|0]=w[e|0];Mf(f);continue}break}break d}o=o+1|0;break c}if(Mb(d+312|0,13558,4)){break c}c=x[l>>1];if(!Ph(c)){break c}e=c+1|0;u[a+480190>>1]=e;v[23220]=0;R(310,h|0,d+32|0);c=v[23220];v[23220]=0;m:{if((c|0)==1){break m}v[23220]=0;e=(B(e&65535,104)+a|0)+484380|0;R(311,d+32|0,e|0);c=v[23220];v[23220]=0;if((c|0)==1){break m}$k(d,2,r);v[23220]=0;R(209,d+16|0,d|0);c=v[23220];v[23220]=0;if((c|0)==1){break m}c=d+16|0;yc(((x[a+480190>>1]<<5)+a|0)+946304|0,c);ub(c);if(!p){break c}j=w[d+45|0]|w[d+46|0]<<8;f=2;c=d+16|0;g=Uc(c,8,1,0,1);n:{if(!(j&64)){f=0;if(!(j&2)){break n}}Qf(g,f)}if(j&4){Eh(g,16)}v[23220]=0;W(206,c|0,e|0,h|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break c}}}a=P()|0;O()|0;wb(h);S(a|0);L()}wb(h);continue}}g=(f<<5)+a|0;Pe(g+480280|0);e=w[(d+f|0)+168|0];if(e>>>0<=128){u[g+480284>>1]=e<<1}f=f+1|0;continue}}fb=d+336|0;return m|0}function Mn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;f=fb-96|0;fb=f;q=Zy(v[a+24>>2],w[a+32|0]);s=hj(q);c=s;e=v[a>>2];d=rd(e,v[a+4>>2]);a:{if(c>>>0>d>>>0){i=fb-32|0;fb=i;c=c-d|0;d=v[Cb(a)>>2];e=v[a+4>>2];b:{if(c>>>0<=(d-e|0)/12>>>0){e=fb-16|0;fb=e;c=st(e,a,c);d=v[c+4>>2];h=v[c+8>>2];while(1){if((d|0)==(h|0)){hc(c);fb=e+16|0}else{JN(d);d=d+12|0;v[c+4>>2]=d;continue}break}break b}d=Cb(a);d=kk(i+8|0,Jm(a,rd(v[a>>2],e)+c|0),rd(v[a>>2],v[a+4>>2]),d);h=fb-16|0;fb=h;e=PP(h,d+8|0,c);c=v[e>>2];while(1){if(v[e+4>>2]!=(c|0)){JN(c);c=v[e>>2]+12|0;v[e>>2]=c;continue}break}Ed(e);fb=h+16|0;h=v[a>>2];c=v[a+4>>2];e=d+4|0;while(1){if((c|0)!=(h|0)){c=c-12|0;Nz(v[e>>2]-12|0,c);v[e>>2]=v[e>>2]-12;continue}break}kc(a,e);kc(a+4|0,d+8|0);kc(Cb(a),vc(d));v[d>>2]=v[d+4>>2];c=v[d+4>>2];while(1){e=v[d+8>>2];if((e|0)!=(c|0)){e=e-12|0;v[d+8>>2]=e;Ie(e);continue}break}c=v[d>>2];if(c){Jo(d);Fb(c)}}fb=i+32|0;break a}if(d>>>0>c>>>0){ON(a,e+B(c,12)|0)}}if(b){c=a+12|0;zp(c,Od(c));z=Cb(c),A=0,v[z>>2]=A;d=c;c=fc(c);v[d>>2]=c;v[c>>2]=0;v[a+28>>2]=0}i=Ib(f+80|0);c=v[a+24>>2];c=Zs(v[c+484344>>2],v[c+484348>>2]);v[23220]=0;h=W(566,f- -64|0,c|0,30220)|0;c=v[23220];v[23220]=0;c:{if((c|0)!=1){e=a+12|0;d:{while(1){if((k|0)==(s|0)){ld(h);$b(i);fb=f+96|0;return}c=v[a+24>>2];m=x[ac(v[q>>2],k)>>1];d=UN(c,m);v[f+60>>2]=d;c=Dd(v[a>>2],k);e:{f:{if(b){v[23220]=0;t[f+40|0]=0;U(738,c|0,d|0,f+40|0);d=v[23220];v[23220]=0;if((d|0)!=1){break f}d=P()|0;O()|0;break d}v[23220]=0;R(694,c|0,d|0);d=v[23220];v[23220]=0;if((d|0)==1){break e}}v[23220]=0;d=Q(300,q|0,k&65535)|0;g=v[23220];v[23220]=0;if((g|0)==1){break e}g:{if(!d){break g}v[f+40>>2]=b?0:v[c+4>>2];r=v[Eb(f+40|0,f+60|0)>>2];o=wf(e);c=x[ac(v[h>>2],m)>>1];if((c|0)!=65535){d=SN(e,x[Tl(f+40|0,c,r)>>1],v[f+44>>2]);h:{if(vg(d,wf(e))){c=SN(e,x[Tl(f+40|0,x[ac(v[h>>2],m)>>1],v[f+60>>2])>>1],v[f+44>>2]);break h}c=wf(e)}v[f+56>>2]=d;while(1){i:{if(!vg(d,c)){break g}g=Ib(f+40|0);d=Hm(pd(d)+8|0);v[23220]=0;R(739,g|0,d|0);d=v[23220];v[23220]=0;if((d|0)!=1){d=mj(f+24|0,o);j=Tl(f+16|0,k,v[pd(v[f+56>>2])+4>>2]);d=v[d>>2];v[23220]=0;d=fa(740,e|0,d|0,j|0,g|0)|0;j=v[23220];v[23220]=0;if((j|0)==1){break i}v[f+32>>2]=d;o=v[Rg(f+32|0)>>2];Wd(g);d=v[Rg(f+56|0)>>2];continue}}break}d=P()|0;O()|0;Wd(g);break d}p=Xb(v[v[a+24>>2]+484344>>2],m);c=zg(v[v[p+48>>2]+12>>2]);v[23220]=0;t[f+40|0]=0;U(718,i|0,c|0,f+40|0);c=v[23220];v[23220]=0;if((c|0)!=1){n=v[f+60>>2];j:while(1){k:{if((n|0)==(r|0)){if(r){break g}z=ac(v[h>>2],m),A=k,u[z>>1]=A;break g}g=1;j=0;c=v[v[p+48>>2]+12>>2];n=n-1|0;d=Of(v[p>>2],c,n);while(1){if(g>>>0<16&zg(c)>>>0>j>>>0){y=Hb(v[i>>2],j);c=w[y|0];l:{m:{n:{switch(w[d+3|0]-19|0){case 1:l=w[d+5|0];if((l&240)==176){break m}break l;case 0:break n;default:break l}}l=w[d+5|0];if((l&240)!=96){break l}}t[y|0]=l&15;l=w[Hb(v[i>>2],j)|0];c=l?l:c}c=c&255;g=B(c?c+1|0:1,g);d=d+6|0;j=j+1|0;c=v[v[p+48>>2]+12>>2];continue}else{o:{if(g>>>0<=1){continue j}c=Ib(f+40|0);v[23220]=0;R(739,c|0,g|0);d=v[23220];v[23220]=0;if((d|0)==1){break o}d=mj(f+8|0,o);g=Tl(f+16|0,k,n);d=v[d>>2];v[23220]=0;o=fa(740,e|0,d|0,g|0,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break k}Wd(c);continue j}}break}}break}d=P()|0;O()|0;Wd(c);break d}d=P()|0;O()|0;break d}k=k+1|0;continue}break}d=P()|0;O()|0}ld(h);break c}d=P()|0;O()|0}$b(i);S(d|0);L()}function Eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-128|0;fb=f;a:{b:{if(Lb(v[c>>2],v[c+8>>2],8)){Yb(c,4);while(1){if(Nt(v[c>>2],v[c+8>>2])){break b}m=fb-288|0;fb=m;e=iO(m);i=fb-384|0;fb=i;j=nc(e,iO(i+96|0),282);e=0;c:{d:{e:{f:{g:{if(wh(c,13618)){jg(c,4);h=fe(i+72|0,c);v[23220]=0;k=Q(729,h|0,j|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break g}h:{if(!k){break h}k=v[h+8>>2];g=v[h>>2];l=w[j+26|0];v[23220]=0;k=W(143,g|0,k|0,l|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break g}if(!k){break h}k=0;i:{while(1){if(w[j+26|0]<=e>>>0){g=v[h+8>>2];l=v[h>>2];e=0;v[23220]=0;k=k&65535;g=W(143,l|0,g|0,k|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break e}if(!g){break h}v[23220]=0;Q(175,h|0,k|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break e}jg(h,jO(j));e=lh(i- -64|0);g=i+96|0;$y(g);v[23220]=0;R(730,h|0,g|0);g=v[23220];v[23220]=0;if((g|0)!=1){u[i+118>>1]=0;u[i+120>>1]=0;e=bz(e,i+96|0,i+123|0);g=w[j+26|0];v[23220]=0;Q(175,h|0,g|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){break i}}e=P()|0;O()|0;break d}v[23220]=0;g=T(185,h|0)|0;l=v[23220];v[23220]=0;if((l|0)!=1){t[(e+j|0)+27|0]=g;e=e+1|0;k=g+k|0;continue}break}e=P()|0;O()|0;break d}l=e;e=j+27|0;l=bz(l,e,e+w[j+26|0]|0);v[23220]=0;U(177,i+16|0,h|0,k|0);e=v[23220];v[23220]=0;if((e|0)==1){break f}g=i+16|0;k=gc(i+40|0,g);wb(g);e=0;v[23220]=0;R(520,g|0,k|0);g=v[23220];v[23220]=0;if((g|0)==1){e=P()|0;O()|0;wb(k);break d}g=i+16|0;XB(i+8|0,g);n=l;l=v[i+8>>2];l=bz(n,l,Hb(l,v[i+12>>2]));Jc(g);wb(k);if(v[l>>2]!=(w[j+22|0]|w[j+23|0]<<8|(w[j+24|0]<<16|w[j+25|0]<<24))){break h}e=jO(j);v[23220]=0;Q(175,c|0,e|0)|0;j=v[23220];v[23220]=0;e=1;if((j|0)==1){break e}}wb(h)}fb=i+384|0;break c}e=P()|0;O()|0;break d}e=P()|0;O()|0;break d}e=P()|0;O()|0}wb(h);S(e|0);L()}fb=m+288|0;if(e){continue}break}}wc(c);hg(b,a,c);a=1;break a}t[d|0]=1;wc(c);e=mg(c);d=f+80|0;Qd(d,c,Ze(c));i=gc(f+104|0,d);wb(d);b=x[a+34>>1]&-66|w[b|0]>15|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=e>>>(b&1)>>>(b>>>6&1);v[f+76>>2]=0;v[f+72>>2]=0;v[23220]=0;R(520,d|0,i|0);b=v[23220];v[23220]=0;j:{k:{l:{m:{if((b|0)!=1){c=te(f+80|0);e=v[f+80>>2];j=iA(c,ui(e),f+76|0,f+72|0);v[23220]=0;b=v[f+76>>2];Q(175,i|0,b|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){if(!j){break j}wg(a);d=b+c|0;b=e-b|0;e=v[f+72>>2];c=0;while(1){n:{if(e){if(!b|(e|0)!=1){break k}e=v[a>>2];if(e>>>0>c>>>0){break n}break k}e=v[a>>2];if(e>>>0<=c>>>0){break k}}if(!Md(e,v[a+20>>2])){break k}v[f+68>>2]=0;v[f+64>>2]=0;k=LR(j,d,ui(b),f+68|0,f+60|0,f- -64|0);v[23220]=0;Q(175,i|0,k|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break m}Uh(f- -64|0,ui(v[a>>2]-c|0));e=v[f+64>>2];o:{if((e|0)<=0){break o}h=v[f+68>>2];l=x[a+34>>1];if((Cd(l)|0)!=(h|0)){break o}m=B(c,h);g=v[a+20>>2];if(l&1){h=Qg(f+48|0,g+(m<<1)|0,h,e);m=v[Qg(f+32|0,v[f+60>>2],v[f+68>>2],e)>>2];h=v[h>>2];v[23220]=0;ka(521,h|0,v[f+52>>2],v[f+56>>2],m|0,v[f+36>>2],v[f+40>>2]);h=v[23220];v[23220]=0;if((h|0)!=1){break o}break m}h=Qg(f+16|0,g+m|0,h,e);m=v[Qg(f,v[f+60>>2],v[f+68>>2],e)>>2];h=v[h>>2];v[23220]=0;ka(522,h|0,v[f+20>>2],v[f+24>>2],m|0,v[f+4>>2],v[f+8>>2]);h=v[23220];v[23220]=0;if((h|0)==1){break m}}b=b-k|0;d=d+k|0;c=c+e|0;e=KR(j);continue}}break m}c=P()|0;O()|0;break l}c=P()|0;O()|0;Jc(f+80|0)}wb(i);S(c|0);L()}JR(j)}Jc(f+80|0);wb(i);a=(j|0)!=0}fb=f+128|0;return a|0}function Ida(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=fb-192|0;fb=e;wc(b);a:{if(!VA(b,e+144|0)){break a}if(!eQ(e+144|0)){break a}if(!Lb(v[b>>2],v[b+8>>2],Pc(dQ(w[e+175|0],w[e+177|0]),ib))){break a}b:{if(!c){break b}zd(a,256);g=e+32|0;rj(g,2,e+144|0);d=e- -64|0;Ac(d,g);xc(a+1298308|0,d);ub(d);f=Qb(d,15304);Db(a+1298344|0,f);vb(f);d=Qb(d,10081);Db(a+1298356|0,d);vb(d);og(g,4232);v[23220]=0;R(239,e+128|0,e+175|0);d=v[23220];v[23220]=0;c:{d:{if((d|0)!=1){v[23220]=0;X(636,e- -64|0,e+32|0,e+174|0,e+128|0);d=v[23220];v[23220]=0;if((d|0)!=1){d=e- -64|0;Db(a+1298368|0,d);vb(d);vb(e+128|0);bc(e+32|0);v[a+1298404>>2]=5;d=Kb(a+1074312|0,107,1);v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;Kb(d,107,1);f=w[e+176|0];d=w[e+175|0];if(d>>>0<=20){g=((f&255)>>>0)/10|0;f=g<<4|B(g,-10)+f}g=(f&255?f:96)&255;f=Lz(g);v[a+480196>>2]=g>>>4;v[a+480204>>2]=f;f=0;if(d>>>0>=11){t[e+64|0]=64;o=a,p=w[Rb(e+178|0,e- -64|0)|0]<<2,v[o+480200>>2]=p}while(1)if((f|0)==4){f=1;while(1){if((f|0)!=32){zt(b,e+32|0);d=w[e+44|0];if(d?(d|0)!=46:0){break c}h=fb-32|0;fb=h;d=(B(f,104)+a|0)+484380|0;kd(d,0);k=e+32|0;g=k;ak(h,2,g);i=h+16|0;Ac(i,h);ue(d+43|0,i);ub(i);v[d+24>>2]=w[g+24|0]|w[g+25|0]<<8;t[h+16|0]=w[g+22|0];t[h|0]=64;o=d,p=w[Rb(i,h)|0]<<2,u[o+30>>1]=p;i=w[g+16|0]|w[g+17|0]<<8;v[d>>2]=i;j=w[g+18|0]|w[g+19|0]<<8;v[d+4>>2]=j;g=w[g+20|0]|w[g+21|0]<<8;v[d+8>>2]=g;e:{if(i>>>0<=1){v[d>>2]=0;break e}if((g|0)==65535|i>>>0<=j>>>0|g>>>0<=j>>>0){break e}u[d+34>>1]=2;o=d,p=v[Eb(d+8|0,d)>>2],v[o+8>>2]=p}fb=h+32|0;g=e+16|0;ak(g,2,k);d=e+128|0;Ac(d,g);yc(((f<<5)+a|0)+946304|0,d);ub(d);u[((f<<1)+e|0)+62>>1]=x[e+46>>1];f=f+1|0;continue}break}d=a+484376|0;fo(Vb(v[a+484360>>2],w[d|0]),b,w[e+175|0]?128:64,65535,65535);f=0;if(!bQ(Vb(v[a+484360>>2],w[d|0]))){break a}m=c&1;if(m){ig(a+484344|0,w[e+177|0])}i=a+484344|0;while(1){if(w[e+177|0]<=l>>>0){f=1;if(!(c&2)){break a}c=Uc(e+32|0,8,1,0,0);while(1){if((f|0)==32){break b}d=B(f,104)+a|0;g=d+484380|0;f:{if(!v[g>>2]|!x[d+484410>>1]){break f}d=x[((f<<1)+e|0)+62>>1];if(d>>>0<4){break f}if(!Vc(b,d<<4)){break f}hg(c,g,b)}f=f+1|0;continue}}f=0;g:{h:{if(m){if(Xg(i,l&65535,64)){break h}}while(1){if((f|0)==256){break g}if((Ae(b)+2&255)>>>0<=252){Yb(b,3)}f=f+1|0;continue}}o=e,p=Ab(v[Xb(v[i>>2],l)>>2]),v[o+128>>2]=p;u[e+14>>1]=65535;v[e+16>>2]=63;h=0;i:while(1){f=0;if((h|0)==64){d=x[e+14>>1];if((d|0)==65535){break g}me(Xb(v[i>>2],l),im(He(Be(e+32|0,12,d&255),v[e+16>>2])));break g}while(1){j:{k:{l:{if((f&65535)>>>0<=3){d=0;j=0;k=0;n=0;m:{n:{o:{p:{g=Ae(b);switch(g-251|0){case 1:break j;case 0:break n;case 2:break p;default:break o}}t[v[e+128>>2]]=254;break j}d=e+32|0;Dq(d,b);j=w[Hb(d,0)|0];k=w[Hb(d,1)|0];n=w[Hb(d,2)|0];d=254;if((g|0)==254){break m}if(g>>>0>=96){break l}d=g}d=(B(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=v[e+128>>2];t[d|0]=g;break k}h=h+1|0;continue i}d=v[e+128>>2]}t[d+1|0]=(j&248)>>>3;g=k>>>1&120|j&7;if(g>>>0<=64){t[d+4|0]=g;t[d+2|0]=1}t[d+5|0]=n;t[d+3|0]=k&15;aQ(d,h,w[e+175|0],e+14|0,e+16|0)}f=f+1|0;Vz(e+128|0);continue}}}l=l+1|0;continue}}else{d=(f<<5)+a|0;Pe(d+480280|0);u[d+480284>>1]=f&1?64:192;f=f+1|0;continue}}f=P()|0;O()|0;vb(e+128|0);break d}f=P()|0;O()|0}bc(e+32|0);S(f|0);L()}f=0;break a}f=1}fb=e+192|0;return f|0}function ty(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0,C=0,D=0,E=0;f=fb-16|0;fb=f;k=B(b,872)+a|0;m=k+1075800|0;i=w[m|0];l=a+1074312|0;xb(f+8|0,l,23);h=c&15;a:{b:{c:{if(yb(v[v[f+8>>2]>>2],v[f+12>>2])){if(!(v[a+1074392>>2]|!w[(B(b,872)+a|0)+1075780|0])){t[m|0]=h;break c}e=w[m|0];if(e){g=e-1|0;t[m|0]=g;e=0;if(g&255){break c}}t[m|0]=h;e=1;break c}xb(f+8|0,l,52);d:{e:{g=c&256;if(!(!g|!yb(v[v[f+8>>2]>>2],v[f+12>>2]))){g=v[a+480208>>2]&4096;if(!g){break e}e=B(b,872)+a|0;if(w[e+1075781|0]){i=ZS(w[e+1075780|0])?1:i}if(w[(B(b,872)+a|0)+1075784|0]?w[e+1075782|0]==1:0){break b}e=0;if(h>>>0>i>>>0){break c}if(!g){break d}if(Oc(w[(B(b,872)+a|0)+1075780|0])){break c}break d}j=v[a+480180>>2];if(j&16777250){e=!(i?(i>>>0)%((h?h:1)>>>0)|0:1);i=i+1|0;break c}f:{if((j|0)!=16){if((j|0)!=1){break f}g=y[a+1074392>>2]%y[a+1074416>>2]|0;if(!g){if(Oc(w[(B(b,872)+a|0)+1075780|0])){break a}}e=h?!((g>>>0)%(h>>>0)|0):e;break c}e=v[a+1074392>>2]==(h|0)&(h|0)!=0;break c}g:{if(!g){break g}e=B(b,872)+a|0;if(w[e+1075782|0]!=1){break g}h=(w[e+1075785|0]>15)+h|0}h:{if(v[a+480208>>2]&4096?g:1){h=h?h:1;e=0;e=!v[a+1074416>>2]|g?e:!(y[a+1074392>>2]%(h>>>0)|0);i=i+1|0;break h}e=0;i=j&1048580?0:i}if(!(!(w[(B(b,872)+a|0)+1075780|0]|!g?v[a+1074392>>2]:1)|(i&255)>>>0<h>>>0)){e=1}xb(f+8|0,l,52);if(!yb(v[v[f+8>>2]>>2],v[f+12>>2])|c){break c}e=!v[a+1074392>>2];break c}if(h>>>0>i>>>0){break c}}i=0;e=1}h=k+1074992|0;n=(B(b,872)+a|0)+1075068|0;i:{if(v[n>>2]){break i}xb(f+8|0,l,38);if(!yb(v[v[f+8>>2]>>2],v[f+12>>2])){break i}if(!Qj(v[h+656>>2])){break a}}xb(f+8|0,l,106);if(C=0,D=yb(v[v[f+8>>2]>>2],v[f+12>>2]),E=v[(B(b,872)+a|0)+1075688>>2],E?C:D){break a}if(e){j=B(b,872)+a|0;q=j+1075680|0;g=v[q>>2];v[f+4>>2]=g;e=c>>>4&15;j:{if(!e){e=v[j+1075080>>2];break j}xb(f+8|0,l,52);k:{if(C=yb(v[v[f+8>>2]>>2],v[f+12>>2]),D=0,E=w[(B(b,872)+a|0)+1075782|0]==1,E?C:D){break k}if(!(16191>>>e&1)){v[f+4>>2]=(B(g,t[e+33856|0])|0)/16;break k}v[f+4>>2]=g+(t[e+33872|0]<<2)}ee(f+4|0,0,256);g=(B(b,872)+a|0)+1075080|0;e=v[g>>2]|2097152;v[g>>2]=e}k=B(b,872)+a|0;r=k+1075692|0;s=v[r>>2];g=w[k+1075794|0];j=0;if(e&512){xb(f+8|0,l,108);j=yb(v[v[f+8>>2]>>2],v[f+12>>2])}if(!((j^-1)&v[a+480180>>2]==2|(!v[n>>2]|(g-1&255)>>>0>119))){DM(a,b,0,g,1)}k=k+1075080|0;l:{if(!(v[a+480180>>2]&1048580)){break l}u=(c|0)<256;if((c|0)>255){break l}e=w[(B(b,872)+a|0)+1075781|0];if(!e){break l}u=1;wp(a,h,e,0,0,1)}o=B(b,872)+a|0;p=o+1075652|0;z=v[p>>2];A=v[k>>2];v[p>>2]=0;xb(f+8|0,l,23);e=1;m:{if(yb(v[v[f+8>>2]>>2],v[f+12>>2])){break m}e=0;if(v[a+480180>>2]!=2){break m}e=(j^1)&v[n>>2]!=0}Ss(a,h,g,e,u,0,b);if(!w[o+1075781|0]){v[p>>2]=z}if(!(!(A&4096)|v[a+480180>>2]!=4)){v[k>>2]=v[k>>2]|4096}j=o+1075780|0;v[q>>2]=v[f+4>>2];if(x[a+480192>>1]){t[j|0]=g;BM(a,b)}g=v[a+480180>>2];if(!(!(g&16777248)|(w[j|0]|!s))){v[r>>2]=s}if(e){v[h>>2]=0;v[h+4>>2]=0}e=g&16777250;n:{if(d-11>>>0<4294967286){break n}g=v[(B(b,872)+a|0)+1075096>>2];if(!g){break n}o:{if((d|0)==1){b=v[(B(b,872)+a|0)+1075656>>2];break o}j=(B(b,872)+a|0)+1075656|0;b=v[zb(g+68|0,d-2|0)>>2];v[j>>2]=b}Kn(a,h,b)}i=e?i:0}a=f+8|0;xb(a,l,52);b=v[v[f+8>>2]>>2];d=v[f+12>>2];xb(a,l,23);if(yb(v[v[f+8>>2]>>2],v[f+12>>2])){break a}i=(yb(b,d)&c>>>8)+i|0}t[m|0]=i}fb=f+16|0}function aaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-112|0;fb=e;h=a+140|0;qj(e+88|0,h,1296125513);v[23220]=0;f=T(165,v[e+88>>2])|0;g=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((g|0)!=1){if(f){f=Gb(e+32|0);v[23220]=0;g=T(147,v[e+88>>2])|0;i=v[23220];v[23220]=0;if((i|0)==1){break p}v[23220]=0;U(748,e+88|0,f|0,g|0);g=v[23220];v[23220]=0;if((g|0)==1){break p}g=x[a+174>>1];v[23220]=0;U(749,e+72|0,g|0,f|0);g=v[23220];v[23220]=0;if((g|0)==1){break o}v[23220]=0;U(8,e+8|0,c|0,e+72|0);c=v[23220];v[23220]=0;if((c|0)==1){break n}c=e+8|0;yc(d,c);ub(c);vb(e+72|0);ub(f)}if(w[a+176|0]){v[23220]=0;R(750,e+32|0,d|0);c=v[23220];v[23220]=0;if((c|0)==1){break e}c=e+32|0;ue(b+43|0,c);ub(c)}v[23220]=0;U(743,e+32|0,h|0,1413894985);c=v[23220];v[23220]=0;if((c|0)==1){break l}v[23220]=0;f=T(751,e+32|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break k}h=e+32|0;wb(h);c=a+40|0;wc(c);v[23220]=0;h=Q(752,c|0,h|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break j}if(h){q:{if(y[e+60>>2]<2){break q}v[23220]=0;h=Q(753,c|0,e+8|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break i}if(!h){break q}tL(e+8|0,b+12|0,b+16|0,v[b>>2],b+34|0,8,16,f)}v[23220]=0;c=Q(753,c|0,e+8|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break i}if(c){tL(e+8|0,b+4|0,b+8|0,v[b>>2],b+34|0,2,4,f)}c=v[e+44>>2];t[b+42|0]=c&128?0:c+1|0;hk(b)}r:{if(w[b+42|0]){break r}c=v[a+60>>2];v[23220]=0;c=Q(615,c|0,7)|0;f=v[23220];v[23220]=0;if((f|0)==1){break j}if(!c){break r}c=a+60|0;wc(c);v[23220]=0;c=Q(754,c|0,e+8|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break d}if(!c){break r}c=t[e+8|0];t[b+42|0]=(c|0)<0?0:c+1|0}c=v[a+120>>2];v[23220]=0;c=T(165,c|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break j}if(!c){break f}v[23220]=0;g=a+120|0;c=T(144,g|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break c}v[e+72>>2]=c;uc(e+72|0,9);f=b+68|0;h=v[e+72>>2];c=0;while(1){if((c|0)==(h|0)){break g}v[23220]=0;R(755,g|0,e+8|0);i=v[23220];v[23220]=0;if((i|0)==1){break h}j=zb(f,c),k=v[e+12>>2],v[j>>2]=k;c=c+1|0;continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}a=P()|0;O()|0;vb(e+72|0)}ub(f);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;wb(e+32|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}Pz(f+(h<<2)|0,SS(f),42840)}a=a+80|0;wc(a);v[23220]=0;c=Q(756,a|0,e+8|0)|0;f=v[23220];v[23220]=0;s:{if((f|0)==1){break s}if(!c){break b}if(w[e+8|0]&32){u[b+34>>1]=x[b+34>>1]|32}u[e+72>>1]=x[e+12>>1];u[e+6>>1]=256;j=b,k=x[Tc(e+72|0,e+6|0)>>1],u[j+28>>1]=k;u[e+72>>1]=x[e+14>>1];u[e+6>>1]=256;j=b,k=x[Tc(e+72|0,e+6|0)>>1],u[j+30>>1]=k;u[e+72>>1]=x[e+16>>1];u[e+6>>1]=64;j=b,k=x[Tc(e+72|0,e+6|0)>>1],u[j+32>>1]=k;t[b+38|0]=w[e+20|0];t[b+39|0]=w[e+21|0];t[b+40|0]=w[e+22|0];t[b+41|0]=w[e+23|0];c=v[a+8>>2];f=v[a>>2];v[23220]=0;c=W(143,f|0,c|0,32)|0;f=v[23220];v[23220]=0;if((f|0)==1){break s}if(!c){break b}v[23220]=0;R(757,a|0,d|0);c=v[23220];v[23220]=0;if((c|0)==1){break s}v[23220]=0;c=T(189,a|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break s}v[23220]=0;U(758,a|0,b+43|0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}wb(e+88|0);fb=e+112|0;return}wb(e+88|0);S(a|0);L()}function YJ(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=0,i=0,j=0,k=0,l=C(0),m=C(0),n=0,o=C(0),p=0,q=C(0),r=C(0),s=C(0),u=0,w=C(0);j=fb-16|0;fb=j;b=a+4208|0;i=kj(C(z[zb(b,12)>>2]*C(3)));v[a+4264>>2]=i;d=C(v[v[a+16>>2]+24620>>2]>>>((i>>>1^-1)&1)>>>0);z[a+4268>>2]=d;u=a,w=C(C(z[zb(b,9)>>2]*C(100))*C(.0061803399585187435)),z[u+4272>>2]=w;u=j,w=ie(C(10),C(C(XJ(a)+C(C(z[zb(b,5)>>2]*C(11e3))+C(-1e4)))/C(2e3))),z[u+12>>2]=w;v[j+8>>2]=1065353216;u=a,w=C(z[Hl(j+12|0,j+8|0)>>2]*C(.7609999775886536)),z[u+4280>>2]=w;c=ie(C(10),C(C(C(C(z[zb(b,1)>>2]*C(1e4))+C(-1e4))/C(100))/C(10)));if(c!=C(1)){d=gp(C(C(WJ(a)*C(6.2831854820251465))/d));f=C(c+c);e=C(c*c);c=Ny(C(C(C(C(d*f)+C(-2))+C(K(C(C(C(C(d*C(C(d*e)*C(4)))+C(c*C(8)))-C(e*C(4)))-C(C(d*c)*C(8))))))/C(f+C(-2))),C(0),C(1))}else{c=C(0)}z[a+4276>>2]=c;i=fb-16|0;fb=i;c=z[a+4268>>2];b=a+4208|0;d=C(z[zb(b,6)>>2]*C(.30000001192092896));u=i,w=C(z[zb(b,8)>>2]*C(.10000000149011612)),z[u+12>>2]=w;v[i+8>>2]=1000593162;f=z[xx(i+12|0,i+8|0)>>2];e=C(c*C(C(d+f)+C(.007000000216066837)));a:{if(C(D(e))<C(2147483648)){b=~~e;break a}b=-2147483648}v[a+4352>>2]=b;b=1;while(1){if((b|0)==12){u=i,w=C(C(C(C(z[zb(a+4208|0,10)>>2]*C(100))/C(100))+C(.10000000149011612))*C(.9090999960899353)),z[u+12>>2]=w;v[i+8>>2]=1065353216;d=z[Hl(i+12|0,i+8|0)>>2];f=C(c*C(C(d*C(75))/C(1e3)));d=C(c*C(C(d*C(67))/C(1e3)));b=0;while(1){if((b|0)==6){h=a+4348|0;d=C(c*C(.0035299998708069324));b:{if(C(D(d))<C(2147483648)){b=~~d;break b}b=-2147483648}v[h>>2]=b;h=a+4344|0;d=C(c*C(.0032500000670552254));c:{if(C(D(d))<C(2147483648)){b=~~d;break c}b=-2147483648}v[h>>2]=b;h=a+4340|0;c=C(c*C(.009999999776482582));d:{if(C(D(c))<C(2147483648)){b=~~c;break d}b=-2147483648}v[h>>2]=b}else{h=(b<<2)+a|0;p=h+4316|0;n=b+n|0;e=ie(C(.9300000071525574),C(n|0));g=C(f*e);e:{if(C(D(g))<C(2147483648)){k=~~g;break e}k=-2147483648}v[p>>2]=k;k=h+4292|0;e=C(d*e);f:{if(C(D(e))<C(2147483648)){h=~~e;break f}h=-2147483648}v[k>>2]=h;b=b+1|0;continue}break}b=0;while(1){if((b|0)!=15){$J((B(b,24)+a|0)+4504|0,v[((b<<2)+a|0)+4292>>2]);b=b+1|0;continue}break}fb=i+16|0}else{k=((B(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=C(c*C(C(f*z[(b<<2)+47056>>2])+d));g:{if(C(D(e))<C(2147483648)){h=~~e;break g}h=-2147483648}v[k>>2]=h;b=b+1|0;continue}break}b=fb-16|0;fb=b;d=gh(a,5);e=gh(a,11);c=C(d*gh(a,4));d=C(C(c*C(.03999999910593033))+C(C(d*C(.02250000089406967))+C(0)));f=C(e*gh(a,10));e=C(C(f*C(.03999999910593033))+C(C(e*C(.02250000089406967))+C(0)));if(t[a+4264|0]&1){g=gh(a,3);l=gh(a,9);g=C(c*g);c=C(g*gh(a,2));d=C(C(c*C(.1444000005722046))+C(C(g*C(.12250000238418579))+d));g=C(f*l);f=C(g*gh(a,8));e=C(C(f*C(.1444000005722046))+C(C(g*C(.12250000238418579))+e))}gh(a,12);g=z[a+4496>>2];l=gh(a,1);m=gh(a,7);q=gh(a,0);r=gh(a,6);u=b,w=ie(C(10),C(C(XJ(a)+C(C(z[zb(a+4208|0,7)>>2]*C(12e3))+C(-1e4)))/C(2e3))),z[u+12>>2]=w;v[b+8>>2]=1065353216;o=z[Hl(b+12|0,b+8|0)>>2];s=c;c=C(g*g);g=C(l*C(s*c));l=C(q*g);c=C(m*C(f*c));f=C(r*c);m=C(C(C(l+f)*C(-.5))+C(1));z[a+4284>>2]=o*C(K(C(m/C(C(l*C(.1444000005722046))+C(C(c*C(.1444000005722046))+d)))));z[a+4288>>2]=o*C(K(C(m/C(C(f*C(.1444000005722046))+C(C(g*C(.1444000005722046))+e)))));fb=b+16|0;t[a+5046|0]=0;fb=j+16|0}function mM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0;if(b){h=a+327720|0;c=fb-400|0;fb=c;gO(c+384|0,8);v[23220]=0;qa(731,c+368|0,9);i=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((i|0)!=1){v[23220]=0;i=Q(732,c+352|0,14)|0;e=v[23220];v[23220]=0;if((e|0)==1){break l}v[23220]=0;R(733,c+384|0,i|0);e=v[23220];v[23220]=0;if((e|0)==1){break k}v[23220]=0;R(733,c+368|0,i|0);e=v[23220];v[23220]=0;if((e|0)==1){break k}fO(c+280|0,4900);fO(c+208|0,32e3);ZN(c+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[23220]=0;e=Q(734,c+104|0,c+384|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break j}bt(c+120|0,c+280|0,e);Wd(e);v[23220]=0;e=Q(734,c+72|0,c+368|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break i}bt(c+88|0,c+208|0,e);Wd(e);v[23220]=0;e=Q(734,c+40|0,c+120|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break h}bt(c+56|0,c+136|0,e);Wd(e);v[23220]=0;e=Q(734,c+8|0,c+88|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break g}g=c+24|0;bt(g,c+136|0,e);Wd(e);e=c+120|0;Cp(e);l=c+56|0;Cp(l);m=c+88|0;Cp(m);Cp(g);p=c+368|0;Cp(p);Bp(v[c+120>>2],v[c+124>>2],Nn(h,0));Bp(v[c+56>>2],v[c+60>>2],Nn(h,1));Bp(v[c+88>>2],v[c+92>>2],Nn(h,2));Bp(v[c+24>>2],v[c+28>>2],Nn(h,3));Bp(v[c+368>>2],v[c+372>>2],Nn(h,4));Wd(g);Wd(l);Wd(m);Wd(e);Yj(i);Wd(p);Wd(c+384|0);fb=c+400|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;Wd(c+56|0)}Wd(c+88|0)}Wd(c+120|0)}Yj(i)}Wd(c+368|0)}Wd(c+384|0);S(a|0);L()}Vx(a+131112|0,9.6377,.97);Vx(a+196648|0,8.5,.5);Vx(a+262184|0,2.7625,.425)}c=a+368680|0;if(!(t=0,x=wL(c,a),y=b,y?t:x)){e=a+24|0;r=A[a+8>>3];g=w[a+16|0];h=fb+-64|0;fb=h;m:while(1){if((n|0)!=8193){s=+(n-4096|0)*.0001220703125;b=0;o=0;while(1)if((b|0)==8){j=1/o;l=n<<3;b=0;while(1)if((b|0)==8){n=n+1|0;continue m}else{m=e+(b+l<<1)|0;d=H(A[h+(b<<3)>>3]*32768*j+.5);d=d<-32768?-32768:F(d,32768);n:{if(D(d)<2147483648){i=~~d;break n}i=-2147483648}u[m>>1]=i;b=b+1|0;continue}}else{j=r;f=1;d=+(b|0)-s;q=d+-3.5;if(!(D(q)<1e-8)){o:{p:{switch(g|0){case 0:f=Me(d*.8975979010256552)*-.5+.5;break o;case 1:f=Me(d*.8975979010256552)*-.46+.54;break o;case 2:f=Me(d*1.7951958020513104)*.08+(Me(d*.8975979010256552)*-.5+.42);break o;case 3:f=Me(d*1.7951958020513104)*.05677+(Me(d*.8975979010256552)*-.49364+.44959);break o;case 4:f=Me(d*1.7951958020513104)*.07922+(Me(d*.8975979010256552)*-.49755+.42323);break o;case 5:f=Me(d*1.7951958020513104);k=Me(d*.8975979010256552);f=Me(d*2.6927937030769655)*-.01168+(f*.14128+(k*-.48829+.35875));break o;case 6:f=Me(d*1.7951958020513104);k=Me(d*.8975979010256552);f=Me(d*2.6927937030769655)*-.00183+(f*.09392+(k*-.49703+.40217));break o;case 7:break p;default:break o}}f=Me(d*1.7951958020513104);k=Me(d*.8975979010256552);f=Me(d*2.6927937030769655)*-.00122+(f*.09831+(k*-.49804+.40243))}d=q*3.141592653589793;j=qi(d*j)/d}j=f*j;A[h+(b<<3)>>3]=j;o=o+j;b=b+1|0;continue}}break}fb=h- -64|0;b=v[a+20>>2];v[c+16>>2]=v[a+16>>2];v[c+20>>2]=b;b=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=b;b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b}}function zga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=fb-224|0;fb=f;Yd(f+208|0,b);g=fb-48|0;fb=g;v[g+44>>2]=0;_j(b,g+44|0);a:{b:{c:{if(v[g+44>>2]!=(rm(14079)|0)){break c}v[g+40>>2]=0;e=fb-32|0;fb=e;v[e+24>>2]=0;zv(e+8|0,e+24|0);cn(e+16|0,b,v[e+8>>2],v[e+12>>2]);v[g+40>>2]=v[e+24>>2];fb=e+32|0;e=-1;i=v[g+40>>2];if(i-3>>>0<4294967294){break c}d:{e:{f:{if(i>>>0<=1){i=Gb(g+24|0);v[23220]=0;h=W(438,b|0,i|0,256)|0;j=v[23220];v[23220]=0;if((j|0)==1){break b}if(!h){break e}v[23220]=0;U(11,g+8|0,d|0,i|0);h=v[23220];v[23220]=0;if((h|0)!=1){break f}break b}i=Gb(g+24|0);v[23220]=0;h=Q(440,b|0,i|0)|0;j=v[23220];v[23220]=0;if((j|0)==1){break b}if(!h){break d}v[23220]=0;U(11,g+8|0,d|0,i|0);h=v[23220];v[23220]=0;if((h|0)==1){break b}}h=g+8|0;Db(c,h);vb(h);ub(i);If(b,h);i=0;v[g+24>>2]=0;_j(b,g+24|0);h=v[g+24>>2];if(h>>>0>50){break c}while(1){if((h|0)!=(i|0)){if(!QK(a,b,d)){break c}i=i+1|0;continue}break}v[g+24>>2]=0;_j(b,g+24|0);e=v[g+24>>2]==(rm(14125)|0)?1:-1;break c}ub(i);break c}ub(i)}fb=g+48|0;break a}a=P()|0;O()|0;ub(i);S(a|0);L()}g:{if(e){break g}Nm(v[v[b>>2]-12>>2]+b|0,0);e=v[f+220>>2];v[f+8>>2]=v[f+216>>2];v[f+12>>2]=e;e=v[f+212>>2];v[f>>2]=v[f+208>>2];v[f+4>>2]=e;b=yl(f+104|0,Ej(b,f));v[23220]=0;e=Q(404,f+88|0,14264)|0;g=v[23220];v[23220]=0;h:{if((g|0)!=1){v[23220]=0;v[f+72>>2]=3;v[f+76>>2]=0;U(405,b|0,e|0,f+72|0);g=v[23220];v[23220]=0;if((g|0)!=1){Pb(e);t[f+87|0]=0;v[23220]=0;e=Q(404,f+72|0,14720)|0;g=v[23220];v[23220]=0;if((g|0)!=1){v[23220]=0;U(406,b|0,f+87|0,e|0);g=v[23220];v[23220]=0;if((g|0)!=1){Pb(e);v[23220]=0;g=w[f+87|0];e=T(419,b|0)|0;i=v[23220];v[23220]=0;if((i|0)!=1){v[23220]=0;i=T(420,b|0)|0;h=v[23220];v[23220]=0;if((h|0)!=1){g=g?0:d;v[f+64>>2]=e;i:{j:{k:{l:{while(1){if(!Nb(e,i)){a=v[b>>2];Ug(b);e=a&1073741824?-1:1;break g}v[23220]=0;d=Q(404,f+48|0,15750)|0;e=v[23220];v[23220]=0;if((e|0)==1){break k}e=v[b+36>>2];h=v[b+32>>2];v[23220]=0;e=fa(421,h|0,e|0,v[f+64>>2],d|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break j}Pb(d);m:{n:{if(!e){v[23220]=0;X(422,b|0,f- -64|0,c|0,g|0);d=v[23220];v[23220]=0;if((d|0)!=1){break n}break i}v[23220]=0;d=Q(404,f+32|0,15420)|0;e=v[23220];v[23220]=0;o:{p:{if((e|0)!=1){e=v[b+36>>2];h=v[b+32>>2];v[23220]=0;e=fa(421,h|0,e|0,v[f+64>>2],d|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break p}Pb(d);if(e){break o}v[23220]=0;U(423,b|0,f- -64|0,f+62|0);d=v[23220];v[23220]=0;if((d|0)==1){break i}break n}a=P()|0;O()|0;break h}a=P()|0;O()|0;Pb(d);break h}v[23220]=0;d=Q(404,f+16|0,15319)|0;e=v[23220];v[23220]=0;if((e|0)==1){break m}e=v[b+36>>2];h=v[b+32>>2];v[23220]=0;e=fa(421,h|0,e|0,v[f+64>>2],d|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break l}Pb(d);if(e){break n}v[23220]=0;X(424,b|0,f- -64|0,a|0,g|0);d=v[23220];v[23220]=0;if((d|0)==1){break i}}Un(f- -64|0);e=v[f+64>>2];continue}break}a=P()|0;O()|0;break h}a=P()|0;O()|0;Pb(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Pb(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Pb(e);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Pb(e);break h}a=P()|0;O()|0}Ug(b);S(a|0);L()}fb=f+224|0;return e|0}function Mga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-400|0;fb=e;g=fb-32|0;fb=g;d=g+8|0;GA(d,b);wu(g,d);v[23220]=0;U(418,e+240|0,v[g>>2],v[g+4>>2]);b=v[23220];v[23220]=0;a:{if((b|0)!=1){Jc(g+8|0);fb=g+32|0;break a}a=P()|0;O()|0;Jc(g+8|0);S(a|0);L()}v[23220]=0;U(400,e+136|0,v[e+240>>2],v[e+244>>2]);b=v[23220];v[23220]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){v[23220]=0;g=Q(76,e+256|0,e+136|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break z}ub(e+136|0);$b(e+240|0);if(c>>>0<2189){break g}b=yl(e+136|0,g);v[23220]=0;c=Q(404,e+120|0,10085)|0;d=v[23220];v[23220]=0;if((d|0)==1){break x}v[23220]=0;v[e+104>>2]=19923968;v[e+108>>2]=0;U(405,b|0,c|0,e+104|0);d=v[23220];v[23220]=0;if((d|0)==1){break w}Pb(c);t[e+119|0]=0;v[23220]=0;c=Q(404,e+104|0,10954)|0;d=v[23220];v[23220]=0;if((d|0)==1){break i}v[23220]=0;U(406,b|0,e+119|0,c|0);d=v[23220];v[23220]=0;if((d|0)==1){break v}Pb(c);c=0;c=w[e+119|0]?c:v[a+1298404>>2];f=v[a+4>>2];v[23220]=0;d=Q(404,e+88|0,15750)|0;h=v[23220];v[23220]=0;if((h|0)==1){break u}v[23220]=0;X(407,b|0,f|0,d|0,c|0);f=v[23220];v[23220]=0;if((f|0)==1){break t}Pb(d);v[23220]=0;d=Q(404,e+72|0,15420)|0;f=v[23220];v[23220]=0;if((f|0)==1){break s}v[23220]=0;X(408,b|0,a|0,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break r}Pb(d);v[23220]=0;c=Q(404,e+56|0,15319)|0;d=v[23220];v[23220]=0;if((d|0)==1){break q}v[23220]=0;d=a+484360|0;U(409,b|0,d|0,c|0);f=v[23220];v[23220]=0;if((f|0)==1){break p}Pb(c);v[23220]=0;c=Q(404,e+40|0,26646)|0;f=v[23220];v[23220]=0;if((f|0)==1){break o}v[23220]=0;U(410,b|0,a+484344|0,c|0);f=v[23220];v[23220]=0;if((f|0)==1){break n}Pb(c);f=v[a+1298404>>2];v[23220]=0;c=Q(404,e+24|0,26652)|0;h=v[23220];v[23220]=0;if((h|0)==1){break m}v[23220]=0;X(411,b|0,d|0,c|0,f|0);d=v[23220];v[23220]=0;if((d|0)==1){break l}Pb(c);if(w[b+3|0]&64){v[23220]=0;c=Q(1,e+8|0,16229)|0;d=v[23220];v[23220]=0;if((d|0)==1){break k}a=v[a+1298464>>2];v[23220]=0;U(360,a|0,1,c|0);a=v[23220];v[23220]=0;if((a|0)==1){break j}vb(c)}Ug(b);break f}a=P()|0;O()|0;break y}a=P()|0;O()|0;ub(e+136|0)}$b(e+240|0);break b}a=P()|0;O()|0;break h}a=P()|0;O()|0;Pb(c);break h}a=P()|0;O()|0;Pb(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Pb(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Pb(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Pb(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Pb(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Pb(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(c);break h}a=P()|0;O()|0}Ug(b);break c}b=Gb(e+136|0);d=v[a+1298404>>2];f=v[a+4>>2];v[23220]=0;d=fa(412,f|0,g|0,b|0,d|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break e}A:{if((d|0)!=1){v[23220]=0;c=Q(1,e+120|0,16535)|0;d=v[23220];v[23220]=0;B:{if((d|0)!=1){a=v[a+1298464>>2];v[23220]=0;U(360,a|0,1,c|0);a=v[23220];v[23220]=0;if((a|0)==1){break B}vb(c);break A}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(c);break d}d=v[a+1298404>>2];v[23220]=0;X(413,g|0,a|0,d|0,c>>>0<2188|0);a=v[23220];v[23220]=0;if((a|0)==1){break e}}vb(b)}df(g);fb=e+400|0;return}a=P()|0;O()|0}vb(b)}df(g)}S(a|0);L()}function Fb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[115706]){break a}a=a+b|0;if(v[115707]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=462808,j=v[115702]&Fia(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+463112|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=462812,j=v[115703]&Fia(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[115704]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[115708]==(f|0)){v[115708]=d;a=v[115705]+a|0;v[115705]=a;v[d+4>>2]=a|1;if(v[115707]!=(d|0)){break a}v[115704]=0;v[115707]=0;return}if(v[115707]==(f|0)){v[115707]=d;a=v[115704]+a|0;v[115704]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=462808,j=v[115702]&Fia(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+463112|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=462812,j=v[115703]&Fia(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[115707]!=(d|0)){break f}v[115704]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;b=(a<<3)+462848|0;c=v[115702];a=1<<a;k:{if(!(c&a)){v[115702]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;v[d+16>>2]=0;v[d+20>>2]=0;g=(e<<2)+463112|0;l:{m:{c=v[115703];b=1<<e;n:{if(!(c&b)){v[115703]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[115710]-1|0;v[115710]=a?a:-1}}function tg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=fb-112|0;fb=j;k=i&2147483647;l=e&2147483647;m=l;a:{b:{p=!(b|c);if(!(d|l?l-2147418112>>>0<2147549184:p)){n=k-2147418112|0;if(!h&(n|0)==-2147418112?f|g:(n|0)==-2147418112&(h|0)!=0|n>>>0>2147549184){break b}}if(!(!d&(m|0)==2147418112?p:m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(m^2147418112|c))){m=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:m;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(k^2147418112|g))){break a}if(!(b|d|(c|m))){if(f|h|(g|k)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}l=(k|0)==(m|0);k=l&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:l&d>>>0<h>>>0|k>>>0>m>>>0;o=k?f:b;l=k?g:c;m=k?i:e;r=m;q=k?h:d;n=m&65535;e=k?e:i;s=e;h=k?d:h;m=e>>>16&32767;p=r>>>16&32767;if(!p){d=!(n|q);e=d<<6;i=E(d?o:q)+32|0;d=E(d?l:n);d=e+((d|0)==32?i:d)|0;vf(j+96|0,o,l,q,n,d-15|0);q=v[j+104>>2];n=v[j+108>>2];o=v[j+96>>2];p=16-d|0;l=v[j+100>>2]}f=k?b:f;g=k?c:g;i=s&65535;if(!m){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;vf(j+80|0,f,g,h,i,b-15|0);m=16-b|0;h=v[j+88>>2];i=v[j+92>>2];g=v[j+84>>2];f=v[j+80>>2]}b=h;k=i<<3|b>>>29;d=b<<3|g>>>29;e=k|524288;b=q;c=n<<3|b>>>29;h=b<<3|l>>>29;i=c;b=f;c=g<<3|b>>>29;b=b<<3;g=r^s;c:{if((m|0)==(p|0)){break c}f=p-m|0;if(f>>>0>127){d=0;e=0;b=1;c=0;break c}vf(j- -64|0,b,c,d,e,128-f|0);cm(j+48|0,b,c,d,e,f);b=v[j+48>>2]|(v[j+64>>2]|v[j+72>>2]|(v[j+68>>2]|v[j+76>>2]))!=0;c=v[j+52>>2];d=v[j+56>>2];e=v[j+60>>2]}m=h;q=i|524288;f=o;k=l<<3|f>>>29;n=f<<3;d:{if((g|0)<0){f=0;g=0;h=0;i=0;if(!(b^n|d^m|(c^k|e^q))){break a}o=n-b|0;l=k-((b>>>0>n>>>0)+c|0)|0;f=m-d|0;b=(c|0)==(k|0)&b>>>0>n>>>0|c>>>0>k>>>0;i=(q-((d>>>0>m>>>0)+e|0)|0)-(f>>>0<b>>>0)|0;h=f-b|0;if(i>>>0>524287){break d}b=!(h|i);c=b<<6;d=E(b?o:h)+32|0;b=E(b?l:i);b=c+((b|0)==32?d:b)|0;b=b-12|0;vf(j+32|0,o,l,h,i,b);p=p-b|0;h=v[j+40>>2];i=v[j+44>>2];o=v[j+32>>2];l=v[j+36>>2];break d}k=c+k|0;f=b+n|0;k=f>>>0<n>>>0?k+1|0:k;o=f;l=k;f=(c|0)==(k|0)&b>>>0>f>>>0|c>>>0>k>>>0;c=e+q|0;b=d+m|0;c=b>>>0<m>>>0?c+1|0:c;d=b;b=f+b|0;h=b;i=b>>>0<d>>>0?c+1|0:c;if(!(i&1048576)){break d}o=o&1|((l&1)<<31|o>>>1);c=h;l=c<<31|l>>>1;p=p+1|0;h=(i&1)<<31|c>>>1;i=i>>>1|0}d=0;e=r&-2147483648;if((p|0)>=32767){h=d;i=e|2147418112;f=0;g=0;break a}m=0;e:{if((p|0)>0){m=p;break e}vf(j+16|0,o,l,h,i,p+127|0);cm(j,o,l,h,i,1-p|0);o=v[j>>2]|(v[j+16>>2]|v[j+24>>2]|(v[j+20>>2]|v[j+28>>2]))!=0;l=v[j+4>>2];h=v[j+8>>2];i=v[j+12>>2]}c=h<<29;b=l>>>3|0;n=(l&7)<<29|o>>>3;l=o&7;g=l>>>0>4;f=n+g|0;b=b|c;k=f>>>0<g>>>0?b+1|0:b;c=f;g=k;b=(b|0)==(k|0)&c>>>0<n>>>0|b>>>0>k>>>0;c=d|((i&7)<<29|h>>>3);b=b+c|0;i=e|(i>>>3&65535|m<<16);i=b>>>0<c>>>0?i+1|0:i;h=b;f:{if((l|0)==4){c=g+0|0;e=f&1;b=f+e|0;c=b>>>0<f>>>0?c+1|0:c;f=b;g=c;c=(d|0)==(c|0)&b>>>0<e>>>0|c>>>0<d>>>0;b=c+h|0;i=b>>>0<c>>>0?i+1|0:i;h=b;break f}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;fb=j+112|0}function yJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=e|0;var f=0,g=0,h=0,i=0;f=fb-144|0;fb=f;v[f+140>>2]=c;v[f+136>>2]=b;A[f+128>>3]=d;a:{if(!c){break a}g=w[Hk(b,c)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}Qk(f+104|0,b,c,c-1|0);b=v[f+108>>2];v[f+136>>2]=v[f+104>>2];v[f+140>>2]=b}b=f+104|0;Kd(b);c=v[f+104>>2];Kd(f+88|0);g=Gk(c,v[f+92>>2],f+136|0);Kd(b);b=v[f+140>>2];c=v[f+136>>2];b:{c:{d:{e:{if((g|0)==v[f+108>>2]){a=oc(f+120|0,21598);if(Hc(c,b,v[a>>2],v[a+4>>2])){b=aa(8)|0;v[23220]=0;R(931,f+88|0,f+128|0);a=v[23220];v[23220]=0;f:{g:{h:{if((a|0)!=1){v[23220]=0;U(934,f+104|0,17577,f+88|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}a=0;c=qc(b,f+104|0);v[23220]=0;U(106,c|0,61832,923);c=v[23220];v[23220]=0;if((c|0)!=1){break b}c=P()|0;O()|0;ub(f+104|0);break g}c=P()|0;O()|0;break f}c=P()|0;a=1;O()|0}ub(f+88|0);if(!a){break c}}ba(b|0);break c}if(!e){break e}b=aa(8)|0;v[23220]=0;e=Bh(f+56|0,v[f+136>>2],v[f+140>>2]);a=v[23220];v[23220]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[23220]=0;U(934,f+72|0,17613,e|0);a=v[23220];v[23220]=0;if((a|0)==1){break q}v[23220]=0;R(936,f+88|0,f+72|0);c=v[23220];v[23220]=0;a=1;if((c|0)==1){break p}v[23220]=0;R(931,f+40|0,f+128|0);a=v[23220];v[23220]=0;if((a|0)==1){break o}v[23220]=0;U(938,f+104|0,f+88|0,f+40|0);c=v[23220];v[23220]=0;a=1;if((c|0)==1){break n}a=qc(b,f+104|0);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(f+104|0);a=0;break m}c=P()|0;O()|0;break i}c=P()|0;a=1;O()|0;break j}c=P()|0;O()|0;break k}c=P()|0;a=1;O()|0;break l}c=P()|0;O()|0}ub(f+40|0)}ub(f+88|0)}ub(f+72|0)}ub(e);if(!a){break c}}ba(b|0);break c}e=oc(f+32|0,21598);if(Hc(c,b,v[e>>2],v[e+4>>2])){b=aa(8)|0;v[23220]=0;R(931,f+88|0,f+128|0);a=v[23220];v[23220]=0;r:{s:{t:{if((a|0)!=1){v[23220]=0;U(934,f+104|0,17577,f+88|0);a=v[23220];v[23220]=0;if((a|0)==1){break t}a=0;c=qc(b,f+104|0);v[23220]=0;U(106,c|0,61832,923);c=v[23220];v[23220]=0;if((c|0)!=1){break b}c=P()|0;O()|0;ub(f+104|0);break s}c=P()|0;O()|0;break r}c=P()|0;a=1;O()|0}ub(f+88|0);if(!a){break c}}ba(b|0);break c}e=oc(f+24|0,7677);if(Hc(c,b,v[e>>2],v[e+4>>2])){if(!Nd(w[a+28|0])){break e}if(d<=0|d>4){a=aa(8)|0;v[23220]=0;b=Q(52,f+104|0,7772)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(b);break c}a=v[a+24>>2];h=a,i=Ee(65536/d),v[h+480244>>2]=i;qp(a);break e}e=oc(f+16|0,7729);if(Hc(c,b,v[e>>2],v[e+4>>2])){if(!Nd(w[a+28|0])){break e}if(d<=0|d>4){a=aa(8)|0;v[23220]=0;b=Q(52,f+104|0,7793)|0;c=v[23220];v[23220]=0;if((c|0)!=1){a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(b);break c}c=P()|0;O()|0;ba(a|0);break c}a=v[a+24>>2];h=a,i=Ee(d*65536),v[h+480240>>2]=i;qp(a);break e}e=b;b=oc(f+8|0,7747);if(!Hc(c,e,v[b>>2],v[b+4>>2])){break e}h=v[a+24>>2],i=Xl(d*65536),v[h+480236>>2]=i}fb=f+144|0;return}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function bH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[115707]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=462808,j=v[115702]&Fia(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+463112|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=462812,j=v[115703]&Fia(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[115704]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[115708]==(f|0)){v[115708]=a;b=v[115705]+b|0;v[115705]=b;v[a+4>>2]=b|1;if(v[115707]!=(a|0)){break a}v[115704]=0;v[115707]=0;return}if(v[115707]==(f|0)){v[115707]=a;b=v[115704]+b|0;v[115704]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=462808,j=v[115702]&Fia(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+463112|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=462812,j=v[115703]&Fia(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[115707]!=(a|0)){break g}v[115704]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){b=b>>>3|0;c=(b<<3)+462848|0;d=v[115702];b=1<<b;l:{if(!(d&b)){v[115702]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;v[a+16>>2]=0;v[a+20>>2]=0;g=(e<<2)+463112|0;m:{d=v[115703];c=1<<e;n:{if(!(d&c)){v[115703]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}function zJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-192|0;fb=f;v[f+188>>2]=c;v[f+184>>2]=b;t[f+183|0]=d;a:{if(!c){break a}g=w[Hk(b,c)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}Qk(f+8|0,b,c,c-1|0);b=v[f+12>>2];v[f+184>>2]=v[f+8>>2];v[f+188>>2]=b}b=f+8|0;Kd(b);c=v[f+8>>2];Kd(f+152|0);g=Gk(c,v[f+156>>2],f+184|0);Kd(b);b=v[f+188>>2];c=v[f+184>>2];b:{c:{d:{e:{f:{g:{h:{if((g|0)==v[f+12>>2]){a=oc(f+168|0,21598);if(Hc(c,b,v[a>>2],v[a+4>>2])){b=aa(8)|0;v[23220]=0;R(927,f+152|0,f+183|0);a=v[23220];v[23220]=0;if((a|0)==1){break g}v[23220]=0;U(934,f+8|0,17577,f+152|0);a=v[23220];v[23220]=0;if((a|0)==1){break f}d=0;a=qc(b,f+8|0);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(f+8|0);break e}if(!e){break h}b=aa(8)|0;v[23220]=0;d=Bh(f+120|0,v[f+184>>2],v[f+188>>2]);a=v[23220];v[23220]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[23220]=0;U(934,f+136|0,17613,d|0);a=v[23220];v[23220]=0;if((a|0)==1){break p}v[23220]=0;R(936,f+152|0,f+136|0);c=v[23220];v[23220]=0;a=1;if((c|0)==1){break o}v[23220]=0;R(927,f+104|0,f+183|0);a=v[23220];v[23220]=0;if((a|0)==1){break n}v[23220]=0;U(938,f+8|0,f+152|0,f+104|0);c=v[23220];v[23220]=0;a=1;if((c|0)==1){break m}a=qc(b,f+8|0);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(f+8|0);a=0;break l}c=P()|0;O()|0;break d}c=P()|0;a=1;O()|0;break i}c=P()|0;O()|0;break j}c=P()|0;a=1;O()|0;break k}c=P()|0;O()|0}ub(f+104|0)}ub(f+152|0)}ub(f+136|0)}ub(d);if(a){break d}break c}e=oc(f+96|0,21598);if(Hc(c,b,v[e>>2],v[e+4>>2])){b=aa(8)|0;v[23220]=0;R(927,f+152|0,f+183|0);a=v[23220];v[23220]=0;q:{r:{if((a|0)!=1){v[23220]=0;U(934,f+8|0,17577,f+152|0);a=v[23220];v[23220]=0;if((a|0)==1){break r}d=0;a=qc(b,f+8|0);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(f+8|0);break q}c=P()|0;O()|0;break d}c=P()|0;d=1;O()|0}ub(f+152|0);if(d){break d}break c}s:{e=oc(f+88|0,7380);if(!Hc(c,b,v[e>>2],v[e+4>>2])){e=oc(f+80|0,7362);if(!Hc(c,b,v[e>>2],v[e+4>>2])){break s}}t[a+60|0]=d;break h}t:{e=oc(f+72|0,6895);if(!Hc(c,b,v[e>>2],v[e+4>>2])){e=oc(f- -64|0,6876);if(!Hc(c,b,v[e>>2],v[e+4>>2])){break t}}t[a+61|0]=d;break h}e=oc(f+56|0,6979);if(Hc(c,b,v[e>>2],v[e+4>>2])){t[a+62|0]=d;break h}e=oc(f+48|0,6025);if(Hc(c,b,v[e>>2],v[e+4>>2])){t[a+63|0]=d;break h}e=oc(f+40|0,7429);if(Hc(c,b,v[e>>2],v[e+4>>2])){t[a+64|0]=d;break h}e=b;b=oc(f+32|0,13359);if(!Hc(c,e,v[b>>2],v[b+4>>2])){break h}b=v[a+24>>2];c=b+24664|0;e=v[c+4>>2];v[f+24>>2]=v[c>>2];v[f+28>>2]=e;c=b+24656|0;e=v[c+4>>2];v[f+16>>2]=v[c>>2];v[f+20>>2]=e;c=v[b+24652>>2];v[f+8>>2]=v[b+24648>>2];v[f+12>>2]=c;if(d){a=$I(v[a+56>>2])}else{a=0}v[f+28>>2]=a;if(!jx(f+8|0,b+24648|0)){break h}ey(b,f+8|0)}fb=f+192|0;return}c=P()|0;O()|0;break d}c=P()|0;d=1;O()|0}ub(f+152|0);if(!d){break c}}ba(b|0)}S(c|0)}L()}function pia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-736|0;fb=e;wc(b);f=fb-16|0;fb=f;h=e+120|0;fU(f+8|0,h);j=b;g=v[b>>2];i=v[b+8>>2];b=v[f+12>>2];jc(f,g,i,v[f+8>>2],b);g=v[f+4>>2];if((g|0)==(b|0)){Yb(j,v[f+12>>2])}fb=f+16|0;b=(b|0)==(g|0);if(!b){eU(h)}a:{if(!b){break a}if(!gU(e+120|0)){break a}b:{if(!c){break b}zd(a,67108864);yg(a);b=w[e+145|0];u[a+480190>>1]=31;u[a+480188>>1]=b;v[a+480228>>2]=256/(b>>>0);b=Qb(e,8166);Db(a+1298344|0,b);vb(b);b=Qb(e,10732);Db(a+1298356|0,b);vb(b);d=e+96|0;og(d,4135);f=w[e+144|0];v[e+72>>2]=f>>>4;b=0;v[23220]=0;v[e+116>>2]=f&15;X(291,e|0,d|0,e+72|0,e+116|0);d=v[23220];v[23220]=0;c:{d:{if((d|0)!=1){Db(a+1298368|0,e);vb(e);bc(e+96|0);v[a+1298404>>2]=13;kq(Vb(v[a+484360>>2],w[a+484376|0]),e+168|0,w[e+167|0]+1|0);while(1){e:{if((b|0)==31){nu(j,a+1298308|0,32);d=1;break e}d=b+1|0;h=B(d,104)+a|0;g=h+484380|0;kd(g,1);f=(e+120|0)+(b<<2)|0;p=g,q=_b(w[f+176|0]|w[f+177|0]<<8|(w[f+178|0]<<16|w[f+179|0]<<24)),v[p>>2]=q;k=_b(w[f+300|0]|w[f+301|0]<<8|(w[f+302|0]<<16|w[f+303|0]<<24));v[h+484384>>2]=k;f=_b(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24));v[h+484388>>2]=f+k;if(f){f=h+484414|0;u[f>>1]=x[f>>1]|2}hk(g);b=(e+120|0)+b|0;t[e|0]=w[b+548|0];t[e+96|0]=64;p=h+484410|0,q=w[Rb(e,e+96|0)|0]<<2,u[p>>1]=q;t[h+484417|0]=w[b+579|0]<<4;b=d;continue}break}while(1){if((d|0)!=32){dU(j,((d<<5)+a|0)+946304|0,30);d=d+1|0;continue}break}n=c&1;if(n){ig(a+484344|0,w[e+166|0]+1|0)}k=a+484344|0;m=a+480188|0;f=0;while(1){if(w[e+166|0]<f>>>0){d=1;if(!(c&2)){break a}b=Uc(e,8,1,1,0);while(1){if((d|0)==32){break b}hg(b,(B(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}h=xh(e+96|0);f:{g:{if(w[e+146|0]){v[23220]=0;b=T(261,j|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break f}v[23220]=0;U(177,e+72|0,j|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break f}break g}b=x[m>>1];v[23220]=0;U(177,e+72|0,j|0,b<<8);b=v[23220];v[23220]=0;if((b|0)==1){break d}}b=e+72|0;d=gc(e,b);Yc(h,d);wb(d);wb(b);h:{if(!n){break h}v[23220]=0;b=W(213,k|0,f&65535,64)|0;d=v[23220];v[23220]=0;if((d|0)==1){break d}if(!b){break h}b=0;if(w[e+146|0]){g=0;v[23220]=0;R(292,h|0,e|0);b=v[23220];v[23220]=0;if((b|0)==1){break d}i:while(1){if((g|0)==64){break h}i=e+g|0;b=128;d=0;l=Xb(v[k>>2],f);l=Of(v[l>>2],v[v[l+48>>2]+12>>2],g);while(1){if(x[m>>1]<=d>>>0){g=g+1|0;continue i}j:{if(!(w[i|0]&b)){break j}v[23220]=0;R(293,h|0,l+B(d,6)|0);o=v[23220];v[23220]=0;if((o|0)!=1){break j}break d}b=b>>>1|0;d=d+1|0;continue}}}k:while(1){d=0;g=b&65535;if(g>>>0>=x[m>>1]){break h}while(1){if((d|0)==64){b=b+1|0;continue k}i=Xb(v[k>>2],f);i=$c(v[i>>2],v[v[i+48>>2]+12>>2],d,g);v[23220]=0;R(293,h|0,i|0);i=v[23220];v[23220]=0;if((i|0)!=1){d=d+1|0;continue}break}break}break d}wb(h);f=f+1|0;continue}break}break d}d=P()|0;O()|0;bc(e+96|0);break c}d=P()|0;O()|0;wb(h)}S(d|0);L()}d=1}fb=e+736|0;return d|0}function MS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=fb-176|0;fb=g;i=eg(g+160|0);a:{b:{c:{if(d){v[23220]=0;U(425,a|0,i|0,c|0);c=v[23220];v[23220]=0;if((c|0)!=1){break c}break b}v[23220]=0;U(426,a|0,i|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}}k=Ib(g+144|0);m=b+480192|0;n=b+1298464|0;d=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{h=d&65535;if(h>>>0<=x[m>>1]){v[23220]=0;u[g+142>>1]=0;R(427,a|0,g+142|0);c=v[23220];v[23220]=0;t:{u:{v:{w:{if((c|0)!=1){j=fb-16|0;fb=j;o=x[g+142>>1];c=Od(i);e=fc(i);f=fb-16|0;fb=f;while(1){if(c){l=bo(x[c+16>>1],o);e=l?e:c;c=v[(l?c+4|0:c)>>2];continue}break}c=v[dc(f+8|0,e)>>2];fb=f+16|0;x:{if(Nb(c,Hf(i))){if(!bo(x[g+142>>1],x[pd(c)>>1])){break x}}c=Hf(i)}c=dc(j+8|0,c);fb=j+16|0;j=((h<<2)+b|0)+900380|0;if(!v[j>>2]){break d}c=v[c>>2];if(!vg(c,wf(i))){break u}v[23220]=0;c=Q(3,g+128|0,pd(c)+4|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break t}v[23220]=0;e=Q(1,g+112|0,16725)|0;f=v[23220];v[23220]=0;if((f|0)==1){break v}f=Tp(c,e);vb(e);if(f){break p}e=v[b+4>>2];v[23220]=0;e=Q(428,e|0,c|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break r}v[v[j>>2]+44>>2]=e;if(!v[v[j>>2]+44>>2]){break w}break e}d=P()|0;O()|0;break f}v[23220]=0;e=Q(1,g+96|0,13390)|0;f=v[23220];v[23220]=0;y:{z:{A:{if((f|0)!=1){B:{if(!Tp(c,e)){v[23220]=0;f=Q(1,g+80|0,13602)|0;h=v[23220];v[23220]=0;if((h|0)==1){break A}h=Tp(c,f);vb(f);vb(e);if(h){break B}break s}vb(e)}v[23220]=0;e=T(429,c|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break z}v[g+56>>2]=e;e=v[b+4>>2];f=v[Rf(g+72|0,g+56|0)>>2];v[23220]=0;e=Q(430,e|0,f|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break y}fg(g+56|0);if(e){break e}break s}d=P()|0;O()|0;break g}d=P()|0;O()|0;vb(e);break g}d=P()|0;O()|0;break g}d=P()|0;O()|0;fg(g+56|0);break g}d=P()|0;O()|0;break g}c=v[j>>2];if(!c){break d}v[c+44>>2]=0;break d}d=P()|0;O()|0;break f}rl(k);KS(i);fb=g+176|0;return}e=Ab(v[k>>2]);h=Ab(v[k+4>>2]);f=fb-16|0;fb=f;v[f+8>>2]=e;while(1){C:{if(!Nb(e,h)){break C}if(Tp(e,c)){break C}e=v[Sp(f+8|0)>>2];continue}break}fb=f+16|0;if(Nb(e,Ab(v[k+4>>2]))){break p}v[23220]=0;R(431,k|0,c|0);e=v[23220];v[23220]=0;if((e|0)!=1){break q}}d=P()|0;O()|0;break g}v[23220]=0;e=Q(1,g+24|0,17426)|0;f=v[23220];v[23220]=0;if((f|0)==1){break o}v[23220]=0;U(432,g+40|0,e|0,c|0);f=v[23220];v[23220]=0;if((f|0)==1){break n}v[23220]=0;f=Q(1,g+8|0,16278)|0;h=v[23220];v[23220]=0;if((h|0)==1){break m}v[23220]=0;U(2,g+56|0,g+40|0,f|0);h=v[23220];v[23220]=0;if((h|0)==1){break l}h=v[n>>2];v[23220]=0;U(360,h|0,2,g+56|0);h=v[23220];v[23220]=0;if((h|0)==1){break k}vb(g+56|0);vb(f);vb(g+40|0);vb(e)}v[v[j>>2]+44>>2]=0;break e}d=P()|0;O()|0;break g}d=P()|0;O()|0;break h}d=P()|0;O()|0;break i}d=P()|0;O()|0;break j}d=P()|0;O()|0;vb(g+56|0)}vb(f)}vb(g+40|0)}vb(e)}vb(c)}rl(k);break a}vb(c)}d=d+1|0;continue}}d=P()|0;O()|0}KS(i);S(d|0);L()}function GV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=fb-32|0;fb=e;v[e+28>>2]=b;a:{if((d|0)<=0){b=0;break a}v[e+8>>2]=d;v[e+16>>2]=214748364;r=e,s=B(v[Eb(e+28|0,e+16|0)>>2],20),v[r+20>>2]=s;Zm(c,v[Eb(e+8|0,e+20|0)>>2]);v[e+12>>2]=b;v[e+8>>2]=a;b=0;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}a=v[e+8>>2];g=v[e+12>>2];f=_g(a,g,b);k=_g(a,g,b+4|0);o=_g(a,g,b+5|0);r=e,s=_g(a,g,b+6|0)<<8|_g(a,g,b+7|0),v[r+24>>2]=s;k=o|k<<8;q=b+8|0;f:{g:{switch(f|0){case 0:b=0;if((d|0)<(k|0)){b=aa(8)|0;v[23220]=0;a=T(180,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break f}break d}while(1){if((b|0)!=(k|0)){r=e,s=_g(v[e+8>>2],v[e+12>>2],b+q|0),t[r+20|0]=s;Ym(c,e+20|0);b=b+1|0;continue}break};o=k;break b;case 1:break g;default:break e}}Uh(e+24|0,d);o=v[e+24>>2];m=_g(a,g,b+10|0);t[e+20|0]=m;Ym(c,e+20|0);h=b+11|0;k=k+3&65532;b=o-1|0;g=0;j=0;n=0;l=0;while(1){if((b|0)<=0){break c}f=lg(h,g,1,e+8|0);h:{i:{j:{k:{l:{if((j|0)<=7){if(f){a=g;break i}a=g+1|0;l=8;break l}a=g+1|0;m:{if(!f){if(!lg(h,a,1,e+8|0)){break i}i=2;n:{o:{f=g+2|0;if(!lg(h,f,1,e+8|0)){break o}i=3;f=g+3|0;if(!lg(h,f,1,e+8|0)){break o}i=lg(h,f,3,e+8|0);a=g+6|0;break n}a=f+1|0}f=4;p:{q:{r:{g=((l<<3)+i|0)-17|0;s:{if((g|0)<0){a=aa(8)|0;v[23220]=0;b=T(180,a|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break r}break s}if(g>>>0<56){break p}a=aa(8)|0;v[23220]=0;b=T(180,a|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break q}}b=P()|0;O()|0;ba(a|0);S(b|0);L()}ia(b|0,26072,155);L()}ia(b|0,26072,155);L()}l=w[g+26112|0];if((l|0)!=8){break k}break m}f=4;if((l|0)!=8){break k}}l=8;f=1;if((n|0)>19){break k}}f=0;break j}n=n+8|0}while(1){if(!((f|0)<0|(b|0)<=0)){i=(a|0)/8|0;g=i+h|0;p=_g(v[e+8>>2],v[e+12>>2],g);m=m-dd((_g(v[e+8>>2],v[e+12>>2],g+1|0)<<8|p<<16|_g(v[e+8>>2],v[e+12>>2],g+2|0))<<(a-(i<<3)|0)+8,32-l|0)|0;t[e+20|0]=m;Ym(c,e+20|0);f=f-1|0;b=b-1|0;a=a+l|0;continue}break}j=(j|0)==31?31:j+1|0;g=a;break h}t:{u:{v:{f=a+1|0;if(!lg(h,f,1,e+8|0)){g=2;break v}f=a+2|0;if(!lg(h,f,1,e+8|0)){g=4;break v}f=a+3|0;if(!lg(h,f,1,e+8|0)){g=6;break v}f=a+5|0;if(!lg(h,a+4|0,1,e+8|0)){a=a+8|0;f=lg(h,f,3,e+8|0)+8|0;break t}a=a+10|0;g=16;f=lg(h,f,5,e+8|0);break u}a=f+2|0;f=lg(h,f+1|0,1,e+8|0)}f=g+f|0}w:{if(lg(h,a,1,e+8|0)){i=-256;g=12;break w}a=a+1|0;g=lg(h,a,1,e+8|0);i=g?-4352:0;g=g?14:8}p=a+1|0;a=lg(h,p,g,e+8|0);if(f>>>0>=3){j=j-((f|0)!=3)|0;j=((j|0)>1?j:1)-1|0}i=(a^-1)+i|0;a=Wc(v[c>>2],v[c+4>>2])+i|0;if(a>>>0<i>>>0){g=g+p|0;while(1){if((f|0)<=0|(b|0)<=0){break h}m=w[Hb(v[c>>2],a)|0];t[e+20|0]=m;Ym(c,e+20|0);b=b-1|0;a=a+1|0;f=f-1|0;continue}}b=aa(8)|0;v[23220]=0;a=T(180,b|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}ia(a|0,26072,155);L()}n=n-(n>>3)|0;continue}}ia(a|0,26072,155);L()}b=rc(v[c>>2],v[c+4>>2])^1;break a}a=P()|0;O()|0;ba(b|0);S(a|0);L()}v[e+24>>2]=b}d=d-o|0;b=k+q|0;continue}}fb=e+32|0;return b|0}function JL(a,b){var c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=C(0),m=C(0),n=0,o=0,p=0,q=0,r=0,s=C(0),t=0;if(b){fy(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;OL(a)}IL(a+24648|0);o=v[a+24620>>2];f=fb-144|0;fb=f;e=a+397456|0;c=v[e+4>>2];if(c>>>0>=29){v[e+4>>2]=0;c=0}h=B(c,44)+47632|0;if(!(b?0:(h|0)==v[e+8>>2])){v[e+8>>2]=h;m=C(o>>>0);c=f+8|0;d=v[h+24>>2];v[c>>2]=d;j=v[h+16>>2];v[c+4>>2]=j;v[c+8>>2]=v[h+4>>2];k=(d|0)>(j|0)?d:j;if((k|0)<=-601){i=j;j=k+600|0;v[c+4>>2]=i-j;v[c>>2]=d-j}g=C(z[h+36>>2]*C(79.30999755859375));a:{if(C(D(g))<C(2147483648)){d=~~g;break a}d=-2147483648}v[c+16>>2]=d- -8192;g=C(C(C(z[h+32>>2]*C(.0036000001709908247))+C(.15000000596046448))*C(32767));b:{if(C(D(g))<C(2147483648)){d=~~g;break b}d=-2147483648}v[c+20>>2]=(d|0)<32512?d:32512;j=0;g=z[h+8>>2];l=C(C(F(z[h+20>>2],C(.10000000149011612)))*m);c:{if(C(D(l))<C(2147483648)){d=~~l;break c}d=-2147483648}k=(d|0)>96?d:96;i=k-7500|0;n=k>>>0<i>>>0?0:i;l=C(z[h+28>>2]*m);d:{if(C(D(l))<C(2147483648)){i=~~l;break d}i=-2147483648}d=n+(i+((d|0)<96?d-96|0:0)|0)|0;i=(d|0)>128?d:128;p=i>>>0<3800?i:3800;v[c+24>>2]=p;n=(d|0)<128?d-128|0:0;g=C(g*m);e:{if(C(D(g))<C(2147483648)){q=~~g;break e}q=-2147483648}d=i-3800|0;i=(q+n|0)+(d>>>0>i>>>0?0:d)|0;v[c+32>>2]=i;n=k>>>0<7500?k:7500;while(1){if((j|0)==8){g=C(i|0);l=C(ie(C(.0010000000474974513),(i|0)<4721?C(1):C(C(4720)/g))*C(32768));f:{if(C(D(l))<C(2147483648)){d=~~l;break f}d=-2147483648}v[c+12>>2]=d;g=C(z[h+12>>2]*g);r=c,s=ie(C(.0010000000474974513),g<=C(4720)?C(1):C(C(4720)/g)),z[r+28>>2]=s}else{d=B(j,12);k=d+c|0;u[k+42>>1]=x[d+48922>>1];u[k+36>>1]=x[d+48916>>1];u[k+40>>1]=x[d+48920>>1];u[k+38>>1]=x[d+48918>>1];v[k+44>>2]=n+((B(v[d+48912>>2],p)+50|0)/100|0);j=j+1|0;continue}break}v[e+20>>2]=v[f+40>>2];c=NJ(OJ(v[f+16>>2]),m);u[e+86>>1]=c;u[e+84>>1]=c;c=x[f+24>>1]<<1;u[e+94>>1]=c;u[e+92>>1]=c;c=0;while(1){if((c|0)==8){v[e+49892>>2]=v[f+32>>2];c=v[f+12>>2];if((c|0)>-9e3){c=MJ(c)}else{c=0}v[e+80>>2]=c;d=e+49948|0;c=v[f+8>>2];if((c|0)>=-8999){c=MJ(c)}else{c=0}v[d>>2]=c;c=v[f+28>>2];d=e+49932|0;v[d>>2]=268464128;v[d+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[e+49906>>1]=c;u[e+49904>>1]=c;u[e+49902>>1]=c;u[e+49900>>1]=c;v[f+4>>2]=v[f+20>>2];ee(f+4|0,0,32752);c=x[f+4>>1];u[e+49914>>1]=c;d=e+49910|0;u[d>>1]=0;u[d+2>>1]=0;u[e+49908>>1]=c;g=z[f+36>>2];r=f,t=NJ(C(g*g),m),v[r>>2]=t;ee(f,256,32512);c=x[f>>1];u[e+49922>>1]=c;d=e+49918|0;u[d>>1]=0;u[d+2>>1]=0;u[e+49916>>1]=c}else{d=(c<<4)+e|0;h=(f+8|0)+B(c,12)|0;j=v[h+44>>2];v[d+100>>2]=j;v[d+104>>2]=j;u[d+108>>1]=x[h+36>>1];u[d+110>>1]=x[h+42>>1];u[d+112>>1]=x[h+40>>1];u[d+114>>1]=x[h+38>>1];c=c+1|0;continue}break}}c=a+397448|0;d=a+397452|0;if(b){v[e+16>>2]=0;QJ(e,c,d)}b=B(o,5);if(b>>>0>y[e+20>>2]){v[e+20>>2]=b}fb=f+144|0;b=v[a+1298300>>2];if(sd(b)){nO(b,v[a+24620>>2])}}function Nca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=fb-32|0;fb=j;a:{if(jt(a)>>>0<b>>>0){n=Sn(j+16|0);v[23220]=0;R(698,n|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}Xk(j+8|0,v[a>>2]);$l(j,v[a>>2],v[a+4>>2]);m=fb-48|0;fb=m;c=v[n+4>>2];e=cc(m+40|0,v[j+8>>2],v[j+12>>2]);f=cc(m+32|0,v[j>>2],v[j+4>>2]);b=fb-16|0;fb=b;e=cc(b+8|0,v[e>>2],v[e+4>>2]);f=cc(b,v[f>>2],v[f+4>>2]);e=AQ(v[e>>2],v[e+4>>2],v[f>>2],v[f+4>>2]);fb=b+16|0;e=c+e|0;v[n+4>>2]=e;b:{c:{if(!c){b=e-1|0;break c}b=e-1|0;if((b^c-1)>>>0<32){break b}}v[v[n>>2]+((e>>>0<33?0:b>>>5|0)<<2)>>2]=0}f=cc(m+24|0,v[j+8>>2],v[j+12>>2]);e=cc(m+16|0,v[j>>2],v[j+4>>2]);b=m+8|0;uo(b,v[n>>2],c);c=v[f>>2];o=fb-48|0;fb=o;f=v[f+4>>2];d:{if((f|0)==v[b+4>>2]){f=cc(o+40|0,c,f);c=cc(o+32|0,v[e>>2],v[e+4>>2]);b=cc(o+24|0,v[b>>2],v[b+4>>2]);e=fb-16|0;fb=e;g=v[f>>2];d=v[f+4>>2];c=Wk(v[c>>2],v[c+4>>2],g,d);v[e+12>>2]=c;e:{if((c|0)<=0){c=v[b>>2];break e}if(d){i=32-d|0;v[e+8>>2]=i;k=c;c=v[nd(e+8|0,e+12|0)>>2];v[e+12>>2]=k-c;h=v[b>>2];d=-1<<d&-1>>>i-c;v[h>>2]=v[h>>2]&(d^-1)|d&v[g>>2];c=c+v[b+4>>2]|0;v[b+4>>2]=c&31;v[b>>2]=h+(c>>>3&536870908);g=v[f>>2]+4|0;v[f>>2]=g;c=v[e+12>>2]}k=g;d=(c|0)/32|0;g=d<<2;Zi(v[b>>2],k,g);d=c-(d<<5)|0;v[e+12>>2]=d;c=g+v[b>>2]|0;v[b>>2]=c;if((d|0)<=0){break e}c=f;f=g+v[f>>2]|0;v[c>>2]=f;c=v[b>>2];g=-1>>>32-d|0;v[c>>2]=v[c>>2]&(g^-1)|g&v[f>>2];v[b+4>>2]=v[e+12>>2]}cc(m,c,v[b+4>>2]);break d}g=cc(o+16|0,c,f);c=cc(o+8|0,v[e>>2],v[e+4>>2]);f=cc(o,v[b>>2],v[b+4>>2]);e=fb-16|0;fb=e;k=v[c>>2];d=v[c+4>>2];b=v[g>>2];c=v[g+4>>2];d=Wk(k,d,b,c);v[e+12>>2]=d;f:{if((d|0)<=0){c=v[f+4>>2];break f}g:{if(!c){c=v[f+4>>2];break g}l=32-c|0;v[e+8>>2]=l;i=e+8|0;h=v[nd(i,e+12|0)>>2];v[e+12>>2]=d-h;d=v[f+4>>2];p=v[b>>2];v[e+8>>2]=h;k=32-d|0;v[e+4>>2]=k;b=v[f>>2];q=v[b>>2];i=v[Eb(i,e+4|0)>>2];l=p&(-1<<c&-1>>>l-h);v[b>>2]=(-1<<d&-1>>>k-i^-1)&q|(c>>>0<d>>>0?l<<d-c:l>>>c-d|0);d=d+i|0;c=d&31;v[f+4>>2]=c;d=b+(d>>>3&536870908)|0;v[f>>2]=d;b=h-i|0;if((b|0)>0){v[d>>2]=v[d>>2]&(-1>>>32-b^-1)|l>>>i+v[g+4>>2];v[f+4>>2]=b;c=b}b=v[g>>2]+4|0;v[g>>2]=b;d=v[e+12>>2]}h=32-c|0;i=-1<<c;l=i^-1;while(1){if((d|0)>=32){d=v[f>>2];b=v[b>>2];v[d>>2]=l&v[d>>2]|b<<c;v[f>>2]=d+4;v[d+4>>2]=i&v[d+4>>2]|b>>>h;d=v[e+12>>2]-32|0;v[e+12>>2]=d;b=v[g>>2]+4|0;v[g>>2]=b;continue}break}if((d|0)<=0){break f}l=v[b>>2];v[e+8>>2]=h;g=v[f>>2];b=v[g>>2];k=b;b=v[nd(e+12|0,e+8|0)>>2];k=k&(i&-1>>>h-b^-1);h=l&-1>>>32-d;v[g>>2]=k|h<<c;d=b+c|0;c=d&31;v[f+4>>2]=c;g=g+(d>>>3&536870908)|0;v[f>>2]=g;d=v[e+12>>2]-b|0;v[e+12>>2]=d;if((d|0)<=0){break f}v[g>>2]=v[g>>2]&(-1>>>32-d^-1)|h>>>b;c=v[e+12>>2];v[f+4>>2]=c}cc(m,v[f>>2],c)}fb=e+16|0;fb=o+48|0;fb=m+48|0;pt(a,n);Ie(n)}fb=j+32|0;return}a=P()|0;O()|0;Ie(n);S(a|0);L()}function cE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=fb-176|0;fb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((c|0)<=5){Av(a+128|0,c);v[23220]=0;c=Q(1,a+112|0,17713)|0;d=v[23220];v[23220]=0;if((d|0)==1){break E}v[23220]=0;U(2,a+144|0,a+128|0,c|0);d=v[23220];v[23220]=0;if((d|0)==1){break D}v[23220]=0;d=Q(3,a+80|0,e|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break C}v[23220]=0;e=Q(1,a- -64|0,19541)|0;f=v[23220];v[23220]=0;if((f|0)==1){break B}v[23220]=0;U(4,a+96|0,d|0,e|0);f=v[23220];v[23220]=0;if((f|0)==1){break A}v[23220]=0;U(2,a+160|0,a+144|0,a+96|0);f=v[23220];v[23220]=0;if((f|0)==1){break z}vb(a+96|0);vb(e);vb(d);d=a+144|0;vb(d);vb(c);vb(a+128|0);c=v[b>>2];v[23220]=0;U(5,d|0,1,(c?c:21598)|0);c=v[23220];v[23220]=0;if((c|0)==1){break t}c=v[b+4>>2];v[23220]=0;U(5,a+128|0,1,(c?c:21598)|0);c=v[23220];v[23220]=0;if((c|0)==1){break s}b=v[b+8>>2];v[23220]=0;v[a+48>>2]=b;R(6,a+96|0,a+48|0);b=v[23220];v[23220]=0;if((b|0)==1){break r}v[23220]=0;Y(7,17592);b=v[23220];v[23220]=0;if((b|0)==1){break q}v[23220]=0;U(8,a+48|0,0,a+144|0);b=v[23220];v[23220]=0;if((b|0)==1){break p}v[23220]=0;Y(9,a+48|0);b=v[23220];v[23220]=0;if((b|0)==1){break o}v[23220]=0;Y(7,17386);b=v[23220];v[23220]=0;if((b|0)==1){break o}v[23220]=0;U(8,a+32|0,0,a+96|0);b=v[23220];v[23220]=0;if((b|0)==1){break n}v[23220]=0;Y(9,a+32|0);b=v[23220];v[23220]=0;if((b|0)==1){break m}v[23220]=0;Y(7,17384);b=v[23220];v[23220]=0;if((b|0)==1){break m}v[23220]=0;Y(7,17713);b=v[23220];v[23220]=0;if((b|0)==1){break m}v[23220]=0;U(8,a+16|0,0,a+160|0);b=v[23220];v[23220]=0;if((b|0)==1){break l}v[23220]=0;Y(9,a+16|0);b=v[23220];v[23220]=0;if((b|0)==1){break k}v[23220]=0;Y(7,13416);b=v[23220];v[23220]=0;if((b|0)==1){break k}v[23220]=0;U(8,a|0,0,a+128|0);b=v[23220];v[23220]=0;if((b|0)==1){break j}v[23220]=0;Y(9,a|0);b=v[23220];v[23220]=0;if((b|0)==1){break i}v[23220]=0;Y(7,13414);b=v[23220];v[23220]=0;if((b|0)==1){break i}v[23220]=0;Z(10);b=v[23220];v[23220]=0;if((b|0)==1){break i}ub(a);ub(a+16|0);ub(a+32|0);ub(a+48|0);vb(a+96|0);vb(a+128|0);vb(a+144|0);vb(a+160|0)}fb=a+176|0;return}b=P()|0;O()|0;break u}b=P()|0;O()|0;break v}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=P()|0;O()|0;break y}b=P()|0;O()|0;vb(a+96|0)}vb(e)}vb(d)}vb(a+144|0)}vb(c)}vb(a+128|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;ub(a)}ub(a+16|0)}ub(a+32|0)}ub(a+48|0)}vb(a+96|0)}vb(a+128|0)}vb(a+144|0)}vb(a+160|0)}S(b|0);L()}function MV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=fb-160|0;fb=d;wc(b);Fo(a);a:{if(!bv(b,d+120|0)){break a}if(!bD(d+120|0)){break a}j=v[b+8>>2];b:{if(!Vc(b,w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))){break b}while(1){c:{if((w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))>>>0>h>>>0){if(Lb(v[b>>2],v[b+8>>2],5)){break c}}f=i&1;break b}f=0;g=1;d:{if((w[d+124|0]|w[d+125|0]<<8)>>>0>=64){if((ki(b)|0)<=0){break d}}while(1){l=Ae(b);if(l){m=f>>>0>4;e=m&g;if(!((g^1)&1|m)){e=(sp(l<<24>>24)&255)==w[f+13071|0]}g=e;f=f+1|0;continue}break}Yb(b,4);i=(f|0)==5?g&1?1:i:i}h=h+1|0;continue}}Vc(b,j);if(!f){break a}if(!Lb(v[b>>2],v[b+8>>2],aD(d+120|0))){break a}if(!c){k=1;break a}g=fb-16|0;fb=g;e=d+120|0;Vc(b,w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24));i=d+104|0;f=Ib(i);c=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24);v[23220]=0;R(168,f|0,c|0);c=v[23220];v[23220]=0;e:{f:{g:{if((c|0)!=1){c=0;h:{i:{while(1){if((w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0<=c>>>0){break h}h=v[b+8>>2];j=v[b>>2];v[23220]=0;h=W(143,j|0,h|0,5)|0;j=v[23220];v[23220]=0;if((j|0)==1){break g}if(!h){break h}h=w[e+4|0]|w[e+5|0]<<8;v[23220]=0;U(169,g|0,b|0,h|0);h=v[23220];v[23220]=0;if((h|0)!=1){v[23220]=0;R(170,f|0,g|0);h=v[23220];v[23220]=0;if((h|0)==1){break i}c=c+1|0;ub(g);continue}break}c=P()|0;O()|0;break f}c=P()|0;O()|0;ub(g);break f}fb=g+16|0;break e}c=P()|0;O()|0;break f}c=P()|0;O()|0}De(f);S(c|0);L()}v[23220]=0;X(163,d+88|0,b|0,e|0,i|0);c=v[23220];v[23220]=0;j:{if((c|0)!=1){v[23220]=0;Q(142,b|0,v[d+144>>2])|0;c=v[23220];v[23220]=0;k:{if((c|0)!=1){g=d+36|0;l:{m:{n:{o:{while(1){p:{q:{if(y[d+140>>2]>k>>>0){c=v[b+8>>2];e=v[b>>2];v[23220]=0;c=W(143,e|0,c|0,8)|0;e=v[23220];v[23220]=0;if((e|0)==1){break q}if(c){break p}}k=rc(v[a>>2],v[a+4>>2])^1;lc(d+88|0);De(d+104|0);break a}b=P()|0;O()|0;break k}v[23220]=0;da(164,d- -64|0,b|0,d+120|0,d+88|0,d+104|0);c=v[23220];v[23220]=0;if((c|0)!=1){e=Go(d- -64|0);v[23220]=0;c=T(165,v[d+64>>2])|0;f=v[23220];v[23220]=0;if((f|0)==1){break o}if(c){v[23220]=0;c=T(166,d+24|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break n}e=v[e>>2];r:{if((e|0)<0){break r}f=v[d+104>>2];if(rd(f,v[d+108>>2])>>>0<=e>>>0){break r}v[23220]=0;U(11,d+8|0,8,Dd(f,e)|0);e=v[23220];v[23220]=0;if((e|0)==1){break m}e=d+8|0;Db(c,e);vb(e)}$u(g,d- -64|0);v[23220]=0;R(167,a|0,c|0);e=v[23220];v[23220]=0;if((e|0)==1){break m}Rq(c)}k=k+1|0;wb(d- -64|0);continue}break}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=P()|0;O()|0;Rq(c)}wb(d- -64|0);break k}b=P()|0;O()|0}lc(d+88|0);break j}b=P()|0;O()|0}De(d+104|0);S(b|0);L()}fb=d+160|0;return k|0}function nda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,B=0,C=0;f=fb-4144|0;fb=f;a:{h=Jb(w[a+14|0]|w[a+15|0]<<8);b:{if(!h|h>>>0>20){break b}i=b+480190|0;h=a+20|0;if(x[i>>1]<=w[h+3|0]){break b}kd(d,32);u[d+34>>1]=1;g=f+24|0;v[g>>2]=h;v[g+4>>2]=(h+80|0)-h>>2;IP(f+4136|0,v[f+24>>2],v[f+28>>2],Jb(w[a+14|0]|w[a+15|0]<<8));h=v[f+4136>>2];j=w[zb(h,0)+3|0];v[f+24>>2]=1;j=v[Sc(Xj(b,j+1|0)+24|0,g)>>2];k=g;g=v[f+4140>>2];IP(k,h,g,c?g:1);r=1/+(j>>>0);g=v[f+24>>2];h=zb(g,v[f+28>>2]);j=v[f+4136>>2];i=x[i>>1];while(1){if((g|0)==(h|0)){c:{p=wg(d);if(!p){break c}i=(e<<12>>>0)/1e4|0;e=v[f+4140>>2];j=Ib(f+4120|0);d:{if(!e){break d}v[23220]=0;R(690,j|0,e|0);g=v[23220];v[23220]=0;if((g|0)!=1){v[23220]=0;wP(j,e);e=v[23220];v[23220]=0;if((e|0)!=1){break d}}break a}s=v[j>>2];k=v[f+4136>>2];z=v[f+4140>>2];A=b+480190|0;g=0;while(1){if((g|0)==(z|0)){h=b+24648|0}else{h=zb(k,g);e=HP(s,g);n=w[h+3|0];e:{if(n>>>0>=x[A>>1]){break e}o=t[h+1|0];if((o|0)<0){break e}l=0;h=w[h+2|0];if((h+14&255)>>>0<=5){l=t[h+26798|0]}h=Xj(b,n+1|0);n=v[h+24>>2];q=r*(Kj(+(l<<24>>24)/96+ +(o-t[zb(k,0)+1|0]|0)/12)*+(n>>>0));if(q<=0){break e}l=GP(q);v[e+8>>2]=l;n=ib;v[e+12>>2]=n;v[e+16>>2]=v[h+20>>2];o=v[h>>2];v[e+76>>2]=o;v[e+88>>2]=x[h+34>>1]&1023;f:{if(c){v[e+664>>2]=m;m=Ee(+(o>>>0)/Hz(l,n))+m|0;h=i;break f}h=(i>>>0)/(Jb(w[a+14|0]|w[a+15|0]<<8)>>>0)|0}v[e+20>>2]=h;v[e+24>>2]=h}g=g+1|0;continue}break}b=0;while(1){g:{a=v[d>>2];if(a>>>0>b>>>0){Sb(f+24|0,0,4096);v[f+16>>2]=512;v[f+12>>2]=a-b;c=v[Eb(f+16|0,f+12|0)>>2];B=f,C=Ab(v[j>>2]),v[B+16>>2]=C;i=Ab(v[j+4>>2]);while(1){a=v[f+16>>2];if(!Nb(a,i)){break g}h:{i:{if(!v[a+16>>2]){break i}e=v[a+664>>2];if(e>>>0>=c>>>0){v[a+664>>2]=e-c;break i}g=v[a+88>>2];v[f+12>>2]=c-e;B=f,C=Ee((+y[a+76>>2]-Hz(v[a>>2],v[a+4>>2]))/Hz(v[a+8>>2],v[a+12>>2])),v[B+8>>2]=C;m=v[Eb(f+12|0,f+8|0)>>2];v[23220]=0;X(v[((g&1|(g&64?18:16))<<2)+27392>>2],a|0,h|0,(f+24|0)+(e<<3)|0,m|0);e=v[23220];v[23220]=0;if((e|0)==1){break h}v[a+664>>2]=0;if(y[a+76>>2]>y[a+4>>2]){break i}v[a+16>>2]=0}v[f+16>>2]=v[f+16>>2]+872;continue}break}break a}Jp(j);break c}e=v[d+20>>2]+(b<<1)|0;g=f+24|0;a=fb-16|0;fb=a;v[a+12>>2]=c;uc(a+12|0,512);m=v[a+12>>2];while(1){if(m){i=dd(v[g>>2]+2048|0,12);i=(i|0)<32767?i:32767;u[e>>1]=(i|0)>-32768?i:-32768;g=g+8|0;e=e+2|0;m=m-1|0;continue}break}fb=a+16|0;b=b+c|0;continue}}g=(p|0)!=0}else{k=w[g+3|0];j:{if(k>>>0>=i>>>0){break j}l=t[g+1|0];if((l|0)<0){break j}k=Xj(b,k+1|0);p=v[k>>2];q=Kj(+(l-t[zb(j,0)+1|0]|0)/-12);B=d,C=v[d>>2]+Ee(r*(q*+(p>>>0)*+y[k+24>>2]))|0,v[B>>2]=C}g=g+4|0;continue}break}}fb=f+4144|0;return g|0}a=P()|0;O()|0;Jp(j);S(a|0);L()}function VJ(a){var b=C(0),c=C(0),d=0,e=C(0),f=C(0),g=0,h=0,i=C(0),k=0,m=C(0),r=C(0),s=0,t=C(0),u=0,w=C(0),x=C(0);d=a+4208|0;vN(zb(d,0),z[a+4272>>2]);b=C(C(z[zb(d,0)>>2]*C(15920))+C(80));t=ie(C(10),C(C(C(z[zb(d,2)>>2]+C(-.5))*C(30))/C(40)));c=C(C(b/C(y[v[a+16>>2]+24620>>2]))*C(6.2831854820251465));b=mK(c);w=gp(c);x=b;f=C(C(c*C(C(C(z[zb(d,1)>>2]*C(35))+C(1))*C(.02888113260269165)))/b);m=(l(2,(p(f),j(2))&-2147483648|1056964608),q());g=(p(f),j(2))&2147483647;c=(l(2,g),q());a:{if(g>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(p(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((h|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(1.7014118346046923e38));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=C(b-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=C(c*C(.5));i=C(c*b);r=C(C(i*C(C(i*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));b=C(C(3)-C(r*b));r=C(i*C(C(r-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*r)-i));if(!d){break b}e=C(C(C(c*C(r-e))-e)-i);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}b=C(c-e);b=C(C(b+b)+C(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(1.7014118346046923e38)):C(c*b))+C(-1));break b}i=(l(2,1065353216-h|0),q());c=C((d>>>0<=22?C(C(C(1)-i)+C(c-e)):C(C(c-C(e+i))+C(1)))*b)}b=c}if(g>>>0<=1065353215){if(g>>>0<964689920){break a}f=C(m*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}f=C(m*C(b+C(b/C(b+C(1)))));break a}m=C(C(m+m)*C(1.661534994731145e35));b=C(c+C(-162.88958740234375));d=Lw(b)&2047;j:{k:{if(Lw(C(88))>>>0>d>>>0){break k}c=C(0);if(((p(b),j(2))|0)==-8388608){break j}c=C(b+b);if(Lw(C(N))>>>0<=d>>>0){break j}if(b>C(88.72283172607422)){c=HD(0);break j}if(!(b<C(-103.97207641601562))){break k}c=kD(0);break j}k=A[165]*+b;s=A[164];u=k+s;k=k-(u-s);s=(A[166]*k+A[167])*(k*k)+(A[168]*k+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+1024|0;g=v[d>>2];d=v[d+4>>2]+h|0;l(0,g|0);l(1,(g>>>0<g>>>0?d+1|0:d)|0);c=C(s*+n())}f=C(C(m*c)*C(1.661534994731145e35))}c=C(x*f);f=C(c/t);b=C(f+C(1));z[a+4236>>2]=C(C(1)-f)/b;f=C(C(w*C(-2))/b);z[a+4232>>2]=f;c=C(c*t);z[a+4228>>2]=C(C(1)-c)/b;z[a+4224>>2]=f;z[a+4220>>2]=C(c+C(1))/b}function Qv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-96|0;fb=f;a:{b:{if(i=1,j=cd(a,11),k=v[a+4>>2],k?i:j){e=v[a+28>>2];d=v[a+12>>2];b=v[a+64>>2];g=b+v[a+8>>2]|0;g=ch(f+80|0,g,b>>>0>g>>>0?d+1|0:d);b=v[g+12>>2];v[f+32>>2]=v[g+8>>2];v[f+36>>2]=b;b=v[g+4>>2];v[f+24>>2]=v[g>>2];v[f+28>>2]=b;Ej(e,f+24|0);b=v[a+28>>2];if(Ek(v[(v[v[b>>2]-12>>2]+b|0)+16>>2])){dh(a,1073741826);break a}c=v[a+92>>2];h=a+44|0;b=v[h>>2];d=bh(b,v[h+4>>2]);c:{if(c>>>0>d>>>0){g=fb-32|0;fb=g;c=c-d|0;b=v[Cb(h)>>2];e=v[h+4>>2];d:{if(c>>>0<=b-e>>4>>>0){e=fb-16|0;fb=e;d=Lo(e,h,c);c=v[d+4>>2];b=v[d+8>>2];while(1){if((b|0)==(c|0)){hc(d);fb=e+16|0}else{aE(c);c=c+16|0;v[d+4>>2]=c;continue}break}break d}b=Cb(h);d=Bv(g+8|0,Cv(h,bh(v[h>>2],e)+c|0),bh(v[h>>2],v[h+4>>2]),b);b=fb-16|0;fb=b;c=$D(b,d+8|0,c);e=v[c>>2];while(1){if(v[c+4>>2]!=(e|0)){aE(e);e=v[c>>2]+16|0;v[c>>2]=e;continue}break}Ed(c);fb=b+16|0;vd(h,d);bE(d)}fb=g+32|0;break c}if(d>>>0>c>>>0){Jd(h,b+(c<<4)|0)}}g=a+32|0;Zm(g,v[a+92>>2]<<2);d=0;e:{while(1){if(y[a+92>>2]<=d>>>0){break e}b=v[a+28>>2];if(Ek(v[(v[v[b>>2]-12>>2]+b|0)+16>>2])){dh(a,1073741828);break a}c=x[a+16>>1];u[f+78>>1]=c;if((c|0)==65535){Sv(b,f+78|0);c=x[f+78>>1]}e=Wc(v[g>>2],v[g+4>>2]);b=c&65535;f:{if(!b){c=0;break f}if(b>>>0>(e^-1)>>>0){break f}Ji(g,b+e|0);Bk(v[a+28>>2],Hb(v[a+32>>2],e),b)}b=_c(v[a+44>>2],d);v[b>>2]=e;u[b+12>>1]=c;if(cd(a,6)){nk(v[a+28>>2],f+56|0);b=v[f+56>>2];if(v[f+60>>2]<0){break b}i=_c(v[a+44>>2],d),j=b,v[i+4>>2]=j}g:{b=v[a+4>>2];h:{if(b){c=_c(v[a+44>>2],d);v[c+8>>2]=b;break h}if(!cd(a,7)){c=_c(v[a+44>>2],d);break h}nk(v[a+28>>2],f+56|0);b=v[f+56>>2];if(v[f+60>>2]<0){break g}c=_c(v[a+44>>2],d);v[c+8>>2]=b}i:{if(v[c+8>>2]==-1){break i}if(cd(a,6)){break i}j:{if(!d){c=0;b=_c(v[a+44>>2],0);break j}e=v[a+44>>2];b=_c(e,d-1|0);c=v[b+8>>2]+v[b+4>>2]|0;b=_c(e,d)}v[b+4>>2]=c}if(cd(a,8)){u[f+56>>1]=0;Sv(v[a+28>>2],f+56|0);b=cd(a,9);Bl(v[a+28>>2],x[f+56>>1]<<b)}d=d+1|0;continue}break}dh(a,1073741829);break a}Yd(f+56|0,v[a+28>>2]);b=v[f+68>>2];v[a+72>>2]=v[f+64>>2];v[a+76>>2]=b}ok(a,4,1);e=v[a+76>>2];b=v[a+88>>2];g=b+v[a+8>>2]|0;d=v[a+12>>2];d=b>>>0>g>>>0?d+1|0:d;b=(b|0)==v[a+64>>2];g=b?v[a+72>>2]:g;v[a+80>>2]=g;b=b?e:d;v[a+84>>2]=b;e=v[a+28>>2];g=ch(f+40|0,g,b);b=v[g+12>>2];v[f+16>>2]=v[g+8>>2];v[f+20>>2]=b;b=v[g+4>>2];v[f+8>>2]=v[g>>2];v[f+12>>2]=b;Ej(e,f+8|0);if(cd(a,6)){break a}if(!(i=1,j=cd(a,7),k=v[a+4>>2],k?i:j)){break a}e=v[a+80>>2];b=v[a+8>>2];d=e-b|0;g=v[a+44>>2];e=v[a+92>>2];a=0;while(1){if((a|0)==(e|0)){break a}b=_c(g,a);v[b+4>>2]=d+v[b+4>>2];a=a+1|0;continue}}dh(a,1073741829)}fb=f+96|0}function YE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;i=fb-48|0;fb=i;o(+a);e=j(1)|0;d=j(0)|0;a:{b:{h=e;k=e&2147483647;c:{if(k>>>0<=1074752122){if((h&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+-6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6.077100506506192e-11;p=c-g;e=p<-.7853981633974483;if(D(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6.077100506506192e-11;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6.077100506506192e-11;c=a+f*-1.5707963267341256}a=c-g;A[b>>3]=a;o(+a);h=j(1)|0;j(0)|0;e=k>>>20|0;e:{if((e-(h>>>20&2047)|0)<17){break e}g=c;a=f*6.077100506303966e-11;c=c-a;g=f*2.0222662487959506e-21-(g-c-a);a=c-g;A[b>>3]=a;h=e;o(+a);e=j(1)|0;j(0)|0;if((h-(e>>>20&2047)|0)<50){break e}g=c;a=f*2.0222662487111665e-21;c=c-a;g=f*8.4784276603689e-32-(g-c-a);a=c-g;A[b>>3]=a}A[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,d|0);l(1,e&1048575|1096810496);a=+n();d=0;h=1;while(1){m=(i+16|0)+(d<<3)|0;if(D(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);A[m>>3]=c;a=(a-c)*16777216;d=1;m=h&1;h=0;if(m){continue}break}A[i+32>>3]=a;f:{if(a!=0){h=3;break f}d=2;while(1){h=d;d=d-1|0;if(A[(i+16|0)+(d<<3)>>3]==0){continue}break}}d=kH(i+16|0,i,(k>>>20|0)-1046|0,h,1);a=A[i>>3];if((e|0)<0){A[b>>3]=-a;A[b+8>>3]=-A[i+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[i+8>>3]}fb=i+48|0;return d}function t9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+8>>2]=43728;v[a+4>>2]=0;v[a>>2]=32160;c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;Gp(a+24604|0);qM(a+24648|0,0);v[a+397448>>2]=0;v[a+397452>>2]=0;c=a+397456|0;v[c>>2]=8;v[c+4>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;t[c+12|0]=0;v[c+8>>2]=0;u[c+24>>1]=0;Sb(c+28|0,0,40);Sb(c+68|0,0,49824);Sb(c+49892|0,0,32832);t[a+480224|0]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;c=a+480186|0;u[c>>1]=0;u[c+2>>1]=0;u[c+4>>1]=0;u[c+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;f=Ib(a+480248|0);v[a+480272>>2]=0;d=a+480280|0;while(1){c=d+(b<<5)|0;t[c+8|0]=0;v[c>>2]=0;v[c+4>>2]=4194432;yC(c+9|0);b=b+1|0;if((b|0)!=127){continue}break}e=Ib(a+484344|0);v[e+12>>2]=a;v[23220]=0;g=Q(780,a+484360|0,a|0)|0;b=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){c=a+484380|0;b=0;while(1){v[23220]=0;T(645,c+B(b,104)|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break i}b=b+1|0;if((b|0)!=4e3){continue}break}b=0;v[23220]=0;T(781,a+901404|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break h}c=a+906300|0;while(1){pM(c+B(b,160)|0);b=b+1|0;if((b|0)!=250){continue}break}b=0;v[a+946300>>2]=0;d=a+946304|0;while(1){ft(d+(b<<5)|0);b=b+1|0;if((b|0)!=4e3){continue}break}v[a+1074304>>2]=0;v[a+1074308>>2]=0;Qq(a+1074312|0);v[23220]=0;Z(782);b=v[23220];v[23220]=0;if((b|0)==1){break g}q=a,r=lM(),v[q+1074328>>2]=r;b=a+1074332|0;v[b+12>>2]=1065353216;ZL(b,4);v[23220]=0;h=T(783,a+1074376|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break g}v[23220]=0;i=W(543,a+1298264|0,a|0,255)|0;b=v[23220];v[23220]=0;if((b|0)==1){break f}j=mf(a+1298300|0);k=mf(a+1298304|0);l=Gb(a+1298308|0);m=Gb(a+1298320|0);n=Gb(a+1298332|0);o=oM(a+1298344|0);p=Ib(a+1298408|0);t[a+1298420|0]=0;b=a+1298424|0;v[b>>2]=0;v[b+4>>2]=0;v[b+32>>2]=0;v[b+36>>2]=1072693248;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[a+1298464>>2]=0;rp(a+12|0);ny(a+8204|0);ny(a+12300|0);b=a+1074408|0;v[b>>2]=4;v[b+4>>2]=16;v[a+480216>>2]=4;v[a+480220>>2]=16;Sb(a+900380|0,0,1024);kM(d);v[23220]=0;b=T(784,12)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}v[b>>2]=0;v[b+4>>2]=0;v[b+8>>2]=0;q=a,r=Ib(b),v[q+4>>2]=r;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;jM(p);qy(o);ub(n);vb(m);ub(l);py(k);oy(j);Rs(i)}Dy(h)}b=c+4e4|0;while(1){b=Js(b-160|0);if((c|0)!=(b|0)){continue}break}}AO(g)}fM(e);lc(f);S(a|0);L()}function xJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-128|0;fb=g;v[g+124>>2]=c;v[g+120>>2]=b;v[g+112>>2]=d;v[g+116>>2]=e;a:{if(!c){break a}h=w[Hk(b,c)|0];if((h|0)==33){f=1}else{if((h|0)!=63){break a}f=0}Qk(g+88|0,b,c,c-1|0);b=v[g+92>>2];v[g+120>>2]=v[g+88>>2];v[g+124>>2]=b}b=g+88|0;Kd(b);c=v[g+88>>2];Kd(g+72|0);h=Gk(c,v[g+76>>2],g+120|0);Kd(b);b=v[g+124>>2];c=v[g+120>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==v[g+92>>2]){a=oc(g+104|0,21598);if(Hc(c,b,v[a>>2],v[a+4>>2])){b=aa(8)|0;v[23220]=0;R(929,g+72|0,g+112|0);a=v[23220];v[23220]=0;if((a|0)==1){break g}v[23220]=0;U(934,g+88|0,17577,g+72|0);a=v[23220];v[23220]=0;if((a|0)==1){break f}a=0;c=qc(b,g+88|0);v[23220]=0;U(106,c|0,61832,923);c=v[23220];v[23220]=0;if((c|0)!=1){break b}c=P()|0;O()|0;ub(g+88|0);break e}if(!f){break h}b=aa(8)|0;v[23220]=0;a=Bh(g+40|0,v[g+120>>2],v[g+124>>2]);c=v[23220];v[23220]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((c|0)!=1){v[23220]=0;U(934,g+56|0,17613,a|0);c=v[23220];v[23220]=0;if((c|0)==1){break p}v[23220]=0;R(936,g+72|0,g+56|0);c=v[23220];v[23220]=0;f=1;if((c|0)==1){break o}v[23220]=0;R(929,g+24|0,g+112|0);c=v[23220];v[23220]=0;if((c|0)==1){break n}v[23220]=0;U(938,g+88|0,g+72|0,g+24|0);c=v[23220];v[23220]=0;if((c|0)==1){break m}c=qc(b,g+88|0);v[23220]=0;U(106,c|0,61832,923);c=v[23220];v[23220]=0;if((c|0)!=1){break b}c=P()|0;O()|0;ub(g+88|0);f=0;break l}c=P()|0;O()|0;break d}c=P()|0;f=1;O()|0;break i}c=P()|0;O()|0;break j}c=P()|0;O()|0;break k}c=P()|0;O()|0}ub(g+24|0)}ub(g+72|0)}ub(g+56|0)}ub(a);if(f){break d}break c}f=oc(g+16|0,21598);if(Hc(c,b,v[f>>2],v[f+4>>2])){b=aa(8)|0;v[23220]=0;R(929,g+72|0,g+112|0);a=v[23220];v[23220]=0;q:{r:{if((a|0)!=1){v[23220]=0;U(934,g+88|0,17577,g+72|0);a=v[23220];v[23220]=0;if((a|0)==1){break r}a=0;c=qc(b,g+88|0);v[23220]=0;U(106,c|0,61832,923);c=v[23220];v[23220]=0;if((c|0)!=1){break b}c=P()|0;O()|0;ub(g+88|0);break q}c=P()|0;O()|0;break d}c=P()|0;a=1;O()|0}ub(g+72|0);if(a){break d}break c}f=oc(g+8|0,10881);if(Hc(c,b,v[f>>2],v[f+4>>2])){rJ(a,Dc(d,e));break h}f=b;b=oc(g,8598);if(!Hc(c,f,v[b>>2],v[b+4>>2])){break h}a=v[a+32>>2];b=Py(d,e);b=b>>>0<4?b:1;c=fb-16|0;fb=c;s:{if((Lj(w[a+140|0])|0)==(b|0)){d=a+120|0;ds(w[d+20|0]);b=fb-16|0;fb=b;v[b+8>>2]=c+8;a=fb-16|0;fb=a;e=v[15386];v[a+8>>2]=v[15385];v[a+12>>2]=e;e=v[15384];v[a>>2]=v[15383];v[a+4>>2]=e;jb[v[cp(a,Lj(w[d+20|0]))>>2]](b+8|0,d);fb=a+16|0;fb=b+16|0;break s}YI(a,b,ZI(a))}fb=c+16|0}fb=g+128|0;return}c=P()|0;O()|0;break d}c=P()|0;a=1;O()|0}ub(g+72|0);if(!a){break c}}ba(b|0)}S(c|0)}L()}function _l(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-80|0;fb=e;h=Ib(a);v[23220]=0;a=T(269,b|0)|0;c=v[23220];v[23220]=0;a:{b:{c:{d:{e:{if((c|0)==1){break e}c=v[b+8>>2];d=v[b>>2];v[23220]=0;c=W(143,d|0,c|0,a|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}if(c){break d}v[23220]=0;a=T(189,b|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break e}v[23220]=0;Q(175,b|0,a|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break c}}a=P()|0;O()|0;break a}v[23220]=0;U(177,e+32|0,b|0,a|0);b=v[23220];v[23220]=0;f:{g:{h:{if((b|0)!=1){b=e+32|0;c=gc(e+56|0,b);wb(b);if(a>>>0<10){break g}v[23220]=0;b=T(672,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}if(!b){break g}v[23220]=0;b=T(269,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}v[e+28>>2]=b;a=a-10|0;uc(e+28|0,a>>>0>25264513?-1:B(a,170));v[23220]=0;d=v[e+28>>2];R(275,h|0,d|0);a=v[23220];v[23220]=0;if((a|0)!=1){break h}break b}a=P()|0;O()|0;break a}b=0;i:while(1){f=0;j:{k:{while(1){if(f){break j}a=v[c+8>>2];f=v[c>>2];v[23220]=0;a=Q(673,f|0,a|0)|0;f=v[23220];v[23220]=0;l:{m:{n:{o:{if((f|0)!=1){if(a){break j}v[23220]=0;a=T(477,c|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break b}f=1;switch(a|0){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}v[23220]=0;a=T(193,c|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}g=v[c+8>>2];i=v[c>>2];v[23220]=0;g=W(143,i|0,g|0,a|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break b}if(!g){continue}ge(e+32|0,v[h>>2],v[h+4>>2]);dq(e+16|0,v[e+32>>2],v[e+36>>2],b,a);v[23220]=0;X(414,e+8|0,c|0,v[e+16>>2],v[e+20>>2]);f=v[23220];v[23220]=0;if((f|0)!=1){d=d-a|0;b=a+b|0;continue i}break b}v[23220]=0;a=T(193,c|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break b}g=a<<2;if(g>>>0>d>>>0){continue}v[23220]=0;i=Q(674,c|0,e+24|0)|0;j=v[23220];v[23220]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}f=e+24|0;i=fc(f);Yg(f,i,Vg(Ab(v[h>>2]),b));b=b+4|0;a=a-1|0;continue}}if(d>>>0<8){continue}v[23220]=0;a=Q(674,c|0,e+24|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break b}if(!a){continue}a=e+24|0;f=fc(a);Yg(a,f,Vg(Ab(v[h>>2]),b));Yg(a,f,Vg(Vg(Ab(v[h>>2]),b),4));d=d-8|0;b=b+8|0;continue i}v[23220]=0;a=T(193,c|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}break}d=d-a|0;b=a+b|0;continue}d=d-g|0;continue}break}if(!d){break f}a=Ib(e+32|0);pt(a,h);$b(a);break f}v[23220]=0;U(318,c|0,h|0,a|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}}wb(c)}fb=e+80|0;return}a=P()|0;O()|0;wb(c)}$b(h);S(a|0);L()}function Vea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=fb-560|0;fb=f;a:{if(!Vc(b,1464)){break a}if(!eo(b,f+556|0)){break a}zd(a,1);Kb(Kb(zf(a+1074312|0,83),84,1),85,1);b:{if(ce(f+556|0,26889)){d=f+32|0;e=Qb(d,8417);Db(a+1298344|0,e);vb(e);e=Qb(d,14795);Db(a+1298356|0,e);vb(e);d=Qb(d,14860);Db(a+1298368|0,d);break b}if(!ce(f+556|0,15476)){break a}d=f+32|0;e=Qb(d,8575);Db(a+1298344|0,e);vb(e);e=Qb(d,12246);Db(a+1298356|0,e);vb(e);d=Qb(d,15383);Db(a+1298368|0,d)}vb(d);v[a+1298404>>2]=13;Vc(b,0);IA(b,a+1298308|0,20);u[a+480190>>1]=31;d=1;while(1)if((d|0)==32){if(g>>>0>40){break a}d=f+552|0;Ju(d,b);m=gd(d);if(w[f+552|0]>128){break a}e=f+32|0;d=fb-16|0;fb=d;c:{if(!Lb(v[b>>2],v[b+8>>2],512)){hR(e);break c}ou(d+8|0,e);md(d,b,v[d+8>>2],v[d+12>>2])}fb=d+16|0;d=0;e=w[m|0];while(1){n=(d|0)==512;if(!n){i=(f+32|0)+d|0;d=d+1|0;if(e>>>0>=w[i|0]){continue}break a}break}if(!c){break a}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;th(a,0);o=a+484376|0;gg(Vb(v[a+484360>>2],w[o|0]),w[f+552|0]);k=a+484344|0;ig(k,w[f+552|0]);e=0;while(1){if(w[f+552|0]<=e>>>0){if(!(c&2)){break a}Vc(b,(w[m|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break a}c=(B(d,104)+a|0)+484380|0;if(v[c>>2]){hg(Uc(f+8|0,8,1,0,0),c,b)}d=d+1|0;continue}}r=ac(v[Vb(v[a+484360>>2],w[o|0])>>2],e),s=e,u[r>>1]=s;d:{if(!Xg(k,e&65535,64)){break d}l=e<<2;i=0;e:while(1){if((i|0)==4){r=f,s=Ab(v[Xb(v[k>>2],e)>>2]),v[r+24>>2]=s;i=0;while(1){if((i|0)==64){break d}d=0;f:{while(1){if((d&65535)>>>0>=4){g:{t[f+31|0]=p;t[f+30|0]=q;d=h&255;if(d){break g}h=0;break f}}else{g=v[f+24>>2];h:{if((w[g+3|0]&254)!=16){break h}t[g+3|0]=16;h=0;j=w[g+5|0];if(j>>>0<16){break h}h=j>>>4|0;t[g+5|0]=h;l=h;h=j&15;g=(l|0)==(h|0)|!h;q=g?q:l;p=g?p:h;h=!g}d=d+1|0;Vz(f+24|0);continue}break}me(Xb(v[k>>2],e),He(Be(f+8|0,16,w[(d+f|0)+29|0]),i));h=h+1|0;h=(h&255)==3?1:h}i=i+1|0;continue}}Vc(b,(w[f+32+(i+l)|0]<<8)+1468|0);g=0;d=Xb(v[k>>2],e);d=$c(v[d>>2],v[v[d+48>>2]+12>>2],0,i&65535);while(1)if((g|0)==64){i=i+1|0;continue e}else{iu(b,d);i:{j:{j=w[d+3|0];k:{if((j|0)!=14){if(!j){if(w[d+5|0]){break j}break k}if((j-5&255)>>>0<5){break k}break j}if(w[d+5|0]<=15){break j}}t[d+3|0]=0;break i}Mf(d)}d=d+24|0;g=g+1|0;continue}}}e=e+1|0;continue}}else{g=bA(b,f+32|0,(B(d,104)+a|0)+484380|0,((d<<5)+a|0)+946304|0,1)+g|0;d=d+1|0;continue}}fb=f+560|0;return n|0}function F9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;j=fb-32|0;fb=j;r=v[a+4>>2];e=Ne(v[a+8>>2],b);u=v[e>>2];a:{if(u+1>>>0<2){break a}i=(B(b,872)+r|0)+616|0;if(!(H=1,I=ni(v[i+8>>2],v[i+12>>2]),J=w[e+4|0],J?H:I)){break a}f=B(b,872)+r|0;if(!v[f+720>>2]){break a}h=v[f+704>>2]&2;e=v[(h?f+700|0:f+692|0)>>2];l=v[f+700>>2];g=v[f+696>>2];xb(j+8|0,v[a>>2]+1074312|0,31);y=yb(v[v[j+8>>2]>>2],v[j+12>>2]);n=af(v[f+624>>2],v[f+628>>2],c);p=n;m=w[f+704|0]&128;n=m?0-n|0:n;k=ib;m=m?0-(k+((p|0)!=0)|0)|0:k;k=0;D=k;p=e;z=h?k:0;e=g;q=h?e:0;k=l-e|0;E=k<<1;F=f+1316|0;o=f+1467|0;A=f+1362|0;G=(w[A|0]&17)!=1;b:{while(1){if((s|0)==(u|0)){break b}c:{if(d>>>0>s>>>0){g=(w[A|0]&17)==1;break c}t[o|0]=w[o|0]&254;g=v[a>>2];e=v[a+4>>2];h=Xb(v[g+484344>>2],x[e+70>>1]);e=$c(v[h>>2],v[v[h+48>>2]+12>>2],v[e+48>>2],b);h=w[e+3|0];if(w[e+2|0]==11){l=j+8|0;Iy(l,g,h,w[e+4|0],0);l=Qe(l);Dn(v[a>>2],i,x[j+8>>1]);g=1;if(w[l|0]){break c}}g=1;d:{switch(h-4|0){case 0:Dn(v[a>>2],i,w[e+5|0]);break c;case 2:break d;default:break c}}Dn(v[a>>2],i,0)}v[j+28>>2]=v[F>>2];if(y){Ps(v[a>>2],i)}if(!G){VM(v[a>>2],i,j+28|0);g=1}if(!y){Ps(v[a>>2],i)}v[j+24>>2]=0;UM(i,j+24|0);e:{f:{if(w[f+705|0]&2){break f}g:{if(!g){if(!w[Ne(v[a+8>>2],b)+4|0]){break g}}if(w[o|0]&96){PO(i,C(1),0,v[a>>2]);e=w[o|0];t[o|0]=(e&64?-65:-33)&e}Ky(j+8|0,v[a>>2],i,v[j+28>>2],0);e=v[j+12>>2];v[f+624>>2]=v[j+8>>2];v[f+628>>2]=e;H=Ne(v[a+8>>2],b),I=0,t[H+4|0]=I;e=af(v[f+624>>2],v[f+628>>2],c);g=w[f+704|0]&128;n=g?0-e|0:e;h=ib;m=g?0-(h+((e|0)!=0)|0)|0:h}Ob(i,n,m);l=v[i>>2];e=v[i+4>>2];if((l>>>0<D>>>0&(e|0)<=(p|0)|(e|0)<(p|0))&((e|0)>=(q|0)&l>>>0>=z>>>0|(e|0)>(q|0)|((m|0)>0|(m|0)>=0))){break f}h=v[f+704>>2];if(!(h&2)){break e}if(h&4){g=v[f+696>>2];if(l>>>0<z>>>0&(e|0)<=(q|0)|(e|0)<(q|0)){H=i,I=Bg(0,g<<1,l,e),v[H>>2]=I;e=ib;v[i+4>>2]=e;v[f+704>>2]=h^128;h=n;n=0-h|0;m=0-(((h|0)!=0)+m|0)|0}xb(j+8|0,v[a>>2]+1074312|0,33);e=(e-g>>>0)%(E-yb(v[v[j+8>>2]>>2],v[j+12>>2])>>>0)|0;h:{if(e>>>0<k>>>0){g=e+v[f+696>>2]|0;break h}g=v[f+700>>2]+(k-e|0)|0}v[i+4>>2]=g;g=v[f+704>>2];if((g&128)>>>7^e>>>0<k>>>0){break f}v[f+704>>2]=g^128;e=n;n=0-e|0;m=0-(((e|0)!=0)+m|0)|0;break f}g=e;h=v[f+700>>2];if(e>>>0>=h+k>>>0){g=h+((g-h>>>0)%(k>>>0)|0)|0}while(1){e=g;g=e-k|0;if(e>>>0>=h>>>0){continue}break}v[i>>2]=l;v[i+4>>2]=e}s=s+1|0;continue}break}SO(i);v[(B(b,872)+r|0)+1324>>2]=0}H=Ne(v[a+8>>2],b),I=0,v[H>>2]=I}fb=j+32|0}function u1(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=fb-192|0;fb=d;v[d+184>>2]=c;a:{b:{c:{if(b>=.8){v[23220]=0;e=ha(1049)|0;f=v[23220];v[23220]=0;d:{e:{f:{if((f|0)!=1){v[d+80>>2]=e;v[23220]=0;c=T(1050,c|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break e}v[d+176>>2]=c;on(e,c);a=fe(d+152|0,a);v[23220]=0;f=v[a+12>>2];c=d- -64|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=f;v[d+72>>2]=v[a+16>>2];c=v[a+4>>2];v[d+56>>2]=v[a>>2];v[d+60>>2]=c;a=W(1042,e|0,d+56|0,15)|0;c=v[23220];v[23220]=0;if((c|0)==1){break f}if(a){v[23220]=0;Y(785,e|0);a=v[23220];v[23220]=0;g=1;if((a|0)==1){break f}}_i(d+176|0);$i(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;_i(d+176|0);break d}c=V(0)|0;O()|0}$i(d+80|0);break c}if(b>=.6){v[23220]=0;e=ha(1049)|0;f=v[23220];v[23220]=0;g:{h:{i:{if((f|0)!=1){v[d+80>>2]=e;v[23220]=0;c=T(1050,c|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break h}v[d+176>>2]=c;on(e,c);a=fe(d+128|0,a);v[23220]=0;c=v[a+12>>2];v[d+40>>2]=v[a+8>>2];v[d+44>>2]=c;v[d+48>>2]=v[a+16>>2];c=v[a+4>>2];v[d+32>>2]=v[a>>2];v[d+36>>2]=c;a=W(1042,e|0,d+32|0,2)|0;c=v[23220];v[23220]=0;if((c|0)==1){break i}if(a){v[23220]=0;Y(785,e|0);a=v[23220];v[23220]=0;g=.8;if((a|0)==1){break i}}_i(d+176|0);$i(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;_i(d+176|0);break g}c=V(0)|0;O()|0}$i(d+80|0);break c}g=.2;if(b>=.2){v[23220]=0;e=ha(1049)|0;f=v[23220];v[23220]=0;j:{k:{l:{if((f|0)!=1){v[d+80>>2]=e;v[23220]=0;c=T(1050,c|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break k}v[d+176>>2]=c;on(e,c);a=fe(d+104|0,a);v[23220]=0;c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;v[d+24>>2]=v[a+16>>2];c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;a=W(1042,e|0,d+8|0,0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break l}g=0;if(a){v[23220]=0;Y(785,e|0);a=v[23220];v[23220]=0;g=.6;if((a|0)==1){break l}}_i(d+176|0);$i(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;_i(d+176|0);break j}c=V(0)|0;O()|0}$i(d+80|0);break c}if(!(b>=.1)){break b}v[23220]=0;U(190,d+80|0,a|0,2048);c=v[23220];v[23220]=0;if((c|0)!=1){c=te(d+80|0);a=v[a>>2];v[23220]=0;e=v[d+80>>2];a=T(147,a|0)|0;f=v[23220];v[23220]=0;m:{if((f|0)==1){break m}v[23220]=0;a=TE(1051,c,e,a,0);c=v[23220];v[23220]=0;if((c|0)==1){break m}g=A[(a<<3)+61560>>3];Jc(d+80|0);break b}c=V(0)|0;O()|0;Jc(d+80|0);break c}c=V(0)|0;O()|0}_(c|0)|0;v[23220]=0;Z(17);a=v[23220];v[23220]=0;g=0;if((a|0)==1){break a}}pe(d+184|0);fb=d+192|0;return+g}a=P()|0;O()|0;pe(d+184|0);S(a|0);L()}function Gca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=fb+-64|0;fb=d;u[d+62>>1]=c;qg(d+62|0,32);j=Ib(a);v[23220]=0;o=x[d+62>>1];R(481,j|0,o|0);a=v[23220];v[23220]=0;a:{b:{if((a|0)!=1){l=b+480190|0;p=b+480192|0;c:{d:{while(1){if((q&65535)>>>0>=o>>>0){break d}e=1;a=x[l>>1];c=a+1|0;u[d+60>>1]=c;e:{f:{g:{if((c&65535)>>>0<4e3){break g}h:{while(1){f=e&65535;if(f>>>0>a>>>0){break h}i:{g=Xj(b,f);if(!Md(v[g>>2],v[g+20>>2])){if(!Nb(Wz(Ab(v[j>>2]),Ab(v[j+4>>2]),e),Ab(v[j+4>>2]))){break i}a=x[l>>1]}e=e+1|0;continue}break}u[d+60>>1]=e;c=1;while(1){if(x[p>>1]<c>>>0){c=e;break h}j:{a=v[((c<<2)+b|0)+900380>>2];if(!a){break j}a=a+236|0;g=$p(a);while(1){if((a|0)==(g|0)){break j}if((f|0)==x[a>>1]){u[a>>1]=0}a=a+2|0;continue}}c=c+1|0;continue}}if((c&65535)>>>0<4e3){break g}e=Sn(d+48|0);v[23220]=0;a=Q(715,b|0,e|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break b}if(!a){break e}v[23220]=0;R(716,b|0,e|0);a=v[23220];v[23220]=0;c=1;if((a|0)==1){break b}while(1){a=c&65535;if(a>>>0<=x[p>>1]){k:{a=v[((a<<2)+b|0)+900380>>2];if(!a){break k}a=a+236|0;f=$p(a);while(1){if((a|0)==(f|0)){break k}g=x[a>>1];l:{if(g>>>0>=y[d+52>>2]){break l}xb(d+40|0,v[e>>2],g);if(yb(v[v[d+40>>2]>>2],v[d+44>>2])){break l}u[a>>1]=0}a=a+2|0;continue}}c=c+1|0;continue}break}Xk(d+24|0,v[e>>2]);gP(d+32|0,v[d+24>>2],v[d+28>>2],1);$l(d+16|0,v[e>>2],v[d+52>>2]);m=fb-16|0;fb=m;g=d+40|0;c=cc(m,v[d+32>>2],v[d+36>>2]);a=Wk(v[d+16>>2],v[d+20>>2],v[d+32>>2],v[d+36>>2]);f=fb-16|0;fb=f;v[f+12>>2]=a;h=v[c+4>>2];m:{if(h){i=32-h|0;v[f+8>>2]=i;n=v[Eb(f+8|0,f+12|0)>>2];k=-1<<h&-1>>>i-n;i=v[c>>2];k=k&(v[i>>2]^-1);if(k){cc(g,i,Aia(k));break m}if((a|0)==(n|0)){gP(g,i,h,a);break m}a=a-n|0;v[f+12>>2]=a;v[c>>2]=i+4}while(1){if(a>>>0>=32){h=v[c>>2];i=v[h>>2];if((i|0)!=-1){cc(g,h,Aia(i^-1));break m}else{v[c>>2]=h+4;a=a-32|0;v[f+12>>2]=a;continue}}break}if(!a){cc(g,v[c>>2],0);break m}c=v[c>>2];h=(v[c>>2]^-1)&-1>>>32-a;if(!h){cc(g,c,a);break m}cc(g,c,Aia(h))}fb=f+16|0;fb=m+16|0;Xk(d+8|0,v[e>>2]);c=Wk(v[d+40>>2],v[d+44>>2],v[d+8>>2],v[d+12>>2]);u[d+60>>1]=c;Ie(e);if((c&65535)>>>0>3999){break f}}v[23220]=0;R(247,j|0,d+60|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}if(x[l>>1]>=(c&65535)>>>0){break f}u[b+480190>>1]=c}q=q+1|0;continue}break}Ie(e)}fb=d- -64|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ie(e)}ld(j);S(a|0);L()}function w8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb-48|0;fb=c;a:{b:{if(!Nb(v[b>>2],v[b+4>>2])){break b}l=v[b+12>>2];k=zg(v[v[b+48>>2]+12>>2]);d=k;g=Ib(c+32|0);c:{if(d){v[23220]=0;R(403,g|0,d|0);e=v[23220];v[23220]=0;if((e|0)==1){break a}f=fb-16|0;fb=f;e=gq(f,g,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){hc(e);fb=f+16|0}else{sh(d);d=d+6|0;v[e+4>>2]=d;continue}break}}break c}while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(j>>>0>=l>>>0){break s}if(!Ch(v[v[a>>2]-12>>2]+a|0)){break s}v[23220]=0;t[c+31|0]=0;Q(847,a|0,c+31|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}d=t[c+31|0];if(!d){j=j+1|0;continue}t[c+30|0]=0;t:{if((d|0)>=0){break t}v[23220]=0;Q(847,a|0,c+30|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){break t}break a}t[c+29|0]=0;sh(c+16|0);u:{d=d&127;f=(d?d-1|0:0)&65535;i=f>>>0>=k>>>0;v:{w:{if(!i){h=$c(v[b>>2],v[v[b+48>>2]+12>>2],j,f);e=w[c+30|0];if(e&1){break w}d=yd(v[g>>2],f);break v}h=c+16|0;e=w[c+30|0];if(!(e&1)){break u}}v[23220]=0;Q(847,a|0,c+29|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}if(i){break u}d=yd(v[g>>2],f);t[d|0]=w[c+29|0]}t[h|0]=w[d|0];e=w[c+30|0];if(!(e&2)){break q}break r}if(e&2){break r}break p}qh(g);break b}v[23220]=0;Q(847,a|0,c+29|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}if(i){break p}d=yd(v[g>>2],f);t[d+1|0]=w[c+29|0]}t[h+1|0]=w[d+1|0];if(e&4){break o}break n}if(!(e&4)){break m}}v[23220]=0;Q(847,a|0,c+29|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}if(i){break m}d=yd(v[g>>2],f);t[d+2|0]=w[c+29|0]}t[h+2|0]=w[d+2|0];if(!(e&8)){break k}break l}if(!(e&8)){break j}}v[23220]=0;Q(847,a|0,c+29|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}if(i){break j}d=yd(v[g>>2],f);t[d+4|0]=w[c+29|0]}t[h+4|0]=w[d+4|0];if(e&16){break i}break h}if(!(e&16)){break g}}v[23220]=0;Q(847,a|0,c+29|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}if(i){break g}d=yd(v[g>>2],f);t[d+3|0]=w[c+29|0]}t[h+3|0]=w[d+3|0];if(!(e&32)){break e}break f}if(!(e&32)){break d}}v[23220]=0;Q(847,a|0,c+29|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}if(i){break d}d=yd(v[g>>2],f);t[d+5|0]=w[c+29|0]}t[h+5|0]=w[d+5|0]}if(!(e&64)){continue}v[23220]=0;Q(847,a|0,c+15|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){v[23220]=0;Q(848,a|0,w[c+15|0])|0;d=v[23220];v[23220]=0;if((d|0)!=1){continue}}break}break a}fb=c+48|0;return}a=P()|0;O()|0;qh(g);S(a|0);L()}function W1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-192|0;fb=d;h=QI(d+176|0);v[h>>2]=49444;Ib(h+4|0);on(v[a+24>>2],h);e=v[a+24>>2];i=w[a+62|0];f=w[a+61|0];g=w[a+60|0];b=fe(d+152|0,b);v[23220]=0;j=v[b+12>>2];v[d+16>>2]=v[b+8>>2];v[d+20>>2]=j;v[d+24>>2]=v[b+16>>2];j=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=j;b=g?13:15;b=f?b&14:b;b=W(1042,e|0,d+8|0,(i?b&3:b)|0)|0;e=v[23220];v[23220]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}if(!b){b=aa(8)|0;v[23220]=0;c=Q(52,d+136|0,11984)|0;a=v[23220];v[23220]=0;if((a|0)!=1){a=qc(b,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ub(c);break b}a=P()|0;O()|0;ba(b|0);break b}if(!w[a+63|0]){v[23220]=0;R(1043,a|0,a+36|0);b=v[23220];v[23220]=0;if((b|0)==1){break e}}t[a+28|0]=1;on(v[a+24>>2],v[a+4>>2]);v[23220]=0;R(1044,d+136|0,h|0);b=v[23220];v[23220]=0;if((b|0)==1){break c}k=d,l=Ab(v[d+136>>2]),v[k+128>>2]=l;e=a+68|0;i=Ab(v[d+140>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=v[d+128>>2];if(!Nb(b,i)){k=d,l=oj(v[c>>2]),v[k+112>>2]=l;c=wf(c);while(1){b=v[d+112>>2];if(!vg(b,c)){break d}v[23220]=0;e=pd(b);b=Q(51,d+32|0,e|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break h}v[23220]=0;X(935,a|0,b|0,e+12|0,0);e=v[23220];v[23220]=0;if((e|0)==1){break g}ub(b);Rg(d+112|0);continue}}f=v[a+24>>2];g=v[b>>2];v[23220]=0;j=f;f=b+4|0;U(1045,j|0,g|0,f|0);g=v[23220];v[23220]=0;if((g|0)!=1){b=v[b>>2];v[23220]=0;R(1046,d- -64|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break r}v[23220]=0;R(981,d+80|0,d- -64|0);b=v[23220];v[23220]=0;if((b|0)==1){break q}v[23220]=0;b=Q(52,d+48|0,17713)|0;g=v[23220];v[23220]=0;if((g|0)==1){break p}v[23220]=0;U(938,d+96|0,d+80|0,b|0);g=v[23220];v[23220]=0;if((g|0)==1){break o}v[23220]=0;U(487,d+112|0,d+96|0,f|0);f=v[23220];v[23220]=0;if((f|0)==1){break n}v[23220]=0;R(170,e|0,d+112|0);f=v[23220];v[23220]=0;if((f|0)==1){break m}ub(d+112|0);ub(d+96|0);ub(b);ub(d+80|0);vb(d- -64|0);Un(d+128|0);continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;break l}a=P()|0;O()|0;ub(d+112|0)}ub(d+96|0)}ub(b)}ub(d+80|0)}vb(d- -64|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;ub(b)}hs(d+136|0);break b}a=P()|0;O()|0;break b}hs(d+136|0);as(h);fb=d+192|0;return}a=P()|0;O()|0}as(h);S(a|0)}L()}function tY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-320|0;fb=d;e=fb-16|0;fb=e;v[a>>2]=0;f=a+32|0;Zm(f,32);t[e+15|0]=0;Ym(f,e+15|0);fb=e+16|0;e=v[a+28>>2];a:{if(!Ch(v[v[e>>2]-12>>2]+e|0)){dh(a,1073741825);break a}f=d+56|0;Yd(f,e);e=v[f+12>>2];v[a+8>>2]=v[f+8>>2];v[a+12>>2]=e;v[f>>2]=3;h=v[a+28>>2];g=d+16|0;e=0;while(1){if(y[f>>2]>e>>>0){ci(h,e+g|0);e=e+1|0;continue}break}if(Mb(g,25968,3)){dh(a,1073741827);break a}t[d+319|0]=0;ci(v[a+28>>2],d+319|0);Sb(d+56|0,0,256);e=w[d+319|0];if(e){Bk(v[a+28>>2],d+56|0,e)}f=b;b=Rm(d+16|0,d+56|0,e);e=Yv(f,b);Pb(b);if(!e){dh(a,1073741830)}if(w[a+3|0]&64){break a}ci(v[a+28>>2],d+55|0);b=w[d+55|0];e=b&3;u[a+16>>1]=(e|0)==3?4:e;if(Ki(b,6)){ok(a,9,1)}v[d+48>>2]=0;bF(v[a+28>>2],d+48|0);f=v[d+48>>2];t[d+47|0]=0;if(f>>>0>=2){ci(v[a+28>>2],d+55|0);e=-1;if(!w[d+55|0]){ci(v[a+28>>2],d+47|0);e=-2}Bl(v[a+28>>2],e+f|0)}v[d+32>>2]=0;v[d+36>>2]=0;b:{if(!Ki(b,4)){break b}nk(v[a+28>>2],d+32|0);e=v[d+36>>2];f=v[d+32>>2];v[a+56>>2]=f;v[a+60>>2]=e;g=v[c+4>>2];if((g|0)==(e|0)&y[c>>2]>=f>>>0|e>>>0<g>>>0){break b}dh(a,536871424)}if(Ki(b,5)){ci(v[a+28>>2],d+55|0);Bl(v[a+28>>2],w[d+55|0])}e=w[d+47|0];c:{if(!Ki(e,0)){break c}ci(v[a+28>>2],d+55|0);c=w[d+55|0];c=c&1?-1:c>>>1|0;u[a+16>>1]=c;if(c){break c}dh(a,536871168)}v[a+4>>2]=0;c=1;if(Ki(e,1)){bF(v[a+28>>2],a+4|0)}ok(a,6,Ki(b,2));ok(a,7,Ki(b,3));ok(a,5,x[a+16>>1]!=0);ok(a,8,Ki(b,7));d:{if(cd(a,5)){break d}if(cd(a,6)){break d}if(cd(a,7)){break d}c=cd(a,8)}ok(a,11,c);cd(a,11);if(Ki(e,2)){u[d+16>>1]=0;Sv(v[a+28>>2],d+16|0);Bl(v[a+28>>2],B(x[d+16>>1],cd(a,9)?2:1))}if(Ki(e,3)){Bl(v[a+28>>2],5)}nk(v[a+28>>2],d+32|0);c=v[d+36>>2];b=v[d+32>>2];if(!c&b>>>0>=16001|c){dh(a,1073741831);break a}v[a+92>>2]=b;if(!b){dh(a,536871040)}e:{if(!cd(a,11)){break e}nk(v[a+28>>2],d+32|0);b=v[d+32>>2];c=v[d+36>>2];if((c|0)>0|(c|0)>=0){break e}dh(a,1073741829);break a}Yd(d,v[a+28>>2]);c=v[a+8>>2];e=v[a+12>>2];f=v[d+4>>2];v[d+16>>2]=v[d>>2];v[d+20>>2]=f;f=v[d+12>>2];v[d+24>>2]=v[d+8>>2];v[d+28>>2]=f;f=v[d+24>>2];e=v[d+28>>2]-(e+(c>>>0>f>>>0)|0)|0;v[d+24>>2]=f-c;v[d+28>>2]=e;c=v[d+24>>2];e=v[d+28>>2];if((e|0)==1|e>>>0>1){dh(a,1073741832);break a}v[a+88>>2]=c;c=cd(a,11);v[a+64>>2]=c?b:v[a+88>>2];if(!cd(a,11)){b=v[a+12>>2];e=v[a+88>>2];c=e+v[a+8>>2]|0;v[a+72>>2]=c;v[a+76>>2]=c>>>0<e>>>0?b+1|0:b}ok(a,10,1)}fb=d+320|0}function oea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;g=fb-16|0;fb=g;a:{if(!Lb(v[a>>2],v[a+8>>2],2)){Xg(c+484344|0,b,64);break a}l=c+484344|0;m=Pd(qq(a),1,1024);if(!Xg(l,b,m)){break a}p=x[c+480188>>1];q=c+480190|0;b:while(1){if((k|0)==(m|0)){break a}i=0;e=Xb(v[l>>2],b);n=Of(v[e>>2],v[v[e+48>>2]+12>>2],k);while(1)if((i|0)==(p|0)){k=k+1|0;continue b}else{f=g+8|0;pm(f,a);e=B(i,6)+n|0;r=Qe(f);f=zi(f);h=w[g+8|0];c:{if((h-1&255)>>>0>35){break c}t[e|0]=h+48;o=w[gd(g+8|0)|0];h=o+1|0;t[e+1|0]=h;j=h;h=h&255;if((j|0)!=(h|0)|h>>>0>x[q>>1]){break c}h=Xj(c,h);j=Hb(d,i);if(!(!w[j|0]|x[h+30>>1]>255)){t[e+4|0]=64;t[e+2|0]=1}h=v[zb(h+68|0,0)>>2];if(!(w[j|0]|h?w[j|0]?(h|0)==1:0:1)){break c}t[e+1|0]=o+101}d:{e:{switch(w[r|0]){case 1:if(!w[f|0]){break d}t[e+3|0]=2;t[e+5|0]=w[f|0];break d;case 2:if(!w[f|0]){break d}t[e+3|0]=3;t[e+5|0]=w[f|0];break d;case 12:if(!w[f|0]){break d}t[e+3|0]=1;t[e+5|0]=w[f|0];break d;case 13:if(!w[f|0]){break d}t[e+3|0]=39;t[g+7|0]=15;s=e,u=w[Rb(g+7|0,f)|0]|16,t[s+5|0]=u;break d;case 30:if(!w[f|0]){break d}t[e+3|0]=38;t[g+6|0]=15;s=e,u=w[Rb(g+6|0,f)|0]|16,t[s+5|0]=u;break d;case 21:if(!w[f|0]){break d}t[e+3|0]=39;t[g+5|0]=15;s=e,u=w[Rb(g+5|0,f)|0]|80,t[s+5|0]=u;break d;case 17:if(!w[f|0]){break d}t[e+3|0]=38;t[g+4|0]=15;s=e,u=w[Rb(g+4|0,f)|0]|80,t[s+5|0]=u;break d;case 15:t[e+3|0]=19;t[e+5|0]=w[f|0]!=0;break d;case 25:t[e+3|0]=12;t[e+5|0]=w[f|0];break d;case 27:Vn(e);t[e|0]=255;break d;case 28:if(w[f|0]>31){break d}t[e+3|0]=16;t[e+5|0]=w[f|0];break d;case 31:h=w[f|0];if(h&15){s=e,u=w[Hb(d,i)|0]?22:11,t[s+3|0]=u;t[e+5|0]=w[f|0]&15;h=w[f|0]}f:{g:{switch(h>>>4|0){case 4:if((h|0)!=64){break f}case 0:case 1:case 2:case 3:if(w[Hb(d,i)|0]){t[e+3|0]=21;t[e+5|0]=w[f|0];break f}t[e+2|0]=1;f=w[f|0];t[e+3|0]=0;t[e+4|0]=f;break f;case 5:t[e+5|0]=w[e+5|0]<<4;break f;case 6:t[g+3|0]=w[e+5|0];t[g+2|0]=14;s=e,u=w[Rb(g+3|0,g+2|0)|0]|240,t[s+5|0]=u;break f;case 7:t[g+1|0]=w[e+5|0];t[g|0]=14;s=e,u=w[Rb(g+1|0,g)|0]<<4|15,t[s+5|0]=u;break f;default:break g}}t[e+3|0]=0}if((w[e+3|0]-21&255)>>>0>1){break d}f=B(t[Hb(d,i)|0]+i|0,6)+n|0;if(vq(f+3|0,f+5|0,1)){t[f+2|0]=w[f+3|0];t[f+4|0]=w[f+5|0]}t[f+3|0]=w[e+3|0];t[f+5|0]=w[e+5|0];break d;case 0:break d;default:break e}}t[e+3|0]=0}i=i+1|0;continue}}}fb=g+16|0}function Efa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;e=fb-32|0;fb=e;a:{b:{if(!c){break b}s=e,u=Ae(a),t[s+16|0]=u;Ym(b,e+16|0);k=c-1|0;c=0;while(1){g=1;if(!k){break a}c:{d:{d=c<<1;c=d&254;if(!c){if(!Ye(a,e+16|0)){break b}i=1;d=w[e+16|0]<<1|1;c=d&255;if(d>>>0<=255){break d}break c}if((d&65535)>>>0<=255){break d}i=1;break c}if(!Ye(a,e+16|0)){break b}wT(b,e+16|0);k=k-1|0;continue}while(1){e:{f:{g:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!Ye(a,e+16|0)){break g}c=w[e+16|0]<<1|1;d=c&255;c=c>>>0>255}i=Op(i,1)+c|0;c=d<<1&254;if(c){break f}if(!Ye(a,e+16|0)){break g}d=w[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break e}c=0;break e}if(d>>>0>127){continue}}break}h:{if((i|0)<=2){j=0;h=i-2|0;break h}if(!Ye(a,e+16|0)){break b}d=Op(i-3|0,8)|w[e+16|0];j=((d|0)>1279?2:1)+((d|0)>31999)|0;n=d^-1;h=0}d=c<<1&254;if(d){f=c>>>0>127}else{if(!Ye(a,e+16|0)){break b}c=w[e+16|0]<<1|1;d=c&255;f=c>>>0>255}g=Op(h,1);c=d<<1&254;if(c){d=d>>>0>127}else{if(!Ye(a,e+16|0)){break b}d=w[e+16|0]<<1|1;c=d&255;d=d>>>0>255}i=1;h=k;d=Op(f+g|0,1)+d|0;if(!d){while(1){i:{j:{k:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!Ye(a,e+16|0)){break k}c=w[e+16|0]<<1|1;d=c&255;c=c>>>0>255}i=Op(i,1)+c|0;c=d<<1&254;if(c){break j}if(!Ye(a,e+16|0)){break k}d=w[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break i}c=0;break i}if(d>>>0>127){continue}}break}d=i+2|0}f=h;h=d+j|0;g=0;if(f>>>0<h>>>0|(h|0)<=0|(n|0)>=0){break a}d=v[b+4>>2];g=0;if((0-Wc(v[b>>2],d)|0)>(n|0)){break a}d=dc(e+24|0,Ab(d));t[e+16|0]=0;l=e+16|0;o=fb-32|0;fb=o;f=v[d>>2];d=v[b>>2];j=Se(f,Ab(d))+d|0;f=v[Cb(b)>>2];g=v[b+4>>2];l:{if(h>>>0<=f-g>>>0){d=h;f=g-j|0;if(d>>>0>f>>>0){vo(b,h-f|0,l);d=f;if(!d){break l}}p=fb-16|0;fb=p;f=g;r=v[b+4>>2];g=(r-(h+j|0)|0)+j|0;q=vk(p,b,f-g|0);m=v[q+4>>2];i=g;while(1){if(i>>>0>=f>>>0){hc(q);cq(j,g,r);fb=p+16|0}else{Hj(m,w[i|0]);m=m+1|0;v[q+4>>2]=m;i=i+1|0;continue}break}Wh(j,d,(j>>>0<=l>>>0?y[b+4>>2]>l>>>0?h:0:0)+l|0);break l}d=Cb(b);d=wl(o+8|0,tl(b,Wc(v[b>>2],g)+h|0),j-v[b>>2]|0,d);wS(d,h,l);j=xT(b,d,j);vl(d)}Ab(j);fb=o+32|0;s=e,u=Vg(IR(Ab(v[b+4>>2]),h),n),v[s+16>>2]=u;s=e,u=IR(Ab(v[b+4>>2]),h),v[s+8>>2]=u;d=h;while(1){f=w[HR(e+16|0)|0];s=HR(e+8|0),u=f,t[s|0]=u;f=d>>>0>1;d=d-1|0;if(f){continue}break}k=k-h|0;continue}}g=0}f=g;fb=e+32|0;return f|0}function Z4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-128|0;fb=e;v[e+124>>2]=c;v[e+120>>2]=b;a:{if(!c){break a}f=w[Hk(b,c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Qk(e+96|0,b,c,c-1|0);b=v[e+100>>2];v[e+120>>2]=v[e+96>>2];v[e+124>>2]=b}c=e+96|0;Kd(c);b=v[e+96>>2];Kd(e+80|0);b=Gk(b,v[e+84>>2],e+120|0);Kd(c);b:{c:{d:{e:{if((b|0)==v[e+100>>2]){b=v[e+120>>2];c=v[e+124>>2];a=oc(e+112|0,21598);if(Hc(b,c,v[a>>2],v[a+4>>2])){a=aa(8)|0;v[23220]=0;b=Q(52,e+96|0,10443)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(b);break c}b=0;if(!d){break e}b=aa(8)|0;v[23220]=0;d=Bh(e+80|0,v[e+120>>2],v[e+124>>2]);a=v[23220];v[23220]=0;f:{g:{h:{if((a|0)!=1){v[23220]=0;U(934,e+96|0,17613,d|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}a=0;c=qc(b,e+96|0);v[23220]=0;U(106,c|0,61832,923);c=v[23220];v[23220]=0;if((c|0)!=1){break b}c=P()|0;O()|0;ub(e+96|0);break g}c=P()|0;O()|0;break f}c=P()|0;a=1;O()|0}ub(d);if(!a){break c}}ba(b|0);break c}if(v[b+4>>2]){a=aa(8)|0;v[23220]=0;b=Q(52,e+96|0,11558)|0;c=v[23220];v[23220]=0;if((c|0)!=1){a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(b);break c}c=P()|0;O()|0;ba(a|0);break c}c=v[e+120>>2];d=v[e+124>>2];b=oc(e+72|0,21598);if(Hc(c,d,v[b>>2],v[b+4>>2])){a=aa(8)|0;v[23220]=0;b=Q(52,e+96|0,10443)|0;c=v[23220];v[23220]=0;if((c|0)!=1){a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(b);break c}c=P()|0;O()|0;ba(a|0);break c}i:{b=oc(e- -64|0,7380);if(!Hc(c,d,v[b>>2],v[b+4>>2])){b=oc(e+56|0,7362);if(!Hc(c,d,v[b>>2],v[b+4>>2])){break i}}b=w[a+60|0]!=0;break e}j:{b=oc(e+48|0,6895);if(!Hc(c,d,v[b>>2],v[b+4>>2])){b=oc(e+40|0,6876);if(!Hc(c,d,v[b>>2],v[b+4>>2])){break j}}b=w[a+61|0]!=0;break e}b=oc(e+32|0,6979);if(Hc(c,d,v[b>>2],v[b+4>>2])){b=w[a+62|0]!=0;break e}b=oc(e+24|0,6025);if(Hc(c,d,v[b>>2],v[b+4>>2])){b=w[a+63|0]!=0;break e}b=oc(e+16|0,7429);if(Hc(c,d,v[b>>2],v[b+4>>2])){b=w[a+64|0]!=0;break e}f=c;c=oc(e+8|0,13359);b=0;if(!Hc(f,d,v[c>>2],v[c+4>>2])){break e}b=v[v[a+24>>2]+24668>>2]!=0}fb=e+128|0;return b|0}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function rV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-384|0;fb=f;wc(b);d=fb-16|0;fb=d;h=f+344|0;tC(d+8|0,h);e=v[d+12>>2];jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],e);i=v[d+4>>2];if((i|0)==(e|0)){Yb(b,v[d+12>>2])}fb=d+16|0;d=(e|0)==(i|0);if(!d){sC(h)}a:{if(!d){break a}if(!vC(f+344|0)){break a}if(!Lb(v[b>>2],v[b+8>>2],Pc(uC(w[f+379|0]),ib))){break a}b:{if(!c){break b}zd(a,2097152);yg(a);th(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[f+376|0];v[a+480204>>2]=B(w[f+377|0],1e4);u[a+480190>>1]=w[f+378|0];d=w[f+381|0];if(d>>>0<w[f+380|0]){Ve(Vb(v[a+484360>>2],w[a+484376|0]),d)}d=f+80|0;g=Qb(d,6480);Db(a+1298344|0,g);vb(g);g=Qb(d,11056);Db(a+1298356|0,g);vb(g);v[a+1298404>>2]=5;Ku(b,d);Cq(Vb(v[a+484360>>2],w[a+484376|0]),d,w[f+380|0],65535,65535);k=a+480190|0;g=1;while(1){i=g&65535;if(i>>>0>x[k>>1]){Yb(b,B(64-w[f+378|0]|0,37));h=a+484344|0;ig(h,w[f+379|0]);i=c&1;g=0;while(1){if(w[f+379|0]<=g>>>0){if(!(c&2)){break b}c=Uc(f+40|0,8,1,0,0);d=a+480190|0;g=1;while(1){e=g&65535;if(e>>>0>x[d>>1]){break b}hg(c,(B(e,104)+a|0)+484380|0,b);g=g+1|0;continue}}c:{d:{if(i){if(Xg(h,g&65535,64)){break d}}Yb(b,2048);break c}d=Xb(v[h>>2],g);n=f,o=Ab(v[d>>2]),v[n+40>>2]=o;k=Ab(v[d+4>>2]);while(1){d=v[f+40>>2];if(!Nb(d,k)){break c}e=f+24|0;pm(e,b);j=gd(e);m=Qe(e);e=zi(e);l=w[f+24|0];if((l-1&255)>>>0<=106){t[d|0]=l+13}t[d+1|0]=w[j|0];t[d+3|0]=w[m|0];t[d+5|0]=w[e|0];Mf(d);gk(f+40|0);continue}}g=g+1|0;continue}}else{d=f+40|0;rC(b,d);h=fb-16|0;fb=h;e=(B(i,104)+a|0)+484380|0;kd(e,0);t[e+37|0]=w[d+22|0]<<4;t[h+15|0]=w[d+23|0];t[h+14|0]=64;n=e,o=w[Rb(h+15|0,h+14|0)|0]<<2,u[n+30>>1]=o;t[e+36|0]=w[d+24|0];v[e>>2]=w[d+25|0]|w[d+26|0]<<8|(w[d+27|0]<<16|w[d+28|0]<<24);j=w[d+33|0]|w[d+34|0]<<8|(w[d+35|0]<<16|w[d+36|0]<<24);if(!(j>>>0<3|j+(w[d+29|0]|w[d+30|0]<<8|(w[d+31|0]<<16|w[d+32|0]<<24))>>>0>(w[d+25|0]|w[d+26|0]<<8|(w[d+27|0]<<16|w[d+28|0]<<24))>>>0)){u[e+34>>1]=x[e+34>>1]|2;v[e+4>>2]=w[d+29|0]|w[d+30|0]<<8|(w[d+31|0]<<16|w[d+32|0]<<24);v[e+8>>2]=(w[d+33|0]|w[d+34|0]<<8|(w[d+35|0]<<16|w[d+36|0]<<24))+(w[d+29|0]|w[d+30|0]<<8|(w[d+31|0]<<16|w[d+32|0]<<24))}fb=h+16|0;e=f+8|0;dl(e,2,d);d=f+24|0;Ac(d,e);yc(((i<<5)+a|0)+946304|0,d);g=g+1|0;ub(d);continue}}}g=1}fb=f+384|0;return g|0}function w2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Gb(a);v[23220]=0;Z(91);c=v[23220];v[23220]=0;a:{b:{if((c|0)==1){c=Sa(61832,91480,92052,0)|0;d=O()|0;c:{d:{e:{if((ea(61832)|0)==(d|0)){c=_(c|0)|0;v[23220]=0;b=Q(908,a|0,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}v[23220]=0;b=Q(908,b|0,17713)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}v[23220]=0;d=Q(908,b|0,17689)|0;b=v[23220];v[23220]=0;if((b|0)==1){break e}b=jb[v[v[c>>2]+8>>2]](c)|0;v[23220]=0;Q(908,d|0,(b?b:21598)|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break e}v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((ea(91480)|0)==(d|0)){c=_(c|0)|0;v[23220]=0;b=Q(908,a|0,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break f}v[23220]=0;b=Q(908,b|0,17713)|0;d=v[23220];v[23220]=0;if((d|0)==1){break f}v[23220]=0;d=Q(908,b|0,17664)|0;b=v[23220];v[23220]=0;if((b|0)==1){break f}b=jb[v[v[c>>2]+8>>2]](c)|0;v[23220]=0;Q(908,d|0,(b?b:21598)|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break f}v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=ea(92052)|0;c=_(c|0)|0;g:{if((d|0)==(e|0)){v[23220]=0;b=Q(908,a|0,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break g}v[23220]=0;b=Q(908,b|0,17713)|0;d=v[23220];v[23220]=0;if((d|0)==1){break g}v[23220]=0;d=Q(908,b|0,17680)|0;b=v[23220];v[23220]=0;if((b|0)==1){break g}b=jb[v[v[c>>2]+8>>2]](c)|0;v[23220]=0;Q(908,d|0,(b?b:21598)|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break g}v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[23220]=0;b=Q(908,a|0,b|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}v[23220]=0;b=Q(908,b|0,17713)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}v[23220]=0;Q(908,b|0,13689)|0;b=v[23220];v[23220]=0;if((b|0)==1){break d}v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[23220]=0;Z(17);c=v[23220];v[23220]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[23220]=0;Z(17);c=v[23220];v[23220]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[23220]=0;Z(17);c=v[23220];v[23220]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[23220]=0;Z(17);c=v[23220];v[23220]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Tb()}L()}return}ub(a);S(b|0);L()}function M8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=fb-16|0;fb=h;f=v[a+8>>2];e=v[a>>2];v[23220]=0;f=Q(562,e|0,f|0)|0;e=v[23220];v[23220]=0;a:{b:{if((e|0)!=1){if(f){break b}v[23220]=0;f=T(193,a|0)|0;e=v[23220];v[23220]=0;c:{if((e|0)==1){break c}v[23220]=0;j=d+484344|0;k=Pd(f+1|0,1,1024);f=W(213,j|0,b|0,k|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}if(!f){break b}d=x[d+480188>>1];if(!d){break b}l=d-1|0;d=0;while(1){if(d>>>0>=k>>>0){break b}f=v[a+8>>2];e=v[a>>2];v[23220]=0;f=W(143,e|0,f|0,1)|0;e=v[23220];v[23220]=0;d:{if((e|0)!=1){if(!f){break b}v[23220]=0;i=T(193,a|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break a}if(i){break d}d=d+1|0;continue}break a}e=v[j>>2];u[h+14>>1]=i&31;u[h+12>>1]=l;e=Xb(e,b);e=$c(v[e>>2],v[v[e+48>>2]+12>>2],d,x[Tc(h+14|0,h+12|0)>>1]);if(!(i&224)){continue}e:{if(!(i&128)){break e}v[23220]=0;g=T(193,a|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break a}t[e+5|0]=g;v[23220]=0;g=T(193,a|0)|0;f=v[23220];v[23220]=0;f:{g:{if((f|0)!=1){if(g>>>0<26){break g}break f}break a}f=w[g+42848|0];t[e+3|0]=f;h:{switch(f-1|0){case 0:if(!w[e+5|0]){break f}break e;case 12:if(w[e+2|0]){break e}t[e+2|0]=1;f=w[e+5|0];t[e+5|0]=0;t[e+3|0]=0;m=e,n=Pd(f,0,64),t[m+4|0]=n;break e;case 5:case 6:case 10:case 23:case 28:f=w[e+5|0]&240;if(!f){break e}t[e+5|0]=f;break e;case 8:f=w[e+5|0];if(f>>>0<=128){m=e,n=vi(f<<1),t[m+5|0]=n;break e}if((f|0)!=164){break e}t[e+5|0]=145;t[e+3|0]=20;break e;case 13:f=w[e+5|0];t[e+5|0]=B(f>>>4|0,10)+(f&15);break e;case 18:zu(e);break e;case 16:if(w[e+5|0]>31){break e}t[e+3|0]=16;break e;case 27:break h;default:break e}}g=w[e+5|0];f=g&240;i:{if((f|0)==16){f=2}else{if((f|0)!=32){break i}f=3}t[e+3|0]=f}t[e+5|0]=g&15|224;break e}t[e+3|0]=0}j:{k:{if(!(i&64)){break k}v[23220]=0;R(250,h+8|0,a|0);f=v[23220];v[23220]=0;if((f|0)==1){break j}t[e+1|0]=w[h+8|0];g=w[gd(h+8|0)|0];t[e|0]=g;f=255;if((g|0)!=128){f=253;if(g>>>0<129){break k}}t[e|0]=f}if(!(i&32)){continue}t[e+2|0]=1;v[23220]=0;g=T(193,a|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break a}t[e+4|0]=g;if(!c){continue}t[e+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}wb(a);fb=h+16|0;return}b=P()|0;O()|0;wb(a);S(b|0);L()}function Faa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;s=v[a+16>>2];u=Zf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;o=v[a+128>>2];if(o){e=v[a+8>>2];k=v[a+12>>2];p=_f(e,k,o);q=ib;i=v[a+76>>2];Df(v[a>>2],v[a+4>>2],af(e,k,d),ib);k=i>>>0<ib>>>0?d:0}else{k=0}j=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}l=v[a+40>>2];m=v[a+36>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;k=k-1|0;p=k?p:0;q=k?q:0;n=(((b&2147483647)<<1|e>>>31)&-2)+s|0;e=o;a:{b:while(1){c:{if((e|0)<=0){Ob(j,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(!h){break a}e=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;g=0;b=0;break c}h=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Hd(j,(g|0)/8<<16>>16);Gd(j,4);Ob(f+40|0,p,q);e=e-1|0;continue b}else{g=(t[n+(b+h|0)|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(t[n+(b+e|0)|0]<<8)+g|0;b=b+1|0;continue}break}Hd(j,(g|0)/8<<16>>16);Gd(j,h);v[j>>2]=v[j>>2];v[j+4>>2]=0}b=Yf(j,u);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){r=(b<<2)+f|0;e=v[r>>2];i=(f+16|0)+(b<<3)|0;G=v[i+8>>2];g=v[i+4>>2];v[i+8>>2]=g;n=e<<8;e=n;e=Bia(E,F,e,e>>31);h=ib;H=i;i=e;e=Ub(g,-16777216,16776704);e=Bia(C,D,e,e>>31);g=i+e|0;i=ib+h|0;i=e>>>0>g>>>0?i+1|0:i;e=Ub(G,-16777216,16776704);h=Bia(z,A,e,e>>31);g=h+g|0;e=ib+i|0;e=g>>>0<h>>>0?e+1|0:e;h=g+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Lc(h,e,24);v[H+4>>2]=e-(n&y);v[r>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];m=v[a+28>>2]+m|0;v[c>>2]=v[c>>2]+B(v[f>>2],m>>12);l=b+l|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],l>>12);Ob(f+8|0,w,x);c=c+8|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function WU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0;f=fb-32|0;fb=f;k=Rh(f+24|0);p=k+3|0;q=k+5|0;r=k+4|0;s=k+2|0;x=k+1|0;d=f+16|0;z=d|5;A=d|3;while(1){a:{if(y[a+12>>2]>m>>>0){C=Of(v[a>>2],v[v[a+48>>2]+12>>2],m);b:while(1){if(!Lb(v[c>>2],v[c+8>>2],1)){break a}l=Ae(c);if((l|0)==255){break a}d=l&31;h=B(d,6)+C|0;i=zg(v[v[a+48>>2]+12>>2])>>>0>d>>>0;j=i?h:k;e=1;if(!(l&64)){d=Ae(c);g=d<<24>>24;e=255;d=d&127;c:{d:{if((d|0)==1){break d}e=d-1|0;if(b?e>>>0<=120:0){break d}if((d-109&255)>>>0<159|b){break c}e=d+13|0}t[j|0]=e}D=i?h+1|0:x,E=Ae(c),t[D|0]=E;e=(g|0)<0}g=i?h+3|0:p;d=i?h+5|0:q;n=i?h+4|0:r;i=i?h+2|0:s;while(1){e:{f:{g:{if(e&1){v[f+16>>2]=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);u[f+20>>1]=w[j+4|0]|w[j+5|0]<<8;o=Ae(c);h=o&63;if(o&64){t[i|0]=1;t[n|0]=h;break e}e=Ae(c);t[d|0]=e;if(h>>>0<=15){t[g|0]=h;Mf(j);h:{i:{j:{e=w[g|0];switch(e-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}t[g|0]=9;t[d|0]=B(w[d|0]&15,17);break f}t[g|0]=0;t[i|0]=1;v[f+12>>2]=w[d|0]+1>>>1;v[f+8>>2]=64;D=n,E=v[nd(f+12|0,f+8|0)>>2],t[D|0]=E;break f}if((e|0)!=19){break f}if(w[d|0]==128){break g}zu(j);break f}if(h>>>0>44){break f}t[g|0]=w[h+26224|0];k:{switch(h-16|0){case 0:if(e>>>0>1){break g}t[d|0]=e|158;break f;case 1:case 2:t[f+12|0]=15;D=d,E=w[Rb(f+12|0,d)|0]|224,t[D|0]=E;break f;case 5:case 6:v[f+12>>2]=16;v[f+8>>2]=e+1;D=d,E=v[nd(f+12|0,f+8|0)>>2]/2|240,t[D|0]=E;break f;case 14:l:{m:{n:{o:{p:{h=e>>>4|0;switch(h-1|0){case 1:break n;case 0:break o;default:break p}}switch(h-10|0){case 1:break l;case 0:break m;default:break g}}t[g|0]=2;t[d|0]=e|240;break f}t[g|0]=3;t[d|0]=e|240;break f}t[g|0]=11;t[d|0]=(e<<3&120)+8|15;break f}t[g|0]=11;t[d|0]=(e&15)+1>>>1|240;break f;case 12:break k;default:break f}}v[f+12>>2]=e+1>>>1;v[f+8>>2]=64;D=d,E=v[nd(f+12|0,f+8|0)>>2],t[D|0]=E;break f}if(!(l&128)){continue b}break a}t[g|0]=0}yu(g,d,A,z);e=w[f+19|0];if(yi(e)>>>0<=yi(w[g|0])>>>0){break e}q:{if(w[i|0]){break q}if(!vq(g,d,1)){break q}t[i|0]=w[g|0];t[n|0]=w[d|0]}t[g|0]=e;t[d|0]=w[f+21|0]}e=o>>>7|0;continue}}}fb=f+32|0;return}m=m+1|0;continue}}function Ys(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=fb-16|0;fb=i;f=v[a+24>>2];h=Zy(f,w[a+32|0]);j=v[h>>2];a:{if(Ic(j,v[h+4>>2])>>>0<=b>>>0){break a}if(UN(f,x[ac(j,b)>>1])>>>0<=c>>>0){break a}h=v[a>>2];b:{if(rd(h,v[a+4>>2])>>>0>b>>>0){if(y[Dd(h,b)+4>>2]>c>>>0){break b}}Mn(a,0);if(rd(v[a>>2],v[a+4>>2])>>>0<=b>>>0){break a}f=v[a+24>>2]}ec(i,v[d>>2],x[f+480188>>1]);d=i+8|0;h=v[i>>2];f=e?-2046629010:-2078137563;e=e?-1352371636:-873292572;j=v[i+4>>2];while(1){if(!g&(k|0)==(j|0)){v[d>>2]=f;v[d+4>>2]=e}else{l=w[HP(h,k)+841|0];m=l^Bia(f^k,e^g,435,256);l=!l;f=(q=f,r=Bia(m,ib,435,256),s=l,s?q:r);e=l?e:ib;k=k+1|0;g=k?g:g+1|0;continue}break}e=d;d=0;f=Tl(i,b,c);h=fb-16|0;fb=h;k=a+12|0;g=KN(x[f>>1],v[f+4>>2],Od(k),fc(k));c:{if(Nb(g,Hf(k))){j=x[f>>1];l=v[f+4>>2];f=pd(g);if(!Sk(j,l,x[f>>1],v[f+4>>2])){break c}}g=Hf(k)}f=v[dc(h+8|0,g)>>2];fb=h+16|0;if(vg(f,wf(k))){d=pd(f);d=rc(v[d+8>>2],v[d+12>>2])^1}h=v[e>>2]!=-2078137563|v[e+4>>2]!=-873292572;xb(i,v[Dd(v[a>>2],b)>>2],c);g=1;j=d|h;m=yb(v[v[i>>2]>>2],v[i+4>>2])^1;if(!(m?1:j)){break a}d:{e:{f:{g:{if(d){l=pd(f);f=Ab(v[l+8>>2]);n=Ab(v[l+12>>2]);o=v[e>>2];p=v[e+4>>2];j=fb-16|0;fb=j;v[j+8>>2]=f;while(1){if(!(!Nb(f,n)|v[f>>2]==(o|0)&v[f+4>>2]==(p|0))){f=v[_s(j+8|0)>>2];continue}break}fb=j+16|0;if(Nb(f,Ab(v[l+12>>2]))){break a}if(!h){break e}break g}if(h){break g}if(!j){break d}break f}v[a+28>>2]=v[a+28>>2]+1}if(d|m){break e}d=IN(k,Tl(i,b,c));h:{if(y[d+4>>2]<y[Cb(d)>>2]){g=fb-16|0;fb=g;d=HN(g,d);GN(v[d+4>>2]);v[d+4>>2]=v[d+4>>2]+8;hc(d);fb=g+16|0;break h}f=fb-32|0;fb=f;g=Cb(d);g=Vq(f+8|0,Wq(d,Dg(v[d>>2],v[d+4>>2])+1|0),Dg(v[d>>2],v[d+4>>2]),g);GN(v[g+8>>2]);v[g+8>>2]=v[g+8>>2]+8;vd(d,g);Uq(g);fb=f+32|0}}d=IN(k,Tl(i,b,c));i:{if(y[d+4>>2]<y[Cb(d)>>2]){g=fb-16|0;fb=g;d=HN(g,d);GM(v[d+4>>2],v[e>>2],v[e+4>>2]);v[d+4>>2]=v[d+4>>2]+8;hc(d);fb=g+16|0;break i}f=fb-32|0;fb=f;g=Cb(d);g=Vq(f+8|0,Wq(d,Dg(v[d>>2],v[d+4>>2])+1|0),Dg(v[d>>2],v[d+4>>2]),g);GM(v[g+8>>2],v[e>>2],v[e+4>>2]);v[g+8>>2]=v[g+8>>2]+8;vd(d,g);Uq(g);fb=f+32|0}}xb(i,v[Dd(v[a>>2],b)>>2],c);sg(i,1);g=0}fb=i+16|0;return g|0}function sx(a){a=a|0;var b=0,c=0,d=C(0),e=0;Sb(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[23220]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}da(896,e|0,67,5,c|0,b|0);b=v[23220];v[23220]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[23220]=0;da(896,a+4528|0,62,5,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[23220]=0;da(896,a+4552|0,53,5,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[23220]=0;da(896,a+4576|0,43,5,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[23220]=0;da(896,a+4600|0,32,5,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[23220]=0;da(896,a+4624|0,22,5,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[23220]=0;da(896,a+4648|0,75,5,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[23220]=0;da(896,a+4672|0,69,5,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[23220]=0;da(896,a+4696|0,60,5,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[23220]=0;da(896,a+4720|0,48,5,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[23220]=0;da(896,a+4744|0,36,5,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[23220]=0;da(896,a+4768|0,25,5,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}v[23220]=0;da(896,a+4792|0,0,0,0,0);b=v[23220];v[23220]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[23220]=0;da(896,a+4816|0,3,0,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[23220]=0;da(896,a+4840|0,3,0,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}v[23220]=0;da(896,a+4864|0,407,1,c|0,0);b=v[23220];v[23220]=0;if((b|0)==1){break a}v[23220]=0;da(896,a+4888|0,400,1,c|0,0);b=v[23220];v[23220]=0;if((b|0)==1){break a}v[23220]=0;da(896,a+4912|0,10,0,c|0,-1);b=v[23220];v[23220]=0;if((b|0)==1){break a}v[23220]=0;da(896,a+4936|0,10,0,c|0,-1);c=v[23220];v[23220]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(91480)|0;if((O()|0)==(ea(91480)|0)){_(c|0)|0;t[a+5045|0]=0;$();return}S(c|0);L()}function hda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-128|0;fb=d;a:{b:{c:{d:{switch(w[a|0]-23|0){case 0:e=t[a+1|0];f=d,g=_Q(c,+w[a+2|0]*1e4/240),t[f|0]=g;v[d+96>>2]=127;v[d+80>>2]=(B(w[a+3|0],127)>>>0)/185;f=d,g=v[nd(d+96|0,d+80|0)>>2],t[f+127|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:ku(d+80|0,15551);v[23220]=0;R(503,d- -64|0,d|0);a=v[23220];v[23220]=0;f:{g:{h:{i:{if((a|0)!=1){v[23220]=0;R(503,d+48|0,d+127|0);a=v[23220];v[23220]=0;if((a|0)==1){break i}v[23220]=0;X(504,d+96|0,d+80|0,d- -64|0,d+48|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}a=d+96|0;re(d+112|0,a);Te(b,v[d+112>>2],v[d+116>>2]);ub(a);ub(d+48|0);ub(d- -64|0);Pb(d+80|0);break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;ub(d+48|0)}ub(d- -64|0)}break c;case 1:ku(d+80|0,15491);v[23220]=0;R(503,d- -64|0,d|0);a=v[23220];v[23220]=0;j:{k:{l:{m:{if((a|0)!=1){v[23220]=0;R(503,d+48|0,d+127|0);a=v[23220];v[23220]=0;if((a|0)==1){break m}v[23220]=0;X(504,d+96|0,d+80|0,d- -64|0,d+48|0);a=v[23220];v[23220]=0;if((a|0)==1){break l}a=d+96|0;re(d+40|0,a);Te(b,v[d+40>>2],v[d+44>>2]);ub(a);ub(d+48|0);ub(d- -64|0);Pb(d+80|0);break b}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;ub(d+48|0)}ub(d- -64|0)}break c;default:break e}}a=oc(d+32|0,15578);Te(b,v[a>>2],v[a+4>>2]);break b;case 1:break d;default:break a}}c=t[a+1|0];t[d+127|0]=(c|0)<5?c:0;c=t[a+2|0];t[d+31|0]=(c|0)>=0?c:127;a=t[a+3|0];t[d+30|0]=(a|0)>=0?a:127;a=fb-16|0;fb=a;c=Qb(a,4009);Mc(d+80|0,c);ub(c);fb=a+16|0;v[23220]=0;R(503,d- -64|0,d+127|0);a=v[23220];v[23220]=0;n:{o:{p:{q:{r:{s:{if((a|0)!=1){v[23220]=0;R(503,d+48|0,d+31|0);a=v[23220];v[23220]=0;if((a|0)==1){break s}v[23220]=0;R(503,d|0,d+30|0);a=v[23220];v[23220]=0;if((a|0)==1){break r}v[23220]=0;da(676,d+96|0,d+80|0,d- -64|0,d+48|0,d|0);a=v[23220];v[23220]=0;if((a|0)==1){break q}a=d+96|0;re(d+16|0,a);Te(b,v[d+16>>2],v[d+20>>2]);ub(a);ub(d);ub(d+48|0);ub(d- -64|0);Pb(d+80|0);break b}a=P()|0;O()|0;break n}a=P()|0;O()|0;break o}a=P()|0;O()|0;break p}a=P()|0;O()|0;ub(d)}ub(d+48|0)}ub(d- -64|0)}}Pb(d+80|0);S(a|0);L()}e=1}fb=d+128|0;return e|0}function Eaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;s=v[a+16>>2];t=Zf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;o=v[a+128>>2];if(o){e=v[a+8>>2];j=v[a+12>>2];p=_f(e,j,o);q=ib;g=v[a+76>>2];Df(v[a>>2],v[a+4>>2],af(e,j,d),ib);j=g>>>0<ib>>>0?d:0}else{j=0}i=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}m=v[a+40>>2];n=v[a+36>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];a:while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;j=j-1|0;p=j?p:0;q=j?q:0;l=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+s|0;b=o;while(1)if((b|0)<=0){Ob(i,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(h){b=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Hd(i,(u[(b<<1|2)+l>>1]+u[l+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Gd(i,h);v[i>>2]=v[i>>2];v[i+4>>2]=0}b=Yf(i,t);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){r=(b<<2)+f|0;e=v[r>>2];g=(f+16|0)+(b<<3)|0;G=v[g+8>>2];k=v[g+4>>2];v[g+8>>2]=k;l=e<<8;e=l;e=Bia(E,F,e,e>>31);h=ib;H=g;g=e;e=Ub(k,-16777216,16776704);e=Bia(C,D,e,e>>31);k=g+e|0;g=ib+h|0;g=e>>>0>k>>>0?g+1|0:g;e=Ub(G,-16777216,16776704);h=Bia(z,A,e,e>>31);k=h+k|0;e=ib+g|0;e=h>>>0>k>>>0?e+1|0:e;h=k+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Lc(h,e,24);v[H+4>>2]=e-(l&y);v[r>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];n=v[a+28>>2]+n|0;v[c>>2]=v[c>>2]+B(v[f>>2],n>>12);m=b+m|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],m>>12);Ob(f+8|0,w,x);c=c+8|0;continue a}else{e=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Hd(i,(u[(e<<1|2)+l>>1]+u[l+((e&2147483646)<<1)>>1]|0)/8<<16>>16);Gd(i,4);Ob(f+40|0,p,q);b=b-1|0;continue}}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=m;v[a+20>>2]=n>>12;v[a+36>>2]=n;v[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function P6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=C(0),A=0,B=0,E=0,F=0,G=0,H=0,I=C(0),J=0,K=0,L=0,M=0,N=0,O=C(0),P=0,Q=C(0);a:{if(!v[a+4316>>2]){break a}if(!Th(a+44|0)){break a}G=a+4300|0;H=a+4288|0;J=a+4264|0;K=a+4276|0;e=v[a+44>>2];s=zc(e,0);t=zc(e,1);e=v[a+56>>2];u=zc(e,0);x=zc(e,1);L=jb[v[v[a>>2]+192>>2]](a)|0;y=C(C(jb[v[v[a>>2]+200>>2]](a))/C(100));I=C(jb[v[v[a>>2]+188>>2]](a));A=jb[v[v[a>>2]+212>>2]](a)|0;M=A&1;o=v[a+4324>>2];i=v[a+4320>>2];m=v[a+4328>>2];k=v[a+4312>>2];N=v[a+4276>>2];p=v[a+4264>>2];B=v[a+4256>>2];E=w[a+4260|0];r=a+4316|0;F=d;while(1){if(F){h=z[t>>2];l=z[s>>2];j=v[r>>2];e=vn(j,k+B|0);j=vn(j,k);b:{if(E){P=zb(H,m),Q=l,z[P>>2]=Q;P=zb(G,m),Q=h,z[P>>2]=Q;q=zb(p,e);P=zb(p,j),Q=C(C(z[q>>2]*y)+l),z[P>>2]=Q;g=C(C(z[zb(N,e)>>2]*y)+h);e=K;break b}g=C(C(z[zb(p,e)>>2]*y)+C(C(l+h)*C(.5)));e=J}P=zb(v[e>>2],j),Q=g,z[P>>2]=Q;c:{if(L){f=z[a+4244>>2];g=C(f+z[a+4236>>2]);z[a+4236>>2]=g;f=C(f+z[a+4240>>2]);z[a+4240>>2]=f;if(g>C(1)){g=C(g+C(-2));z[a+4236>>2]=g}if(f>C(1)){f=C(f+C(-2));z[a+4240>>2]=f}g=C(D(g));g=C(C(g+g)+C(-1));f=C(D(f));f=C(C(f+f)+C(-1));break c}f=z[a+4240>>2];n=z[a+4244>>2];g=C(C(f*n)+z[a+4236>>2]);z[a+4236>>2]=g;f=C(f-C(g*n));z[a+4240>>2]=f}if(E){e=(m+2|0)%3|0;l=z[zb(H,e)>>2];h=z[zb(G,e)>>2]}e=v[r>>2];j=zb(p,vn(e,i+k|0));q=e;e=k+4096|0;O=z[zb(p,vn(q,e+i|0))>>2];n=z[j>>2];z[u>>2]=C(C(C(C(C(O-n)*C(C(i&4095)*C(.000244140625)))+n)-l)*I)+l;i=v[(E?4276:4264)+a>>2];j=v[r>>2];q=zb(i,vn(j,k+o|0));n=z[zb(i,vn(j,e+o|0))>>2];l=z[q>>2];z[x>>2]=C(C(C(C(C(n-l)*C(C(o&4095)*C(.000244140625)))+l)-h)*I)+h;m=((m|0)<=0?m+3|0:m)-1|0;v[a+4328>>2]=m;k=(((k|0)>0?0:v[r>>2]<<12)+k|0)-4096|0;v[a+4312>>2]=k;h=M?f:g;f=z[a+4248>>2];h=C(h*f);d:{if(C(D(h))<C(2147483648)){e=~~h;break d}e=-2147483648}o=(A>>>0>1?e:0-e|0)+B|0;v[a+4324>>2]=o;i=A>>>0<4;t=t+4|0;s=s+4|0;g=C(g*f);e:{if(C(D(g))<C(2147483648)){e=~~g;break e}e=-2147483648}i=(i?e:0-e|0)+B|0;v[a+4320>>2]=i;F=F-1|0;x=x+4|0;u=u+4|0;continue}else{e=a;a=v[a+56>>2];hi(e,b,c,zc(a,0),zc(a,1),d)}break}}}function w5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=C(0),n=0,o=C(0),p=C(0),q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,A=C(0),B=0,D=0,E=0,F=0,G=C(0),H=0,I=0,J=0,K=0,L=C(0),M=C(0),N=C(0),O=C(0),P=C(0),Q=0,R=C(0);if(Th(a+44|0)){f=v[a+44>>2];B=zc(f,0);D=zc(f,1);f=v[a+56>>2];E=zc(f,0);F=zc(f,1);s=v[a+4296>>2];g=s+1|0;l=a+4304|0;f=a+4272|0;u=g+v[zb(f,0)>>2]&4095;q=l+(u<<4)|0;w=g+v[zb(f,1)>>2]&4095;n=((w<<4)+l|0)+4|0;x=g+v[zb(f,2)>>2]&4095;j=((x<<4)+l|0)+8|0;h=zb(f,3);i=v[zb(f,4)>>2];r=v[a+4300>>2];i=i+r|0;y=g+v[h>>2]&4095;h=((y<<4)+l|0)+12|0;t=v[zb(f,5)>>2]+r|0;g=a+4232|0;H=a+69840|0;I=a+78032|0;f=d;while(1){if(f){L=z[h>>2];M=z[j>>2];N=z[n>>2];O=z[q>>2];A=z[D>>2];P=z[B>>2];J=i&1023;j=(J<<3)+H|0;k=z[j+4>>2];u=u-1&4095;q=(u<<4)+l|0;e=z[q>>2];h=r<<3;i=h+H|0;w=w-1&4095;n=(w<<4)+l|0;m=z[n+4>>2];o=m;p=C(m*C(.6180340051651001));G=z[j>>2];m=z[zb(g,0)>>2];p=C(p+C(G*m));z[i+4>>2]=o+C(p*C(-.6180340051651001));o=e;e=C(C(k*m)+C(e*C(-.6180340051651001)));z[i>>2]=o+C(e*C(.6180340051651001));z[q>>2]=p;z[n+4>>2]=e;t=t&1023;K=(t<<3)+I|0;m=z[K+4>>2];x=x-1&4095;i=(x<<4)+l|0;e=z[i+8>>2];h=h+I|0;y=y-1&4095;j=(y<<4)+l|0;k=z[j+12>>2];o=k;G=z[K>>2];p=z[zb(g,1)>>2];k=C(C(k*C(.6180340051651001))+C(G*p));z[h+4>>2]=o+C(k*C(-.6180340051651001));o=e;e=C(C(m*p)+C(e*C(-.6180340051651001)));z[h>>2]=o+C(e*C(.6180340051651001));z[i+8>>2]=k;z[j+12>>2]=e;e=C(P+C(1.0000000031710769e-30));z[E>>2]=k+C(C(e*z[a+4224>>2])+z[q>>2]);k=C(A+C(1.0000000031710769e-30));z[F>>2]=C(C(k*z[a+4224>>2])+z[n+4>>2])+z[j+12>>2];h=(s<<4)+l|0;m=e;e=z[a+4228>>2];A=C(m*e);Q=h,R=C(A+C(C(z[q>>2]*z[zb(g,2)>>2])+C(O*z[zb(g,3)>>2]))),z[Q>>2]=R;e=C(k*e);Q=h,R=C(e+C(C(z[n+4>>2]*z[zb(g,4)>>2])+C(N*z[zb(g,5)>>2]))),z[Q+4>>2]=R;Q=h,R=C(C(C(z[i+8>>2]*z[zb(g,6)>>2])+C(M*z[zb(g,7)>>2]))-e),z[Q+8>>2]=R;Q=h,R=C(A+C(C(z[j+12>>2]*z[zb(g,8)>>2])+C(L*z[zb(g,9)>>2]))),z[Q+12>>2]=R;h=j+12|0;j=i+8|0;n=n+4|0;f=f-1|0;F=F+4|0;E=E+4|0;D=D+4|0;B=B+4|0;t=t-1|0;i=J-1|0;r=r-1&1023;s=s-1&4095;continue}else{v[a+4300>>2]=r;v[a+4296>>2]=s;f=a;a=v[a+56>>2];hi(f,b,c,zc(a,0),zc(a,1),d)}break}}}function Jaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;q=v[a+16>>2];r=Zf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;m=v[a+128>>2];if(m){e=v[a+8>>2];k=v[a+12>>2];n=_f(e,k,m);o=ib;i=v[a+76>>2];Df(v[a>>2],v[a+4>>2],af(e,k,d),ib);k=i>>>0<ib>>>0?d:0}else{k=0}j=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];u=v[a+20>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;k=k-1|0;n=k?n:0;o=k?o:0;l=(((b&2147483647)<<1|e>>>31)&-2)+q|0;e=m;a:{b:while(1){c:{if((e|0)<=0){Ob(j,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(!h){break a}e=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;g=0;b=0;break c}h=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Hd(j,(g|0)/8<<16>>16);Gd(j,4);Ob(f+40|0,n,o);e=e-1|0;continue b}else{g=(t[l+(b+h|0)|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(t[l+(b+e|0)|0]<<8)+g|0;b=b+1|0;continue}break}Hd(j,(g|0)/8<<16>>16);Gd(j,h);v[j>>2]=v[j>>2];v[j+4>>2]=0}b=Yf(j,r);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=v[p>>2];i=(f+16|0)+(b<<3)|0;G=v[i+8>>2];g=v[i+4>>2];v[i+8>>2]=g;l=e<<8;e=l;e=Bia(E,F,e,e>>31);h=ib;H=i;i=e;e=Ub(g,-16777216,16776704);e=Bia(C,D,e,e>>31);g=i+e|0;i=ib+h|0;i=e>>>0>g>>>0?i+1|0:i;e=Ub(G,-16777216,16776704);h=Bia(z,A,e,e>>31);g=h+g|0;e=ib+i|0;e=g>>>0<h>>>0?e+1|0:e;h=g+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Lc(h,e,24);v[H+4>>2]=e-(l&y);v[p>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],u);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],s);Ob(f+8|0,w,x);c=c+8|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function $O(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-128|0;fb=j;a:{b:{c:{if(!gm(f,g,h,i,0,0,0,0)){break c}m=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){l=4;if(n){break e}l=f|h|(g|m)?3:2;break d}l=!(f|h|(g|m))}}r=e>>>16|0;o=r&32767;if((o|0)==32767){break c}if(l){break b}}Ad(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];EP(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}m=e&65535|o<<16;p=m;l=d;m=h;q=i>>>16&32767;k=i&65535|q<<16;if((gm(b,c,l,p,f,g,h,k)|0)<=0){if(gm(b,c,l,p,f,g,m,k)){h=b;i=c;break a}Ad(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(o){i=c;h=b}else{Ad(j+96|0,b,c,l,p,0,0,0,1081540608);h=v[j+108>>2];p=h;l=v[j+104>>2];o=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){Ad(j+80|0,f,g,m,k,0,0,0,1081540608);f=v[j+92>>2];k=f;m=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){t=l-m|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=(p-((l>>>0<m>>>0)+s|0)|0)-(t>>>0<k>>>0)|0;k=t-k|0;f:{if((n|0)>0|(n|0)>=0){l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(!(h|k|(i|n))){Ad(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}n=n<<1|k>>>31;l=k<<1|i>>>31;p=n;break f}n=p<<1|l>>>31;l=l<<1|i>>>31;p=n}n=i<<1|h>>>31;h=h<<1;i=n;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}q=l-m|0;n=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=(p-((l>>>0<m>>>0)+s|0)|0)-(q>>>0<n>>>0)|0;m=q-n|0;g:{if((k|0)<0){m=l;k=p;break g}l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(h|m|(i|k)){break g}Ad(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m;k=k<<1|b>>>31;m=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){Ad(j- -64|0,h,i,m,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=m;e=k&65535|(b|o)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;fb=j+128|0}function jba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;e=fb-48|0;fb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}s=b;t=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}m=v[a+40>>2];n=v[a+36>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;w=v[a+32>>2];x=v[a+28>>2];y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;while(1){if(d){b=v[e+16>>2];G=((((v[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(b>>>16&65520)+s|0;H=u[b+14>>1];g=u[b+12>>1];q=u[b+10>>1];r=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];o=0;p=0;while(1){if((p|0)!=2){i=G+(p<<1)|0;v[(e+8|0)+(p<<2)>>2]=(((((((B(u[i-8>>1],f)+B(u[i-12>>1],b)|0)+B(u[i-4>>1],k)|0)+B(u[i>>1],h)|0)+B(u[i+4>>1],r)|0)+B(u[i+8>>1],q)|0)+B(g,u[i+12>>1])|0)+B(H,u[i+16>>1])|0)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){q=(e+8|0)+(o<<2)|0;b=v[q>>2];g=(e+24|0)+(o<<3)|0;r=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=Bia(E,F,b,b>>31);f=ib;i=g;g=b;b=Ub(h,-16777216,16776704);b=Bia(C,D,b,b>>31);h=g+b|0;g=ib+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Ub(r,-16777216,16776704);f=Bia(z,A,b,b>>31);h=f+h|0;b=ib+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Lc(f,b,24);v[i+4>>2]=b-(k&y);v[q>>2]=(b|0)/256;o=o+1|0;continue}break}n=n+x|0;v[c>>2]=v[c>>2]+B(v[e+8>>2],n>>12);m=m+w|0;v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],m>>12);Ob(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;v[a+40>>2]=m;v[a+20>>2]=n>>12;v[a+36>>2]=n;v[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=e+48|0}function oaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=fb-16|0;fb=i;c=bf(a,c);Yd(i,v[a+28>>2]);j=a;a:{if(!c){e=0;if(cd(a,5)){break a}}e=fb-224|0;fb=e;g=yl(e+120|0,v[a+28>>2]);v[23220]=0;f=Q(404,e+104|0,27800)|0;a=v[23220];v[23220]=0;b:{c:{d:{e:{if((a|0)!=1){v[23220]=0;v[e+88>>2]=19923968;v[e+92>>2]=0;U(405,g|0,f|0,e+88|0);a=v[23220];v[23220]=0;if((a|0)==1){break e}Pb(f);if(!(w[g+3|0]&64)){break d}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;Pb(f);break c}t[e+103|0]=0;v[23220]=0;f=Q(404,e+88|0,5466)|0;a=v[23220];v[23220]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[23220]=0;U(406,g|0,e+103|0,f|0);a=v[23220];v[23220]=0;if((a|0)==1){break q}Pb(f);f=Gb(e+72|0);v[23220]=0;a=Q(404,e+56|0,10055)|0;h=v[23220];v[23220]=0;if((h|0)==1){break p}v[23220]=0;U(724,g|0,f|0,a|0);h=v[23220];v[23220]=0;if((h|0)==1){break o}Pb(a);v[23220]=0;U(11,e+40|0,(w[e+103|0]?0:d)|0,f|0);d=v[23220];v[23220]=0;if((d|0)==1){break n}v[23220]=0;R(263,b|0,e+40|0);d=v[23220];v[23220]=0;if((d|0)==1){break m}d=e+40|0;vb(d);u[e+38>>1]=0;v[23220]=0;d=Q(404,d|0,10715)|0;a=v[23220];v[23220]=0;if((a|0)==1){break g}v[23220]=0;W(434,g|0,e+38|0,d|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break l}Pb(d);qg(e+38|0,4e3);v[23220]=0;d=Q(404,e+24|0,13388)|0;a=v[23220];v[23220]=0;if((a|0)==1){break k}h=x[e+38>>1];a=v[dc(e+16|0,h)>>2];v[23220]=0;X(725,g|0,b|0,d|0,a|0);a=v[23220];v[23220]=0;if((a|0)==1){break j}Pb(d);u[e+14>>1]=65535;v[23220]=0;d=Q(404,e|0,8935)|0;a=v[23220];v[23220]=0;if((a|0)==1){break i}v[23220]=0;k=W(434,g|0,e+14|0,d|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break h}a=x[e+14>>1];Pb(d);if(!((k|0)==1|a>>>0>=h>>>0)){Ve(b,a)}ub(f);break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;Pb(f);break c}b=P()|0;O()|0;break f}b=P()|0;O()|0;Pb(a);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(e+40|0);break f}b=P()|0;O()|0;Pb(d);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;Pb(d);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;Pb(d);break f}b=P()|0;O()|0}ub(f)}Ug(g);S(b|0);L()}Ug(g);fb=e+224|0;e=c}We(j,e);fb=i+16|0}function Lga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0),h=0,i=C(0);d=fb-112|0;fb=d;c=fb-16|0;fb=c;e=b+16|0;sS(c+8|0,e);f=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],f);h=v[c+4>>2];if((h|0)==(f|0)){Yb(a,v[c+12>>2])}fb=c+16|0;if((f|0)!=(h|0)){Sb(e,0,128)}t[b+79|0]=0;t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;c=d- -64|0;Qd(c,a,mg(a));f=gc(d+88|0,c);wb(c);v[23220]=0;c=T(189,f|0)|0;e=v[23220];v[23220]=0;a:{b:{if((e|0)==1){break b}v[23220]=0;R(275,b+4|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}ge(d+56|0,v[b+4>>2],v[b+8>>2]);v[23220]=0;X(414,d- -64|0,f|0,v[d+56>>2],v[d+60>>2]);c=v[23220];v[23220]=0;if((c|0)!=1){v[23220]=0;c=T(144,a|0)|0;e=v[23220];v[23220]=0;c:{if((e|0)==1){break c}v[23220]=0;U(177,d+32|0,a|0,c|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}a=d+32|0;c=gc(d- -64|0,a);wb(a);a=v[c>>2];v[23220]=0;a=T(165,a|0)|0;e=v[23220];v[23220]=0;d:{if((e|0)!=1){e:{f:{if(!a){break f}while(1){g:{a=v[c+8>>2];e=v[c>>2];v[23220]=0;a=W(143,e|0,a|0,5)|0;e=v[23220];v[23220]=0;if((e|0)==1){break e}if(!a){break f}v[23220]=0;Q(415,c|0,d+28|0)|0;a=v[23220];v[23220]=0;h:{if((a|0)!=1){a=4;if(!Mb(d+28|0,13573,4)){break h}if(!Mb(d+28|0,14092,4)){break h}v[23220]=0;a=T(144,c|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[23220]=0;U(177,d+8|0,c|0,a|0);a=v[23220];v[23220]=0;i:{j:{k:{if((a|0)!=1){a=d+8|0;e=gc(d+32|0,a);wb(a);if(Mb(d+28|0,13573,4)){break k}v[23220]=0;g=C(Ca(416,e|0));a=v[23220];v[23220]=0;if((a|0)==1){break g}z[d+8>>2]=g;v[d+4>>2]=0;v[d>>2]=1065353216;g=z[Mt(d+8|0,d+4|0,d)>>2];z[b+144>>2]=g;i=C(D(g));if((i<C(1.1754943508222875e-38)^-1)&(!(i>=C(N))&g==g)){break j}v[b+144>>2]=0;break j}a=P()|0;O()|0;break d}if(Mb(d+28|0,14092,4)){break j}v[23220]=0;a=T(144,e|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break i}v[b+148>>2]=a}wb(e);continue}}break}a=P()|0;O()|0;wb(e);break d}wb(c);wb(f);fb=d+112|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0}wb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}wb(f);S(a|0);L()}function kba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=fb-48|0;fb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}s=b;w=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}m=v[a+40>>2];n=v[a+36>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;x=v[a+32>>2];y=v[a+28>>2];z=v[a+72>>2];b=v[a+68>>2];A=b;C=b>>31;b=v[a+64>>2];D=b;E=b>>31;b=v[a+60>>2];F=b;G=b>>31;while(1){if(d){b=v[e+16>>2];H=(((v[e+20>>2]&2147483647)<<1|b>>>31)&-2)+w|0;b=(b>>>16&65520)+s|0;I=u[b+14>>1];g=u[b+12>>1];q=u[b+10>>1];r=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];o=0;p=0;while(1){if((p|0)!=2){i=p+H|0;v[(e+8|0)+(p<<2)>>2]=(((((((B(t[i-4|0],f)+B(t[i-6|0],b)|0)+B(t[i-2|0],k)|0)+B(t[i|0],h)|0)+B(t[i+2|0],r)|0)+B(t[i+4|0],q)|0)+B(g,t[i+6|0])|0)+B(I,t[i+8|0])<<8)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){q=(e+8|0)+(o<<2)|0;b=v[q>>2];g=(e+24|0)+(o<<3)|0;r=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=Bia(F,G,b,b>>31);f=ib;i=g;g=b;b=Ub(h,-16777216,16776704);b=Bia(D,E,b,b>>31);h=g+b|0;g=ib+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Ub(r,-16777216,16776704);f=Bia(A,C,b,b>>31);h=f+h|0;b=ib+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Lc(f,b,24);v[i+4>>2]=b-(k&z);v[q>>2]=(b|0)/256;o=o+1|0;continue}break}n=n+y|0;v[c>>2]=v[c>>2]+B(v[e+8>>2],n>>12);m=m+x|0;v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],m>>12);Ob(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;v[a+40>>2]=m;v[a+20>>2]=n>>12;v[a+36>>2]=n;v[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=e+48|0}function J4(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=fb-96|0;fb=j;a:{b:{c:{k=ep(1,32);d:{e:{if(!k){a=tn(aa(4)|0);v[23220]=0;U(106,a|0,91480,25);a=v[23220];v[23220]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:900;c=eg(j+80|0);f:{g:{h:{if(!i){break h}while(1){d=v[i>>2];if(!d){break h}e=v[i+4>>2];i:{if(e){v[23220]=0;d=Q(52,j- -64|0,d|0)|0;f=v[23220];v[23220]=0;j:{if((f|0)!=1){v[23220]=0;f=Q(911,c|0,d|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break j}v[23220]=0;Q(260,f|0,e|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;ub(d);break f}v[23220]=0;d=Q(52,j+48|0,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break g}os(c,d)}ub(d);i=i+8|0;continue}}d=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[23220]=0;a=T(784,96)|0;i=v[23220];v[23220]=0;k:{l:{m:{if((i|0)!=1){v[j+44>>2]=d;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=v[k+4>>2];d=v[k>>2];v[23220]=0;b=Q(912,d|0,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break m}v[j+16>>2]=b;b=v[Rf(j+24|0,j+16|0)>>2];d=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=d;v[23220]=0;d=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=d;b=fa(942,a|0,j|0,b|0,c|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break k}i=V(0)|0;O()|0;pe(j+16|0);break l}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0}Fb(a);break f}v[k+28>>2]=b;pe(j+16|0);a=v[k+28>>2];v[k+24>>2]=a?a+8|0:0;Rk(c);break d}i=V(0)|0;O()|0}Rk(c);_(i|0)|0;v[23220]=0;X(906,11314,k|0,g|0,h|0);a=v[23220];v[23220]=0;if((a|0)!=1){v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)!=1){a=v[k+28>>2];if(a){jb[v[v[a>>2]+4>>2]](a)}v[k+24>>2]=0;v[k+28>>2]=0;a=v[k+20>>2];if(a){Fb(a);v[k+20>>2]=0}Fb(k);k=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)==1){break b}}_(i|0)|0;k=0;v[23220]=0;X(906,11314,0,g|0,h|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}$()}fb=j+96|0;return k|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Tb()}L()}function X4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-80|0;fb=e;v[e+76>>2]=c;v[e+72>>2]=b;a:{if(!c){break a}g=w[Hk(b,c)|0];if((g|0)==33){d=1}else{if((g|0)!=63){break a}d=0}Qk(e+48|0,b,c,c-1|0);b=v[e+52>>2];v[e+72>>2]=v[e+48>>2];v[e+76>>2]=b}c=e+48|0;Kd(c);b=v[e+48>>2];Kd(e+32|0);b=Gk(b,v[e+36>>2],e+72|0);Kd(c);b:{c:{d:{e:{if((b|0)==v[e+52>>2]){b=v[e+72>>2];c=v[e+76>>2];a=oc(e- -64|0,21598);if(Hc(b,c,v[a>>2],v[a+4>>2])){a=aa(8)|0;v[23220]=0;b=Q(52,e+48|0,10443)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(b);break c}f=0;if(!d){break e}a=aa(8)|0;v[23220]=0;b=Bh(e+32|0,v[e+72>>2],v[e+76>>2]);c=v[23220];v[23220]=0;f:{g:{h:{if((c|0)!=1){v[23220]=0;U(934,e+48|0,17613,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break h}d=0;c=qc(a,e+48|0);v[23220]=0;U(106,c|0,61832,923);c=v[23220];v[23220]=0;if((c|0)!=1){break b}c=P()|0;O()|0;ub(e+48|0);break g}c=P()|0;O()|0;break f}c=P()|0;d=1;O()|0}ub(b);if(!d){break c}}ba(a|0);break c}if(v[b+4>>2]!=2){a=aa(8)|0;v[23220]=0;b=Q(52,e+48|0,11558)|0;c=v[23220];v[23220]=0;if((c|0)!=1){a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(b);break c}c=P()|0;O()|0;ba(a|0);break c}b=v[e+72>>2];c=v[e+76>>2];d=oc(e+24|0,21598);if(Hc(b,c,v[d>>2],v[d+4>>2])){a=aa(8)|0;v[23220]=0;b=Q(52,e+48|0,10443)|0;c=v[23220];v[23220]=0;if((c|0)!=1){a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(b);break c}c=P()|0;O()|0;ba(a|0);break c}d=oc(e+16|0,7677);if(Hc(b,c,v[d>>2],v[d+4>>2])){f=1;if(!Nd(w[a+28|0])){break e}f=65536/+y[v[a+24>>2]+480244>>2];break e}d=oc(e+8|0,7729);if(Hc(b,c,v[d>>2],v[d+4>>2])){f=1;if(!Nd(w[a+28|0])){break e}f=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break e}d=b;b=oc(e,7747);f=0;if(!Hc(d,c,v[b>>2],v[b+4>>2])){break e}f=+y[v[a+24>>2]+480236>>2]*152587890625e-16}fb=e+80|0;return+f}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function aO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;c=fb-176|0;fb=c;i=1;p=2;d=v[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=p>>>0){m=m>>>2|0;w=B(i,3);x=i<<1;h=0;b:while(1){if((h|0)==(m|0)){p=p+2|0;i=i<<2;d=v[a+12>>2];continue a}d=v[a>>2];e=_c(d,h<<1);vL(c+160|0,A[e>>3],A[e+8>>3]);d=_c(d,h);vL(c+144|0,A[d>>3],A[d+8>>3]);li(c+128|0,A[c+144>>3],A[c+152>>3],A[c+160>>3],A[c+168>>3]);d=h<<p;e=i+d|0;y=d>>>0>e>>>0?d:e;while(1)if((d|0)==(y|0)){h=h+1|0;continue b}else{f=v[b>>2];e=_c(f,d);g=e+8|0;j=v[g+4>>2];v[c+120>>2]=v[g>>2];v[c+124>>2]=j;g=v[e+4>>2];v[c+112>>2]=v[e>>2];v[c+116>>2]=g;k=d+i|0;g=_c(f,k);n=A[g+8>>3];o=A[g>>3];r=d+x|0;g=_c(f,r);j=v[g+12>>2];v[c+104>>2]=v[g+8>>2];v[c+108>>2]=j;j=v[g+4>>2];v[c+96>>2]=v[g>>2];v[c+100>>2]=j;s=d+w|0;f=_c(f,s);t=A[f+8>>3];u=A[f>>3];g=c+80|0;f=c+112|0;Lk(g,f,o,n);j=c- -64|0;aj(j,f,o,n);l=c+96|0;Lk(c+48|0,l,u,t);f=c+16|0;aj(f,l,u,t);li(c+32|0,0,1,A[c+16>>3],A[c+24>>3]);Lk(f,g,A[c+48>>3],A[c+56>>3]);l=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=l;l=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=l;Lk(c,j,A[c+32>>3],A[c+40>>3]);li(f,A[c+160>>3],A[c+168>>3],A[c>>3],A[c+8>>3]);e=_c(v[b>>2],k);k=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=k;k=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=k;aj(c,g,A[c+48>>3],A[c+56>>3]);li(f,A[c+144>>3],A[c+152>>3],A[c>>3],A[c+8>>3]);e=_c(v[b>>2],r);g=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=g;g=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=g;aj(c,j,A[c+32>>3],A[c+40>>3]);li(f,A[c+128>>3],A[c+136>>3],A[c>>3],A[c+8>>3]);e=_c(v[b>>2],s);f=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=f;f=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=f;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}i=q>>>1|0;d=0;while(1){if((d|0)==(i|0)){break c}h=v[b>>2];a=_c(h,d+i|0);m=_c(h,d);n=A[a>>3];o=A[a+8>>3];aj(c+160|0,m,n,o);h=v[c+172>>2];v[a+8>>2]=v[c+168>>2];v[a+12>>2]=h;h=v[c+164>>2];v[a>>2]=v[c+160>>2];v[a+4>>2]=h;Tx(_c(v[b>>2],d),n,o);d=d+1|0;continue}}fb=c+176|0}function Iaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;q=v[a+16>>2];r=Zf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;m=v[a+128>>2];if(m){e=v[a+8>>2];j=v[a+12>>2];n=_f(e,j,m);o=ib;g=v[a+76>>2];Df(v[a>>2],v[a+4>>2],af(e,j,d),ib);j=g>>>0<ib>>>0?d:0}else{j=0}i=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];t=v[a+20>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];a:while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;j=j-1|0;n=j?n:0;o=j?o:0;l=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+q|0;b=m;while(1)if((b|0)<=0){Ob(i,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(h){b=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Hd(i,(u[(b<<1|2)+l>>1]+u[l+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Gd(i,h);v[i>>2]=v[i>>2];v[i+4>>2]=0}b=Yf(i,r);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=v[p>>2];g=(f+16|0)+(b<<3)|0;G=v[g+8>>2];k=v[g+4>>2];v[g+8>>2]=k;l=e<<8;e=l;e=Bia(E,F,e,e>>31);h=ib;H=g;g=e;e=Ub(k,-16777216,16776704);e=Bia(C,D,e,e>>31);k=g+e|0;g=ib+h|0;g=e>>>0>k>>>0?g+1|0:g;e=Ub(G,-16777216,16776704);h=Bia(z,A,e,e>>31);k=h+k|0;e=ib+g|0;e=h>>>0>k>>>0?e+1|0:e;h=k+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Lc(h,e,24);v[H+4>>2]=e-(l&y);v[p>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],t);v[c+4>>2]=v[c+4>>2]+B(s,v[f+4>>2]);Ob(f+8|0,w,x);c=c+8|0;continue a}else{e=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Hd(i,(u[(e<<1|2)+l>>1]+u[l+((e&2147483646)<<1)>>1]|0)/8<<16>>16);Gd(i,4);Ob(f+40|0,n,o);b=b-1|0;continue}}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function EJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=fb-96|0;fb=j;a:{b:{c:{d:{e:{f:{k=ep(1,28);if(!k){a=tn(aa(4)|0);v[23220]=0;U(106,a|0,91480,25);a=v[23220];v[23220]=0;if((a|0)!=1){break a}break f}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:900;c=eg(j+80|0);g:{h:{i:{if(!i){break i}while(1){d=v[i>>2];if(!d){break i}e=v[i+4>>2];j:{if(e){v[23220]=0;d=Q(52,j- -64|0,d|0)|0;f=v[23220];v[23220]=0;k:{if((f|0)!=1){v[23220]=0;f=Q(911,c|0,d|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break k}v[23220]=0;Q(260,f|0,e|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break k}break j}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;ub(d);break g}v[23220]=0;d=Q(52,j+48|0,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break h}os(c,d)}ub(d);i=i+8|0;continue}}d=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[23220]=0;a=T(784,80)|0;i=v[23220];v[23220]=0;l:{m:{n:{if((i|0)!=1){v[j+44>>2]=d;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=v[k+4>>2];d=v[k>>2];v[23220]=0;b=Q(912,d|0,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break n}v[j+16>>2]=b;b=v[Rf(j+24|0,j+16|0)>>2];d=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=d;v[23220]=0;d=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=d;b=fa(913,a|0,j|0,b|0,c|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break l}i=V(0)|0;O()|0;pe(j+16|0);break m}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0}Fb(a);break g}v[k+24>>2]=b;pe(j+16|0);Rk(c);i=k;break d}i=V(0)|0;O()|0}Rk(c);_(i|0)|0;v[23220]=0;X(906,15175,k|0,g|0,h|0);a=v[23220];v[23220]=0;if((a|0)!=1){v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){Fb(ns(a))}i=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){Fb(a);v[k+20>>2]=0}Fb(k);break d}i=V(0)|0;O()|0;v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;i=0;v[23220]=0;X(906,15175,0,g|0,h|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}$()}fb=j+96|0;return i|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Tb()}L()}function me(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;e=v[a>>2];a:{if(rc(e,v[a+4>>2])){break a}f=v[b+4>>2];if(f>>>0>=y[a+12>>2]){break a}c=x[b+8>>1];i=v[v[a+48>>2]+12>>2];g=zg(i);if(c>>>0>=g>>>0&(c|0)!=65535){break a}d=(c|0)==65535;l=d?g-1|0:c;g=f;f=d?0:c;c=$c(e,i,g,f);g=w[b+12|0];j=g&4;b:{c:{if(g&2){break c}k=w[b+10|0];e=c;d=f;while(1){if((d&65535)>>>0>(l&65535)>>>0){break c}d:{if(!j){if((k|0)!=w[e+3|0]){break d}break b}if((k|0)==w[e+2|0]){break b}}e=e+6|0;d=d+1|0;continue}}k=l&65535;d=c;e=f;while(1){if(k>>>0>=(e&65535)>>>0){e:{if(!j){if(w[d+3|0]){break e}t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break b}if(w[d+2|0]){break e}t[d+2|0]=w[b+10|0];t[d+4|0]=w[b+11|0];break b}d=d+6|0;e=e+1|0;continue}break}f:{if(!(g&1)){break f}d=v[i+480180>>2]&2;g:{h:{if(!j){while(1){if((f&65535)>>>0<=(l&65535)>>>0){i:{j:{switch(w[c+3|0]-9|0){case 4:if(!cT(v[v[i+8>>2]+88>>2])){break i}d=1;t[c+2|0]=1;t[c+4|0]=w[c+5|0];t[c+3|0]=w[b+10|0];t[c+5|0]=w[b+11|0];break a;case 0:break j;default:break i}}k:{if(d){e=w[c+5|0];if(e>>>0>128){break i}t[c+2|0]=2;t[c+3|0]=w[b+10|0];a=1;break k}t[c+2|0]=2;t[c+3|0]=w[b+10|0];e=w[c+5|0];a=2}t[c+4|0]=a+e>>>a;t[c+5|0]=w[b+11|0];break b}c=c+6|0;f=f+1|0;continue}break}if(!j){break h}}e=w[b+11|0];f=13;l:{switch(w[b+10|0]-1|0){case 1:f=9;e=sm(B(d?2:4,e));break;case 0:break l;default:break g}}t[b+11|0]=e;t[b+10|0]=f;g=g&254;t[b+12|0]=g;break g}c=w[b+11|0];t[h+14|0]=c;f=!d;d=w[b+10|0];m:{n:{if(!(f|(d|0)!=9)){if(c>>>0>128){break m}d=2;f=(c&254)>>>1|0;break n}t[h+15|0]=d;if(!vq(h+15|0,h+14|0,1)){break m}d=w[h+15|0];if(!d){break m}g=w[b+12|0];f=w[h+14|0]}t[b+11|0]=f;t[b+10|0]=d;t[b+12|0]=g&254}g=w[b+12|0]}d=1;if(g&1){break f}t[b+12|0]=g^4;if(me(a,b)){break a}}d=0;o:{p:{switch(v[b>>2]-1|0){case 0:c=v[b+4>>2]+1|0;if(c>>>0>=y[a+12>>2]){break a}v[b+4>>2]=c;break o;case 1:break p;default:break a}}c=v[b+4>>2];if(!c){break a}v[b+4>>2]=c-1}t[b+12|0]=w[b+12|0]|1;d=me(a,b);break a}d=1}fb=h+16|0;return d}function gG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!d){break k}h=v[d>>2];if(!h){break k}if(!a){g=c;break j}v[d>>2]=0;g=c;break i}l:{if(!v[v[115701]>>2]){if(!a){break l}if(!c){break a}d=c;while(1){g=t[e|0];if(g){v[a>>2]=g&57343;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-d|0}if(!a){g=c;d=0;break g}g=c;d=0;break h}return Cf(e)}d=1;break g}d=1}while(1){if(!d){if(!g){break a}while(1){m:{f=w[e|0];h=f-1|0;n:{o:{if(h>>>0>126){d=f;break o}if(e&3|g>>>0<5){break n}p:{while(1){d=v[e>>2];if((d|d-16843009)&-2139062144){break p}v[a>>2]=d&255;v[a+4>>2]=w[e+1|0];v[a+8>>2]=w[e+2|0];v[a+12>>2]=w[e+3|0];a=a+16|0;e=e+4|0;g=g-4|0;if(g>>>0>4){continue}break}d=w[e|0]}f=d&255;h=f-1|0}if(h>>>0>126){break m}}v[a>>2]=f;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;h=v[(f<<2)+82608>>2];d=1;continue}d=w[e|0];f=d>>>3|0;if((f-16|f+(h>>26))>>>0>7){break f}q:{r:{f=e+1|0;d=d-128|h<<6;s:{if((d|0)>=0){break s}i=w[f|0]-128|0;if(i>>>0>63){break r}f=e+2|0;d=i|d<<6;if((d|0)>=0){break s}f=w[f|0]-128|0;if(f>>>0>63){break r}d=f|d<<6;f=e+3|0}e=f;v[a>>2]=d;g=g-1|0;a=a+4|0;break q}v[115696]=25;e=e-1|0;break c}d=0;continue}}while(1){t:{if(!d){u:{v:{d=w[e|0];if(!(e&3|d-1>>>0>126)){d=v[e>>2];if(!((d|d-16843009)&-2139062144)){break v}}f=e;break u}while(1){g=g-4|0;d=v[e+4>>2];f=e+4|0;e=f;if(!((d-16843009|d)&-2139062144)){continue}break}}e=d&255;if(e-1>>>0<=126){e=f+1|0;g=g-1|0;break t}h=e-194|0;if(h>>>0>50){e=f;break e}e=f+1|0;h=v[(h<<2)+82608>>2];d=1;continue}d=w[e|0]>>>3|0;if((d-16|d+(h>>26))>>>0>7){break f}d=e+1|0;w:{if(!(h&33554432)){break w}if((w[d|0]&192)!=128){e=e-1|0;break d}d=e+2|0;if(!(h&524288)){break w}if((w[d|0]&192)!=128){e=e-1|0;break d}d=e+3|0}e=d;g=g-1|0}d=0;continue}}e=e-1|0;if(h){break d}d=w[e|0]}if(d&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-g|0}v[115696]=25;if(!a){break b}}v[b>>2]=e}return-1}v[b>>2]=e;return c}function nba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;e=fb-48|0;fb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}q=b;r=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];t=v[a+20>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;w=v[a+72>>2];b=v[a+68>>2];x=b;y=b>>31;b=v[a+64>>2];z=b;A=b>>31;b=v[a+60>>2];C=b;D=b>>31;while(1){if(d){b=v[e+16>>2];E=((((v[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=(b>>>16&65520)+q|0;F=u[b+14>>1];g=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];m=0;n=0;while(1){if((n|0)!=2){i=E+(n<<1)|0;v[(e+8|0)+(n<<2)>>2]=(((((((B(u[i-8>>1],f)+B(u[i-12>>1],b)|0)+B(u[i-4>>1],k)|0)+B(u[i>>1],h)|0)+B(u[i+4>>1],p)|0)+B(u[i+8>>1],o)|0)+B(g,u[i+12>>1])|0)+B(F,u[i+16>>1])|0)/32768;n=n+1|0;continue}break}while(1){if((m|0)!=2){o=(e+8|0)+(m<<2)|0;b=v[o>>2];g=(e+24|0)+(m<<3)|0;p=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=Bia(C,D,b,b>>31);f=ib;i=g;g=b;b=Ub(h,-16777216,16776704);b=Bia(z,A,b,b>>31);h=g+b|0;g=ib+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Ub(p,-16777216,16776704);f=Bia(x,y,b,b>>31);h=f+h|0;b=ib+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Lc(f,b,24);v[i+4>>2]=b-(k&w);v[o>>2]=(b|0)/256;m=m+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],t);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],s);Ob(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=e+48|0}function jh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Gb(a);d=Bb(c);v[23220]=0;R(43,a|0,d|0);d=v[23220];v[23220]=0;d:{if((d|0)!=1){e:{while(1){if(Bb(c)>>>0>b>>>0){d=v[ej(c,b)>>2];v[23220]=0;R(44,a|0,(d>>>0<128?d:63)<<24>>24);d=v[23220];v[23220]=0;if((d|0)==1){break e}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Gb(a);d=Bb(c);v[23220]=0;R(43,a|0,d|0);d=v[23220];v[23220]=0;f:{if((d|0)!=1){g:{while(1){if(Bb(c)>>>0>b>>>0){d=v[ej(c,b)>>2];v[23220]=0;R(44,a|0,(d>>>0<256?d:63)<<24>>24);d=v[23220];v[23220]=0;if((d|0)==1){break g}b=b+1|0;continue}break}break f}}break a}return;case 3:Vl(a,c,49744);return;case 5:Vl(a,c,50768);return;case 4:Vl(a,c,51792);return;case 6:Vl(a,c,52816);return;case 7:Vl(a,c,53840);return;case 8:Vl(a,c,54864);return;case 9:az(a,c,55888);return;case 10:az(a,c,49744);return;case 11:az(a,c,53840);return;default:a=aa(8)|0;v[23220]=0;b=Q(42,a|0,11013)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break b}b=P()|0;O()|0;ba(a|0);S(b|0);L();case 0:break c}}e=fb-16|0;fb=e;f=Gb(a);h:{while(1){i:{j:{k:{if(Bb(c)>>>0>g>>>0){b=v[ej(c,g)>>2];if(b>>>0>=2097152){v[23220]=0;R(44,f|0,63);a=v[23220];v[23220]=0;if((a|0)!=1){break j}break i}a=0;while(1){if((a|0)==6){b=7;a=6;break k}d=b&63;t[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break k}a=1;b=2;if((d|0)!=1){break k}a=w[e+10|0]|64}else{a=w[e+10|0]}v[23220]=0;R(44,f|0,a<<24>>24);a=v[23220];v[23220]=0;if((a|0)!=1){break j}break i}fb=e+16|0;break h}i=(-1<<b^-1)<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break j}l:{if((a|0)==(b|0)){a=w[j|0];v[23220]=0;R(44,f|0,(a|i)<<24>>24);h=v[23220];v[23220]=0;a=d;break l}v[23220]=0;a=a-1|0;R(44,f|0,t[a+(e+10|0)|0]|-128);h=v[23220];v[23220]=0}if((h|0)!=1){continue}break}break i}g=g+1|0;continue}break}a=P()|0;O()|0;ub(f);S(a|0);L()}return}ia(b|0,91600,24);L()}b=P()|0;O()|0;ub(a);S(b|0);L()}function oba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;e=fb-48|0;fb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}q=b;r=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];w=v[a+20>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;x=v[a+72>>2];b=v[a+68>>2];y=b;z=b>>31;b=v[a+64>>2];A=b;C=b>>31;b=v[a+60>>2];D=b;E=b>>31;while(1){if(d){b=v[e+16>>2];F=(((v[e+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=(b>>>16&65520)+q|0;G=u[b+14>>1];g=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];m=0;n=0;while(1){if((n|0)!=2){i=n+F|0;v[(e+8|0)+(n<<2)>>2]=(((((((B(t[i-4|0],f)+B(t[i-6|0],b)|0)+B(t[i-2|0],k)|0)+B(t[i|0],h)|0)+B(t[i+2|0],p)|0)+B(t[i+4|0],o)|0)+B(g,t[i+6|0])|0)+B(G,t[i+8|0])<<8)/32768;n=n+1|0;continue}break}while(1){if((m|0)!=2){o=(e+8|0)+(m<<2)|0;b=v[o>>2];g=(e+24|0)+(m<<3)|0;p=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=Bia(D,E,b,b>>31);f=ib;i=g;g=b;b=Ub(h,-16777216,16776704);b=Bia(A,C,b,b>>31);h=g+b|0;g=ib+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Ub(p,-16777216,16776704);f=Bia(y,z,b,b>>31);h=f+h|0;b=ib+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Lc(f,b,24);v[i+4>>2]=b-(k&x);v[o>>2]=(b|0)/256;m=m+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],w);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],s);Ob(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=e+48|0}function m_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=fb-16|0;fb=j;k=yw(g);o=fw(g);Gg(j,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[23220]=0;g=Q(1122,k|0,g<<24>>24)|0;i=v[23220];v[23220]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[23220]=0;g=Q(1122,k|0,48)|0;h=v[23220];v[23220]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;g=t[i+1|0];v[23220]=0;g=Q(1122,k|0,g|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];wd();if(!tG(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];wd();if(!Jj(h)){break d}g=g+1|0;continue}}e:{if(ze(j)){h=v[f>>2];v[23220]=0;X(1116,k|0,i|0,g|0,h|0);h=v[23220];v[23220]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i<<2);break e}ul(i,g);v[23220]=0;q=T(1114,o|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){ur((i-a<<2)+d|0,v[f>>2]);break e}f:{if(t[Fc(j,l)|0]<=0){break f}if(t[Fc(j,l)|0]!=(m|0)){break f}m=v[f>>2];v[f>>2]=m+4;v[m>>2]=q;l=(Bb(j)-1>>>0>l>>>0)+l|0;m=0}p=t[h|0];v[23220]=0;p=Q(1122,k|0,p|0)|0;n=v[23220];v[23220]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+4;v[n>>2]=p;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=w[g|0];if((i|0)==46){v[23220]=0;i=T(1117,o|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break a}l=v[f>>2];h=l+4|0;v[f>>2]=h;v[l>>2]=i;g=g+1|0;break g}v[23220]=0;i=Q(1122,k|0,i<<24>>24)|0;h=v[23220];v[23220]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=i;g=g+1|0;continue}break}h=v[f>>2]}v[23220]=0;X(1116,k|0,g|0,c|0,h|0);i=v[23220];v[23220]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g<<2)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;ub(j);fb=j+16|0;return}a=P()|0;O()|0;ub(j);S(a|0);L()}function Pr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(!a){return Fd(b)}if(b>>>0>=4294967232){v[115696]=48;return 0}e=b>>>0<11?16:b+11&-8;g=a-8|0;h=v[a-4>>2];c=h&-8;a:{b:{if(!(h&3)){if(e>>>0<256|c>>>0<(e|4)>>>0){break b}if(c-e>>>0<=v[115822]<<1>>>0){break a}break b}f=c+g|0;if(c>>>0>=e>>>0){b=c-e|0;if(b>>>0<16){break a}v[g+4>>2]=h&1|e|2;c=e+g|0;v[c+4>>2]=b|3;v[f+4>>2]=v[f+4>>2]|1;bH(c,b);return a}if(v[115708]==(f|0)){c=c+v[115705]|0;if(c>>>0<=e>>>0){break b}v[g+4>>2]=h&1|e|2;b=e+g|0;c=c-e|0;v[b+4>>2]=c|1;v[115705]=c;v[115708]=b;return a}if(v[115707]==(f|0)){c=c+v[115704]|0;if(c>>>0<e>>>0){break b}b=c-e|0;c:{if(b>>>0>=16){v[g+4>>2]=h&1|e|2;d=e+g|0;v[d+4>>2]=b|1;c=c+g|0;v[c>>2]=b;v[c+4>>2]=v[c+4>>2]&-2;break c}v[g+4>>2]=c|h&1|2;b=c+g|0;v[b+4>>2]=v[b+4>>2]|1;b=0}v[115707]=d;v[115704]=b;return a}d=v[f+4>>2];if(d&2){break b}i=c+(d&-8)|0;if(i>>>0<e>>>0){break b}k=i-e|0;d:{if(d>>>0<=255){b=v[f+8>>2];d=d>>>3|0;c=v[f+12>>2];if((c|0)==(b|0)){m=462808,n=v[115702]&Fia(-2,d),v[m>>2]=n;break d}v[b+12>>2]=c;v[c+8>>2]=b;break d}j=v[f+24>>2];c=v[f+12>>2];e:{if((f|0)!=(c|0)){b=v[f+8>>2];v[b+12>>2]=c;v[c+8>>2]=b;break e}f:{b=f+20|0;d=v[b>>2];if(d){break f}b=f+16|0;d=v[b>>2];if(d){break f}c=0;break e}while(1){l=b;c=d;b=c+20|0;d=v[b>>2];if(d){continue}b=c+16|0;d=v[c+16>>2];if(d){continue}break}v[l>>2]=0}if(!j){break d}b=v[f+28>>2];d=(b<<2)+463112|0;g:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break g}m=462812,n=v[115703]&Fia(-2,b),v[m>>2]=n;break d}v[(v[j+16>>2]==(f|0)?16:20)+j>>2]=c;if(!c){break d}}v[c+24>>2]=j;b=v[f+16>>2];if(b){v[c+16>>2]=b;v[b+24>>2]=c}b=v[f+20>>2];if(!b){break d}v[c+20>>2]=b;v[b+24>>2]=c}if(k>>>0<=15){v[g+4>>2]=h&1|i|2;b=g+i|0;v[b+4>>2]=v[b+4>>2]|1;return a}v[g+4>>2]=h&1|e|2;b=e+g|0;v[b+4>>2]=k|3;c=g+i|0;v[c+4>>2]=v[c+4>>2]|1;bH(b,k);return a}c=Fd(b);if(!c){return 0}d=v[g+4>>2];d=(d&3?-4:-8)+(d&-8)|0;nc(c,a,b>>>0>d>>>0?d:b);Fb(a);a=c}return a}function hi(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0),o=C(0),p=C(0),q=0,r=C(0);m=jb[v[v[a>>2]+136>>2]](a)|0;h=v[a+20>>2];g=m?g:w[h+25|0];j=z[h+144>>2];k=C(1);if(!(jb[v[v[a>>2]+136>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((jb[v[v[a>>2]+152>>2]](a)|0)<=0){break a}if(!yK(w[v[a+20>>2]+24|0])){break a}j=C(C(j+j)+C(-1));k=C(-j)}n=z[a+4196>>2];k=C(k*n);j=C(j*n);h=0;l=v[a+44>>2];m=zc(l,0);l=zc(l,1);b:{c:{switch(g&255){case 0:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]+C(C(z[d+g>>2]*j)+C(k*z[g+m>>2]));i=c+g|0;z[i>>2]=z[i>>2]+C(C(z[e+g>>2]*j)+C(k*z[g+l>>2]));h=h+1|0;continue};case 1:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]+C(z[g+m>>2]-C(z[d+g>>2]*j));i=c+g|0;z[i>>2]=z[i>>2]+C(z[g+l>>2]-C(z[e+g>>2]*j));h=h+1|0;continue};case 2:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]+C(z[d+g>>2]-C(z[g+m>>2]*k));i=c+g|0;z[i>>2]=z[i>>2]+C(z[e+g>>2]-C(z[g+l>>2]*k));h=h+1|0;continue};case 3:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]-C(z[d+g>>2]-C(z[g+m>>2]*j));i=c+g|0;z[i>>2]=z[i>>2]-C(z[e+g>>2]-C(z[g+l>>2]*j));h=h+1|0;continue};case 4:while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;k=z[i>>2];q=i;r=k;n=z[g+m>>2];i=c+g|0;o=z[i>>2];p=z[g+l>>2];k=C(C(C(C(k+n)+o)+p)*C(.5));z[q>>2]=r-C(C(k+C(k-C(z[d+g>>2]*j)))-n);z[i>>2]=o-C(C(k+C(k-C(z[e+g>>2]*j)))-p);h=h+1|0;continue};case 5:break c;default:break b}}h=yK(w[v[a+20>>2]+24|0]);j=h?C(j*C(.5)):j;k=h?C(k*C(.5)):k;g=0;while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;n=C(z[d+h>>2]-z[h+m>>2]);o=C(z[h+l>>2]-z[e+h>>2]);z[i>>2]=z[i>>2]+C(C(j*n)+C(k*o));h=c+h|0;z[h>>2]=z[h>>2]+C(C(k*n)+C(j*o));g=g+1|0;continue}}d:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break d}if(jb[v[v[a>>2]+136>>2]](a)|0){break d}h=0;while(1){if((f|0)==(h|0)){break d}a=h<<2;d=a+b|0;z[d>>2]=z[a+m>>2]+z[d>>2];d=a+c|0;z[d>>2]=z[a+l>>2]+z[d>>2];h=h+1|0;continue}}}function Sha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;d=fb-1104|0;fb=d;v[d+1100>>2]=c;i=hB(d+40|0,b);q=eq(i);e=Ib(a);v[23220]=0;a=T(189,b|0)|0;c=v[23220];v[23220]=0;a:{if((c|0)!=1){v[d+8>>2]=a;v[d+36>>2]=85899345;s=d,z=B(v[Eb(d+8|0,d+36|0)>>2],50),v[s+24>>2]=z;a=v[Eb(d+1100|0,d+24|0)>>2];v[23220]=0;R(313,e|0,a|0);a=v[23220];v[23220]=0;if((a|0)!=1){v[23220]=0;h=T(325,d+24|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){v[23220]=0;f=Q(326,d+8|0,8192)|0;a=v[23220];v[23220]=0;b:{if((a|0)!=1){c=v[h>>2];a=0;while(1){if((a|0)!=256){g=zb(c,a);t[g+2|0]=a;u[g>>1]=8192;a=a+1|0;continue}break}m=9;c:{d:while(1){g=0;n=257;while(1){r=m&255;e:{while(1){j=n&65535;while(1){v[23220]=0;o=Q(151,i|0,r|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}k=o&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(Wc(v[e>>2],v[e+4>>2])>>>0>=y[d+1100>>2]){break e}if((k|0)==256){m=9;continue d}a=j>>>0>k>>>0?o:g;c=v[h>>2];l=8192;while(1){a=a&65535;c=zb(c,a);l=l-1|0;p=l&65535;s=Hb(v[f>>2],p),z=w[c+2|0],t[s|0]=z;c=v[h>>2];a=x[zb(c,a)>>1];if(a>>>0<8192){continue}break}a=dc(d,Ab(v[e+4>>2]));c=Vg(Ab(v[f>>2]),p);l=Ab(v[f+4>>2]);a=v[a>>2];v[23220]=0;X(314,e|0,a|0,c|0,l|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=v[f>>2];v[23220]=0;R(327,e|0,Hb(a,p)|0);a=v[23220];v[23220]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){g=o;continue}if(Wc(v[e>>2],v[e+4>>2])>>>0>=y[d+1100>>2]){continue}break}a=w[Hb(v[f>>2],p)|0];c=zb(v[h>>2],j);u[c>>1]=g;t[c+2|0]=a;a=n+1|0;n=8192;g=o;c=a&65535;if((c|0)==8192){continue}break}m=((c|0)==1<<r)+m|0;n=a;continue}break}break}a=eq(i);v[23220]=0;Q(142,b|0,((a-q|0)+3&-4)+q|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}$b(f);lc(h);wb(i);fb=d+1104|0;return}a=P()|0;O()|0;$b(f);break b}a=P()|0;O()|0}lc(h);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}$b(e);wb(i);S(a|0);L()}function n3(a,b,c){a=a|0;b=C(b);c=c|0;var d=0,e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),k=C(0),m=0,n=0,o=0;d=fb-16|0;fb=d;a:{b:{c:{d:{switch(c-1|0){case 0:a=(p(b),j(2));e:{f:{g:{if((a|0)<=8388607){e=C(C(-1)/C(b*b));if(!(a&2147483647)){break e}e=C(C(b-b)/C(0));if((a|0)<0){break e}a=(p(C(b*C(33554432))),j(2));c=-152;break g}if(a>>>0>2139095039){break f}c=-127;b=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;k=C((a>>>23|0)+c|0);b=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));f=C(b*C(b*C(.5)));g=C(b/C(b+C(2)));h=C(g*g);i=C(h*h);e=b;b=(l(2,(p(C(b-f)),j(2))&-4096),q());f=C(C(g*C(f+C(C(h*C(C(i*C(.2849878668785095))+C(.6666666269302368)))+C(i*C(C(i*C(.24279078841209412))+C(.40000972151756287))))))+C(C(e-b)-f));b=C(C(k*C(.3010292053222656))+C(C(b*C(.434326171875))+C(C(f*C(.434326171875))+C(C(k*C(7.903415166765626e-7))+C(C(f+b)*C(-3168997136526741e-20))))))}e=b}b=C(e*C(2e3));if(!(C(D(b))<C(2147483648))){break c}a=~~b;break b;case 1:a=(B(v[a+24604>>2],100)|0)/128|0;break b;case 2:c=fb-16|0;fb=c;h:{i:{j:{k:{a=w[a+24648|0];if(a>>>0>=6){a=aa(8)|0;v[23220]=0;c=Q(52,c|0,5084)|0;d=v[23220];v[23220]=0;if((d|0)==1){break k}a=qc(a,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break i}d=P()|0;O()|0;ub(c);break j}fb=c+16|0;a=v[(a<<24>>24<<2)+61576>>2];break h}d=P()|0;O()|0;ba(a|0)}S(d|0)}L()}break b;case 3:v[d>>2]=0;m=v[a+24640>>2];c=fb-80|0;fb=c;a=v[a+24636>>2];v[c+40>>2]=a;v[c>>2]=m;n=c+40|0;o=v[Ke(n,c)>>2];l:{if((a|0)==v[Gp(n)+32>>2]){a=-1;if(v[Gp(c)+36>>2]==(m|0)){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}v[d>>2]=a;fb=c+80|0;a=v[d>>2];break b;default:break d}}a=aa(8)|0;v[23220]=0;d=Q(52,d|0,10346)|0;c=v[23220];v[23220]=0;m:{if((c|0)!=1){a=qc(a,d);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}c=P()|0;O()|0;ub(d);break m}c=P()|0;O()|0;ba(a|0)}S(c|0);L()}a=-2147483648}fb=d+16|0;return a|0}L()}function $fa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb-48|0;fb=c;a:{b:{c:{d:{e:{f:{g:{if(sd(v[a+24>>2])){break g}h=a+4|0;k=Bb(h);e=fb-32|0;fb=e;d=e+24|0;b=d;v[b>>2]=-1;v[b+4>>2]=-1;v[23220]=0;f=SE(36);b=v[23220];v[23220]=0;if((b|0)==1){break a}v[e+8>>2]=f;v[e+12>>2]=ib;g=fb-16|0;fb=g;i=e+8|0;b=i;l=g,m=Bia(v[b>>2],v[b+4>>2],1e3,0),v[l>>2]=m;v[g+4>>2]=ib;f=ht(g+8|0,g);b=v[f+4>>2];fb=g+16|0;v[e+16>>2]=v[f>>2];v[e+20>>2]=b;b=e+16|0;l=e,m=gA(v[b>>2],v[b+4>>2]),v[l+16>>2]=m;v[e+20>>2]=ib;g=AR(d,b,Cb(b));v[23220]=0;d=SE(37);f=v[23220];v[23220]=0;if((f|0)==1){break a}j=a+24|0;v[e+8>>2]=d;v[e+12>>2]=ib;d=fb-16|0;fb=d;a=v[i+4>>2];v[d>>2]=v[i>>2];v[d+4>>2]=a;f=ht(d+8|0,d);a=v[f+4>>2];fb=d+16|0;v[e+16>>2]=v[f>>2];v[e+20>>2]=a;l=e,m=gA(v[b>>2],v[b+4>>2]),v[l+16>>2]=m;v[e+20>>2]=ib;a=AR(g,b,Cb(b));b=v[a>>2];a=v[a+4>>2];fb=e+32|0;if(k){d=Ib(c+32|0);v[23220]=0;v[c+16>>2]=a;R(30,d|0,c+16|0);a=v[23220];v[23220]=0;if((a|0)==1){break d}v[23220]=0;v[c+16>>2]=b;R(30,d|0,c+16|0);a=v[23220];v[23220]=0;if((a|0)==1){break e}a=0;h:{while(1){if(Bb(h)>>>0<=a>>>0){b=Ab(v[d>>2]);a=Ab(v[d+4>>2]);v[23220]=0;f=W(31,c+16|0,b|0,a|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break c}b=w[Fc(h,a)|0];v[23220]=0;v[c+16>>2]=b;R(30,d|0,c+16|0);b=v[23220];v[23220]=0;if((b|0)!=1){a=a+1|0;continue}break}a=P()|0;O()|0;break c}v[23220]=0;b=T(32,f|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){v[c+8>>2]=b;a=c+8|0;jA(j,a);$n(a);bm(f);lc(d);break g}a=P()|0;O()|0;bm(f);break c}ib=b;v[c+16>>2]=a;v[c+20>>2]=ib;b=Ib(c+32|0);v[23220]=0;U(35,b|0,c+16|0,c+24|0);a=v[23220];v[23220]=0;if((a|0)==1){a=P()|0;O()|0;lc(b);S(a|0);L()}v[23220]=0;f=T(32,b|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break f}v[c+8>>2]=f;a=c+8|0;jA(j,a);$n(a);bm(b)}fb=c+48|0;return}a=P()|0;O()|0;bm(b);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0}lc(d)}S(a|0);L()}V(0)|0;O()|0;Tb();L()}function w_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=fb-16|0;fb=j;k=Tu(g);o=kw(g);Gg(j,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[23220]=0;g=Q(19,k|0,g<<24>>24)|0;i=v[23220];v[23220]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[23220]=0;g=Q(19,k|0,48)|0;h=v[23220];v[23220]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;g=t[i+1|0];v[23220]=0;g=Q(19,k|0,g|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];wd();if(!tG(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];wd();if(!Jj(h)){break d}g=g+1|0;continue}}e:{if(ze(j)){h=v[f>>2];v[23220]=0;X(1102,k|0,i|0,g|0,h|0);h=v[23220];v[23220]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break e}ul(i,g);v[23220]=0;q=T(1100,o|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){ul((i-a|0)+d|0,v[f>>2]);break e}f:{if(t[Fc(j,m)|0]<=0){break f}if(t[Fc(j,m)|0]!=(l|0)){break f}l=v[f>>2];v[f>>2]=l+1;t[l|0]=q;m=(Bb(j)-1>>>0>m>>>0)+m|0;l=0}p=t[h|0];v[23220]=0;p=Q(19,k|0,p|0)|0;n=v[23220];v[23220]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+1;t[n|0]=p;h=h+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){i=w[g|0];if((i|0)!=46){break g}v[23220]=0;i=T(1103,o|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0}i=v[f>>2];v[23220]=0;X(1102,k|0,g|0,c|0,i|0);i=v[23220];v[23220]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g|0)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;ub(j);fb=j+16|0;return}v[23220]=0;i=Q(19,k|0,i<<24>>24)|0;h=v[23220];v[23220]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0;continue}}a=P()|0;O()|0;ub(j);S(a|0);L()}function bO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;c=fb-176|0;fb=c;e=v[a+12>>2];j=1<<e;a:{if(!(e&1)){h=j>>>2|0;l=1;break a}l=j>>>1|0;e=0;while(1){if((e|0)==(l|0)){h=j>>>3|0;l=2;e=v[a+12>>2]}else{i=v[b>>2];h=_c(i,e+l|0);d=_c(i,e);o=A[h>>3];p=A[h+8>>3];aj(c+160|0,d,o,p);i=v[c+172>>2];v[h+8>>2]=v[c+168>>2];v[h+12>>2]=i;i=v[c+164>>2];v[h>>2]=v[c+160>>2];v[h+4>>2]=i;Tx(_c(v[b>>2],e),o,p);e=e+1|0;continue}break}}i=e&-2;b:while(1){if(i){x=B(h,3);y=h<<1;j=0;c:while(1){if((j|0)==(l|0)){i=i-2|0;h=h>>>2|0;l=l<<2;continue b}d=v[a>>2];e=_c(d,j<<1);d=_c(d,j);o=A[d>>3];p=A[d+8>>3];r=A[e>>3];s=A[e+8>>3];li(c+160|0,o,p,r,s);e=j<<i;d=h+e|0;z=d>>>0<e>>>0?e:d;while(1)if((e|0)==(z|0)){j=j+1|0;continue c}else{f=v[b>>2];d=_c(f,e);g=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=g;g=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=g;g=c+128|0;t=e+h|0;k=_c(f,t);li(g,r,s,A[k>>3],A[k+8>>3]);u=e+y|0;k=_c(f,u);li(c+112|0,o,p,A[k>>3],A[k+8>>3]);m=A[c+160>>3];n=A[c+168>>3];w=e+x|0;f=_c(f,w);li(c+96|0,m,n,A[f>>3],A[f+8>>3]);k=c+80|0;f=c+144|0;m=A[c+112>>3];n=A[c+120>>3];Lk(k,f,m,n);q=c- -64|0;aj(q,f,m,n);m=A[c+96>>3];n=A[c+104>>3];Lk(c+48|0,g,m,n);f=c+16|0;Ul(f,-0,-1);aj(c,g,m,n);li(c+32|0,A[c+16>>3],A[c+24>>3],A[c>>3],A[c+8>>3]);Lk(f,k,A[c+48>>3],A[c+56>>3]);g=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=g;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;aj(f,k,A[c+48>>3],A[c+56>>3]);d=_c(v[b>>2],t);g=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=g;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;Lk(f,q,A[c+32>>3],A[c+40>>3]);d=_c(v[b>>2],u);g=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=g;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;aj(f,q,A[c+32>>3],A[c+40>>3]);d=_c(v[b>>2],w);f=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=f;f=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=f;e=e+1|0;continue}}}break}fb=c+176|0}function W4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-80|0;fb=e;v[e+76>>2]=c;v[e+72>>2]=b;a:{if(!c){break a}f=w[Hk(b,c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Qk(e+48|0,b,c,c-1|0);b=v[e+52>>2];v[e+72>>2]=v[e+48>>2];v[e+76>>2]=b}c=e+48|0;Kd(c);b=v[e+48>>2];Kd(e+32|0);b=Gk(b,v[e+36>>2],e+72|0);Kd(c);b:{c:{d:{e:{if((b|0)==v[e+52>>2]){b=v[e+72>>2];c=v[e+76>>2];a=oc(e- -64|0,21598);if(Hc(b,c,v[a>>2],v[a+4>>2])){a=aa(8)|0;v[23220]=0;b=Q(52,e+48|0,10443)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(b);break c}b=0;c=0;if(!d){break e}b=aa(8)|0;v[23220]=0;d=Bh(e+32|0,v[e+72>>2],v[e+76>>2]);a=v[23220];v[23220]=0;f:{g:{h:{if((a|0)!=1){v[23220]=0;U(934,e+48|0,17613,d|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}a=0;c=qc(b,e+48|0);v[23220]=0;U(106,c|0,61832,923);c=v[23220];v[23220]=0;if((c|0)!=1){break b}c=P()|0;O()|0;ub(e+48|0);break g}c=P()|0;O()|0;break f}c=P()|0;a=1;O()|0}ub(d);if(!a){break c}}ba(b|0);break c}if(v[b+4>>2]!=1){a=aa(8)|0;v[23220]=0;b=Q(52,e+48|0,11558)|0;c=v[23220];v[23220]=0;if((c|0)!=1){a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(b);break c}c=P()|0;O()|0;ba(a|0);break c}d=v[e+72>>2];f=v[e+76>>2];b=oc(e+24|0,21598);if(Hc(d,f,v[b>>2],v[b+4>>2])){a=aa(8)|0;v[23220]=0;b=Q(52,e+48|0,10443)|0;c=v[23220];v[23220]=0;if((c|0)!=1){a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(b);break c}c=P()|0;O()|0;ba(a|0);break c}b=oc(e+16|0,10881);if(Hc(d,f,v[b>>2],v[b+4>>2])){a=v[a+8>>2];b=a;c=a>>31;break e}b=0;g=d;d=oc(e+8|0,8598);c=0;if(!Hc(g,f,v[d>>2],v[d+4>>2])){break e}b=Lj(w[v[a+32>>2]+140|0]);c=0}fb=e+80|0;ib=c;return b|0}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function H4(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=fb+-64|0;fb=k;a:{b:{c:{j=ep(1,32);d:{e:{if(!j){a=tn(aa(4)|0);v[23220]=0;U(106,a|0,91480,25);a=v[23220];v[23220]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:900;c=eg(k+48|0);f:{g:{h:{if(!i){break h}while(1){d=v[i>>2];if(!d){break h}e=v[i+4>>2];i:{if(e){v[23220]=0;d=Q(52,k+32|0,d|0)|0;f=v[23220];v[23220]=0;j:{if((f|0)!=1){v[23220]=0;f=Q(911,c|0,d|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break j}v[23220]=0;Q(260,f|0,e|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;ub(d);break f}v[23220]=0;d=Q(52,k+16|0,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break g}os(c,d)}ub(d);i=i+8|0;continue}}v[23220]=0;d=T(784,96)|0;e=v[23220];v[23220]=0;k:{l:{m:{if((e|0)!=1){e=v[j+4>>2];f=v[j>>2];v[23220]=0;e=Q(912,f|0,e|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break m}v[k>>2]=e;e=v[Rf(k+8|0,k)>>2];v[23220]=0;a=ga(943,d|0,a|0,b|0,e|0,c|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break k}i=V(0)|0;O()|0;pe(k);break l}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0}Fb(d);break f}v[j+28>>2]=a;pe(k);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;Rk(c);break d}i=V(0)|0;O()|0}Rk(c);_(i|0)|0;v[23220]=0;X(906,4934,j|0,g|0,h|0);a=v[23220];v[23220]=0;if((a|0)!=1){v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)!=1){a=v[j+28>>2];if(a){jb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Fb(a);v[j+20>>2]=0}Fb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)==1){break b}}_(i|0)|0;j=0;v[23220]=0;X(906,4934,0,g|0,h|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}$()}fb=k- -64|0;return j|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Tb()}L()}function Vaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;g=fb-48|0;fb=g;p=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(g+24|0)|0;e=a+e|0;v[i+4>>2]=v[e+44>>2];v[i+8>>2]=v[e+48>>2];f=f+1|0;continue}break}i=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+32>>2];s=v[a+28>>2];t=v[a+72>>2];b=v[a+68>>2];w=b;x=b>>31;b=v[a+64>>2];y=b;z=b>>31;b=v[a+60>>2];A=b;C=b>>31;D=v[a+8>>2];E=v[a+12>>2];while(1){if(d){f=v[g+16>>2];l=((((v[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+p|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;j=u[b+14>>1];h=u[b+12>>1];m=u[b+10>>1];n=u[b+8>>1];o=u[b+6>>1];F=u[b+4>>1];G=u[b+2>>1];H=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=l+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((((B(u[b+8>>1],m)+B(u[b+4>>1],n)|0)+B(h,u[b+12>>1])|0)+B(j,u[b+16>>1])|0)/2|0)+((((B(u[b-8>>1],G)+B(u[b-12>>1],H)|0)+B(u[b-4>>1],F)|0)+B(u[b>>1],o)|0)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){l=(g+8|0)+(f<<2)|0;e=v[l>>2];b=(g+24|0)+(f<<3)|0;j=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;m=e<<8;e=m;e=Bia(A,C,e,e>>31);n=ib;o=b;b=Ub(h,-16777216,16776704);h=Bia(y,z,b,b>>31);e=h+e|0;b=ib+n|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Ub(j,-16777216,16776704);j=Bia(w,x,e,e>>31);e=h+j|0;b=ib+b|0;b=e>>>0<j>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Lc(e,b,24);v[o+4>>2]=b-(m&t);v[l>>2]=(b|0)/256;f=f+1|0;continue}break}k=k+s|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);i=i+r|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],i>>12);Ob(g+16|0,D,E);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}fb=g+48|0}function kh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Gb(a);d=Bb(c);v[23220]=0;R(45,a|0,d|0);d=v[23220];v[23220]=0;d:{if((d|0)!=1){e:{while(1){if(Bb(c)>>>0>b>>>0){d=t[Vf(c,b)|0];v[23220]=0;R(46,a|0,((d|0)<0?65533:d&255)|0);d=v[23220];v[23220]=0;if((d|0)==1){break e}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Gb(a);d=Bb(c);v[23220]=0;R(45,a|0,d|0);d=v[23220];v[23220]=0;f:{if((d|0)!=1){while(1){if(Bb(c)>>>0<=b>>>0){break f}d=w[Vf(c,b)|0];v[23220]=0;R(46,a|0,d|0);d=v[23220];v[23220]=0;if((d|0)!=1){b=b+1|0;continue}break}}break a}return;case 3:Sl(a,c,49744);return;case 5:Sl(a,c,50768);return;case 4:Sl(a,c,51792);return;case 6:Sl(a,c,52816);return;case 7:Sl(a,c,53840);return;case 8:Sl(a,c,54864);return;case 9:Uy(a,c,55888);return;case 10:Uy(a,c,49744);return;case 11:Uy(a,c,53840);return;default:a=aa(8)|0;v[23220]=0;b=Q(42,a|0,11013)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break b}b=P()|0;O()|0;ba(a|0);S(b|0);L();case 0:break c}}e=fb-16|0;fb=e;f=Gb(a);g=e,h=Vs(c),v[g+8>>2]=h;g=e,h=Ts(c),v[g>>2]=h;a=0;g:{h:{while(1){i:{if(!Kh(e+8|0,e)){if(!a){break i}v[23220]=0;R(46,f|0,65533);a=v[23220];v[23220]=0;if((a|0)!=1){break i}break h}b=w[v[e+8>>2]];j:{k:{if(!a){if(!(b&128)){a=0;v[23220]=0;R(46,f|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break j}break h}if((b&224)==192){d=b&31;a=1;break j}if((b&240)==224){d=b&15;a=2;break j}d=65533;if((b&248)!=240){break k}d=b&7;a=3;break j}if((b&192)!=128){d=0;v[23220]=0;R(46,f|0,65533);c=v[23220];v[23220]=0;a=0;if((c|0)==1){break h}}d=b&63|d<<6;a=a-1|0;if(a){break j}}a=0;v[23220]=0;R(46,f|0,d|0);b=v[23220];v[23220]=0;d=0;if((b|0)==1){break h}}xe(e+8|0);continue}break}fb=e+16|0;break g}a=P()|0;O()|0;Nc(f);S(a|0);L()}return}ia(b|0,91600,24);L()}b=P()|0;O()|0;Nc(a);S(b|0);L()}function Pj(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{if(!d){break a}g=v[c>>2];if(!g){break a}b:{c:{d:{e:{f=v[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break e}f=B(d,20)+g|0;break d}f=((B(d,36318)|0)/1024|0)+g|0;break d}f:{g:{h:{if(w[a+480208|0]&16){if((f|0)==4){break h}f=d>>31;v[i+12>>2]=(f^d)-f;uc(i+12|0,1020);h=v[i+12>>2];i:{if((d|0)>0){if(h>>>0<=15){f=fb-16|0;fb=f;xb(f+8|0,a+1074312|0,7);j=yb(v[v[f+8>>2]>>2],v[f+12>>2]);fb=f+16|0;h=v[(h<<2)+(j?37168:37232)>>2];break i}f=fb-16|0;fb=f;xb(f+8|0,a+1074312|0,7);j=yb(v[v[f+8>>2]>>2],v[f+12>>2]);fb=f+16|0;h=v[(h>>>2<<2)+(j?37296:38320)>>2];break i}if(h>>>0<=15){f=fb-16|0;fb=f;xb(f+8|0,a+1074312|0,7);j=yb(v[v[f+8>>2]>>2],v[f+12>>2]);fb=f+16|0;h=v[(h<<2)+(j?37232:37168)>>2];break i}f=fb-16|0;fb=f;xb(f+8|0,a+1074312|0,7);j=yb(v[v[f+8>>2]>>2],v[f+12>>2]);fb=f+16|0;h=v[(h>>>2<<2)+(j?38320:37296)>>2]}h=Bia(h,h>>31,g,g>>31)+32768|0;f=ib;f=Dc(Cia(h,h>>>0<32768?f+1|0:f,65536,0),ib);v[c>>2]=f;if((f|0)!=(g|0)){break c}xb(i,a+1074312|0,7);g=v[c>>2];if(!(yb(v[v[i>>2]>>2],v[i+4>>2])^(d|0)>0)){f=2147483647;d=1;if((g|0)==2147483647){break c}break f}d=-1;if((g|0)>=2){break f}f=g;break c}xb(i,a+1074312|0,7);if(yb(v[v[i>>2]>>2],v[i+4>>2])){break g}g=v[c>>2]}f=g-d|0;break d}f=v[c>>2];if((d|0)<0){g=Bia(f,0,14317456,0);h=ib;f=Bia(f,0,0-d|0,0)+14317456|0;d=ib;f=MM(Eia(g,h,f,f>>>0<14317456?d+1|0:d),ib);break d}d=Bia(f,f>>31,d,0);g=ib;if((g|0)>=0&d>>>0>=14317456|(g|0)>0){if(e){v[c>>2]=2147483647;break a}v[c>>2]=0;v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248;break a}d=MM(Eia(Bia(f,0,14317456,0),ib,14317456-d|0,0-(g+(d>>>0>14317456)|0)|0),ib);v[c>>2]=d;if((d|0)>0){break a}break b}f=d+g|0}v[c>>2]=f}if((f|0)>0){break a}}v[c>>2]=1;if(v[a+480180>>2]!=2|e){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}fb=i+16|0}function Waa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=fb-48|0;fb=g;p=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(g+24|0)|0;e=a+e|0;v[i+4>>2]=v[e+44>>2];v[i+8>>2]=v[e+48>>2];f=f+1|0;continue}break}i=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+32>>2];s=v[a+28>>2];w=v[a+72>>2];b=v[a+68>>2];x=b;y=b>>31;b=v[a+64>>2];z=b;A=b>>31;b=v[a+60>>2];C=b;D=b>>31;E=v[a+8>>2];F=v[a+12>>2];while(1){if(d){f=v[g+16>>2];l=(((v[g+20>>2]&2147483647)<<1|f>>>31)&-2)+p|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;j=u[b+14>>1];h=u[b+12>>1];m=u[b+10>>1];n=u[b+8>>1];o=u[b+6>>1];G=u[b+4>>1];H=u[b+2>>1];I=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=e+l|0;v[(g+8|0)+(e<<2)>>2]=(((((B(t[b+4|0],m)+B(t[b+2|0],n)|0)+B(h,t[b+6|0])|0)+B(j,t[b+8|0])<<8)/2|0)+((((B(t[b-4|0],H)+B(t[b-6|0],I)|0)+B(t[b-2|0],G)|0)+B(t[b|0],o)<<8)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){l=(g+8|0)+(f<<2)|0;e=v[l>>2];b=(g+24|0)+(f<<3)|0;j=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;m=e<<8;e=m;e=Bia(C,D,e,e>>31);n=ib;o=b;b=Ub(h,-16777216,16776704);h=Bia(z,A,b,b>>31);e=h+e|0;b=ib+n|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Ub(j,-16777216,16776704);j=Bia(x,y,e,e>>31);e=h+j|0;b=ib+b|0;b=e>>>0<j>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Lc(e,b,24);v[o+4>>2]=b-(m&w);v[l>>2]=(b|0)/256;f=f+1|0;continue}break}k=k+s|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);i=i+r|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],i>>12);Ob(g+16|0,E,F);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}fb=g+48|0}function U4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-80|0;fb=f;v[f+76>>2]=d;v[f+72>>2]=c;a:{if(!d){break a}g=w[Hk(c,d)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}Qk(f+48|0,c,d,d-1|0);c=v[f+52>>2];v[f+72>>2]=v[f+48>>2];v[f+76>>2]=c}c=f+48|0;Kd(c);d=v[f+48>>2];Kd(f+32|0);g=Gk(d,v[f+36>>2],f+72|0);Kd(c);c=v[f+76>>2];d=v[f+72>>2];b:{c:{d:{e:{if((g|0)==v[f+52>>2]){b=oc(f- -64|0,21598);if(Hc(d,c,v[b>>2],v[b+4>>2])){a=aa(8)|0;v[23220]=0;b=Q(52,f+48|0,10443)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}d=P()|0;O()|0;ub(b);break c}if(e){b=aa(8)|0;v[23220]=0;c=Bh(f+32|0,v[f+72>>2],v[f+76>>2]);a=v[23220];v[23220]=0;f:{g:{h:{if((a|0)!=1){v[23220]=0;U(934,f+48|0,17613,c|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}a=0;d=qc(b,f+48|0);v[23220]=0;U(106,d|0,61832,923);d=v[23220];v[23220]=0;if((d|0)!=1){break b}d=P()|0;O()|0;ub(f+48|0);break g}d=P()|0;O()|0;break f}d=P()|0;a=1;O()|0}ub(c);if(!a){break c}}ba(b|0);break c}Gb(a);break e}e=oc(f+24|0,21598);if(Hc(d,c,v[e>>2],v[e+4>>2])){a=aa(8)|0;v[23220]=0;b=Q(52,f+48|0,10443)|0;c=v[23220];v[23220]=0;if((c|0)!=1){a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}d=P()|0;O()|0;ub(b);break c}d=P()|0;O()|0;ba(a|0);break c}e=oc(f+16|0,12327);if(Hc(d,c,v[e>>2],v[e+4>>2])){i:{switch(v[b+52>>2]){case 0:Qb(a,5562);break e;case 1:Qb(a,11259);break e;case 2:Qb(a,9177);break e;default:break i}}Gb(a);break e}e=c;c=oc(f+8|0,11496);if(Hc(d,e,v[c>>2],v[c+4>>2])){j:{switch(v[b+56>>2]){case 0:Qb(a,15540);break e;case 1:Qb(a,15545);break e;case 2:Qb(a,12601);break e;case 3:Qb(a,9241);break e;default:break j}}Gb(a);break e}Gb(a)}fb=f+80|0;return}d=P()|0;O()|0;ba(a|0)}S(d|0)}L()}function cR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;t[a|0]=0;c=w[b|0];if(c){t[a|0]=c>>>0>96?-1:c+12|0}t[a+1|0]=w[b+1|0];c=w[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){t[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch((c+96&240)>>>4|0){case 0:t[a+2|0]=4;c=c&15;break b;case 1:t[a+2|0]=3;c=c&15;break b;case 2:t[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;c=c&15}t[a+4|0]=c}e=w[b+4|0];d=w[b+5|0];c=w[b+6|0];d:{if(!(c?1:e|d)){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}t[a+2|0]=15;t[a+3|0]=20;t[a+4|0]=c>>>3;t[f+15|0]=15;h=a,i=w[Rb(b+5|0,f+15|0)|0]|208,t[h+5|0]=i;break d;case 0:t[a+5|0]=d;t[a+3|0]=c;Mf(a);g=w[b+6|0]==15;break d;case 1:t[a+3|0]=2;h=a,i=vi(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 2:t[a+3|0]=3;h=a,i=vi(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 3:t[a+3|0]=4;h=a,i=vi(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 4:t[a+3|0]=5;t[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){t[a+5|0]=d;t[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d;case 12:t[a+3|0]=13;t[a+5|0]=c>>>1;break d;case 15:if(c){t[a+5|0]=c;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}t[a+5|0]=d;t[a+3|0]=c;LA(a,1);g=(w[a+3|0]&254)==16;break d}t[a+5|0]=d;t[a+3|0]=18;break d}t[a+3|0]=31;t[a+5|0]=c>>>1;break d}t[a+3|0]=31;t[a+5|0]=c>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=c>>>2}b=w[b+3|0];l:{if(!b){break l}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break l}if(w[a+2|0]){break l}t[a+2|0]=2;t[a+4|0]=b>>>2}fb=f+16|0;return g}function CJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=fb+-64|0;fb=k;a:{b:{c:{d:{e:{f:{j=ep(1,28);if(!j){a=tn(aa(4)|0);v[23220]=0;U(106,a|0,91480,25);a=v[23220];v[23220]=0;if((a|0)!=1){break a}break f}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:900;c=eg(k+48|0);g:{h:{i:{if(!i){break i}while(1){d=v[i>>2];if(!d){break i}e=v[i+4>>2];j:{if(e){v[23220]=0;d=Q(52,k+32|0,d|0)|0;f=v[23220];v[23220]=0;k:{if((f|0)!=1){v[23220]=0;f=Q(911,c|0,d|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break k}v[23220]=0;Q(260,f|0,e|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break k}break j}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;ub(d);break g}v[23220]=0;d=Q(52,k+16|0,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break h}os(c,d)}ub(d);i=i+8|0;continue}}v[23220]=0;d=T(784,80)|0;e=v[23220];v[23220]=0;l:{m:{n:{if((e|0)!=1){e=v[j+4>>2];f=v[j>>2];v[23220]=0;e=Q(912,f|0,e|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break n}v[k>>2]=e;e=v[Rf(k+8|0,k)>>2];v[23220]=0;a=ga(917,d|0,a|0,b|0,e|0,c|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break l}i=V(0)|0;O()|0;pe(k);break m}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0}Fb(d);break g}v[j+24>>2]=a;pe(k);Rk(c);i=j;break d}i=V(0)|0;O()|0}Rk(c);_(i|0)|0;v[23220]=0;X(906,15118,j|0,g|0,h|0);a=v[23220];v[23220]=0;if((a|0)!=1){v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){Fb(ns(a))}i=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){Fb(a);v[j+20>>2]=0}Fb(j);break d}i=V(0)|0;O()|0;v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;i=0;v[23220]=0;X(906,15118,0,g|0,h|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}$()}fb=k- -64|0;return i|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Tb()}L()}function Dn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;v[b+88>>2]=v[b+88>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){xb(e+8|0,a+1074312|0,15);if(yb(v[v[e+8>>2]>>2],v[e+12>>2])){break b}}if(v[a+480180>>2]!=268435456){break a}}c=c?c:w[b+811|0];t[b+812|0]=c;t[b+811|0]=c}if(c){u[b+768>>1]=c}d=v[b+656>>2];c:{if(lj(d)){c=x[b+768>>1];if(!c){break c}f=v[b+856>>2];g=v[a+1074392>>2];i=0-c|0;j=c;c=v[b+708>>2];h=(+(g>>>0)+1)*+(((c|0)<0?i:j)|0)/+y[a+1074416>>2];d:{if(D(h)<2147483648){a=~~h;break d}a=-2147483648}v[b+856>>2]=a;if(w[b+90|0]&16){a=B(v[v[d+44>>2]+36>>2]+1|0,a);v[b+856>>2]=a}a=a-(g?f:0)|0;d=a>>31;f=c>>31;if((f^c)-f>>>0<=(a^d)-d>>>0){if(!c){break c}v[b+708>>2]=0;v[b+852>>2]=c+v[b+852>>2];t[b+851|0]=w[b+851|0]|64;break c}v[b+708>>2]=c-a;v[b+852>>2]=a+v[b+852>>2];t[b+851|0]=w[b+851|0]|64;break c}c=1;e:{if(!(t[b+851|0]&1)){break e}d=v[a+480180>>2];if(d&524352){break e}if(v[a+1074416>>2]==1){xb(e+8|0,a+1074312|0,6);if(yb(v[v[e+8>>2]>>2],v[e+12>>2])){break e}d=v[a+480180>>2]}c=0;if((d|0)!=8){break e}c=(w[a+480208|0]&2)>>>1|0}f:{if(!v[b+700>>2]|!v[b+708>>2]){break f}f=v[a+480180>>2];d=x[b+768>>1];g=(f|0)==268435456&d>>>0>239;if(!((g?w[b+851|0]:c)&1)){break f}c=b+700|0;d=B((f|0)==64?2:4,g?d-240|0:d);d=cj(a)?d:0-d|0;f=v[b+700>>2];g=v[b+708>>2];if(!(w[b+851|0]&16?0:(f|0)>=(g|0))){Pj(a,b,c,d,1);d=v[b+708>>2];if((d|0)>=v[b+700>>2]){break f}v[c>>2]=d;break f}if((f|0)<=(g|0)){break f}Pj(a,b,c,0-d|0,1);f=v[b+700>>2];d=v[b+708>>2];g:{if((f|0)<(d|0)){v[c>>2]=d;break g}if((d|0)!=(f|0)){break f}}xb(e+8|0,a+1074312|0,112);if(!yb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}t[b+851|0]=w[b+851|0]|16}if(v[b+700>>2]!=v[b+708>>2]){break c}xb(e+8|0,a+1074312|0,25);if(!yb(v[v[e+8>>2]>>2],v[e+12>>2])&v[a+480180>>2]!=1){break c}v[b+708>>2]=0}fb=e+16|0}function FZ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=fb-1072|0;fb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;j=a+960|0;v[a+956>>2]=j;j=ow(j,100,11076,a+16|0);v[a+48>>2]=1091;k=a+48|0;o=he(a+536|0,0,k);v[a+48>>2]=1091;k=he(a+528|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+544|0;f=a+960|0;break d}j=wd();v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;j=Oi(a+956|0,j,11076,a);if((j|0)!=-1){f=v[a+956>>2];Je(o,f);Je(k,Fd(j<<2));h=v[k>>2];if(!Tj(h)){break d}}v[23220]=0;Z(1092);a=v[23220];v[23220]=0;if((a|0)!=1){break a}j=P()|0;O()|0;break c}g=a+520|0;Xc(g,d);v[23220]=0;q=T(1104,g|0)|0;g=v[23220];v[23220]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}v[23220]=0;X(1116,q|0,f|0,f+j|0,h|0);g=v[23220];v[23220]=0;if((g|0)==1){break j}p=(j|0)>0?w[f|0]==45:p;i=Gb(a+488|0);f=Gb(a+472|0);g=Gb(a+456|0);v[23220]=0;ma(1143,c|0,p|0,a+520|0,a+512|0,a+508|0,a+504|0,i|0,f|0,g|0,a+452|0);c=v[23220];v[23220]=0;if((c|0)==1){break i}v[a+36>>2]=1091;c=he(a+40|0,0,a+36|0);m=a+48|0;n=v[a+452>>2];k:{if((n|0)<(j|0)){l=((Bb(g)+(j-n<<1)|0)+Bb(f)|0)+1|0;break k}l=(Bb(g)+Bb(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Je(c,Fd(l<<2));m=v[c>>2];if(m){break h}v[23220]=0;Z(1092);b=v[23220];v[23220]=0;if((b|0)!=1){break a}break g}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}l=v[d+4>>2];v[23220]=0;oa(1144,m|0,a+36|0,a+32|0,l|0,h|0,(j<<2)+h|0,q|0,p|0,a+512|0,v[a+508>>2],v[a+504>>2],i|0,f|0,g|0,n|0);h=v[23220];v[23220]=0;if((h|0)!=1){v[23220]=0;b=la(1125,b|0,m|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break b}}}j=P()|0;O()|0;Kc(c)}Nc(g);Nc(f);ub(i)}Wb(a+520|0)}Kc(k);Kc(o);S(j|0);L()}Kc(c);Nc(g);Nc(f);ub(i);Wb(a+520|0);Kc(k);Kc(o);fb=a+1072|0;return b|0}L()}function Wf(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=j;i=w[a+79|0]?x[v[a>>2]+3836>>1]:i;b=x[a+20>>1];l=x[a+22>>1];m=x[a+70>>1];a:{b:{c:{d:{switch(v[a+16>>2]){case 1:c=x[v[a>>2]+3832>>1];f=x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((c>>>x[a+44>>1]&7)<<1)>>1]|0:0;g=c;c=x[a+46>>1];f=b+(c?g&c?0:f:f)|0;u[a+20>>1]=f;c=2;h=x[a+28>>1];if((h|0)<=f<<16>>16){break c}break b;case 2:if(w[a+78|0]){break b}case 3:c=0;f=x[v[a>>2]+3832>>1];h=x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((f>>>x[a+56>>1]&7)<<1)>>1]|0:0;g=f;f=x[a+58>>1];f=b+(f?g&f?0:h:h)|0;u[a+20>>1]=f;if(f<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:c=0;v[a+72>>2]=0;break a;case 0:break d}}c=1;f=x[v[a>>2]+3832>>1];k=x[a+24>>1]?B((b^-1)<<16>>16,x[a+36>>1]>>>x[v[a+40>>2]+((f>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;g=f;f=x[a+34>>1];f=b+(f?g&f?0:k:k)|0;u[a+20>>1]=f;if(f<<16>>16>0){break b}}v[a+16>>2]=c;u[a+20>>1]=h}i=((b+l|0)+m|0)+i<<3;if(e){d=(u[a+74>>1]+u[a+72>>1]>>e)+d|0}d=(j>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(x[a+12>>1]){case 0:d=(b&512)>>>9|0;b=x[((b&256?c^255:c)<<1)+28400>>1];break e;case 1:d=0;b=x[((b&512?0:b&256?c^255:c)<<1)+28400>>1];break e;case 2:d=0;b=x[((b&256?c^255:c)<<1)+28400>>1];break e;case 3:d=0;b=x[((b&256?0:c)<<1)+28400>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=x[(e<<1)+28400>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=x[(b<<1)+28400>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}u[a+74>>1]=x[a+72>>1];e=a;a=b+i&65535;a=a>>>0<8191?a:8191;c=0-d^x[((a&255)<<1)+27888>>1]+1024>>>(a>>>8)<<1;u[e+72>>1]=c}return c<<16>>16}function yp(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;v[e+12>>2]=u[b+780>>1]+w[b+837|0];v[e+8>>2]=u[b+782>>1]+(w[b+838|0]&127);ee(e+12|0,0,127);ee(e+8|0,0,127);k=a+1074312|0;xb(e,k,1);j=v[e+12>>2];a:{if(yb(v[v[e>>2]>>2],v[e+4>>2])){i=v[e+8>>2];break a}u[b+780>>1]=0;t[b+837|0]=j;i=v[e+8>>2];u[b+782>>1]=0;t[b+838|0]=i}xb(e,k,36);l=B(j,d+256|0);m=(l|0)/256|0;b:{if(!(!yb(v[v[e>>2]>>2],v[e+4>>2])|i|(l|0)<65024)){m=-1;if(!Oc(w[b+788|0])){break b}if(Us(w[b+790|0],w[b+791|0])|x[b+786>>1]|!(w[b+851|0]&2)){break b}v[b+88>>2]=v[b+88>>2]&-32769;break b}v[b+88>>2]=v[b+88>>2]|32768;f=ie(C(10),C(C(0-i|0)*C(.00937500037252903)));i=fb-16|0;fb=i;g=C(B(j,d+256|0)>>>0);c:{if(v[a+480180>>2]!=33554432){h=C(110);g=C(C(g/(w[a+480209|0]&128?C(10240):C(12288)))+C(.25));break c}h=C(125);g=C(C(g*C(6))/C(65024))}n=i,o=Lh(C(ie(C(2),g)*h)),v[n+12>>2]=o;ee(i+12|0,120,2e4);d=v[i+12>>2];j=v[a+24620>>2];fb=i+16|0;xb(e,k,36);g=C(C(((j|0)<d<<1?j>>>1|0:d)>>>0)*C(6.2831854820251465));d:{if(!(!yb(v[v[e>>2]>>2],v[e+4>>2])|v[a+480208>>2]&32768)){h=C(C(y[a+24620>>2])/g);g=C(C(C(f*h)+f)+C(-1));z[e>>2]=g;f=C(h*h);break d}h=C(f+f);f=C(g/C(y[a+24620>>2]));z[e>>2]=C(C(1)-h)*f;vN(e,C(2));g=C(C(h-z[e>>2])/f);z[e>>2]=g;f=C(C(1)/C(f*f))}h=C(f+C(g+C(1)));g=C(C(f+C(f+g))/h);f=C(C(-f)/h);h=C(C(1)/h);e:{if(w[b+845|0]==1){n=b,o=Lh(C(C(C(1)-h)*C(16777216))),v[n+60>>2]=o;n=b,o=Lh(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Lh(C(f*C(16777216))),v[n+68>>2]=o;a=-1;break e}d=Lh(C(h*C(16777216)));v[b+60>>2]=d;n=b,o=Lh(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Lh(C(f*C(16777216))),v[n+68>>2]=o;a=0;if(d){break e}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break b}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}fb=e+16|0;return m}function JZ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=fb-464|0;fb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;j=a+352|0;v[a+348>>2]=j;j=ow(j,100,11076,a+16|0);v[a+48>>2]=1091;k=a+48|0;o=he(a+232|0,0,k);v[a+48>>2]=1091;k=he(a+224|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+240|0;f=a+352|0;break d}j=wd();v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;j=Oi(a+348|0,j,11076,a);if((j|0)!=-1){f=v[a+348>>2];Je(o,f);Je(k,Fd(j));h=v[k>>2];if(!Tj(h)){break d}}v[23220]=0;Z(1092);a=v[23220];v[23220]=0;if((a|0)!=1){break a}j=P()|0;O()|0;break c}g=a+216|0;Xc(g,d);v[23220]=0;q=T(18,g|0)|0;g=v[23220];v[23220]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}v[23220]=0;X(1102,q|0,f|0,f+j|0,h|0);g=v[23220];v[23220]=0;if((g|0)==1){break j}p=(j|0)>0?w[f|0]==45:p;i=Gb(a+192|0);f=Gb(a+176|0);g=Gb(a+160|0);v[23220]=0;ma(1141,c|0,p|0,a+216|0,a+208|0,a+207|0,a+206|0,i|0,f|0,g|0,a+156|0);c=v[23220];v[23220]=0;if((c|0)==1){break i}v[a+36>>2]=1091;c=he(a+40|0,0,a+36|0);m=a+48|0;n=v[a+156>>2];k:{if((n|0)<(j|0)){l=((Bb(g)+(j-n<<1)|0)+Bb(f)|0)+1|0;break k}l=(Bb(g)+Bb(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Je(c,Fd(l));m=v[c>>2];if(m){break h}v[23220]=0;Z(1092);b=v[23220];v[23220]=0;if((b|0)!=1){break a}break g}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}l=v[d+4>>2];v[23220]=0;oa(1142,m|0,a+36|0,a+32|0,l|0,h|0,h+j|0,q|0,p|0,a+208|0,t[a+207|0],t[a+206|0],i|0,f|0,g|0,n|0);h=v[23220];v[23220]=0;if((h|0)!=1){v[23220]=0;b=la(14,b|0,m|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break b}}}j=P()|0;O()|0;Kc(c)}ub(g);ub(f);ub(i)}Wb(a+216|0)}Kc(k);Kc(o);S(j|0);L()}Kc(c);ub(g);ub(f);ub(i);Wb(a+216|0);Kc(k);Kc(o);fb=a+464|0;return b|0}L()}function GL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-16|0;fb=g;e=B(b,872)+a|0;j=e+1074992|0;a:{b:{i=v[e+1075080>>2];if(i&131072){h=a+480180|0;e=v[h>>2];i=1;c:{d:{e:{f=v[a+480208>>2];if(f&4096){if(!(e&16777248)){break e}i=!(f&4)}if((e|0)!=64){break d}break b}if((e|0)==64){break b}h=a+480180|0;i=0;break c}if(!i){break c}xb(g+8|0,a+1074312|0,21);if(!yb(v[v[g+8>>2]>>2],v[g+12>>2])){break c}e=B(b,872)+a|0;f=e+1075811|0;t[f|0]=w[f|0]+(w[e+1075815|0]<<2)}f=B(b,872)+a|0;k=f+1075814|0;l=f+1075811|0;e=dy(a,w[k|0],w[l|0]);f:{if(lj(v[j+656>>2])){z[d>>2]=z[d>>2]+C(C(C(B(w[f+1075816|0],e)|0)*C(.05000000074505806))/C(7680));c=f+1075843|0;d=w[c|0];t[c|0]=d&159|64;if(v[a+1074416>>2]!=(v[a+1074392>>2]+1|0)){break f}t[c|0]=d|96;break f}d=v[a+480208>>2];if((d&2101248)==2101248){break a}f=v[h>>2];if(d&4096?f&67633152:0){break a}e=f&5?(w[k|0]&3)==1?0-e|0:e:e;k=a+1074312|0;xb(g+8|0,k,21);f=v[a+480208>>2];g:{if(yb(v[v[g+8>>2]>>2],v[g+12>>2])){d=f&4;e=d?e:0-e|0;d=d?5:6;break g}d=5;h:{if(f&131072){break h}h=v[h>>2];d=8;if((h|0)==1024){break h}d=7;if(h&524304){break h}d=h&16777248?f&4?6:7:6}xb(g+8|0,k,80);if(!yb(v[v[g+8>>2]>>2],v[g+12>>2])){break g}d=w[(B(b,872)+a|0)+1075783|0]==26?d+2|0:d}d=(0-B(w[(B(b,872)+a|0)+1075816|0],e)|0)/(1<<d)|0;Pj(a,j,c,d,0);e=v[j+656>>2];c=Ls(a,v[j+88>>2],e);if(!c){break f}jb[v[v[c>>2]+88>>2]](c,d,(e?t[e+33|0]:2)<<24>>24,b)}if(!i){break a}xb(g+8|0,a+1074312|0,21);if(yb(v[v[g+8>>2]>>2],v[g+12>>2])){break a}t[l|0]=w[l|0]+w[(B(b,872)+a|0)+1075815|0];break a}if(!(w[e+1075662|0]&2)){break a}a=Ls(a,i,v[j+656>>2]);if(!a){break a}jb[v[v[a>>2]+88>>2]](a,0,0,b);break a}a=B(b,872)+a|0;b=a+1075811|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075816|0],167)}t[b|0]=d+1}fb=g+16|0}function BQ(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=fb-16|0;fb=l;a:{if((c|0)==(g|0)){f=cc(l+8|0,f,c);g=fb-16|0;fb=g;d=Wk(d,e,b,c);v[g+12>>2]=d;b:{if((d|0)<=0){d=v[f>>2];break b}c:{if(!c){c=v[f>>2];break c}k=32-c|0;v[g+8>>2]=k;e=d;d=v[nd(g+8|0,g+12|0)>>2];v[g+12>>2]=e-d;e=v[f>>2];c=-1<<c&-1>>>k-d;v[e>>2]=v[e>>2]&(c^-1)|c&v[b>>2];c=d+v[f+4>>2]|0;v[f+4>>2]=c&31;c=e+(c>>>3&536870908)|0;v[f>>2]=c;b=b+4|0;d=v[g+12>>2]}k=c;e=(d|0)/32|0;c=e<<2;Zi(k,b,c);e=d-(e<<5)|0;v[g+12>>2]=e;d=c+v[f>>2]|0;v[f>>2]=d;if((e|0)<=0){break b}e=-1>>>32-e|0;v[d>>2]=v[d>>2]&(e^-1)|e&v[b+c>>2];v[f+4>>2]=v[g+12>>2]}cc(a,d,v[f+4>>2]);fb=g+16|0;break a}k=a;g=cc(l,f,g);f=fb-16|0;fb=f;d=Wk(d,e,b,c);v[f+12>>2]=d;d:{if((d|0)<=0){a=v[g+4>>2];break d}e:{if(!c){a=v[g+4>>2];break e}i=32-c|0;v[f+8>>2]=i;a=d;e=f+8|0;d=v[nd(e,f+12|0)>>2];v[f+12>>2]=a-d;a=v[g+4>>2];j=v[b>>2];v[f+8>>2]=d;m=32-a|0;v[f+4>>2]=m;h=v[g>>2];n=v[h>>2];e=v[Eb(e,f+4|0)>>2];i=j&(-1<<c&-1>>>i-d);v[h>>2]=(-1<<a&-1>>>m-e^-1)&n|(a>>>0>c>>>0?i<<a-c:i>>>c-a|0);j=a+e|0;a=j&31;v[g+4>>2]=a;h=h+(j>>>3&536870908)|0;v[g>>2]=h;d=d-e|0;if((d|0)>0){v[h>>2]=v[h>>2]&(-1>>>32-d^-1)|i>>>c+e;v[g+4>>2]=d;a=d}b=b+4|0;d=v[f+12>>2]}e=32-a|0;h=-1<<a;i=h^-1;while(1){if((d|0)>=32){c=v[g>>2];d=v[b>>2];v[c>>2]=i&v[c>>2]|d<<a;v[g>>2]=c+4;v[c+4>>2]=h&v[c+4>>2]|d>>>e;d=v[f+12>>2]-32|0;v[f+12>>2]=d;b=b+4|0;continue}break}if((d|0)<=0){break d}i=v[b>>2];v[f+8>>2]=e;c=v[g>>2];b=v[c>>2];j=b;b=v[nd(f+12|0,f+8|0)>>2];j=j&(h&-1>>>e-b^-1);e=i&-1>>>32-d;v[c>>2]=j|e<<a;d=a+b|0;a=d&31;v[g+4>>2]=a;c=c+(d>>>3&536870908)|0;v[g>>2]=c;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<=0){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|e>>>b;a=v[f+12>>2];v[g+4>>2]=a}cc(k,v[g>>2],a);fb=f+16|0}fb=l+16|0}function mY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;r=fb-16|0;fb=r;j=c;while(1){a:{if((d|0)==(j|0)){j=d;break a}if(!w[j|0]){break a}j=j+1|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}i=v[b+4>>2];v[r+8>>2]=v[b>>2];v[r+12>>2]=i;s=fb-16|0;fb=s;u=$h(s+8|0,v[a+8>>2]);m=j-c|0;k=0;o=0;n=fb-1040|0;fb=n;i=v[e>>2];v[n+12>>2]=i;p=f?f:n+16|0;l=f?g-f>>2:256;e:{f:{if(!(!i|!l)){while(1){g:{q=m>>>2|0;if(q>>>0<l>>>0&m>>>0<=131){break f}q=gG(p,n+12|0,l>>>0>q>>>0?q:l,b);if((q|0)==-1){k=-1;l=0;i=v[n+12>>2];break g}t=(n+16|0)==(p|0)?0:q;l=l-t|0;p=(t<<2)+p|0;m=i+m|0;i=v[n+12>>2];m=i?m-i|0:0;k=k+q|0;if(!i){break g}if(l){continue}}break}}if(!i){break e}}if(!(!l|!m)){o=i;i=k;while(1){h:{k=yr(p,o,m,b);i:{if(k+2>>>0<=2){j:{switch(k+1|0){case 1:o=0;break i;case 0:break e;default:break j}}v[b>>2]=0;break i}i=i+1|0;o=k+o|0;l=l-1|0;if(l){break h}}k=i;break e}p=p+4|0;m=m-k|0;k=i;if(m){continue}break}break e}o=i}if(f){v[e>>2]=o}fb=n+1040|0;_h(u);fb=s+16|0;k:{l:{m:{n:{if((k|0)==-1){while(1){o:{v[h>>2]=f;if(v[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=iF(f,c,j-c|0,r+8|0,v[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}v[e>>2]=c;break n}g=b}c=c+g|0;f=v[h>>2]+4|0;continue}break}v[e>>2]=c;break d}f=v[h>>2]+(k<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break k}c=v[e>>2];if((d|0)==(j|0)){j=d;continue}if(!iF(f,c,1,b,v[a+8>>2])){break m}}a=2;break c}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;j=c;while(1){if((d|0)==(j|0)){j=d;break b}if(!w[j|0]){break b}j=j+1|0;continue}}v[e>>2]=c;a=1;break c}c=v[e>>2]}a=(c|0)!=(d|0)}fb=r+16|0;return a|0}f=v[h>>2];continue}}function vr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=fb-128|0;fb=i;v[i+120>>2]=b;k=cG(c,d);v[i+4>>2]=1091;m=bG(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Fd(k);if(!j){v[23220]=0;Z(1092);a=v[23220];v[23220]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}Je(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[23220]=0;h=Q(1093,a|0,i+120|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[23220]=0;b=Q(1094,a|0,i+120|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}b=v[a>>2];v[23220]=0;n=T(1095,b|0)|0;b=v[23220];v[23220]=0;g:{if((b|0)!=1){if(g){break g}v[23220]=0;n=Q(1096,e|0,n|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}q=o+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=q;if(!r){continue e}v[23220]=0;T(1097,a|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Bb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=t[Vf(b,o)|0];j:{if(g){break j}v[23220]=0;p=Q(1096,e|0,p<<24>>24)|0;s=v[23220];v[23220]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n&255)==(p&255)){r=1;if((Bb(b)|0)!=(q|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Kc(m);fb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!ze(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Kc(m);S(b|0)}L()}function li(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;q=c*d;r=b*e;m=q+r;s=b*d;t=c*e;p=s-t;a:{if(!Mh(p)){break a}if(!Mh(m)){break a}h=Xe(b);f=Xe(c);k=h|f;if((k|0)==1){o(+(f?1:0));f=j(1)|0;i=j(0)|0;o(+c);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);c=+n();o(0);f=j(1)|0;i=j(0)|0;o(+d);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);d=(u=+n(),v=d,w=Mh(d),w?u:v);o(0);f=j(1)|0;i=j(0)|0;o(+e);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);e=(u=+n(),v=e,w=Mh(e),w?u:v);o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=+n()}h=Xe(d);f=Xe(e);b:{if(f?1:h){o(+(f?1:0));f=j(1)|0;g=j(0)|0;o(+e);k=j(1)|0;j(0)|0;l(0,g|0);l(1,f&2147483647|k&-2147483648);e=+n();o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=+n();o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Mh(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Mh(c),w?u:v);break b}if(k){break b}c:{if(Xe(s)){break c}if(Xe(t)){break c}if(Xe(r)){break c}if(!Xe(q)){break a}}o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Mh(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Mh(c),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=(u=+n(),v=d,w=Mh(d),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+e);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);e=(u=+n(),v=e,w=Mh(e),w?u:v)}m=(b*e+d*c)*N;p=(b*d-e*c)*N}Ul(a,p,m)}function y8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=fb-208|0;fb=c;e=yl(c+104|0,a);v[23220]=0;d=Q(404,c+88|0,43966)|0;a=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[23220]=0;v[c+72>>2]=19923968;v[c+76>>2]=0;U(405,e|0,d|0,c+72|0);a=v[23220];v[23220]=0;if((a|0)==1){break n}Pb(d);if(w[e+3|0]&64){break e}v[23220]=0;d=Q(404,c+72|0,13313)|0;a=v[23220];v[23220]=0;if((a|0)==1){break m}v[23220]=0;X(436,e|0,b|0,d|0,843);a=v[23220];v[23220]=0;if((a|0)==1){break l}Pb(d);v[c+68>>2]=0;v[c+64>>2]=0;v[23220]=0;d=Q(404,c+48|0,16694)|0;a=v[23220];v[23220]=0;if((a|0)==1){break k}v[23220]=0;U(844,e|0,c+68|0,d|0);a=v[23220];v[23220]=0;if((a|0)==1){break j}Pb(d);v[23220]=0;d=Q(404,c+32|0,16666)|0;a=v[23220];v[23220]=0;if((a|0)==1){break i}v[23220]=0;U(844,e|0,c- -64|0,d|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}Pb(d);a=v[c+68>>2];d=v[c+64>>2];o:{if(!a|d>>>0<a>>>0){break o}f=v[v[v[v[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}v[b+20>>2]=d;v[b+16>>2]=a}d=Ib(c+16|0);v[23220]=0;f=Q(404,c|0,14097)|0;a=v[23220];v[23220]=0;if((a|0)==1){break d}v[23220]=0;U(845,e|0,d|0,f|0);a=v[23220];v[23220]=0;if((a|0)==1){break g}Pb(f);if(rc(v[d>>2],v[d+4>>2])){break f}a=v[b+16>>2];v[23220]=0;R(798,d|0,a|0);a=v[23220];v[23220]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;Pb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Pb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Pb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Pb(d);break a}a=P()|0;O()|0;Pb(f);break b}v[23220]=0;R(846,b|0,d|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}lc(d)}Ug(e);fb=c+208|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}lc(d)}Ug(e);S(a|0);L()}function tr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=fb-128|0;fb=i;v[i+120>>2]=b;k=cG(c,d);v[i+4>>2]=1091;m=bG(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Fd(k);if(!j){v[23220]=0;Z(1092);a=v[23220];v[23220]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}Je(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[23220]=0;h=Q(1109,a|0,i+120|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[23220]=0;b=Q(1110,a|0,i+120|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}b=v[a>>2];v[23220]=0;n=T(1111,b|0)|0;b=v[23220];v[23220]=0;g:{if((b|0)!=1){if(g){break g}v[23220]=0;n=Q(1112,e|0,n|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}q=o+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=q;if(!r){continue e}v[23220]=0;T(1113,a|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Bb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=v[ej(b,o)>>2];j:{if(g){break j}v[23220]=0;p=Q(1112,e|0,p|0)|0;s=v[23220];v[23220]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n|0)==(p|0)){r=1;if((Bb(b)|0)!=(q|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Kc(m);fb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!ze(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Kc(m);S(b|0)}L()}function Zaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;g=fb-48|0;fb=g;o=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;j=e+(g+24|0)|0;e=a+e|0;v[j+4>>2]=v[e+44>>2];v[j+8>>2]=v[e+48>>2];f=f+1|0;continue}break}j=v[a+24>>2];p=v[a+20>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){f=v[g+16>>2];k=((((v[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+o|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;i=u[b+14>>1];h=u[b+12>>1];l=u[b+10>>1];m=u[b+8>>1];n=u[b+6>>1];D=u[b+4>>1];E=u[b+2>>1];F=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=k+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((((B(u[b+8>>1],l)+B(u[b+4>>1],m)|0)+B(h,u[b+12>>1])|0)+B(i,u[b+16>>1])|0)/2|0)+((((B(u[b-8>>1],E)+B(u[b-12>>1],F)|0)+B(u[b-4>>1],D)|0)+B(u[b>>1],n)|0)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){k=(g+8|0)+(f<<2)|0;e=v[k>>2];b=(g+24|0)+(f<<3)|0;i=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;l=e<<8;e=l;e=Bia(y,z,e,e>>31);m=ib;n=b;b=Ub(h,-16777216,16776704);h=Bia(w,x,b,b>>31);e=h+e|0;b=ib+m|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Ub(i,-16777216,16776704);i=Bia(s,t,e,e>>31);e=h+i|0;b=ib+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Lc(e,b,24);v[n+4>>2]=b-(l&r);v[k>>2]=(b|0)/256;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],p);v[c+4>>2]=v[c+4>>2]+B(j,v[g+12>>2]);Ob(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}fb=g+48|0}function $4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb+-64|0;fb=d;f=1;a:{if(ze(c)){break a}e=w[cJ(c)|0];if((e|0)!=33){if((e|0)!=63){break a}f=0}e=d+48|0;vv(e,c,0,Bb(c)-1|0);xc(c,e);ub(e)}e=d+48|0;Kd(e);g=v[d+48>>2];Kd(d+40|0);g=bJ(g,v[d+44>>2],c);Kd(e);b:{c:{d:{e:{f:{if((g|0)==v[d+52>>2]){if(je(c,21598)){a=aa(8)|0;v[23220]=0;b=Q(52,d+48|0,10443)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(b);break c}if(!f){break f}a=aa(8)|0;v[23220]=0;U(925,d+48|0,17613,c|0);b=v[23220];v[23220]=0;if((b|0)!=1){a=qc(a,d+48|0);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(d+48|0);break c}c=P()|0;O()|0;ba(a|0);break c}e=Gb(d+48|0);g:{h:{i:{j:{switch(v[g+4>>2]){case 0:re(d+32|0,c);v[23220]=0;b=fa(926,b|0,v[d+32>>2],v[d+36>>2],f|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){v[23220]=0;t[d+40|0]=b;R(927,a|0,d+40|0);a=v[23220];v[23220]=0;if((a|0)!=1){break g}}break i;case 1:re(d+24|0,c);v[23220]=0;b=UE(b,v[d+24>>2],v[d+28>>2],f);c=ib;f=v[23220];v[23220]=0;if((f|0)!=1){v[23220]=0;v[d+40>>2]=b;v[d+44>>2]=c;R(929,a|0,d+40|0);a=v[23220];v[23220]=0;if((a|0)!=1){break g}}break i;case 2:re(d+16|0,c);v[23220]=0;h=+za(930,b|0,v[d+16>>2],v[d+20>>2],f|0);b=v[23220];v[23220]=0;if((b|0)!=1){v[23220]=0;A[d+40>>3]=h;R(931,a|0,d+40|0);a=v[23220];v[23220]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}re(d+8|0,c);v[23220]=0;da(932,a|0,b|0,v[d+8>>2],v[d+12>>2],f|0);a=v[23220];v[23220]=0;if((a|0)!=1){break g}}c=P()|0;O()|0;ub(e);break c}Mc(a,e)}ub(e);break e}Gb(a)}fb=d- -64|0;return}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function _aa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;g=fb-48|0;fb=g;o=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;j=e+(g+24|0)|0;e=a+e|0;v[j+4>>2]=v[e+44>>2];v[j+8>>2]=v[e+48>>2];f=f+1|0;continue}break}j=v[a+24>>2];p=v[a+20>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+72>>2];b=v[a+68>>2];s=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;C=v[a+8>>2];D=v[a+12>>2];while(1){if(d){f=v[g+16>>2];k=(((v[g+20>>2]&2147483647)<<1|f>>>31)&-2)+o|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;i=u[b+14>>1];h=u[b+12>>1];l=u[b+10>>1];m=u[b+8>>1];n=u[b+6>>1];E=u[b+4>>1];F=u[b+2>>1];G=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=e+k|0;v[(g+8|0)+(e<<2)>>2]=(((((B(t[b+4|0],l)+B(t[b+2|0],m)|0)+B(h,t[b+6|0])|0)+B(i,t[b+8|0])<<8)/2|0)+((((B(t[b-4|0],F)+B(t[b-6|0],G)|0)+B(t[b-2|0],E)|0)+B(t[b|0],n)<<8)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){k=(g+8|0)+(f<<2)|0;e=v[k>>2];b=(g+24|0)+(f<<3)|0;i=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;l=e<<8;e=l;e=Bia(z,A,e,e>>31);m=ib;n=b;b=Ub(h,-16777216,16776704);h=Bia(x,y,b,b>>31);e=h+e|0;b=ib+m|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Ub(i,-16777216,16776704);i=Bia(s,w,e,e>>31);e=h+i|0;b=ib+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Lc(e,b,24);v[n+4>>2]=b-(l&r);v[k>>2]=(b|0)/256;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],p);v[c+4>>2]=v[c+4>>2]+B(j,v[g+12>>2]);Ob(g+16|0,C,D);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}fb=g+48|0}function iaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;h=fb-48|0;fb=h;e=dO(h+32|0,1<<v[b+12>>2]);f=v[e>>2];while(1){c=v[a>>2];if(Dg(c,v[a+4>>2])>>>0>d>>>0){c=Ne(c,d);cO(_c(f,d),A[c>>3]);d=d+1|0;continue}break}bO(b,e);x=h,y=Ab(v[e>>2]),v[x+8>>2]=y;w=Ab(v[e+4>>2]);while(1){f=v[h+8>>2];if(Nb(f,w)){m=A[f+8>>3];k=fb-32|0;fb=k;o(+A[f>>3]);g=j(1)|0;r=j(0)|0;o(+m);c=j(1)|0;s=j(0)|0;q=g&2147483647;t=c&2147483647;d=t;c=(q|0)==(d|0)&r>>>0<s>>>0|d>>>0>q>>>0;g=c?r:s;c=c?q:d;d=c;l(0,g|0);l(1,c|0);p=+n();u=c>>>20|0;i=p;a:{if((u|0)==2047){break a}c=(q|0)==(t|0)&r>>>0>s>>>0|q>>>0>t>>>0;l(0,(c?r:s)|0);c=c?q:t;l(1,c|0);m=+n();b:{if(!(d|g)){break b}c=c>>>20|0;if((c|0)==2047){break b}i=m+p;if((c-u|0)>=65){break a}c:{if(c>>>0>=1534){p=p*1.90109156629516e-211;m=m*1.90109156629516e-211;i=5.260135901548374e210;break c}i=1;if(u>>>0>572){break c}p=p*5.260135901548374e210;m=m*5.260135901548374e210;i=1.90109156629516e-211}qH(k+24|0,k+16|0,m);qH(k+8|0,k,p);i=i*K(A[k>>3]+A[k+16>>3]+A[k+8>>3]+A[k+24>>3]);break a}i=m}p=i;fb=k+32|0;cO(f,ip(p));Un(h+8|0);continue}break}aO(b,e);$N(e);g=v[e>>2];f=bh(g,v[e+4>>2])>>>1|0;c=f>>>0>1?f:1;d=1;while(1){if((c|0)!=(d|0)){_y(_c(g,d),2);_y(_c(g,d+f|0),0);d=d+1|0;continue}break}bO(b,e);x=h,y=Ab(v[e>>2]),v[x+24>>2]=y;f=Ab(v[e+4>>2]);while(1){g=v[h+24>>2];if(Nb(g,f)){_N(h+8|0,g);c=v[h+20>>2];v[g+8>>2]=v[h+16>>2];v[g+12>>2]=c;c=v[h+12>>2];v[g>>2]=v[h+8>>2];v[g+4>>2]=c;Un(h+24|0);continue}break}aO(b,e);$N(e);f=v[a>>2];c=Dg(f,v[a+4>>2]);b=v[e>>2];d=0;while(1){if((c|0)==(d|0)){Yj(e);fb=h+48|0}else{a=_c(b,d);x=Ne(f,d),z=A[a>>3],A[x>>3]=z;d=d+1|0;continue}break}}function OV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=fb+-64|0;fb=f;wc(b);Fo(a);a:{if(!Xh(b,f+56|0)){break a}if(!fD(f+56|0)){break a}if(!c){l=1;break a}if(!Lb(v[b>>2],v[b+8>>2],4)){break a}rv(a);p=f,q=qv(),v[p+32>>2]=q;c=f+32|0;pv(Aj(v[a+4>>2])+32|0,c);Zq(c);k=v[Aj(v[a+4>>2])+32>>2];c=$g(v[b>>2]);if(c&1){break a}d=c-4|0;Vc(b,d);h=fb-16|0;fb=h;c=h+8|0;dv(c,b);e=w[Hb(c,0)|0];i=w[Hb(c,1)|0];c=w[Hb(c,2)|0];fb=h+16|0;h=c|(i<<8|e<<16);if(!h){break a}v[23220]=0;R(162,k|0,h|0);c=v[23220];v[23220]=0;l=1;if((c|0)==1){a=V(91480)|0;if((O()|0)==(ea(91480)|0)){_(a|0)|0;$();l=0;break a}S(a|0);L()}Vc(b,4);m=f+32|0;eD(m,b);i=v[k>>2];e=fb-32|0;fb=e;b=v[f+32>>2];t[e+24|0]=w[b|0];t[e+25|0]=w[b+1|0];t[e+26|0]=w[b+2|0];t[e+27|0]=w[b+3|0];c=Qq(e+8|0);d=b+d|0;v[c+12>>2]=d-4;v[c+8>>2]=b;zj(c,w[d-1|0]);b=h;b:while(1){c:{d:{e:{if(!b){break e}if(zj(c,1)){break d}d=1;while(1){g=zj(c,2);d=g+d|0;if((g|0)==3){continue}break}v[e+4>>2]=d;uc(e+4|0,b);d=0;g=v[e+4>>2];while(1)if((d|0)==(g|0)){if(!b){break e}break d}else{b=b-1|0;p=i+b|0,q=zj(c,8),t[p|0]=q;d=d+1|0;continue}}fb=e+32|0;break c}g=zj(c,2);d=g+2|0;v[e+4>>2]=d;f:{if((g|0)==3){if(zj(c,1)){g=w[Hb(e+24|0,3)|0]}else{g=7}g=zj(c,g);while(1){j=zj(c,3);d=j+d|0;if((j|0)==7){continue}break}v[e+4>>2]=d;break f}g=zj(c,w[Hb(e+24|0,g)|0])}uc(e+4|0,b);d=0;o=v[e+4>>2];while(1){if((d|0)==(o|0)){continue b}j=0;n=b+g|0;if(h>>>0>n>>>0){j=w[i+n|0]}b=b-1|0;t[i+b|0]=j;d=d+1|0;continue}}break}ge(f+16|0,v[k>>2],v[k+4>>2]);Hg(f+24|0,v[f+16>>2],v[f+20>>2]);b=Xd(f+8|0);b=Xq(m,v[f+24>>2],v[f+28>>2],v[b>>2],v[b+4>>2]);Yc(Aj(v[a+4>>2])+12|0,b);wb(b)}fb=f- -64|0;return l|0}function zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=fb-48|0;fb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){e=v[g+16>>2];m=((((v[g+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+o|0;b=e>>>21&2040;j=u[b+39878>>1];i=u[b+39876>>1];n=u[b+39874>>1];l=u[b+39872>>1];b=0;e=0;while(1){if((e|0)!=2){f=m+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((B(u[f>>1],n)+B(u[f-4>>1],l)|0)+B(i,u[f+4>>1])|0)+B(j,u[f+8>>1])|0)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=v[m>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=Bia(y,z,f,f>>31);l=ib;D=e;e=Ub(i,-16777216,16776704);i=Bia(w,x,e,e>>31);f=i+f|0;e=ib+l|0;e=f>>>0<i>>>0?e+1|0:e;l=f;f=Ub(j,-16777216,16776704);j=Bia(s,t,f,f>>31);f=l+j|0;e=ib+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Lc(f,e,24);v[D+4>>2]=e-(n&r);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Ob(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=g+48|0}function Aga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=fb-16|0;fb=g;i=bf(a,c);Yd(g,v[a+28>>2]);j=a;a:{if(!i){c=0;if(cd(a,5)){break a}}e=fb-192|0;fb=e;f=yl(e+88|0,v[a+28>>2]);v[23220]=0;a=Q(404,e+72|0,27807)|0;c=v[23220];v[23220]=0;b:{c:{d:{e:{if((c|0)!=1){v[23220]=0;v[e+8>>2]=19923968;v[e+12>>2]=0;U(405,f|0,a|0,e+8|0);c=v[23220];v[23220]=0;if((c|0)==1){break e}Pb(a);if(!(w[f+3|0]&64)){break d}break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;Pb(a);break c}t[e+71|0]=0;t[e+70|0]=0;v[23220]=0;a=Q(404,e+56|0,10055)|0;c=v[23220];v[23220]=0;f:{g:{h:{i:{if((c|0)!=1){v[23220]=0;U(444,f|0,e+71|0,a|0);c=v[23220];v[23220]=0;if((c|0)==1){break i}Pb(a);if(!w[e+71|0]){break b}hf(e+71|0,50);v[23220]=0;a=Q(404,e+40|0,13194)|0;c=v[23220];v[23220]=0;if((c|0)==1){break f}v[23220]=0;U(444,f|0,e+70|0,a|0);c=v[23220];v[23220]=0;if((c|0)==1){break g}Pb(a);a=v[b>>2];c=gj(a,v[b+4>>2]);h=w[e+71|0];if(c>>>0<h>>>0){a=mz(e+8|0,v[b+12>>2]);v[23220]=0;U(445,b|0,h|0,a|0);c=v[23220];v[23220]=0;if((c|0)==1){break h}Uk(a);a=v[b>>2]}k=x[nj(a,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){a=w[e+70|0];n=b,o=gj(v[b>>2],v[b+4>>2])>>>0>a>>>0?a:0,t[n+16|0]=o;break b}Ve(nj(v[b>>2],a),k);l=v[b>>2];v[23220]=0;R(446,e+8|0,c|0);m=v[23220];v[23220]=0;if((m|0)!=1){v[23220]=0;X(447,f|0,nj(l,a)|0,e+8|0,d|0);a=v[23220];v[23220]=0;if((a|0)==1){break j}c=c+1|0;Pb(e+8|0);continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;Pb(e+8|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;Pb(a);break c}c=P()|0;O()|0;Uk(a);break c}c=P()|0;O()|0;Pb(a);break c}c=P()|0;O()|0}Ug(f);S(c|0);L()}Ug(f);fb=e+192|0;c=i}We(j,c);fb=g+16|0}function Aba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0;g=fb-48|0;fb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;C=v[a+8>>2];D=v[a+12>>2];while(1){if(d){e=v[g+16>>2];m=(((v[g+20>>2]&2147483647)<<1|e>>>31)&-2)+o|0;b=e>>>21&2040;j=u[b+39878>>1];i=u[b+39876>>1];n=u[b+39874>>1];l=u[b+39872>>1];b=0;e=0;while(1){if((e|0)!=2){f=e+m|0;v[(g+8|0)+(e<<2)>>2]=(((B(t[f|0],n)+B(t[f-2|0],l)|0)+B(i,t[f+2|0])|0)+B(j,t[f+4|0])<<8)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=v[m>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=Bia(z,A,f,f>>31);l=ib;E=e;e=Ub(i,-16777216,16776704);i=Bia(x,y,e,e>>31);f=i+f|0;e=ib+l|0;e=f>>>0<i>>>0?e+1|0:e;l=f;f=Ub(j,-16777216,16776704);j=Bia(s,w,f,f>>31);f=l+j|0;e=ib+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Lc(f,e,24);v[E+4>>2]=e-(n&r);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Ob(g+16|0,C,D);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=g+48|0}function Ng(a,b,c,d,e){var f=0,g=0,h=0;if(!b){c=fb-16|0;fb=c;a:{if((d|0)==189){t[a+3843|0]=e>>>7;t[a+3844|0]=e>>>6&1;break a}b=d&224;if(!b){if((d|0)!=8){if((d|0)!=260){break a}b=0;d=1;while(1){if((b|0)==6){break a}f=B(b>>>0<3?b:b+6|0,44)+a|0;g=f+148|0;f=f+16|0;h=d&e;b:{if(h){On(f,g);break b}On(f,0)}t[g+40|0]=!h;b=b+1|0;d=d<<1&510;continue}}t[a+3842|0]=e>>>6&1;b=0;while(1){if((b|0)==18){break a}gz((B(b,44)+a|0)+16|0);b=b+1|0;continue}}if(b-160>>>0<=32){b=d&15;if(b>>>0>8){break a}a=B(d&256?b+9|0:b,44)+a|0;v[c+8>>2]=a+16;b=v[a+52>>2];v[c+12>>2]=b;g=b?2:1;c:{b=d&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}f=e&3;h=e>>>2&7;b=0;d=(e&32)!=0;while(1){if((b|0)==(g|0)){break a}a=v[(c+8|0)+(b<<2)>>2];pO(v[a>>2],d);pO(v[a+4>>2],d);u[a+22>>1]=h;fz(a);gz(a);t[a+21|0]=f;fz(a);gz(a);b=b+1|0;continue}}b=0;while(1){if((b|0)==(g|0)){break a}a=v[(c+8|0)+(b<<2)>>2];u[a+20>>1]=x[a+20>>1]&768|e&255;fz(a);b=b+1|0;continue}}t[a+58|0]=(e&32)>>>5;t[a+57|0]=(e&16)>>>4;b=e>>>1&7;u[a+46>>1]=b?9-b|0:0;u[a+48>>1]=e&1;break a}if((b|0)!=224&b>>>0>=129|-4144960>>>d&1){break a}f=a;a=t[(d&31)+28992|0];a=(f+B(d&256?a+18|0:a,84)|0)+808|0;d:{switch(b-32>>>5|0){case 0:t[a+79|0]=e>>>7;t[a+80|0]=(e&64)>>>6;t[a+78|0]=(e&32)>>>5;t[a+77|0]=(e&16)>>>4;Pn(a);u[a+14>>1]=x[((e&15)<<1)+29024>>1];break a;case 1:u[a+68>>1]=w[(e>>>6|0)+21583|0];qO(a);u[a+22>>1]=(e&63)<<2;break a;case 2:u[a+24>>1]=e>>>4;Pn(a);u[a+26>>1]=e&15;Pn(a);break a;case 3:b=e>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=e&15;Pn(a);break a;case 6:break d;default:break a}}u[a+12>>1]=e&7}fb=c+16|0;return}jb[v[v[b>>2]>>2]](b,c,d,e)}function Jca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=fb-48|0;fb=h;j=c+484344|0;ig(j,w[b+70|0]|w[b+71|0]<<8);a:{b:{while(1){if((w[b+70|0]|w[b+71|0]<<8)>>>0<=i>>>0){break b}g=v[a+8>>2];e=mg(a);Yb(a,1);c:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=Ae(a)+1|0;break c}c=Ag(a)}d=Ag(a);Vc(a,e+g|0);Qd(h,a,d);g=gc(h+24|0,h);wb(h);v[23220]=0;c=W(213,j|0,i&65535,(c?c>>>0<1024?c:1024:64)|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){d:{if(!(c&(d|0)!=0)){break d}c=Xb(v[j>>2],i);m=h,n=Ab(v[c>>2]),v[m>>2]=n;k=Ab(v[c+4>>2]);while(1){c=v[h>>2];if(!Nb(c,k)){break d}v[23220]=0;d=T(193,g|0)|0;e=v[23220];v[23220]=0;e:{f:{g:{if((e|0)!=1){if(!(d&128)){break g}if(d&1){v[23220]=0;e=T(193,g|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break a}t[c|0]=e}if(d&2){break f}break e}break a}t[c|0]=d;d=255}v[23220]=0;e=T(193,g|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break a}t[c+1|0]=e}e=0;if(d&4){v[23220]=0;e=T(193,g|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break a}}if(d&8){v[23220]=0;f=T(193,g|0)|0;l=v[23220];v[23220]=0;if((l|0)==1){break a}t[c+3|0]=f}if(d&16){v[23220]=0;d=T(193,g|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break a}t[c+5|0]=d}h:{i:{d=w[c|0];if(!d){break i}f=255;if((d|0)==97){break h}if(d>>>0>96){break i}f=d+12|0;break h}f=0}t[c|0]=f;j:{if(w[c+5|0]|w[c+3|0]){Mf(c);break j}t[c+3|0]=0}if(w[c+1|0]==255){t[c+1|0]=0}d=e-16|0;k:{if((d&255)>>>0<=64){t[c+4|0]=d;t[c+2|0]=1;break k}if(e>>>0<96){break k}d=e&15;t[c+4|0]=d;e=e-96>>4;t[c+2|0]=w[e+27134|0];if((e|0)!=6){break k}t[c+4|0]=d<<2}gk(h);continue}}wb(g);i=i+1|0;continue}break}break a}fb=h+48|0;return}a=P()|0;O()|0;wb(g);S(a|0);L()}function vq(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=w[a|0];switch(d|0){case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break a;case 2:break j;case 13:break k;case 0:break l;case 5:break c;case 9:break e;case 11:break f;case 20:break g;case 4:break h;case 3:break i;default:break d}}t[a|0]=0;break b}e=1;t[a|0]=1;t[f+15|0]=64;h=b,i=w[Rb(b,f+15|0)|0],t[h|0]=i;break a}d=c;c=w[b|0];if(!(c&3|c>>>0>223?d:1)){break a}t[b|0]=(c&252)>>>2;t[a|0]=12;break b}d=c;c=w[b|0];if(!(c&3|c>>>0>223?d:1)){break a}t[b|0]=(c&252)>>>2;t[a|0]=13;break b}d=w[b|0];if(d>>>0<240){while(1){if((e|0)==10){e=0;break a}g=w[e+43904|0];m:{n:{if(c){if(d>>>0<=g>>>0){break n}break m}if((d|0)!=(g|0)){break m}}t[a|0]=11;t[b|0]=e;e=e>>>0<10;break a}e=e+1|0;continue}}t[a|0]=11;t[b|0]=9;break b}o:{p:{q:{d=w[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}t[b|0]=0;t[a|0]=0;break b}t[a|0]=2;t[b|0]=w[b|0]<<2&60|2;break b}c=w[b|0];if(!c){break a}d=c&15;if(!d){t[b|0]=c>>>4;t[a|0]=3;break b}g=c&240;if(!g){t[a|0]=4;break b}if((d|0)==15){t[b|0]=c>>>4;t[a|0]=5;break b}if((g|0)!=240){break a}t[b|0]=d;t[a|0]=6;break b}c=b;b=w[b|0];t[c|0]=(b|0)==255?64:b>>>2|0;t[a|0]=2;break b}if((d|0)!=26){break a}r:{if(c){t[b|0]=0;break r}if(w[b|0]){break a}}t[a|0]=8;break b}s:{if(c){t[f+14|0]=w[b|0]&15;t[f+13|0]=9;c=w[Rb(f+14|0,f+13|0)|0];break s}c=w[b|0];if((c&14)>>>0>9|c&240){break a}}t[b|0]=c&15;t[a|0]=8}e=1}fb=f+16|0;return e}function XK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{d=b;e=v[b>>2];if(e){if(!v[b+4>>2]){break b}g=v[b+4>>2];c:{if(!g){while(1){g=nh(d);d=v[d+8>>2];if(!g){continue}break}break c}d=QR(g)}e=v[d>>2];if(e){break b}}e=v[d+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[d+8>>2];g=0}d:{e:{if(nh(d)){c=v[d+8>>2];v[c>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=c+4|0;break e}c=v[d+8>>2];v[c+4>>2]=e}c=v[c>>2]}h=!w[d+12|0];if((b|0)!=(d|0)){f=v[b+8>>2];v[d+8>>2]=f;i=f+(nh(b)?0:4)|0,j=d,v[i>>2]=j;f=v[b>>2];v[d>>2]=f;Gl(f,d);f=v[b+4>>2];v[d+4>>2]=f;if(f){Gl(f,d)}t[d+12|0]=w[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=w[c+12|0];f:{g:{if(!nh(c)){if(!b){t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;Rp(b);b=v[c>>2];a=(b|0)==(a|0)?c:a;c=v[b+4>>2]}b=v[c>>2];h:{if(!(w[b+12|0]?0:b)){d=v[c+4>>2];if(w[d+12|0]?0:d){break h}t[c+12|0]=0;i:{b=v[c+8>>2];if((b|0)!=(a|0)){if(w[b+12|0]){break i}a=b}t[a+12|0]=1;return}if(!nh(b)){break g}b=v[b+8>>2]+4|0;break f}d=v[c+4>>2];if(w[d+12|0]?0:d){break h}t[b+12|0]=1;t[c+12|0]=0;Qp(c);c=v[c+8>>2];d=v[c+4>>2]}a=v[c+8>>2];t[c+12|0]=w[a+12|0];t[a+12|0]=1;t[d+12|0]=1;Rp(a);return}if(!b){t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;Qp(b);b=v[c+4>>2];a=(b|0)==(a|0)?c:a;c=v[b>>2]}d=v[c>>2];j:{if(w[d+12|0]?0:d){break j}b=v[c+4>>2];if(!(w[b+12|0]?0:b)){t[c+12|0]=0;b=v[c+8>>2];if(!((a|0)!=(b|0)?w[b+12|0]:0)){t[b+12|0]=1;return}if(nh(b)){b=v[b+8>>2]+4|0;break f}b=v[b+8>>2];break f}if(w[d+12|0]?0:d){break j}t[b+12|0]=1;t[c+12|0]=0;Rp(c);c=v[c+8>>2];d=v[c>>2]}a=v[c+8>>2];t[c+12|0]=w[a+12|0];t[a+12|0]=1;t[d+12|0]=1;Qp(a);return}b=v[b+8>>2]}c=v[b>>2];continue}}t[e+12|0]=1}}function kha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-32|0;fb=e;t[e+24|0]=44;v[e+16>>2]=-1;v[e+20>>2]=0;v[e+8>>2]=1042;v[e+12>>2]=2;d=fb+-64|0;fb=d;j=v[e+8>>2]&2?16:10;l=fb-32|0;fb=l;g=Ge(l+16|0,1,0);a:{b:{c:{while(1){m=l+8|0;c=pc(g);n=c;o=Bb(g)+c|0;i=x[b>>1];h=0;d:{if((j|0)==10){ox(m,n,o,i);break d}f=i;c=B(j,j);q=B(c,j);p=B(c,c);e:{while(1){f=f&65535;k=h|1;if(f>>>0<j>>>0){break e}k=h|2;if(c>>>0>f>>>0){break e}k=h|3;if(f>>>0<q>>>0){break e}if(f>>>0<p>>>0){k=h+4|0}else{h=h+4|0;f=(f>>>0)/(p>>>0)|0;continue}break}}c=k;if((c|0)>(o-n|0)){v[m+4>>2]=61;v[m>>2]=o;break d}f=c+n|0;c=f;while(1){h=i&65535;i=(h|0)/(j|0)|0;c=c-1|0;t[c|0]=w[(h-B(i,j)|0)+4856|0];if(i&65535){continue}break}v[m+4>>2]=0;v[m>>2]=f}if(!v[l+12>>2]){break c}c=Ff(Bb(g));v[23220]=0;R(56,g|0,c|0);c=v[23220];v[23220]=0;if((c|0)!=1){continue}break}break b}b=v[l+8>>2];c=pc(g);v[23220]=0;R(57,g|0,b-c|0);b=v[23220];v[23220]=0;f:{if((b|0)!=1){v[23220]=0;R(69,d|0,g|0);b=v[23220];v[23220]=0;if((b|0)!=1){break f}break b}break b}ub(g);fb=l+32|0;break a}a=P()|0;O()|0;ub(g);S(a|0);L()}b=d+16|0;bs(b,d,v[e+8>>2]);c=v[e+12>>2];i=v[e+8>>2];v[23220]=0;X(73,d+32|0,b|0,i|0,c|0);b=v[23220];v[23220]=0;g:{h:{i:{j:{k:{if((b|0)!=1){b=w[e+24|0];c=v[e+20>>2];v[23220]=0;X(74,d+48|0,d+32|0,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break k}v[23220]=0;R(68,a|0,d+48|0);a=v[23220];v[23220]=0;if((a|0)==1){break j}vb(d+48|0);vb(d+32|0);vb(d+16|0);vb(d);fb=d- -64|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(d+48|0)}vb(d+32|0)}vb(d+16|0);vb(d);S(a|0);L()}fb=e+32|0}function QZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=fb-624|0;fb=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=1126;h=he(a+200|0,a+208|0,a+16|0);b=a+192|0;Xc(b,e);v[23220]=0;i=T(1104,b|0)|0;b=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){t[a+191|0]=0;b=v[e+4>>2];v[23220]=0;b=pa(1134,a+616|0,c|0,d|0,a+192|0,b|0,f|0,a+191|0,i|0,h|0,a+196|0,a+608|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}if(!b){break e}b=w[14630]|w[14631]<<8|(w[14632]<<16|w[14633]<<24);t[a+183|0]=b;t[a+184|0]=b>>>8;t[a+185|0]=b>>>16;t[a+186|0]=b>>>24;b=w[14627]|w[14628]<<8|(w[14629]<<16|w[14630]<<24);v[a+176>>2]=w[14623]|w[14624]<<8|(w[14625]<<16|w[14626]<<24);v[a+180>>2]=b;v[23220]=0;X(1116,i|0,a+176|0,a+186|0,a+128|0);b=v[23220];v[23220]=0;if((b|0)==1){break g}v[a+4>>2]=1091;d=he(a+8|0,0,a+4|0);c=a+16|0;b=v[a+196>>2];e=b-v[h>>2]|0;if((e|0)<393){break f}Je(d,Fd((e>>2)+2|0));c=v[d>>2];if(c){break f}v[23220]=0;Z(1092);b=v[23220];v[23220]=0;if((b|0)==1){break c}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}if(w[a+191|0]){t[c|0]=45;c=c+1|0}e=v[h>>2];while(1){if(b>>>0<=e>>>0){t[c|0]=0;v[a>>2]=g;if((mG(a+16|0,a)|0)!=1){v[23220]=0;Y(1128,7987);b=v[23220];v[23220]=0;if((b|0)!=1){break a}break c}Kc(d)}else{b=a+128|0;j=c,k=w[(a+176|0)+(ew(b,b+40|0,v[e>>2])-b>>2)|0],t[j|0]=k;c=c+1|0;e=e+4|0;b=v[a+196>>2];continue}break}}v[23220]=0;b=Q(1110,a+616|0,a+608|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}if(b){v[f>>2]=v[f>>2]|2}b=v[a+616>>2];Wb(a+192|0);Kc(h);fb=a+624|0;return b|0}e=P()|0;O()|0;break b}e=P()|0;O()|0;Kc(d)}Wb(a+192|0);Kc(h);S(e|0);L()}L()}function XZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=fb-288|0;fb=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=1126;h=he(a+152|0,a+160|0,a+16|0);b=a+144|0;Xc(b,e);v[23220]=0;i=T(18,b|0)|0;b=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){t[a+143|0]=0;b=v[e+4>>2];v[23220]=0;b=pa(1127,a+280|0,c|0,d|0,a+144|0,b|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}if(!b){break e}b=w[14630]|w[14631]<<8|(w[14632]<<16|w[14633]<<24);t[a+135|0]=b;t[a+136|0]=b>>>8;t[a+137|0]=b>>>16;t[a+138|0]=b>>>24;b=w[14627]|w[14628]<<8|(w[14629]<<16|w[14630]<<24);v[a+128>>2]=w[14623]|w[14624]<<8|(w[14625]<<16|w[14626]<<24);v[a+132>>2]=b;v[23220]=0;X(1102,i|0,a+128|0,a+138|0,a+118|0);b=v[23220];v[23220]=0;if((b|0)==1){break g}v[a+4>>2]=1091;d=he(a+8|0,0,a+4|0);c=a+16|0;b=v[a+148>>2];e=b-v[h>>2]|0;if((e|0)<99){break f}Je(d,Fd(e+2|0));c=v[d>>2];if(c){break f}v[23220]=0;Z(1092);b=v[23220];v[23220]=0;if((b|0)==1){break c}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}if(w[a+143|0]){t[c|0]=45;c=c+1|0}e=v[h>>2];while(1){if(b>>>0<=e>>>0){t[c|0]=0;v[a>>2]=g;if((mG(a+16|0,a)|0)!=1){v[23220]=0;Y(1128,7987);b=v[23220];v[23220]=0;if((b|0)!=1){break a}break c}Kc(d)}else{b=a+118|0;j=c,k=w[((mi(b,b+10|0,e)-a|0)+a|0)+10|0],t[j|0]=k;c=c+1|0;e=e+1|0;b=v[a+148>>2];continue}break}}v[23220]=0;b=Q(1094,a+280|0,a+272|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}if(b){v[f>>2]=v[f>>2]|2}b=v[a+280>>2];Wb(a+144|0);Kc(h);fb=a+288|0;return b|0}e=P()|0;O()|0;break b}e=P()|0;O()|0;Kc(d)}Wb(a+144|0);Kc(h);S(e|0);L()}L()}function h3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-48|0;fb=c;f=Ib(a);a:{b:{c:{d:{if(Nb(v[b+36>>2],v[b+40>>2])){mf(c+40|0);break d}v[23220]=0;R(994,c+24|0,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}v[23220]=0;a=T(978,c+24|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}v[c+40>>2]=a;Tf(c+24|0)}a=b+36|0;d=v[a>>2];if(!Nb(d,v[b+40>>2])){a=v[c+40>>2];d=v[a>>2]}g=v[a+4>>2];v[23220]=0;R(168,f|0,pn(d,g)|0);d=v[23220];v[23220]=0;e:{if((d|0)!=1){i=c,j=Ab(v[a>>2]),v[i+16>>2]=j;g=Ab(v[a+4>>2]);f:{g:{h:{i:{j:{k:{while(1){a=v[c+16>>2];if(!Nb(a,g)){Fk(c+40|0);fb=c+48|0;return}d=w[a+16|0];e=v[v[b+24>>2]+484360>>2];v[23220]=0;d=nj(e,d);R(995,c|0,d|0);e=v[23220];v[23220]=0;if((e|0)!=1){v[23220]=0;R(981,c+24|0,c|0);e=v[23220];v[23220]=0;if((e|0)==1){break k}v[23220]=0;R(170,f|0,c+24|0);e=v[23220];v[23220]=0;if((e|0)==1){break j}ub(c+24|0);vb(c);l:{if(!ze($w(v[f+4>>2]))){break l}e=w[a+12|0];v[23220]=0;e=Q(300,d|0,e|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break f}if(!e){break l}e=v[b+24>>2];h=v[e+1298404>>2];a=x[ac(v[d>>2],v[a+12>>2])>>1];d=v[e+484344>>2];v[23220]=0;R(988,c|0,Xb(d,a)|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}v[23220]=0;X(225,c+24|0,0,h|0,c|0);a=v[23220];v[23220]=0;if((a|0)==1){break g}a=c+24|0;xc($w(v[f+4>>2]),a);ub(a);ub(c)}pI(c+16|0);continue}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break i}a=P()|0;O()|0;ub(c+24|0)}vb(c);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;ub(c);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0}Fk(c+40|0);break a}a=P()|0;O()|0;Tf(c+24|0);break a}a=P()|0;O()|0}De(f);S(a|0);L()}function cy(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;i=FL(b,c);a:{if(!v[b+656>>2]|!(t[i+6|0]&1)){break a}f=v[i>>2];j=a+1074312|0;xb(e+8|0,j,31);g=yb(v[v[e+8>>2]>>2],v[e+12>>2]);d=Nu(v[b+656>>2],c);if(rc(v[d>>2],v[d+4>>2])){break a}g=f+(g^1)|0;xb(e+8|0,j,31);f=w[d+12|0];b:{c:{if(!yb(v[v[e+8>>2]>>2],v[e+12>>2])){d:{if(!(f&2)){break d}h=w[d+14|0];k=!(v[a+480180>>2]&1048580)+x[zb(v[d>>2],h)>>1]|0;if(!(w[b+89|0]&8)|(!(f&4)|(h|0)!=w[d+16|0])){f=l}else{xb(e+8|0,j,70);f=yb(v[v[e+8>>2]>>2],v[e+12>>2])}if(f|(g|0)!=(k|0)){break d}g=x[zb(v[d>>2],w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){a=v[d>>2];if((x[zb(a,w[d+16|0])>>1]+1|0)!=(g|0)){break b}g=x[zb(a,w[d+15|0])>>1];xb(e+8|0,j,93);if(!yb(v[v[e+8>>2]>>2],v[e+12>>2])|(c|0)!=1|v[b+88>>2]&2048){break b}t[i+6|0]=w[i+6|0]&254;break b}k=1;f=x[zn(v[d+4>>2])>>1];if(g>>>0>f>>>0){break c}break b}e:{f:{if(!(!(f&4)|w[b+669|0]&8)){if(x[i+4>>1]==65535){break f}xb(e+8|0,j,97);if(yb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}f=w[d+12|0]}if(f&2){h=v[d>>2];f=x[zb(h,w[d+13|0])>>1];h=x[zb(h,w[d+14|0])>>1]+1|0;break e}f=x[zn(v[d+4>>2])>>1];k=g>>>0>f>>>0;h=f;break e}h=v[d>>2];f=x[zb(h,w[d+15|0])>>1];h=x[zb(h,w[d+16|0])>>1]+1|0}f=g>>>0<h>>>0?g:f}g:{if(!k|c){break g}g=v[a+480180>>2];c=v[b+88>>2];if(!(!(g&16777248)&(!(c&2048)|(g|0)==16384))){c=c|4096;v[b+88>>2]=c}if(w[zn(v[d+4>>2])+2|0]|!(v[a+480180>>2]&16777248?1:x[b+786>>1])){break g}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=c|4096}g=f}xb(e+8|0,j,31);m=i,n=yb(v[v[e+8>>2]>>2],v[e+12>>2])+g|0,v[m>>2]=n}fb=e+16|0}function Fs(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-144|0;fb=g;a:{b:{c:{d:{e:{f:{g:{h:{if(!d){break h}e=v[d+4>>2];if(!e&c>>>0<=y[d>>2]|e){break h}a=aa(8)|0;v[23220]=0;b=Q(93,a|0,21598)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break g}b=P()|0;O()|0;ba(a|0);break a}if(!b){a=aa(8)|0;v[23220]=0;b=T(787,a|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break f}b=P()|0;O()|0;ba(a|0);break a}e=fb-16|0;fb=e;Hg(e+8|0,b,c);h=g+120|0;CD(h,v[e+8>>2],v[e+12>>2]);v[h+12>>2]=0;fb=e+16|0;i:{j:{if(a&2){b=Am(g+96|0,h);v[23220]=0;b=T(788,b|0)|0;f=v[23220];v[23220]=0;e=1;if((f|0)==1){break i}if((b|0)==1){break j}e=Am(g+72|0,h);v[23220]=0;f=T(789,e|0)|0;i=v[23220];v[23220]=0;e=1;if((i|0)==1){break e}k=(f|0)==1;if(k){break j}e=Am(g+48|0,h);v[23220]=0;i=Q(790,e|0,d|0)|0;j=v[23220];v[23220]=0;e=1;if((j|0)==1){break d}l=(i|0)==1;if(l){break j}e=Am(g+24|0,h);v[23220]=0;j=Q(791,e|0,d|0)|0;m=v[23220];v[23220]=0;e=1;if((m|0)==1){break c}if((j|0)==1){break j}b=(b|0)==-1?-1:0;b=k?b:(f|0)==-1?-1:b;f=(j|0)==-1?-1:l?b:(i|0)==-1?-1:b}k:{if(!(a&1)){break k}b=31552;while(1){if((b|0)==32068){break k}a=v[b>>2];if(a){e=Am(g,h);v[23220]=0;a=Q(a|0,e|0,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break b}e=1;if((a|0)==1){break j}f=(a|0)==-1?-1:f}b=b+12|0;continue}}if(d){e=0;if((f|0)!=-1){break j}e=Pc(v[d>>2],v[d+4>>2])>>>0>c>>>0?-1:0;break j}e=0;if((f|0)!=-1){break j}e=c>>>0>2047?1:-1}fb=g+144|0;return e}b=P()|0;O()|0;break a}ia(b|0,91760,24);L()}ia(b|0,91656,24);L()}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}S(b|0);L()}function Pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=fb-48|0;fb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){b=v[g+16>>2];l=b>>>18|0;j=((((v[g+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=0;e=0;while(1){if((e|0)!=2){i=j+(e<<1)|0;f=u[i>>1];v[(g+8|0)+(e<<2)>>2]=f+((B(l,u[i+4>>1]-f|0)|0)/16384|0);e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=v[l>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=Bia(y,z,f,f>>31);m=ib;D=e;e=Ub(i,-16777216,16776704);i=Bia(w,x,e,e>>31);f=i+f|0;e=ib+m|0;e=f>>>0<i>>>0?e+1|0:e;m=f;f=Ub(j,-16777216,16776704);j=Bia(s,t,f,f>>31);f=m+j|0;e=ib+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Lc(f,e,24);v[D+4>>2]=e-(r&n);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Ob(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=g+48|0}function BM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=fb-16|0;fb=c;d=a+1074376|0;e=B(b,872);a:{if(v[(d+e|0)+704>>2]&134218752){break a}h=v[(a+e|0)+1075648>>2];if(!Qj(h)|w[h+15|0]&2){break a}d=ml(a,d,b,2,1);if((d-1&255)>>>0>249){break a}g=v[(B(d,160)+a|0)+906140>>2];if(!g){break a}f=B(b,872)+a|0;d=w[f+1075780|0];b:{if(w[f+1075782|0]==1){t[c+8|0]=64;e=w[Rb(f+1075784|0,c+8|0)|0];break b}e=255;if(w[f+1075783|0]!=13){break b}t[c+8|0]=64;e=w[Rb((B(b,872)+a|0)+1075785|0,c+8|0)|0]}i=a+1074312|0;xb(c+8|0,i,2);if(yb(v[v[c+8>>2]>>2],v[c+12>>2])){if(d){if(Oc(d)){d=w[Hb(h+108|0,d-1|0)|0]}Nl(a,b,d,x[(B(b,872)+a|0)+1075680>>1]);break a}if((e|0)==255){break a}jb[v[v[g>>2]+76>>2]](g,39,e,b);break a}j=v[h+4>>2];if(d){f=w[h+35|0]?j<<2:v[(B(b,872)+a|0)+1075680>>2];k=u[(B(b,872)+a|0)+1075768>>1];xb(c+8|0,i,28);l=c,m=f+(yb(v[v[c+8>>2]>>2],v[c+12>>2])?k<<2:k)|0,v[l+4>>2]=m;ee(c+4|0,0,256);f=a;if(Oc(d)){a=w[Hb(h+108|0,d-1|0)|0]}else{a=d}Nl(f,b,a&255,x[c+4>>1])}f=w[h+35|0];xb(c+8|0,i,101);if(yb(v[v[c+8>>2]>>2],v[c+12>>2])){a=(d|0)!=0}else{a=Oc(d)}if(a^1|(f|0)!=1?(a|(e|0)==255)==1:0){break a}c:{switch(w[h+36|0]){case 1:if((e|0)!=255){Ms(v[g+20>>2],C(C(C(e<<1)/C(-127))+C(1)));break a}Ms(v[g+20>>2],C(C(C(j<<1>>>0)/C(-127))+C(1)));break a;case 0:break c;default:break a}}if((e|0)!=255){t[c+8|0]=127;t[c+4|0]=e<<1;m=g,n=7,o=w[Rb(c+8|0,c+4|0)|0],p=b,l=v[v[g>>2]+76>>2],jb[l](m|0,n|0,o|0,p|0);break a}v[c+8>>2]=127;v[c+4>>2]=j<<1;p=g,o=7,n=w[Eb(c+8|0,c+4|0)|0],m=b,l=v[v[g>>2]+76>>2],jb[l](p|0,o|0,n|0,m|0)}fb=c+16|0}function Qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=fb-48|0;fb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;u=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){b=v[g+16>>2];l=b>>>10&4194048;j=(((v[g+20>>2]&2147483647)<<1|b>>>31)&-2)+o|0;b=0;e=0;while(1){if((e|0)!=2){i=e+j|0;f=t[i|0];v[(g+8|0)+(e<<2)>>2]=((B(l,t[i+2|0]-f|0)|0)/16384|0)+(f<<8);e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=v[l>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=Bia(y,z,f,f>>31);m=ib;D=e;e=Ub(i,-16777216,16776704);i=Bia(w,x,e,e>>31);f=i+f|0;e=ib+m|0;e=f>>>0<i>>>0?e+1|0:e;m=f;f=Ub(j,-16777216,16776704);j=Bia(s,u,f,f>>31);f=m+j|0;e=ib+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Lc(f,e,24);v[D+4>>2]=e-(r&n);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Ob(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=g+48|0}function DZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;v[c>>2]=a;y=d&512;z=h<<2;while(1){if((x|0)==4){if(Bb(n)>>>0>1){f=Td(n);e=fb-16|0;fb=e;v[e+8>>2]=f;f=v[ye(e+8|0)>>2];fb=e+16|0;B=c,C=Gi(f,uk(n),v[c>>2]),v[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}}else{a:{b:{switch(t[i+x|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];h=Dr(g,32);p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 3:if(ze(n)){break a}h=v[ej(n,0)>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 2:if(ze(m)|!y){break a}B=c,C=Gi(Td(m),uk(m),v[c>>2]),v[B>>2]=C;break a;case 4:break b;default:break a}}A=v[c>>2];e=e+z|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!yk(g,2048,v[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=v[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){h=h-4|0;s=v[h>>2];r=p+4|0;v[c>>2]=r;v[p>>2]=s;q=q-1|0;p=r;continue}break}d:{if(!q){s=0;break d}s=Dr(g,48);p=v[c>>2]}while(1){r=p+4|0;if((q|0)>0){v[p>>2]=s;q=q-1|0;p=r;continue}break}v[c>>2]=r;v[p>>2]=j}e:{if((e|0)==(h|0)){p=Dr(g,48);q=v[c>>2];h=q+4|0;v[c>>2]=h;v[q>>2]=p;break e}if(ze(l)){s=-1}else{s=t[Vf(l,0)|0]}q=0;u=0;while(1){if((e|0)!=(h|0)){r=v[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;v[c>>2]=p;v[r>>2]=k;r=0;u=u+1|0;if(Bb(l)>>>0<=u>>>0){s=q;break f}s=-1;if(w[Vf(l,u)|0]==127){break f}s=t[Vf(l,u)|0]}h=h-4|0;q=v[h>>2];v[c>>2]=p+4;v[p>>2]=q;q=r+1|0;continue}break}h=v[c>>2]}ur(A,h)}x=x+1|0;continue}break}}function Dba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=fb-48|0;fb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){e=v[g+16>>2];k=((((v[g+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+m|0;b=e>>>21&2040;i=u[b+39878>>1];h=u[b+39876>>1];l=u[b+39874>>1];j=u[b+39872>>1];b=0;e=0;while(1){if((e|0)!=2){f=k+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((B(u[f>>1],l)+B(u[f-4>>1],j)|0)+B(h,u[f+4>>1])|0)+B(i,u[f+8>>1])|0)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=v[k>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Bia(w,x,f,f>>31);j=ib;A=e;e=Ub(h,-16777216,16776704);h=Bia(s,t,e,e>>31);f=h+f|0;e=ib+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Ub(i,-16777216,16776704);i=Bia(q,r,f,f>>31);f=j+i|0;e=ib+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Lc(f,e,24);v[A+4>>2]=e-(l&p);v[k>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],n);Ob(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=g+48|0}function eK(a){var b=C(0),c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,k=0,l=C(0),m=0,n=C(0);c=fb-16|0;fb=c;e=a+4208|0;b=ux(z[zb(e,2)>>2]);f=v[a+16>>2]+24620|0;z[c+12>>2]=b/C(y[f>>2]);v[c+8>>2]=1056964608;b=gp(C(z[Hl(c+12|0,c+8|0)>>2]*C(6.2831854820251465)));b=C(K(C(C(C(b+b)+C(3))/C(5))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));b=C(C(z[zb(e,1)>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){i=~~b>>>0;break a}i=0}t[a+4272|0]=i;d=i;while(1){if(d&255){k=k+1|0;d=(d&254)>>>1|0;continue}break}t[a+4273|0]=k;l=ie(C(10),C(C(C(z[e>>2]*C(60))+C(-60))/C(20)));m=c,n=C(ux(z[zb(e,3)>>2])/C(y[f>>2])),z[m+12>>2]=n;v[c+8>>2]=1056964608;g=z[Hl(c+12|0,c+8|0)>>2];m=c,n=C(ux(z[zb(e,4)>>2])/C(y[f>>2])),z[m+12>>2]=n;v[c+8>>2]=1056964608;b=C(C(z[Hl(c+12|0,c+8|0)>>2]*C(6.2831854820251465))*C(.5));f=fb-16|0;fb=f;e=(p(b),j(2));d=e&2147483647;b:{if(d>>>0<=1061752794){if(d>>>0<964689920){break b}b=hn(+b,0);break b}if(d>>>0<=1081824209){h=+b;if(d>>>0<=1075235811){b=hn(((e|0)<0?1.5707963267948966:-1.5707963267948966)+h,1);break b}b=hn(((e|0)<0?3.141592653589793:-3.141592653589793)+h,0);break b}if(d>>>0<=1088565717){h=+b;if(d>>>0<=1085271519){b=hn(((e|0)<0?4.71238898038469:-4.71238898038469)+h,1);break b}b=hn(((e|0)<0?6.283185307179586:-6.283185307179586)+h,0);break b}if(d>>>0>=2139095040){b=C(b-b);break b}d=Jw(b,f+8|0);b=hn(A[f+8>>3],d&1)}fb=f+16|0;b=C(C(C(1)-b)/C(b+C(1)));z[a+4268>>2]=b;g=gp(C(g*C(6.2831854820251465)));z[a+4264>>2]=-g;z[a+4260>>2]=C(C(l*C(K(C(C(1)-C(g*g)))))*C(K(C(C(1)-C(b*b)))))*z[(i<<2)+45728>>2];fb=c+16|0}function qJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=C(0);e=fb-48|0;fb=e;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;d=v[a+24>>2];if((b|0)==v[d+24604>>2]){break d}a=e+8|0;nc(a,d+24604|0,40);v[e+8>>2]=b;gy(d,a);break d;case 2:f=v[a+24>>2];d=f+24664|0;b=v[d+4>>2];v[e+24>>2]=v[d>>2];v[e+28>>2]=b;d=f+24656|0;b=v[d+4>>2];v[e+16>>2]=v[d>>2];v[e+20>>2]=b;b=v[f+24652>>2];v[e+8>>2]=v[f+24648>>2];v[e+12>>2]=b;d=fb-16|0;fb=d;b=3;f:{g:{h:{if(!c|(c|0)>7){break h}b=2;if((c|0)>2){break h}b=1;if((c|0)==2){break h}b=0;if((c|0)>0){break h}c=aa(8)|0;v[23220]=0;b=Q(52,d|0,10737)|0;a=v[23220];v[23220]=0;i:{if((a|0)!=1){a=qc(c,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break g}a=P()|0;O()|0;ub(b);break i}a=P()|0;O()|0;ba(c|0)}S(a|0);L()}fb=d+16|0;break f}L()}t[e+8|0]=b;a=v[a+24>>2];if(!jx(e+8|0,a+24648|0)){break d}ey(a,e+8|0);break d;case 3:f=e+8|0;d=v[a+24>>2];nc(f,d+24604|0,40);b=fb-48|0;fb=b;j:{if((c|0)==-1){fs(f,v[Gp(b+8|0)+32>>2]);On(f,v[Gp(b+8|0)+36>>2]);break j}if((c|0)<=0){fs(f,0);On(f,0);break j}a=B(c,1e3);fs(f,a);On(f,a)}fb=b+48|0;if(v[d+24636>>2]==v[e+40>>2]&v[d+24640>>2]==v[e+44>>2]){break d}gy(d,e+8|0);break d;default:d=aa(8)|0;v[23220]=0;b=Q(52,e+8|0,10346)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}a=qc(d,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}c=P()|0;O()|0;ub(b);break b;case 0:break e}}g=a,h=ie(C(10),C(C(C(c|0)*C(.0010000000474974513))*C(.5))),z[g+48>>2]=h}fb=e+48|0;return}c=P()|0;O()|0;ba(d|0)}S(c|0)}L()}function X8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-112|0;fb=c;qj(c+88|0,b,1413829443);v[23220]=0;b=T(165,v[c+88>>2])|0;d=v[23220];v[23220]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){v[23220]=0;U(743,c- -64|0,a+140|0,1413894985);a=v[23220];v[23220]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){v[23220]=0;a=Q(820,c- -64|0,13585)|0;b=v[23220];v[23220]=0;if((b|0)==1){break e}b=28591;if(a){b=Gb(c+48|0);v[23220]=0;a=T(189,c- -64|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break m}v[23220]=0;U(258,c- -64|0,b|0,a|0);a=v[23220];v[23220]=0;if((a|0)==1){break m}v[23220]=0;d=Q(51,c+16|0,b|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break l}v[23220]=0;Y(821,c|0);a=v[23220];v[23220]=0;if((a|0)==1){break k}v[23220]=0;U(822,c+32|0,d|0,c|0);a=v[23220];v[23220]=0;if((a|0)==1){break j}a=c+32|0;e=xc(b,a);ub(a);ub(c);ub(d);v[23220]=0;U(11,a|0,2,e|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}v[23220]=0;a=T(711,c+32|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break g}vb(c+32|0);ub(e);b=a-1>>>0<19398657?1252:28591}wb(c- -64|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;ub(c)}ub(d);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c+32|0)}ub(b);break d}a=P()|0;O()|0}wb(c- -64|0);break b}v[23220]=0;a=W(143,v[c+88>>2],v[c+96>>2],2)|0;b=v[23220];v[23220]=0;if((b|0)==1){break c}b=28591;if(!a){break a}v[23220]=0;b=T(181,c+88|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0}wb(c+88|0);S(a|0);L()}wb(c+88|0);fb=c+112|0;return b|0}function lba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;h=fb-16|0;fb=h;a:{b:{c:{i=v[a+12>>2];j=v[a+8>>2];d:{if((i|0)<=1&j>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&j>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&j>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&j>>>0>2147483648|i>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;r=v[a+32>>2];s=v[a+28>>2];t=v[a+72>>2];e=v[a+68>>2];w=e;x=e>>31;e=v[a+64>>2];y=e;z=e>>31;e=v[a+60>>2];A=e;C=e>>31;while(1){e=b;if(d){b=Ub(e,-16777216,16776704);b=Bia(y,z,b,b>>31);m=ib;n=b;g=(v[h+12>>2]<<1)+q|0;b=(v[h+8>>2]>>>16&65520)+p|0;g=(((((((B(u[g-4>>1],u[b+2>>1])+B(u[g-6>>1],u[b>>1])|0)+B(u[g-2>>1],u[b+4>>1])|0)+B(u[g>>1],u[b+6>>1])|0)+B(u[g+2>>1],u[b+8>>1])|0)+B(u[g+4>>1],u[b+10>>1])|0)+B(u[g+6>>1],u[b+12>>1])|0)+B(u[g+8>>1],u[b+14>>1])|0)/32768<<8;b=g;b=Bia(b,b>>31,A,C);n=n+b|0;o=ib+m|0;o=b>>>0>n>>>0?o+1|0:o;b=Ub(f,-16777216,16776704);f=Bia(w,x,b,b>>31);m=f+n|0;b=ib+o|0;b=f>>>0>m>>>0?b+1|0:b;f=m+8388608|0;b=f>>>0<8388608?b+1|0:b;f=Lc(f,b,24);b=(f|0)/256|0;l=l+s|0;v[c>>2]=B(b,l>>12)+v[c>>2];k=k+r|0;v[c+4>>2]=v[c+4>>2]+B(b,k>>12);Ob(h+8|0,j,i);b=f-(g&t)|0;c=c+8|0;d=d-1|0;f=e;continue}break}b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;v[a+40>>2]=k;v[a+20>>2]=l>>12;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=k>>12;fb=h+16|0}function jda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;k=f,l=Zj(b),v[k>>2]=l;e=fb-16|0;fb=e;h=a;c=Od(a);a:{if(c){g=fc(h);while(1){a=c;c=a+14|0;if(lt(b,c)){g=a;c=v[a>>2];if(c){continue}break a}if(!lt(c,b)){break a}g=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=fc(h);g=a}v[e+12>>2]=a;b=v[g>>2];if(!b){i=fb-16|0;fb=i;a=fc(h);j=oh(e,tc(48),ph(i+8|0,a));a=v[j>>2];b=v[f>>2];c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+14|0]=d;t[a+15|0]=d>>>8;t[a+16|0]=d>>>16;t[a+17|0]=d>>>24;t[a+18|0]=c;t[a+19|0]=c>>>8;t[a+20|0]=c>>>16;t[a+21|0]=c>>>24;c=w[b+28|0]|w[b+29|0]<<8|(w[b+30|0]<<16|w[b+31|0]<<24);d=w[b+24|0]|w[b+25|0]<<8|(w[b+26|0]<<16|w[b+27|0]<<24);t[a+38|0]=d;t[a+39|0]=d>>>8;t[a+40|0]=d>>>16;t[a+41|0]=d>>>24;t[a+42|0]=c;t[a+43|0]=c>>>8;t[a+44|0]=c>>>16;t[a+45|0]=c>>>24;c=w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24);d=w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24);t[a+30|0]=d;t[a+31|0]=d>>>8;t[a+32|0]=d>>>16;t[a+33|0]=d>>>24;t[a+34|0]=c;t[a+35|0]=c>>>8;t[a+36|0]=c>>>16;t[a+37|0]=c>>>24;c=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);b=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[a+22|0]=b;t[a+23|0]=b>>>8;t[a+24|0]=b>>>16;t[a+25|0]=b>>>24;t[a+26|0]=c;t[a+27|0]=c>>>8;t[a+28|0]=c>>>16;t[a+29|0]=c>>>24;u[a+46>>1]=0;k=fc(j),l=1,t[k+4|0]=l;fb=i+16|0;Tg(h,v[e+12>>2],g,v[e>>2]);b=Ud(e);_k(e);d=1}Sg(f+8|0,v[dc(e,b)>>2],d);fb=e+16|0;a=Pp(v[f+8>>2]);fb=f+16|0;return a+32|0}function Gaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=fb-16|0;fb=g;w=v[a+16>>2];x=Zf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);p=v[a+128>>2];a:{if(!p){n=v[a+8>>2];s=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];o=0;break a}b=v[a+12>>2];s=b;n=v[a+8>>2];q=_f(n,b,p);r=ib;k=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Df(i,e,af(n,b,d),ib);o=k>>>0<ib>>>0?d:0}h=a+112|0;f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{k=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;o=o-1|0;b=o;q=b?q:0;r=b?r:0;e=(e<<1)+w|0;b=p;while(1)if((b|0)<=0){Ob(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Hd(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Gd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];y=v[a+32>>2];m=v[a+28>>2]+m|0;b=v[a+60>>2];e=b;j=b>>31;t=Yf(h,x)<<8;b=t;b=Bia(e,j,b,b>>31);z=ib;e=b;b=v[a+64>>2];j=b;A=b>>31;b=Ub(k,-16777216,16776704);j=Bia(j,A,b,b>>31);e=e+j|0;b=ib+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Ub(f,-16777216,16776704);e=Bia(e,e>>31,f,f>>31);f=j+e|0;b=ib+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Lc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(m>>12,f)+v[c>>2];l=l+y|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,f);Ob(g,n,s);b=b-(i&t)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=k;continue b}else{Hd(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Gd(h,4);Ob(g+8|0,q,r);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=k;v[a+24>>2]=l>>12;fb=g+16|0}function Eba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0;g=fb-48|0;fb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){if(d){e=v[g+16>>2];k=(((v[g+20>>2]&2147483647)<<1|e>>>31)&-2)+m|0;b=e>>>21&2040;i=u[b+39878>>1];h=u[b+39876>>1];l=u[b+39874>>1];j=u[b+39872>>1];b=0;e=0;while(1){if((e|0)!=2){f=e+k|0;v[(g+8|0)+(e<<2)>>2]=(((B(t[f|0],l)+B(t[f-2|0],j)|0)+B(h,t[f+2|0])|0)+B(i,t[f+4|0])<<8)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=v[k>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Bia(x,y,f,f>>31);j=ib;C=e;e=Ub(h,-16777216,16776704);h=Bia(s,w,e,e>>31);f=h+f|0;e=ib+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Ub(i,-16777216,16776704);i=Bia(q,r,f,f>>31);f=j+i|0;e=ib+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Lc(f,e,24);v[C+4>>2]=e-(l&p);v[k>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],n);Ob(g+16|0,z,A);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=g+48|0}function $9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,A=0;f=fb+-64|0;fb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}s=l-4|0;o=B(b,e);x=o-8|0;h:while(1){b=v[c+8>>2];h=v[c>>2];v[23220]=0;b=W(143,h|0,b|0,l|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break b}if(!(b&n>>>0<o>>>0)){break g}v[23220]=0;U(177,f+16|0,c|0,d|0);b=v[23220];v[23220]=0;if((b|0)==1){break c}b=f+16|0;h=gc(f+40|0,b);wb(b);v[23220]=0;R(520,b|0,h|0);b=v[23220];v[23220]=0;if((b|0)==1){break e}y=te(f+16|0);p=v[f+16>>2];z=p-4|0;k=0;while(1){if((e|0)==(k|0)){Jc(f+16|0);wb(h);n=(p-l<<1)+n|0;continue h}v[23220]=0;g=T(513,h|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){v[23220]=0;b=T(193,h|0)|0;j=v[23220];v[23220]=0;if((j|0)==1){break f}v[f+8>>2]=b;ee(f+8|0,0,89);v[23220]=0;Q(175,h|0,1)|0;b=v[23220];v[23220]=0;if((b|0)==1){break f}j=k+n|0;b=e+k<<2;i:while(1){j:{if(j>>>0>x>>>0){break j}m=0;if(b>>>0>z>>>0){break j}while(1)if((m|0)==8){b=b+s|0;continue i}else{q=v[f+8>>2];i=w[b+y|0];r=m&1;i=r?i>>>4|0:i&15;v[f+8>>2]=q+t[(i&7)+30264|0];A=g;g=u[(q<<1)+30272>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;v[f+12>>2]=A+(i&8?0-g|0:g);ee(f+8|0,0,88);ee(f+12|0,-32768,32767);g=v[f+12>>2];u[(j<<1)+a>>1]=g;m=m+1|0;j=e+j|0;b=b+r|0;continue}}break}k=k+1|0;continue}break}break}break f}wb(c);fb=f- -64|0;return}b=P()|0;O()|0;Jc(f+16|0);break d}b=P()|0;O()|0}wb(h);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}wb(c);S(b|0);L()}function KV(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-48|0;fb=f;g=ki(b)^-1;a:{if(sc(v[d>>2],v[d+4>>2])>>>0<=g>>>0){Ds(a);break a}ki(b);if((w[c+4|0]|w[c+5|0]<<8)>>>0>=60){Yb(b,4)}j=f,k=ki(b),v[j+44>>2]=k;Yb(b,4);h=ki(b);i=ki(b);if(!((h|0)>0&(i|0)>36)){Ds(a);break a}if(_p(Dd(v[e>>2],v[zb(v[d>>2],g)>>2]),13071)){Ds(a);break a}nv(f,b,i,h);d=gc(f+24|0,f);wb(f);b=v[d>>2];v[23220]=0;b=T(165,b|0)|0;e=v[23220];v[23220]=0;b:{if((e|0)==1){break b}c:{d:{if(!b){v[23220]=0;T(174,a|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break d}break b}b=w[c+4|0]|w[c+5|0]<<8;if(b>>>0<=39){v[23220]=0;Q(175,d|0,8)|0;b=v[23220];v[23220]=0;if((b|0)==1){break b}b=w[c+4|0]|w[c+5|0]<<8}if((b&65535)>>>0<=59){v[23220]=0;Q(175,d|0,16)|0;b=v[23220];v[23220]=0;if((b|0)==1){break b}}v[23220]=0;T(176,d|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break b}e:{f:{b=w[c+4|0]|w[c+5|0]<<8;g:{if(b>>>0>=120){v[23220]=0;T(176,d|0)|0;c=v[23220];v[23220]=0;b=8;break g}h:{if(b>>>0>=100){v[23220]=0;Q(175,d|0,4)|0;b=v[23220];v[23220]=0;if((b|0)==1){break b}break h}if(b>>>0<62){break f}}v[23220]=0;T(176,d|0)|0;c=v[23220];v[23220]=0;b=4}if((c|0)==1){break b}v[23220]=0;Q(175,d|0,b|0)|0;break e}v[23220]=0;T(176,d|0)|0}b=v[23220];v[23220]=0;if((b|0)==1){break b}v[23220]=0;b=T(176,d|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break c}v[23220]=0;U(177,f|0,d|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break c}j=gc(a,f),k=v[f+44>>2],v[j+20>>2]=k;wb(f)}wb(d);break a}}a=P()|0;O()|0;wb(d);S(a|0);L()}fb=f+48|0}function mba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0;h=fb-16|0;fb=h;a:{b:{c:{i=v[a+12>>2];k=v[a+8>>2];d:{if((i|0)<=1&k>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=v[a+16>>2];b=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];e=v[a+44>>2];f=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=f;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];f=v[a+68>>2];s=f;w=f>>31;f=v[a+64>>2];x=f;y=f>>31;f=v[a+60>>2];z=f;A=f>>31;while(1){f=e;if(d){e=Ub(f,-16777216,16776704);e=Bia(x,y,e,e>>31);g=ib;j=e;b=Ub(b,-16777216,16776704);e=Bia(s,w,b,b>>31);j=j+e|0;b=ib+g|0;b=e>>>0>j>>>0?b+1|0:b;g=v[h+12>>2]+o|0;e=(v[h+8>>2]>>>16&65520)+n|0;g=(((((((B(t[g-2|0],u[e+2>>1])+B(t[g-3|0],u[e>>1])|0)+B(t[g-1|0],u[e+4>>1])|0)+B(t[g|0],u[e+6>>1])|0)+B(t[g+1|0],u[e+8>>1])|0)+B(t[g+2|0],u[e+10>>1])|0)+B(t[g+3|0],u[e+12>>1])|0)+B(t[g+4|0],u[e+14>>1])<<8)/32768<<8;e=g;e=Bia(e,e>>31,z,A);j=e+j|0;b=ib+b|0;b=e>>>0>j>>>0?b+1|0:b;e=j+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Lc(e,b,24);b=(e|0)/256|0;m=m+q|0;v[c>>2]=B(b,m>>12)+v[c>>2];l=l+p|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,b);Ob(h+8|0,k,i);e=e-(g&r)|0;c=c+8|0;d=d-1|0;b=f;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=b;v[a+44>>2]=f;v[a+24>>2]=l>>12;fb=h+16|0}function dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=fb-48|0;fb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){d=d-1|0;f=((((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&2147483646)<<1)+o|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=u[f+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=v[m>>2];e=(g+24|0)+(b<<3)|0;k=v[e+8>>2];j=v[e+4>>2];v[e+8>>2]=j;n=f<<8;f=n;f=Bia(y,z,f,f>>31);l=ib;D=e;e=Ub(j,-16777216,16776704);j=Bia(w,x,e,e>>31);f=j+f|0;e=ib+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Ub(k,-16777216,16776704);k=Bia(s,t,f,f>>31);f=l+k|0;e=ib+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Lc(f,e,24);v[D+4>>2]=e-(r&n);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}i=i+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],i>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Ob(g+16|0,A,C);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+36>>2]=i;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=g+48|0}function fV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-32|0;fb=f;wc(c);while(1){a:{if(!Lb(v[c>>2],v[c+8>>2],3)){break a}d=f+24|0;Dq(d,c);i=gd(d);h=Qe(d);d=w[f+24|0];if(d>>>0>=y[a+12>>2]){break a}g=$c(v[a>>2],v[v[a+48>>2]+12>>2],d,b);d=w[i|0];if(d>>>0<=126){if(!(d|w[h|0])){t[g|0]=254;continue}t[g|0]=d+1;if(w[h|0]==255){continue}t[g+2|0]=1;t[g+4|0]=w[h|0];continue}b:{switch(d-127|0){case 1:t[g+1|0]=w[h|0]+1;continue;case 0:continue;default:break b}}e=t[h|0];t[f+23|0]=e;h=0;d=d&127;if(d>>>0<=23){h=w[d+26208|0]}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{j=w[i|0];switch((j&127)-2|0){case 21:break g;case 18:break h;case 17:break i;case 16:case 20:break j;case 15:break k;case 2:break l;case 1:break m;case 0:case 8:case 9:break n;default:break d}}if((e|0)>=0){break f}d=0-e&15;break e}t[f+16|0]=64;e=w[Rb(f+23|0,f+16|0)|0];if(w[g+2|0]>1){break d}t[g+4|0]=e;t[g+2|0]=1;continue}d=3;if((e|0)>=0){break c}d=0-e&127;break e}if(!e){continue}d=0-e|-16;if((e|0)<0){break e}d=e<<4|15;break e}if(!e){continue}d=(e|0)>=0;if(!d){e=0-e&15;t[f+23|0]=e;j=w[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;t[f+23|0]=e;break c}d=e&15|-48;break e}d=e&15|-64;break e}d=164;if((e|0)==100){break e}v[f+16>>2]=e- -64;v[f+12>>2]=0;v[f+8>>2]=128;e=v[uj(f+16|0,f+12|0,f+8|0)>>2];if(!w[g+3|0]){break d}o:{switch(w[g+2|0]){case 0:case 2:break o;default:continue}}t[g+2|0]=2;t[g+4|0]=(e&254)>>>1;continue}d=e<<4}e=d;t[f+23|0]=e}d=h;if(!d){continue}}t[g+5|0]=e;t[g+3|0]=d;continue}break}fb=f+32|0}function sU(){var a=0,b=0,c=0;a=fb-16|0;fb=a;a:{if(ab(a+12|0,a+8|0)|0){break a}b=Fd((v[a+12>>2]<<2)+4|0);v[116606]=b;if(!b){break a}b=Fd(v[a+8>>2]);if(b){c=v[116606];v[c+(v[a+12>>2]<<2)>>2]=0;if(!($a(c|0,b|0)|0)){break a}}v[116606]=0}fb=a+16|0;if(!w[466416]){a=fb-16|0;fb=a;ms(466064);v[116528]=-1;v[116526]=466120;v[116524]=92568;v[116516]=77508;t[466116]=0;b=a+8|0;Fr(b,466064);c=v[v[116516]+8>>2];v[23220]=0;R(c|0,466064,b|0);b=v[23220];v[23220]=0;b:{if((b|0)!=1){Wb(a+8|0);fb=a+16|0;break b}b=P()|0;O()|0;Wb(a+8|0);un(466064);S(b|0);L()}ss(465392);v[116348]=77640;v[116346]=77620;v[116347]=0;sn(465392,466064);a=fb-16|0;fb=a;VG(466128);v[116544]=-1;v[116542]=466184;v[116540]=92568;v[116532]=77732;t[466180]=0;b=a+8|0;Fr(b,466128);c=v[v[116532]+8>>2];v[23220]=0;R(c|0,466128,b|0);b=v[23220];v[23220]=0;c:{if((b|0)!=1){Wb(a+8|0);fb=a+16|0;break c}b=P()|0;O()|0;Wb(a+8|0);Kr(466128);S(b|0);L()}xG(465480);v[116370]=77864;v[116368]=77844;v[116369]=0;sn(465480,466128);BG(466192,92712,466240);rw(465560,466192);AG(466248,92712,466296);qw(465644,466248);BG(466304,92408,466352);rw(465728,466304);rw(465896,v[(v[v[116432]-12>>2]+465728|0)+24>>2]);AG(466360,92408,466408);qw(465812,466360);qw(465980,v[(v[v[116453]-12>>2]+465812|0)+24>>2]);zG(v[v[116346]-12>>2]+465384|0);yG(v[v[116368]-12>>2]+465472|0);DI(v[v[116432]-12>>2]+465728|0);DI(v[v[116453]-12>>2]+465812|0);zG(v[v[116432]-12>>2]+465728|0);yG(v[v[116453]-12>>2]+465812|0);t[466416]=1}t[462800]=1;v[115701]=466516}function HZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;v[c>>2]=a;z=d&512;while(1){if((x|0)==4){if(Bb(n)>>>0>1){f=Vs(n);e=fb-16|0;fb=e;v[e+8>>2]=f;f=v[xe(e+8|0)>>2];fb=e+16|0;B=c,C=tF(f,Ts(n),v[c>>2]),v[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}return}a:{b:{switch(t[i+x|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];p=fl(g,32);q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break a;case 3:if(ze(n)){break a}p=w[Vf(n,0)|0];q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break a;case 2:if(ze(m)|!z){break a}B=c,C=tF(Vs(m),Ts(m),v[c>>2]),v[B>>2]=C;break a;case 4:break b;default:break a}}p=v[g+8>>2];A=v[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!eh(p,2048,t[r|0])){break c}r=r+1|0;continue}break}p=o;if((p|0)>0){while(1){if(!(!p|e>>>0>=r>>>0)){r=r-1|0;q=w[r|0];s=v[c>>2];v[c>>2]=s+1;t[s|0]=q;p=p-1|0;continue}break}if(p){q=fl(g,48)}else{q=0}while(1){s=v[c>>2];v[c>>2]=s+1;if((p|0)>0){t[s|0]=q;p=p-1|0;continue}break}t[s|0]=j}d:{if((e|0)==(r|0)){p=fl(g,48);q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break d}if(ze(l)){q=-1}else{q=t[Vf(l,0)|0]}p=0;u=0;while(1){if((e|0)==(r|0)){break d}e:{if((p|0)!=(q|0)){s=p;break e}q=v[c>>2];v[c>>2]=q+1;t[q|0]=k;s=0;u=u+1|0;if(Bb(l)>>>0<=u>>>0){q=p;break e}q=-1;if(w[Vf(l,u)|0]==127){break e}q=t[Vf(l,u)|0]}r=r-1|0;p=w[r|0];y=v[c>>2];v[c>>2]=y+1;t[y|0]=p;p=s+1|0;continue}}ul(A,v[c>>2])}x=x+1|0;continue}}function Haa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=fb-16|0;fb=g;w=v[a+16>>2];x=Zf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);p=v[a+128>>2];a:{if(!p){n=v[a+8>>2];s=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];o=0;break a}b=v[a+12>>2];s=b;n=v[a+8>>2];q=_f(n,b,p);r=ib;k=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Df(i,e,af(n,b,d),ib);o=k>>>0<ib>>>0?d:0}h=a+112|0;f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{k=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;o=o-1|0;b=o;q=b?q:0;r=b?r:0;e=e+w|0;b=p;while(1)if((b|0)<=0){Ob(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Hd(h,t[e+v[g+12>>2]|0]<<6);Gd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];y=v[a+32>>2];m=v[a+28>>2]+m|0;b=v[a+60>>2];e=b;j=b>>31;u=Yf(h,x)<<8;b=u;b=Bia(e,j,b,b>>31);z=ib;e=b;b=v[a+64>>2];j=b;A=b>>31;b=Ub(k,-16777216,16776704);j=Bia(j,A,b,b>>31);e=e+j|0;b=ib+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Ub(f,-16777216,16776704);e=Bia(e,e>>31,f,f>>31);f=j+e|0;b=ib+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Lc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(m>>12,f)+v[c>>2];l=l+y|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,f);Ob(g,n,s);b=b-(i&u)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=k;continue b}else{Hd(h,t[e+v[g+12>>2]|0]<<6);Gd(h,4);Ob(g+8|0,q,r);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=k;v[a+24>>2]=l>>12;fb=g+16|0}function eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=fb-48|0;fb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;u=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){d=d-1|0;f=(((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&-2)+o|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=t[e+f|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=v[m>>2];e=(g+24|0)+(b<<3)|0;k=v[e+8>>2];j=v[e+4>>2];v[e+8>>2]=j;n=f<<8;f=n;f=Bia(y,z,f,f>>31);l=ib;D=e;e=Ub(j,-16777216,16776704);j=Bia(w,x,e,e>>31);f=j+f|0;e=ib+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Ub(k,-16777216,16776704);k=Bia(s,u,f,f>>31);f=l+k|0;e=ib+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Lc(f,e,24);v[D+4>>2]=e-(r&n);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}i=i+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],i>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Ob(g+16|0,A,C);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+36>>2]=i;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=g+48|0}function v3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-80|0;fb=e;f=Ib(a);a=v[b+24>>2];g=hj(Vb(v[a+484360>>2],w[a+484376|0]));v[23220]=0;R(168,f|0,g|0);a=v[23220];v[23220]=0;a:{if((a|0)!=1){a=0;while(1){b:{if((a|0)!=(g|0)){c=v[b+24>>2];d=v[c+484344>>2];h=v[c+484348>>2];c=x[ac(v[Vb(v[c+484360>>2],w[c+484376|0])>>2],a)>>1];if(om(d,h,c)){v[23220]=0;R(988,e+48|0,Xb(d,c)|0);c=v[23220];v[23220]=0;c:{d:{e:{if((c|0)!=1){c=v[b+24>>2];v[23220]=0;U(975,e- -64|0,c|0,e+48|0);c=v[23220];v[23220]=0;if((c|0)==1){break e}v[23220]=0;R(170,f|0,e- -64|0);c=v[23220];v[23220]=0;if((c|0)==1){break d}ub(e- -64|0);ub(e+48|0);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;ub(e- -64|0)}ub(e+48|0);break a}f:{switch(c-65534|0){case 0:v[23220]=0;c=Q(52,e+32|0,9211)|0;d=v[23220];v[23220]=0;g:{if((d|0)!=1){v[23220]=0;R(170,f|0,c|0);d=v[23220];v[23220]=0;if((d|0)==1){break g}ub(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;ub(c);break a;case 1:v[23220]=0;c=Q(52,e+16|0,9173)|0;d=v[23220];v[23220]=0;h:{if((d|0)!=1){v[23220]=0;R(170,f|0,c|0);d=v[23220];v[23220]=0;if((d|0)==1){break h}ub(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;ub(c);break a;default:break f}}v[23220]=0;c=Q(52,e|0,14592)|0;d=v[23220];v[23220]=0;i:{if((d|0)!=1){v[23220]=0;R(170,f|0,c|0);d=v[23220];v[23220]=0;if((d|0)==1){break i}ub(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;ub(c);break a}fb=e+80|0;return}a=a+1|0;continue}}a=P()|0;O()|0}De(f);S(a|0);L()}function yca(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-48|0;fb=e;u[e+46>>1]=254;c=hj(a);g=Ib(e+32|0);a:{b:{if(c){v[23220]=0;R(580,g|0,c|0);f=v[23220];v[23220]=0;if((f|0)==1){break a}fC(g,c)}break b}c:{while(1){d:{if((b|0)==(c|0)){if(!(d&65535)){break c}c=Ab(v[a>>2]);d=Ab(v[a+4>>2]);b=fb-16|0;fb=b;c=Wz(c,d,x[e+46>>1]);v[b+8>>2]=c;if(Nb(c,d)){v[b>>2]=c;while(1){c=v[Oe(b)>>2];if(Nb(c,d)){c=x[c>>1];if((c|0)==x[e+46>>1]){continue}u[v[b+8>>2]>>1]=c;Oe(b+8|0);continue}break}c=v[b+8>>2]}fb=b+16|0;b=dc(e+24|0,c);c=v[dc(e+16|0,Ab(v[a+4>>2]))>>2];d=v[b>>2];b=v[a>>2];b=(jo(d,Ab(b))<<1)+b|0;if(Nb(d,c)){Jd(a,Gi(b+(jo(c,d)<<1)|0,v[a+4>>2],b))}Ab(b);k=e,l=Ab(v[a>>2]),v[k+8>>2]=l;d=Ab(v[a+4>>2]);break d}k=ac(v[g>>2],b),l=b-d|0,u[k>>1]=l;f=v[a+4>>2];h=v[a>>2];v[23220]=0;f=W(717,h|0,f|0,b|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break a}b=b+1|0;d=(x[f>>1]==254)+d|0;continue}break}while(1){b=v[e+8>>2];if(!Nb(b,d)){b=v[g>>2];d=Ic(b,v[g+4>>2]);c=x[a+28>>1];if(d>>>0<=c>>>0){break c}k=a,l=x[ac(b,c)>>1],u[k+28>>1]=l;break c}e:{c=v[a+24>>2];f=v[c+484344>>2];b=x[b>>1];if(!ke(f,v[c+484348>>2],b)){break e}b=Xb(f,b);k=e,l=Ab(v[b>>2]),v[k>>2]=l;f=Ab(v[b+4>>2]);h=v[g+4>>2];c=v[g>>2];while(1){b=v[e>>2];if(!Nb(b,f)){break e}f:{if(w[b+3|0]!=12){break f}j=Ic(c,h);i=w[b+5|0];if(j>>>0<=i>>>0){break f}k=b,l=w[ac(c,i)|0],t[k+5|0]=l}gk(e);continue}}Oe(e+8|0);continue}}ld(g);fb=e+48|0;return}a=P()|0;O()|0;ld(g);S(a|0);L()}function Tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=fb-48|0;fb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){b=v[g+16>>2];j=b>>>18|0;i=((((v[g+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+m|0;b=0;e=0;while(1){if((e|0)!=2){h=i+(e<<1)|0;f=u[h>>1];v[(g+8|0)+(e<<2)>>2]=f+((B(j,u[h+4>>1]-f|0)|0)/16384|0);e=e+1|0;continue}break}while(1){if((b|0)!=2){j=(g+8|0)+(b<<2)|0;f=v[j>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Bia(w,x,f,f>>31);k=ib;A=e;e=Ub(h,-16777216,16776704);h=Bia(s,t,e,e>>31);f=h+f|0;e=ib+k|0;e=f>>>0<h>>>0?e+1|0:e;k=f;f=Ub(i,-16777216,16776704);i=Bia(q,r,f,f>>31);f=k+i|0;e=ib+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Lc(f,e,24);v[A+4>>2]=e-(p&l);v[j>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(n,v[g+12>>2]);Ob(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=g+48|0}function Uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=fb-48|0;fb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;u=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){b=v[g+16>>2];j=b>>>10&4194048;i=(((v[g+20>>2]&2147483647)<<1|b>>>31)&-2)+m|0;b=0;e=0;while(1){if((e|0)!=2){h=e+i|0;f=t[h|0];v[(g+8|0)+(e<<2)>>2]=((B(j,t[h+2|0]-f|0)|0)/16384|0)+(f<<8);e=e+1|0;continue}break}while(1){if((b|0)!=2){j=(g+8|0)+(b<<2)|0;f=v[j>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Bia(w,x,f,f>>31);k=ib;A=e;e=Ub(h,-16777216,16776704);h=Bia(s,u,e,e>>31);f=h+f|0;e=ib+k|0;e=f>>>0<h>>>0?e+1|0:e;k=f;f=Ub(i,-16777216,16776704);i=Bia(q,r,f,f>>31);f=k+i|0;e=ib+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Lc(f,e,24);v[A+4>>2]=e-(p&l);v[j>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(n,v[g+12>>2]);Ob(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=g+48|0}function M6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=fb-16|0;fb=j;i=fb-32|0;fb=i;h=Ge(i+16|0,1,0);a:{b:{c:{while(1){g=pc(h);d=g+Bb(h)|0;c=v[b>>2];f=v[b+4>>2];if(!((f|0)>0|(f|0)>=0|(d|0)==(g|0))){t[g|0]=45;e=c;c=0-c|0;g=g+1|0;f=0-(f+((e|0)!=0)|0)|0}k=d-g|0;d:{if((k|0)<=19){e=E(f);e=B(64-((e|0)==32?E(c|1)+32|0:e)|0,1233)>>>12|0;n=(e<<3)+25808|0;l=k;k=v[n+4>>2];m=61;if((l|0)<((e-((f|0)==(k|0)&c>>>0<y[n>>2]|f>>>0<k>>>0)|0)+1|0)){break d}}e:{if(!f&c>>>0<=99999999){d=Gw(g,c);break e}if((f|0)==2328306&c>>>0<=1874919423|f>>>0<2328306){d=Eia(c,f,1e8,0);e=ib;l=Gw(g,d);d=Bia(d,e,-1e8,0)+c|0;c=d;d=(c>>>0)/1e4|0;d=Vi(Vi(l,d),c+B(d,-1e4)|0);break e}d=Eia(c,f,1874919424,2328306);e=ib;g=Fw(g,d);d=Bia(d,e,-1874919424,-2328307)+c|0;e=f+ib|0;e=c>>>0>d>>>0?e+1|0:e;c=Eia(d,e,1e8,0);e=ib;f=(c>>>0)/1e4|0;l=Vi(Vi(g,f),c+B(f,-1e4)|0);c=Bia(c,e,-1e8,0)+d|0;d=(c>>>0)/1e4|0;d=Vi(Vi(l,d),c+B(d,-1e4)|0)}m=0}v[i+12>>2]=m;v[i+8>>2]=d;if(!v[i+12>>2]){break c}c=Ff(Bb(h));v[23220]=0;R(56,h|0,c|0);c=v[23220];v[23220]=0;if((c|0)!=1){continue}break}break b}b=v[i+8>>2];c=pc(h);v[23220]=0;R(57,h|0,b-c|0);b=v[23220];v[23220]=0;f:{if((b|0)!=1){v[23220]=0;R(58,j|0,h|0);b=v[23220];v[23220]=0;if((b|0)!=1){break f}break b}break b}ub(h);fb=i+32|0;break a}a=P()|0;O()|0;ub(h);S(a|0);L()}v[23220]=0;R(55,a|0,j|0);a=v[23220];v[23220]=0;if((a|0)!=1){ub(j);fb=j+16|0;return}a=P()|0;O()|0;ub(j);S(a|0);L()}function F_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=fb-384|0;fb=a;v[a+368>>2]=c;v[a+376>>2]=b;dw(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Gb(a+200|0);b=Qc(d);v[23220]=0;R(57,d|0,b|0);b=v[23220];v[23220]=0;a:{b:{c:{if((b|0)!=1){c=Fc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;h=v[a+232>>2];i=v[a+236>>2];while(1){d:{v[23220]=0;b=Q(1109,a+376|0,a+368|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+196>>2];b=Bb(d);if((g|0)==(b+c|0)){v[23220]=0;R(57,d|0,b<<1);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Fc(d,0);v[a+196>>2]=b+c}v[23220]=0;b=T(1111,v[a+376>>2])|0;g=v[23220];v[23220]=0;if((g|0)==1){break d}if(cw(b,a+23|0,a+22|0,c,a+196|0,i,h,a+216|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[23220]=0;T(1113,a+376|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}SF(a,c,v[a+196>>2],e);b=v[a>>2];c=v[a+4>>2];h=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=h;v[f>>2]=b;v[f+4>>2]=c;pf(a+216|0,a+32|0,v[a+28>>2],e);v[23220]=0;b=Q(1110,a+376|0,a+368|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];ub(d);ub(a+216|0);fb=a+384|0;break a}}b=P()|0;O()|0;ub(d);ub(a+216|0);S(b|0);L()}return b|0}function O_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=fb-288|0;fb=a;v[a+272>>2]=c;v[a+280>>2]=b;hw(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Gb(a+208|0);b=Qc(d);v[23220]=0;R(57,d|0,b|0);b=v[23220];v[23220]=0;a:{b:{c:{if((b|0)!=1){c=Fc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;h=t[a+238|0];i=t[a+239|0];while(1){d:{v[23220]=0;b=Q(1093,a+280|0,a+272|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+204>>2];b=Bb(d);if((g|0)==(b+c|0)){v[23220]=0;R(57,d|0,b<<1);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Fc(d,0);v[a+204>>2]=b+c}v[23220]=0;b=T(1095,v[a+280>>2])|0;g=v[23220];v[23220]=0;if((g|0)==1){break d}if(gw(b,a+23|0,a+22|0,c,a+204|0,i,h,a+224|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[23220]=0;T(1097,a+280|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}SF(a,c,v[a+204>>2],e);b=v[a>>2];c=v[a+4>>2];h=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=h;v[f>>2]=b;v[f+4>>2]=c;pf(a+224|0,a+32|0,v[a+28>>2],e);v[23220]=0;b=Q(1094,a+280|0,a+272|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];ub(d);ub(a+224|0);fb=a+288|0;break a}}b=P()|0;O()|0;ub(d);ub(a+224|0);S(b|0);L()}return b|0}function l_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=fb-432|0;fb=i;v[i+424>>2]=37;v[i+428>>2]=0;m=rr(i+424|1,13855,v[c+4>>2]);v[i+380>>2]=i+384;a=wd();a:{if(m){j=v[c+8>>2];k=i- -64|0;v[k>>2]=g;v[k+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=j;j=Fg(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;j=Fg(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=1091;l=he(i+368|0,0,i+128|0);k=i+384|0;a=k;b:{c:{d:{if((j|0)>=30){a=wd();e:{if(m){j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i+8>>2]=e;v[i+12>>2]=f;v[i>>2]=j;j=Oi(i+380|0,a,i+424|0,i);break e}v[i+32>>2]=e;v[i+36>>2]=f;v[i+40>>2]=g;v[i+44>>2]=h;j=Oi(i+380|0,a,i+424|0,i+32|0)}if((j|0)==-1){v[23220]=0;Z(1092);a=v[23220];v[23220]=0;if((a|0)==1){break c}break d}a=v[i+380>>2];Je(l,a)}f=a+j|0;g=Pi(a,f,c);v[i+116>>2]=1091;e=he(i+120|0,0,i+116|0);f:{g:{if((i+384|0)==(a|0)){j=i+128|0;break g}j=Fd(j<<3);if(!j){v[23220]=0;Z(1092);a=v[23220];v[23220]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Je(e,j);k=a}a=i+104|0;Xc(a,c);v[23220]=0;ja(1124,k|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=v[23220];v[23220]=0;h:{if((a|0)!=1){Wb(i+104|0);v[23220]=0;a=la(1125,b|0,j|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break h}Kc(e);Kc(l);fb=i+432|0;return a|0}c=P()|0;O()|0;Wb(i+104|0);break f}c=P()|0;O()|0}Kc(e);break b}L()}c=P()|0;O()|0}Kc(l);S(c|0);L()}function ij(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!Md(v[a>>2],v[a+20>>2])){break a}hk(a);b:{switch(ym(x[a+34>>1])-1|0){case 1:e=fb+-64|0;fb=e;h=v[a+20>>2];c=v[a>>2];d=Cd(x[a+34>>1]);f=h+(B(c,d)<<1)|0;while(1){c:{d:{if((g|0)!=16){i=B(d,g);j=B(d,g^-1);c=0;break d}g=f+(d<<5)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];xb(e+32|0,b+1074312|0,33);KO(e+40|0,g,h+(B(d,f)<<1)|0,i-f|0,d,(c&4)>>>2|0,yb(v[v[e+32>>2]>>2],v[e+36>>2]));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];xb(e+32|0,b+1074312|0,33);KO(e+8|0,g+(d<<7)|0,h+(B(a,d)<<1)|0,f-a|0,d,(c&16)>>>4|0,yb(v[v[e+32>>2]>>2],v[e+36>>2]))}fb=e- -64|0;break c}while(1){if((c|0)!=(d|0)){u[f+(c+i<<1)>>1]=x[f+(c-d<<1)>>1];u[h+(c+j<<1)>>1]=x[h+(c<<1)>>1];c=c+1|0;continue}break}g=g+1|0;continue}break};return;case 0:break b;default:break a}}e=fb+-64|0;fb=e;h=v[a+20>>2];c=v[a>>2];d=Cd(x[a+34>>1]);f=h+B(c,d)|0;while(1){e:{f:{if((g|0)!=16){i=B(d,g);j=B(d,g^-1);c=0;break f}g=f+(d<<4)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];xb(e+32|0,b+1074312|0,33);JO(e+40|0,g,h+B(d,f)|0,i-f|0,d,(c&4)>>>2|0,yb(v[v[e+32>>2]>>2],v[e+36>>2]));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];xb(e+32|0,b+1074312|0,33);JO(e+8|0,g+(d<<6)|0,h+B(a,d)|0,f-a|0,d,(c&16)>>>4|0,yb(v[v[e+32>>2]>>2],v[e+36>>2]))}fb=e- -64|0;break e}while(1){if((c|0)!=(d|0)){t[f+(c+i|0)|0]=w[f+(c-d|0)|0];t[h+(c+j|0)|0]=w[c+h|0];c=c+1|0;continue}break}g=g+1|0;continue}break}}}function v_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=fb-256|0;fb=i;v[i+248>>2]=37;v[i+252>>2]=0;m=rr(i+248|1,13855,v[c+4>>2]);v[i+204>>2]=i+208;a=wd();a:{if(m){j=v[c+8>>2];k=i- -64|0;v[k>>2]=g;v[k+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=j;j=Fg(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;j=Fg(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=1091;l=he(i+192|0,0,i+128|0);k=i+208|0;a=k;b:{c:{d:{if((j|0)>=30){a=wd();e:{if(m){j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i+8>>2]=e;v[i+12>>2]=f;v[i>>2]=j;j=Oi(i+204|0,a,i+248|0,i);break e}v[i+32>>2]=e;v[i+36>>2]=f;v[i+40>>2]=g;v[i+44>>2]=h;j=Oi(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){v[23220]=0;Z(1092);a=v[23220];v[23220]=0;if((a|0)==1){break c}break d}a=v[i+204>>2];Je(l,a)}f=a+j|0;g=Pi(a,f,c);v[i+116>>2]=1091;e=he(i+120|0,0,i+116|0);f:{g:{if((i+208|0)==(a|0)){j=i+128|0;break g}j=Fd(j<<1);if(!j){v[23220]=0;Z(1092);a=v[23220];v[23220]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Je(e,j);k=a}a=i+104|0;Xc(a,c);v[23220]=0;ja(1119,k|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=v[23220];v[23220]=0;h:{if((a|0)!=1){Wb(i+104|0);v[23220]=0;a=la(14,b|0,j|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break h}Kc(e);Kc(l);fb=i+256|0;return a|0}c=P()|0;O()|0;Wb(i+104|0);break f}c=P()|0;O()|0}Kc(e);break b}L()}c=P()|0;O()|0}Kc(l);S(c|0);L()}function XW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=Gb(a);a=w[b+11|0];g=v[b+4>>2];v[23220]=0;k=nl(g,a);R(102,i|0,k|0);a=v[23220];v[23220]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=t[qd(b)+a|0];h=e&255;d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(h-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(h-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}v[23220]=0;Q(103,i|0,Dd(c,g)|0)|0;h=v[23220];v[23220]=0;g=e;if((h|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;j=e;break d;case 3:f=-1;j:{switch(h-123|0){case 2:f=0;if(d>>>0<=j>>>0){break d}v[23220]=0;Q(103,i|0,Dd(c,j)|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}j=(B(j,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}h=(e|0)!=125;f=-1;e=125;if(h){break d}}f=0;v[23220]=0;Q(104,i|0,e|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b}f=-1}a=a+1|0;continue}break}b=aa(8)|0;v[23220]=0;a=T(105,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){v[23220]=0;U(106,a|0,41972,24);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;ba(b|0);break b}a=P()|0;O()|0}vb(i);S(a|0)}L()}function Kaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;g=fb-16|0;fb=g;s=v[a+16>>2];t=Zf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){k=v[a+8>>2];l=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];m=0;break a}k=v[a+8>>2];l=v[a+12>>2];o=_f(k,l,n);p=ib;b=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Df(i,e,af(k,l,d),ib);m=b>>>0<ib>>>0?d:0}h=a+112|0;f=v[a+48>>2];w=v[a+24>>2];x=v[a+20>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;m=m-1|0;b=m;o=b?o:0;p=b?p:0;e=(e<<1)+s|0;b=n;while(1)if((b|0)<=0){Ob(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Hd(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Gd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];b=v[a+60>>2];e=b;j=b>>31;r=Yf(h,t)<<8;b=r;b=Bia(e,j,b,b>>31);y=ib;e=b;b=v[a+64>>2];j=b;z=b>>31;b=Ub(q,-16777216,16776704);j=Bia(j,z,b,b>>31);e=e+j|0;b=ib+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Ub(f,-16777216,16776704);e=Bia(e,e>>31,f,f>>31);f=j+e|0;b=ib+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Lc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(f,x)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(f,w);Ob(g,k,l);b=b-(i&r)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=q;continue b}else{Hd(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Gd(h,4);Ob(g+8|0,o,p);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+48>>2]=f;v[a+44>>2]=q;fb=g+16|0}
function E_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=fb-352|0;fb=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Gb(a+208|0);b=a+16|0;Xc(b,d);v[23220]=0;b=T(1104,b|0)|0;c=v[23220];v[23220]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23220]=0;X(1116,b|0,82816,82842,a+224|0);b=v[23220];v[23220]=0;if((b|0)==1){break d}Wb(a+16|0);c=Gb(a+192|0);b=Qc(c);v[23220]=0;R(57,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break b}b=Fc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[23220]=0;d=Q(1109,a+344|0,a+336|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break e}if(!d){break c}g=v[a+188>>2];d=Bb(c);if((g|0)==(d+b|0)){v[23220]=0;R(57,c|0,d<<1);b=v[23220];v[23220]=0;if((b|0)==1){break b}b=Qc(c);v[23220]=0;R(57,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break b}b=Fc(c,0);v[a+188>>2]=d+b}v[23220]=0;d=T(1111,v[a+344>>2])|0;g=v[23220];v[23220]=0;if((g|0)==1){break e}if(Vm(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[23220]=0;T(1113,a+344|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;Wb(a+16|0);break a}v[23220]=0;R(57,c|0,v[a+188>>2]-b|0);b=v[23220];v[23220]=0;f:{if((b|0)==1){break f}b=Ec(c);d=wd();v[a>>2]=f;if((QF(b,d,a)|0)!=1){v[e>>2]=4}v[23220]=0;b=Q(1110,a+344|0,a+336|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];ub(c);ub(h);fb=a+352|0;return b|0}}b=P()|0;O()|0;ub(c)}ub(h);S(b|0);L()}function pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;h=fb-16|0;fb=h;a:{b:{c:{i=v[a+12>>2];j=v[a+8>>2];d:{if((i|0)<=1&j>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&j>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&j>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&j>>>0>2147483648|i>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=v[a+16>>2];f=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];b=v[a+44>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;r=v[a+72>>2];e=v[a+68>>2];s=e;t=e>>31;e=v[a+64>>2];w=e;x=e>>31;e=v[a+60>>2];y=e;z=e>>31;while(1){e=b;if(d){b=Ub(e,-16777216,16776704);b=Bia(w,x,b,b>>31);k=ib;l=b;g=(v[h+12>>2]<<1)+o|0;b=(v[h+8>>2]>>>16&65520)+n|0;g=(((((((B(u[g-4>>1],u[b+2>>1])+B(u[g-6>>1],u[b>>1])|0)+B(u[g-2>>1],u[b+4>>1])|0)+B(u[g>>1],u[b+6>>1])|0)+B(u[g+2>>1],u[b+8>>1])|0)+B(u[g+4>>1],u[b+10>>1])|0)+B(u[g+6>>1],u[b+12>>1])|0)+B(u[g+8>>1],u[b+14>>1])|0)/32768<<8;b=g;b=Bia(b,b>>31,y,z);l=l+b|0;m=ib+k|0;m=b>>>0>l>>>0?m+1|0:m;b=Ub(f,-16777216,16776704);f=Bia(s,t,b,b>>31);k=f+l|0;b=ib+m|0;b=f>>>0>k>>>0?b+1|0:b;f=k+8388608|0;b=f>>>0<8388608?b+1|0:b;f=Lc(f,b,24);b=(f|0)/256|0;v[c>>2]=B(b,q)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(b,p);Ob(h+8|0,j,i);b=f-(g&r)|0;c=c+8|0;d=d-1|0;f=e;continue}break}b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;v[a+48>>2]=f;v[a+44>>2]=e;fb=h+16|0}function N_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=fb-272|0;fb=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Gb(a+208|0);b=a+16|0;Xc(b,d);v[23220]=0;b=T(18,b|0)|0;c=v[23220];v[23220]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23220]=0;X(1102,b|0,82816,82842,a+224|0);b=v[23220];v[23220]=0;if((b|0)==1){break d}Wb(a+16|0);c=Gb(a+192|0);b=Qc(c);v[23220]=0;R(57,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break b}b=Fc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[23220]=0;d=Q(1093,a+264|0,a+256|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break e}if(!d){break c}g=v[a+188>>2];d=Bb(c);if((g|0)==(d+b|0)){v[23220]=0;R(57,c|0,d<<1);b=v[23220];v[23220]=0;if((b|0)==1){break b}b=Qc(c);v[23220]=0;R(57,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break b}b=Fc(c,0);v[a+188>>2]=d+b}v[23220]=0;d=T(1095,v[a+264>>2])|0;g=v[23220];v[23220]=0;if((g|0)==1){break e}if(Xm(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[23220]=0;T(1097,a+264|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;Wb(a+16|0);break a}v[23220]=0;R(57,c|0,v[a+188>>2]-b|0);b=v[23220];v[23220]=0;f:{if((b|0)==1){break f}b=Ec(c);d=wd();v[a>>2]=f;if((QF(b,d,a)|0)!=1){v[e>>2]=4}v[23220]=0;b=Q(1094,a+264|0,a+256|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];ub(c);ub(h);fb=a+272|0;return b|0}}b=P()|0;O()|0;ub(c)}ub(h);S(b|0);L()}function Ky(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;f=v[c+656>>2];a:{if(!lj(f)){i=v[c+704>>2];f=fb-16|0;fb=f;v[f+12>>2]=d;g=0;b:{if(!d){break b}j=v[b+480180>>2];if(j&20){e=b+1074312|0;xb(f,e,73);d=yb(v[v[f>>2]>>2],v[f+4>>2])?d&65535:d;if(w[b+480208|0]&16){xb(f,e,73);e=yb(v[v[f>>2]>>2],v[f+4>>2])?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=v[((d>>>0)%768<<2)+34096>>2]<<6>>>e|0;break b}if(!d){v[f+12>>2]=1;d=1}g=229079296/(d>>>0)|0;break b}g=227001280/(d>>>0)|0;if(em(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}uc(f+12|0,16777215);if(j&17408){g=Pc(Eia(Bia(i?i:8363,0,3506176,0),ib,(v[f+12>>2]<<8)+e|0,0),ib);break b}if(cj(b)){d=v[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(w[b+480208|0]&16){g=Pc(Eia(Bia(i?i:8363,0,7012352,0),ib,(v[f+12>>2]<<8)+e|0,0),ib);break b}g=Pc(Eia(-1485242368,13,(v[f+12>>2]<<8)+e|0,0),ib)}d=g;fb=f+16|0;f=v[c+656>>2];break a}d=v[c+700>>2]}v[h+12>>2]=d;c=u[c+774>>1];c:{if(!c){break c}c=f?B(t[f+33|0],c):c;if(!c){break c}d=Ee(Kj(+(c|0)/393216)*+(d>>>0));v[h+12>>2]=d}d:{if(!f){break d}c=v[f+40>>2];if(!c){break d}e=(c|0)/2|0;f=v[b+1074420>>2];d=Bia(f,f>>31,d,d>>31);f=e+d|0;e=ib+(e>>31)|0;k=h,l=Dc(Cia(f,d>>>0>f>>>0?e+1|0:e,c,c>>31),ib),v[k+12>>2]=l}uc(h+12|0,2147483647);c=v[h+12>>2];b=Cia(0,c,v[b+24620>>2]<<4,0);v[a+8>>2]=c;v[a>>2]=b;v[a+4>>2]=ib;fb=h+16|0}function YD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-96|0;fb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){Qb(a,9711);break j}if(!(b&65535)){d=fb-16|0;fb=d;e=Qb(d,4360);Mc(c+80|0,e);vb(e);fb=d+16|0;v[23220]=0;v[c+24>>2]=b>>>24;R(96,c- -64|0,c+24|0);d=v[23220];v[23220]=0;k:{l:{m:{n:{if((d|0)!=1){v[23220]=0;v[c+8>>2]=b>>>16&255;R(97,c+48|0,c+8|0);b=v[23220];v[23220]=0;if((b|0)==1){break n}v[23220]=0;X(98,a|0,c+80|0,c- -64|0,c+48|0);a=v[23220];v[23220]=0;if((a|0)==1){break m}vb(c+48|0);vb(c- -64|0);bc(c+80|0);break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(c+48|0)}vb(c- -64|0)}break a}d=fb-16|0;fb=d;e=Qb(d,4084);Mc(c+80|0,e);vb(e);fb=d+16|0;v[23220]=0;v[c+44>>2]=b>>>24;R(96,c- -64|0,c+44|0);d=v[23220];v[23220]=0;if((d|0)==1){break i}v[23220]=0;v[c+40>>2]=b>>>16&255;R(97,c+48|0,c+40|0);d=v[23220];v[23220]=0;if((d|0)==1){break h}v[23220]=0;v[c+20>>2]=b>>>8&255;R(97,c+24|0,c+20|0);d=v[23220];v[23220]=0;if((d|0)==1){break g}v[23220]=0;v[c+4>>2]=b&255;R(97,c+8|0,c+4|0);b=v[23220];v[23220]=0;if((b|0)==1){break f}v[23220]=0;ka(99,a|0,c+80|0,c- -64|0,c+48|0,c+24|0,c+8|0);a=v[23220];v[23220]=0;if((a|0)==1){break e}vb(c+8|0);vb(c+24|0);vb(c+48|0);vb(c- -64|0);bc(c+80|0)}fb=c+96|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(c+8|0)}vb(c+24|0)}vb(c+48|0)}vb(c- -64|0)}bc(c+80|0);S(b|0);L()}function cz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{e=a;b:{c:{h=a+62|0;f=Hb(h,b);a=t[f|0];if((a|0)==-1){break c}if((a|0)>=0){break b}a=a&127;d=ac(e+26|0,a);g=x[d>>1];if((g|0)!=65535&(b|0)!=(g|0)){break c}u[d>>1]=b;t[f|0]=a;break b}l=e+8|0;i=e+26|0;d=255;a=0;g=255;while(1){if((a|0)!=18){j=ac(i,a);k=x[j>>1];if((k|0)==65535){u[j>>1]=b;t[f|0]=a;break b}else{if(!(w[Hb(l,a)|0]&32)){g=t[Hb(h,k)|0]<0?a:g;d=a}a=a+1|0;continue}}break}if((d&255)!=255){a=(g&255)==255?d:g;d=ac(i,a&255);m=Hb(h,x[d>>1]),n=255,t[m|0]=n;u[d>>1]=b;t[f|0]=a}a=Tk(e,b)}g=a&255;if((g|0)==255){break a}if(Tj(v[e>>2])){break a}d=Dd(e+318|0,g);a=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[d+8|0]=a;t[d+9|0]=a>>>8;t[d+10|0]=a>>>16;t[d+11|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;t[d+4|0]=a;t[d+5|0]=a>>>8;t[d+6|0]=a>>>16;t[d+7|0]=a>>>24;f=lO(g);h=f+3|0;a=0;while(1){if((a|0)==2){Ng(v[e>>2],v[e+4>>2],b,ct(g)|192,w[Hb(c,10)|0])}else{d=a?h:f;Ng(v[e>>2],v[e+4>>2],b,(d|32)&65535,w[Hb(c,a)|0]);Ng(v[e>>2],v[e+4>>2],b,(d|64)&65535,w[Hb(c,a+2|0)|0]);Ng(v[e>>2],v[e+4>>2],b,(d|96)&65535,w[Hb(c,a+4|0)|0]);Ng(v[e>>2],v[e+4>>2],b,(d|128)&65535,w[Hb(c,a+6|0)|0]);Ng(v[e>>2],v[e+4>>2],b,(d|224)&65535,w[Hb(c,a+8|0)|0]);a=a+1|0;continue}break}}}function oz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;if(b&5){if((b|0)==1){d=Bia(v[a+24>>2],0,8363,0)+4136|0;c=ib;h=a,i=Pc(Eia(d,d>>>0<4136?c+1|0:c,8272,0),ib),v[h+24>>2]=i}d=fb-16|0;fb=d;f=d+8|0;c=fb-16|0;fb=c;g=v[a+24>>2];a:{if(!g){t[f|0]=0;t[f+1|0]=0;break a}jB(c+8|0,Ub(Xl(ip(+(g>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);g=v[c+8>>2];t[c+7|0]=v[c+12>>2];et(f,g,c+7|0)}fb=c+16|0;dc(dc(d,a+36|0)+4|0,a+37|0);t[v[d>>2]]=w[f|0];t[v[d+4>>2]]=w[f+1|0];fb=d+16|0}if(b&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(b&7){u[a+32>>1]=64;c=x[a+34>>1];if(c&8){d=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=d;c=c&16?c|6:c&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=c&65511}b:{if(!(b&4)){break b}c=x[a+34>>1];if(!(c&32)){u[a+28>>1]=128;u[a+34>>1]=c|32}hf(a+40|0,15);hf(a+41|0,63);if(!w[a+41|0]){break b}d=w[a+40|0];if(!d){break b}c=w[a+39|0];if(c){c=sm(Pc(((d<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}t[a+39|0]=c}c:{d:{if((b|0)!=4){if((b|0)==16777216){break c}if((b|0)!=32|w[a+38|0]!=2){break d}t[a+38|0]=3;break d}if(w[a+38|0]!=4){break d}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}e:{if(!(!(w[a+35|0]&2)|b&16777218)){v[e+24>>2]=0;v[e+8>>2]=0;v[e+16>>2]=0;v[e+20>>2]=0;v[e>>2]=0;v[e+4>>2]=0;cl(a,0,e);break e}if(!(w[a+35|0]&2)|(b|0)!=2){break e}a=a+68|0;b=Hb(a,8);t[b|0]=w[b|0]&3;a=Hb(a,9);t[a|0]=w[a|0]&3}fb=e+32|0}function qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;h=fb-16|0;fb=h;a:{b:{c:{i=v[a+12>>2];k=v[a+8>>2];d:{if((i|0)<=1&k>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];b=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];e=v[a+44>>2];f=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=f;p=v[a+72>>2];f=v[a+68>>2];q=f;r=f>>31;f=v[a+64>>2];s=f;w=f>>31;f=v[a+60>>2];x=f;y=f>>31;while(1){f=e;if(d){e=Ub(f,-16777216,16776704);e=Bia(s,w,e,e>>31);g=ib;j=e;b=Ub(b,-16777216,16776704);e=Bia(q,r,b,b>>31);j=j+e|0;b=ib+g|0;b=e>>>0>j>>>0?b+1|0:b;g=v[h+12>>2]+m|0;e=(v[h+8>>2]>>>16&65520)+l|0;g=(((((((B(t[g-2|0],u[e+2>>1])+B(t[g-3|0],u[e>>1])|0)+B(t[g-1|0],u[e+4>>1])|0)+B(t[g|0],u[e+6>>1])|0)+B(t[g+1|0],u[e+8>>1])|0)+B(t[g+2|0],u[e+10>>1])|0)+B(t[g+3|0],u[e+12>>1])|0)+B(t[g+4|0],u[e+14>>1])<<8)/32768<<8;e=g;e=Bia(e,e>>31,x,y);j=e+j|0;b=ib+b|0;b=e>>>0>j>>>0?b+1|0:b;e=j+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Lc(e,b,24);b=(e|0)/256|0;v[c>>2]=B(b,o)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(b,n);Ob(h+8|0,k,i);e=e-(g&p)|0;c=c+8|0;d=d-1|0;b=f;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=b;v[a+44>>2]=f;fb=h+16|0}function JQ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=fb-16|0;fb=j;a:{if((b|0)==(c|0)){break a}v[j+12>>2]=-1953789045;Pz(b,c,j+12|0);c=c-b|0;e=c>>2;v[j+8>>2]=e;f=sc(v[a>>2],v[a+4>>2]);g=11;b:{if(c>>>0>2488){break b}g=7;if(c>>>0>268){break b}g=5;if(c>>>0>152){break b}g=3;if(c>>>0>24){break b}g=e-1>>>1|0}c=f+1|0;v[j+4>>2]=c;n=v[Sc(j+4|0,j+8|0)>>2];k=e-g>>>1|0;d=(k<<2)+b|0;h=v[d>>2];i=B(ut(v[((e<<2)+b|0)-4>>2]^(h^v[b>>2])),1664525);v[d>>2]=i+h;g=g+k|0;d=(g<<2)+b|0;f=f+i|0;v[d>>2]=f+v[d>>2];v[b>>2]=f;i=v[a>>2];a=1;while(1)if((a|0)==(c|0)){while(1)if(c>>>0>=n>>>0){c=n;while(1){if(e+n>>>0<=c>>>0){break a}d=((c+k>>>0)%(e>>>0)<<2)+b|0;h=v[d>>2];f=(c>>>0)%(e>>>0)|0;i=(f<<2)+b|0;a=B(ut(v[((c-1>>>0)%(e>>>0)<<2)+b>>2]+(h+v[i>>2]|0)|0),1566083941);v[d>>2]=a^h;d=((c+g>>>0)%(e>>>0)<<2)+b|0;a=a-f|0;v[d>>2]=a^v[d>>2];v[i>>2]=a;c=c+1|0;continue}}else{d=((c+k>>>0)%(e>>>0)<<2)+b|0;h=v[d>>2];f=(c>>>0)%(e>>>0)|0;i=(f<<2)+b|0;a=B(ut(v[((c-1>>>0)%(e>>>0)<<2)+b>>2]^(h^v[i>>2])),1664525);v[d>>2]=a+h;d=((c+g>>>0)%(e>>>0)<<2)+b|0;a=a+f|0;v[d>>2]=a+v[d>>2];v[i>>2]=a;c=c+1|0;continue}}else{d=a-1|0;l=((a+k>>>0)%(e>>>0)<<2)+b|0;m=v[l>>2];h=(a>>>0)%(e>>>0)|0;o=(h<<2)+b|0;f=B(ut(v[((d>>>0)%(e>>>0)<<2)+b>>2]^(m^v[o>>2])),1664525);v[l>>2]=f+m;l=((a+g>>>0)%(e>>>0)<<2)+b|0;m=v[l>>2];f=v[zb(i,d)>>2]+(f+h|0)|0;v[l>>2]=f+m;v[o>>2]=f;a=a+1|0;continue}}fb=j+16|0}function hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=fb-48|0;fb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){d=d-1|0;f=((((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&2147483646)<<1)+m|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=u[f+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=v[k>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Bia(w,x,f,f>>31);j=ib;A=e;e=Ub(h,-16777216,16776704);h=Bia(s,t,e,e>>31);f=h+f|0;e=ib+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Ub(i,-16777216,16776704);i=Bia(q,r,f,f>>31);f=j+i|0;e=ib+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Lc(f,e,24);v[A+4>>2]=e-(p&l);v[k>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(n,v[g+12>>2]);Ob(g+16|0,y,z);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=g+48|0}function uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Gb(a);k=Bb(b);v[23220]=0;R(286,h|0,k|0);a=v[23220];v[23220]=0;a:{b:{if((a|0)!=1){a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=t[Vf(b,a)|0];g=e&255;d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(g-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(g-123|0){case 2:m=1;e=i+1|0;f=0;if(d>>>0<=i>>>0){i=e;break d}v[23220]=0;Q(287,h|0,Dd(c,i)|0)|0;g=v[23220];v[23220]=0;i=e;if((g|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;j=e;break d;case 3:f=-1;j:{switch(g-123|0){case 2:f=0;if(d>>>0<=j>>>0){break d}v[23220]=0;Q(287,h|0,Dd(c,j)|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}j=(B(j,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}g=(e|0)!=125;f=-1;e=125;if(g){break d}}f=0;v[23220]=0;Q(288,h|0,e|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b}f=-1}a=a+1|0;continue}break}b=aa(8)|0;v[23220]=0;a=T(105,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){v[23220]=0;U(106,a|0,41972,24);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;ba(b|0);break b}a=P()|0;O()|0}ub(h);S(a|0)}L()}function nY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=fb-16|0;fb=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!v[b>>2]){break a}b=b+4|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=fb-16|0;fb=r;s=$h(r+8|0,v[a+8>>2]);i=f;j=g-f|0;m=0;o=fb-16|0;fb=o;k=v[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=i?j:0;while(1){l=Iw(j>>>0<4?o+12|0:i,v[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}nc(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!v[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){v[e>>2]=k}fb=o+16|0;_h(s);fb=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:v[h>>2]=f;while(1){i:{if(v[e>>2]==(c|0)){break i}b=Zv(f,v[c>>2],v[a+8>>2]);if((b|0)==-1){break i}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;continue}break};v[e>>2]=c;break g;case 1:break c;default:break h}}f=m+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=v[e>>2];b=d;continue}b=Zv(n+12|0,0,v[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-v[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=w[c|0];i=v[h>>2];v[h>>2]=i+1;t[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=v[e>>2]+4|0;v[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!v[b>>2]){break b}b=b+4|0;continue}}c=v[e>>2]}q=(c|0)!=(d|0)}fb=n+16|0;return q|0}f=v[h>>2];continue}}function hN(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-32|0;fb=e;f=v[b+64>>2];a:{b:{h=v[b+60>>2];g=x[b+68>>1];if(!((h|0)==-1&(g|0)==65535)){c:{if((f|0)==-1){break c}f=a+1074312|0;xb(e+24|0,f,68);if(yb(v[v[e+24>>2]>>2],v[e+28>>2])){break c}xb(e+16|0,f,103);if(i=yb(v[v[e+16>>2]>>2],v[e+20>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}xb(e+8|0,f,49);if(i=yb(v[v[e+8>>2]>>2],v[e+12>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}f=v[b+64>>2];break b}if((g|0)==65535){u[b+68>>1]=x[b+72>>1]+1}if((h|0)==-1){v[b+60>>2]=0}g=Ic(v[c>>2],v[c+4>>2]);f=x[b+68>>1];if(g>>>0<=f>>>0){f=x[c+28>>1];u[b+68>>1]=f}d:{if(x[b+72>>1]==(f&65535)){break d}c=a+1074312|0;xb(e+24|0,c,26);if(yb(v[v[e+24>>2]>>2],v[e+28>>2])){break d}xb(e+16|0,c,68);if(yb(v[v[e+16>>2]>>2],v[e+20>>2])|v[a+480180>>2]==1){break d}c=x[a+480188>>1];f=0;while(1){if((c|0)==(f|0)){break d}t[(B(f,872)+b|0)+1457|0]=0;f=f+1|0;continue}}v[b+52>>2]=v[b+60>>2];if(d){c=1;if(w[a+480208|0]&32){break a}}u[b+74>>1]=x[b+68>>1];c=1;break a}if((f|0)!=-1){break b}c=0;break a}v[b+52>>2]=f;u[b+74>>1]=x[b+72>>1];e:{if(!v[b+20>>2]){break e}c=v[a+480180>>2];if((c|0)==32){xb(e+24|0,a+1074312|0,103);if(yb(v[v[e+24>>2]>>2],v[e+28>>2])){break e}c=v[a+480180>>2]}if((c|0)==2){break e}v[b+52>>2]=v[b+52>>2]+1}c=0;if(y[b+64>>2]<y[Xb(v[a+484344>>2],x[b+70>>1])+12>>2]){break a}v[b+52>>2]=0;u[b+74>>1]=x[b+74>>1]+1;c=0}fb=e+32|0;return c}function Laa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0;g=fb-16|0;fb=g;s=v[a+16>>2];u=Zf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){k=v[a+8>>2];l=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];m=0;break a}k=v[a+8>>2];l=v[a+12>>2];o=_f(k,l,n);p=ib;b=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Df(i,e,af(k,l,d),ib);m=b>>>0<ib>>>0?d:0}h=a+112|0;f=v[a+48>>2];w=v[a+24>>2];x=v[a+20>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;m=m-1|0;b=m;o=b?o:0;p=b?p:0;e=e+s|0;b=n;while(1)if((b|0)<=0){Ob(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Hd(h,t[e+v[g+12>>2]|0]<<6);Gd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];b=v[a+60>>2];e=b;j=b>>31;r=Yf(h,u)<<8;b=r;b=Bia(e,j,b,b>>31);y=ib;e=b;b=v[a+64>>2];j=b;z=b>>31;b=Ub(q,-16777216,16776704);j=Bia(j,z,b,b>>31);e=e+j|0;b=ib+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Ub(f,-16777216,16776704);e=Bia(e,e>>31,f,f>>31);f=j+e|0;b=ib+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Lc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(f,x)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(f,w);Ob(g,k,l);b=b-(i&r)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=q;continue b}else{Hd(h,t[e+v[g+12>>2]|0]<<6);Gd(h,4);Ob(g+8|0,o,p);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+48>>2]=f;v[a+44>>2]=q;fb=g+16|0}function ky(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=88;j=92;k=91;l=85;m=84;n=83;o=5;p=113;q=111;r=107;s=106;t=96;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;c=Qq(a);a:{b:{c:{d:{switch(b-1|0){default:a=(b|0)==16777216;if(!a&(b|0)!=32){break c}Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(c,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1);if(!a){break a}d=111;e=105;f=99;break b;case 3:Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(c,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1),67,1);p=112;q=98;r=93;s=90;t=89;u=86;v=76;w=75;x=74;y=73;z=72;A=71;d=70;e=69;g=68;case 1:Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(c,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1);m=88;o=v;n=u;l=t;k=s;j=r;i=q;h=p;break;case 2:break c;case 0:break d}}Kb(Kb(Kb(Kb(c,o,1),n,1),m,1),l,1);g=k;f=j;e=i;d=h}Kb(c,g,1)}Kb(Kb(Kb(c,f,1),e,1),d,1)}}function WH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=fb-16|0;fb=h;g=v[a+32>>2];f=ks(g);if(!f){f=js(g)}a:{b:{c:{if(b>>>0>=f>>>0){b=aa(8)|0;v[23220]=0;c=Q(52,h|0,5961)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}a=qc(b,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ub(c);break b}if(c>>>0>=120){b=aa(8)|0;v[23220]=0;c=Q(52,h|0,11292)|0;a=v[23220];v[23220]=0;if((a|0)!=1){a=qc(b,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ub(c);break b}a=P()|0;O()|0;ba(b|0);break b}f=wy(g,65535);j=(f|0)==65535?255:f;u[h>>1]=j;f=g+B(j,872)|0;i=f+1074992|0;Qn(i,g,65535,1024);c=c+1|0;t[f+1075794|0]=c;t[f+1075791|0]=c;u[f+1075778>>1]=0;Ol(i);wp(v[a+32>>2],i,b+1|0,0,1,1);v[f+1075688>>2]=65536;Ss(v[a+32>>2],i,c,0,1,1,65535);l=f+1075684|0,m=Xl(My(e*128,-128,128)+128),v[l>>2]=m;l=f+1075680|0,m=Xl(My(d*256,0,256)),v[l>>2]=m;c=v[a+32>>2];i=c+1074478|0;b=i;c=b+(x[c+480212>>1]<<1)|0;g=x[h>>1];f=g;while(1){d:{e:{if((b|0)!=(c|0)){if((f|0)!=x[b>>1]){break e}}else{b=c}break d}b=b+2|0;continue}break}f:{if((b|0)==(c|0)){break f}f=b;while(1){f=f+2|0;if((f|0)==(c|0)){c=b;break f}k=x[f>>1];if((k|0)==(g|0)){continue}u[b>>1]=k;b=b+2|0;g=x[h>>1];continue}}l=v[a+32>>2],m=Ty(i,c),u[l+480212>>1]=m;fb=h+16|0;return j|0}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function mha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-80|0;fb=d;b=b&4095;u[d+78>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=fb-16|0;fb=e;f=Qb(e,4412);Mc(d- -64|0,f);vb(f);fb=e+16|0;v[23220]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=Bia(e,e>>31,1e4,0)+14780|0;b=ib;b=Cia(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(B(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;v[d+44>>2]=g+f;R(84,d+48|0,d+44|0);g=v[23220];v[23220]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){v[23220]=0;v[d+28>>2]=(e+B(f,-12)|0)+1;R(86,d+32|0,d+28|0);e=v[23220];v[23220]=0;if((e|0)==1){break j}v[23220]=0;v[d+12>>2]=(((B(b,306)+5|0)/-10|0)+c|0)+1;R(86,d+16|0,d+12|0);b=v[23220];v[23220]=0;if((b|0)==1){break i}v[23220]=0;da(356,a|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}vb(d+16|0);vb(d+32|0);break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(d+16|0)}vb(d+32|0)}vb(d+48|0)}break a}og(d- -64|0,4392);v[23220]=0;R(357,d+48|0,d+78|0);b=v[23220];v[23220]=0;if((b|0)==1){break c}v[23220]=0;U(132,a|0,d- -64|0,d+48|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}}vb(d+48|0);bc(d- -64|0);fb=d+80|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(d+48|0)}bc(d- -64|0);S(b|0);L()}function nO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;c=v[a>>2];a:{if(Tj(c)){h=fb-16|0;fb=h;f=tc(3848);d=f+16|0;while(1){c=d+B(e,44)|0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+36>>2]=0;t[c+42|0]=1;u[c+40>>1]=257;v[c+24>>2]=0;v[c+28>>2]=0;u[c+32>>1]=0;e=e+1|0;if((e|0)!=18){continue}break}d=f+808|0;e=0;while(1){c=d+B(e,84)|0;v[c>>2]=0;v[c+4>>2]=0;v[c+68>>2]=0;v[c+72>>2]=0;v[c+24>>2]=0;v[c+28>>2]=0;u[c+20>>1]=511;v[c+16>>2]=-1;u[c+14>>1]=1;u[c+6>>1]=0;u[c+8>>1]=0;u[c+10>>1]=0;u[c+12>>1]=0;t[c+73|0]=0;t[c+74|0]=0;t[c+75|0]=0;t[c+76|0]=0;t[c+77|0]=0;t[c+78|0]=0;t[c+79|0]=0;t[c+80|0]=0;e=e+1|0;if((e|0)!=36){continue}break}c=0;e=0;v[f+3832>>2]=0;v[f+3836>>2]=0;d=f+3837|0;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;while(1){if((e|0)==36){while(1){if((c|0)==18){b:{c=0;e=0;while(1)if((c|0)==18){while(1){if((e|0)==36){break b}Pn((B(e,84)+f|0)+808|0);e=e+1|0;continue}}else{d=(B(c,44)+f|0)+16|0;j=v[(c<<2)+28912>>2];c:{if(!(!(1<<c&3591)|c>>>0>11)){i=d;d=B(j,84)+f|0;sO(i,d+808|0,d+1060|0,d+1312|0,d+1564|0);break c}i=d;d=B(j,84)+f|0;sO(i,d+808|0,d+1060|0,0,0)}c=c+1|0;continue}}}else{v[(B(c,44)+f|0)+32>>2]=f;c=c+1|0;continue}break}rO(f,b)}else{td((B(e,84)+f|0)+808|0,f);e=e+1|0;continue}break}b=v[uf(h+8|0,f)>>2];fb=h+16|0;v[g+8>>2]=b;b=g+8|0;jA(a,b);$n(b);break a}rO(c,b)}mO(a);fb=g+16|0}function mda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,z=0,A=0,C=0;i=fb-16|0;fb=i;kd(d,32);g=i+8|0;FP(g,w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24),w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24),v[b>>2]);g=fc(g);FP(i,w[a+40|0]|w[a+41|0]<<8|(w[a+42|0]<<16|w[a+43|0]<<24),w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24),v[c>>2]);a=0;g=v[g>>2];if(g-838861>>>0>=4294128436){a=v[fc(i)>>2];v[d>>2]=B(g,320);u[d+34>>1]=1;a:{m=wg(d);if(!m){break a}l=g<<2;e=+(l>>>0);q=+(a>>>0)/e;r=+(g>>>0)/e;s=1/+y[d>>2];t=+y[i>>2];z=+y[i+8>>2];g=0;b:while(1){if((g|0)==(l|0)){break a}n=+(g>>>0);o=0;p=0;a=v[b+20>>2];if(Md(v[b>>2],a)){e=n*r+z;c:{if(e<4294967296&e>=0){f=~~e>>>0;break c}f=0}k=x[b+34>>1];j=Cd(k);h=B(f,j);e=e-+(f>>>0);d:{if(k&1){f=x[a+(h<<1)>>1];a=x[a+(h+j<<1)>>1];break d}f=w[a+h|0]<<8;a=w[a+(h+j|0)|0]<<8}p=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}a=v[c+20>>2];if(Md(v[c>>2],a)){e=n*q+t;e:{if(e<4294967296&e>=0){f=~~e>>>0;break e}f=0}k=x[c+34>>1];j=Cd(k);h=B(f,j);e=e-+(f>>>0);f:{if(k&1){f=x[a+(h<<1)>>1];a=x[a+(h+j<<1)>>1];break f}f=w[a+h|0]<<8;a=w[a+(h+j|0)|0]<<8}o=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}f=0;a=g;while(1)if((f|0)==80){g=g+1|0;continue b}else{e=s*+(a>>>0);A=v[d+20>>2]+(a<<1)|0,C=Gz(p*(1-e)+o*e),u[A>>1]=C;a=a+l|0;f=f+1|0;continue}}}a=(m|0)!=0}fb=i+16|0;return a|0}function ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=fb-48|0;fb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;u=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){d=d-1|0;f=(((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&-2)+m|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=t[e+f|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=v[k>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Bia(w,x,f,f>>31);j=ib;A=e;e=Ub(h,-16777216,16776704);h=Bia(s,u,e,e>>31);f=h+f|0;e=ib+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Ub(i,-16777216,16776704);i=Bia(q,r,f,f>>31);f=j+i|0;e=ib+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Lc(f,e,24);v[A+4>>2]=e-(p&l);v[k>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(n,v[g+12>>2]);Ob(g+16|0,y,z);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}fb=g+48|0}function QA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=fb-16|0;fb=j;a:{if(b&4){break a}c=w[a+14|0];b:{if(c>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|c>>>0<=w[a+13|0]){break a}e=v[a>>2];d=v[a+4>>2];if(ne(e,d)>>>0<=c>>>0){break a}e=x[Gc(e,d,c)>>1];d=Gc(v[a>>2],v[a+4>>2],w[a+14|0]-1|0);c=w[a+14|0];if(x[d>>1]<(e-1|0)){c=x[Gc(v[a>>2],v[a+4>>2],c)>>1]-1&65535;e=Ep(a,c,64,64);d=dc(j+8|0,Yl(Ab(v[a>>2]),w[a+14|0]));k=_n(j,c,e&255);m=fb-32|0;fb=m;c=v[d>>2];d=v[a>>2];c=(Gt(c,Ab(d))<<2)+d|0;h=v[a+4>>2];c:{d:{if(h>>>0<y[Cb(a)>>2]){if((c|0)!=(h|0)){break d}fS(a,k);break c}d=Cb(a);f=cg(m+8|0,Pg(a,sc(v[a>>2],h)+1|0),c-v[a>>2]>>2,d);v[23220]=0;R(719,f|0,k|0);d=v[23220];v[23220]=0;if((d|0)!=1){d=v[f+4>>2];i=f+4|0;Ip(v[a>>2],c,i);e=v[a+4>>2];g=f+8|0;while(1){if((c|0)!=(e|0)){Zn(v[g>>2],x[c>>1]|x[c+2>>1]<<16);v[g>>2]=v[g>>2]+4;c=c+4|0;continue}break}kc(a,i);kc(a+4|0,g);kc(Cb(a),vc(f));v[f>>2]=v[f+4>>2];c=d;bg(f);break c}a=P()|0;O()|0;bg(f);S(a|0);L()}f=fb-16|0;fb=f;i=v[a+4>>2];d=(i-(c+4|0)|0)+c|0;g=ri(f,a,h-d>>2);l=v[g+4>>2];e=d;while(1){if(e>>>0>=h>>>0){hc(g);cq(c,d,i);fb=f+16|0}else{Zn(l,x[e>>1]|x[e+2>>1]<<16);l=l+4|0;v[g+4>>2]=l;e=e+4|0;continue}break}t[c+2|0]=w[k+2|0];u[c>>1]=x[k>>1]}Ab(c);fb=m+32|0;break a}t[a+14|0]=c-1}if((b|0)!=16777216){t[a+17|0]=255}fb=j+16|0}function ufa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+a|0;i=Hb(h,d),j=w[f+4|0]+1|0,t[i|0]=j;i=ac(g,d),j=(w[f+6|0]|w[f+7|0]<<8)+1|0,u[i>>1]=j;d=d+1|0;continue}}f=b+236|0;while(1){if((d|0)==96){break a}g=(d<<2)+a|0;i=ac(f,d+12|0),j=(w[g+6|0]|w[g+7|0]<<8)+1|0,u[i>>1]=j;d=d+1|0;continue}}hA(a+484|0,b+48|0,0);hA(a+590|0,b+68|0,0);hA(a+696|0,b+88|0,5);v[b>>2]=w[a+806|0]|w[a+807|0]<<8;d=t[a+808|0];b:{if((d|0)<0){t[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(t[a|0]&1){t[b+31|0]=d+1;break b}if(!d){break b}t[b+31|0]=d+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=w[a+810|0];break d}d=t[a+809|0];if((d|0)>=0){u[b+28>>1]=(d&255)+1}d=t[a+810|0];if((d|0)<0){break c}}t[b+30|0]=d+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;i=b,j=w[Rb(e+15|0,e+14|0)|0]>>>1|0,v[i+4>>2]=j}c=w[a+813|0]|w[a+814|0]<<8;if(c>>>0<=256){v[b+8>>2]=c;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];u[e+12>>1]=w[a+820|0]|w[a+821|0]<<8;u[e+10>>1]=100;i=b,j=w[Tc(e+12|0,e+10|0)|0],t[i+20|0]=j;u[e+8>>1]=w[a+822|0]|w[a+823|0]<<8;u[e+6>>1]=256;i=b,j=x[Tc(e+8|0,e+6|0)>>1]>>>2|0,t[i+19|0]=j;c=w[a+824|0];um(b,c&127,c>>>7|0);a=w[a+825|0];tm(b,a&127,a>>>7|0);fb=e+16|0}function qY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=fb-16|0;fb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{while(1){c=v[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=t[c|0];j=i&255;d:{if((i|0)>=0){u[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=w[c+1|0];if((i&192)!=128){break a}u[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=w[c+2|0];i=w[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}u[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=w[c+3|0];i=w[c+2|0];c=w[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;u[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;v[a+8>>2]=f+2;u[f+2>>1]=i<<6&960|k&63|56320;b=v[a+12>>2]+4|0}v[a+12>>2]=b;f=v[a+8>>2]+2|0;v[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];fb=a+16|0;return b|0}function Kn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=fb-16|0;fb=d;h=a+1074312|0;xb(d+8|0,h,96);i=b,j=(k=0,l=v[b+660>>2],m=yb(v[v[d+8>>2]>>2],v[d+12>>2]),m?k:l)+c|0,v[i+660>>2]=j;g=v[a+480180>>2];e=v[b+84>>2];if(!(!(g&18)|e>>>0>c>>>0|(!(w[b+88|0]&2)|!e))){f=c;c=v[b+80>>2];c=((f-c>>>0)%(e-c>>>0)|0)+c|0}c=c>>>(v[b+88>>2]&1&(g|0)==16384)|0;a:{b:{if(!Oc(w[b+788|0])){xb(d+8|0,h,114);if(!yb(v[v[d+8>>2]>>2],v[d+12>>2])){break b}}e=v[b+656>>2];c:{if(!e){break c}g=w[b+788|0];if(!Oc(g)){break c}e=x[ac(e+236|0,g-1|0)>>1];if(!e|e>>>0>x[a+480190>>1]){break a}}d:{if(w[a+480210|0]&32){f=c;c=v[b+660>>2];v[b+660>>2]=f+c;f=0;break d}f=0}v[b>>2]=f;v[b+4>>2]=c;if((!(w[b+88|0]&2)|c>>>0<y[b+84>>2])&c>>>0<y[b+76>>2]){break a}xb(d+8|0,h,57);e:{if(!yb(v[v[d+8>>2]>>2],v[d+12>>2])){c=v[a+480180>>2];if((c|0)!=16){break e}}v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break a}if(!(c&1048581)){xb(d+8|0,h,27);if(yb(v[v[d+8>>2]>>2],v[d+12>>2])){if(w[a+480208|0]&4){c=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=c;break a}v[b>>2]=0;v[b+4>>2]=0;break a}c=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=c;if(!(w[a+480208|0]&4)){break a}a=v[b+76>>2];if(a>>>0<5){break a}v[b>>2]=0;v[b+4>>2]=a-2;break a}if(!(w[b+88|0]&2)|(c|0)!=1){break a}c=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=c;break a}if(!(v[a+480180>>2]&268582928)|c>>>0>=y[b+76>>2]){break a}v[b>>2]=0;v[b+4>>2]=c}fb=d+16|0}function Yfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=v[a>>2];b=Kt(c,v[a+4>>2]);if(b>>>0<=63){g=fb-32|0;fb=g;f=64-b|0;c=v[Cb(a)>>2];d=v[a+4>>2];a:{if(f>>>0<=(c-d|0)/33>>>0){b=fb-16|0;fb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+B(f,33);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=b+16|0}else{yA(a);a=a+33|0;v[b+4>>2]=a;continue}break}break a}i=Cb(a);c=g+8|0;h=Kt(v[a>>2],d)+f|0;d=fb-16|0;fb=d;v[d+12>>2]=h;e=fb-16|0;fb=e;v[e+12>>2]=130150524;v[e+8>>2]=2147483647;b=v[Eb(e+12|0,e+8|0)>>2];fb=e+16|0;b:{if(b>>>0>=h>>>0){e=eS(a);if(e>>>0<b>>>1>>>0){v[d+8>>2]=e<<1;b=v[Sc(d+8|0,d+12|0)>>2]}fb=d+16|0;break b}od();L()}e=Kt(v[a>>2],v[a+4>>2]);Gf(c+12|0,i);if(b){if(b>>>0>=130150525){xf(11129);L()}d=tc(B(b,33))}else{d=0}v[c>>2]=d;e=d+B(e,33)|0;v[c+8>>2]=e;v[c+4>>2]=e;j=vc(c),k=d+B(b,33)|0,v[j>>2]=k;b=fb-16|0;fb=b;v[b>>2]=v[c+8>>2];d=v[c+8>>2];v[b+8>>2]=c+8;v[b+4>>2]=d+B(f,33);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){yA(d);d=v[b>>2]+33|0;v[b>>2]=d;continue}break}Ed(b);fb=b+16|0;b=c+4|0;f=v[a>>2];d=v[a+4>>2]-f|0;e=v[b>>2]+B((d|0)/-33|0,33)|0;v[b>>2]=e;if((d|0)>0){nc(e,f,d)}kc(a,b);kc(a+4|0,c+8|0);kc(Cb(a),vc(c));v[c>>2]=v[c+4>>2];b=v[c+4>>2];a=v[c+8>>2];while(1){if((a|0)!=(b|0)){a=a-33|0;v[c+8>>2]=a;continue}break}a=v[c>>2];if(a){vc(c);Fb(a)}}fb=g+32|0;return}if((b|0)!=64){Jd(a,c+2112|0)}}function H_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=C(0);a=fb-368|0;fb=a;v[a+352>>2]=c;v[a+360>>2]=b;dw(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Gb(a+184|0);b=Qc(d);v[23220]=0;R(57,d|0,b|0);b=v[23220];v[23220]=0;a:{b:{c:{if((b|0)!=1){c=Fc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[23220]=0;b=Q(1109,a+360|0,a+352|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+180>>2];b=Bb(d);if((g|0)==(b+c|0)){v[23220]=0;R(57,d|0,b<<1);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Fc(d,0);v[a+180>>2]=b+c}v[23220]=0;b=T(1111,v[a+360>>2])|0;g=v[23220];v[23220]=0;if((g|0)==1){break d}if(cw(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23220]=0;T(1113,a+360|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=VF(c,v[a+180>>2],e),z[j>>2]=k;pf(a+200|0,a+16|0,v[a+12>>2],e);v[23220]=0;b=Q(1110,a+360|0,a+352|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];ub(d);ub(a+200|0);fb=a+368|0;break a}}b=P()|0;O()|0;ub(d);ub(a+200|0);S(b|0);L()}return b|0}function Q_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=C(0);a=fb-272|0;fb=a;v[a+256>>2]=c;v[a+264>>2]=b;hw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Gb(a+192|0);b=Qc(d);v[23220]=0;R(57,d|0,b|0);b=v[23220];v[23220]=0;a:{b:{c:{if((b|0)!=1){c=Fc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=t[a+222|0];i=t[a+223|0];while(1){d:{v[23220]=0;b=Q(1093,a+264|0,a+256|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+188>>2];b=Bb(d);if((g|0)==(b+c|0)){v[23220]=0;R(57,d|0,b<<1);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Fc(d,0);v[a+188>>2]=b+c}v[23220]=0;b=T(1095,v[a+264>>2])|0;g=v[23220];v[23220]=0;if((g|0)==1){break d}if(gw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23220]=0;T(1097,a+264|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=VF(c,v[a+188>>2],e),z[j>>2]=k;pf(a+208|0,a+16|0,v[a+12>>2],e);v[23220]=0;b=Q(1094,a+264|0,a+256|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];ub(d);ub(a+208|0);fb=a+272|0;break a}}b=P()|0;O()|0;ub(d);ub(a+208|0);S(b|0);L()}return b|0}function Mda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;kd(b,2);f=e+16|0;ak(f,2,a+1|0);d=e+32|0;Ac(d,f);ue(b+43|0,d);ub(d);a:{b:{c:{d:{switch(w[a|0]){case 0:f=v[b+4>>2];d=v[b+8>>2];break c;case 2:break b;case 1:break d;default:break a}}d=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);v[b>>2]=d;v[e+32>>2]=w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24);v[e+16>>2]=d-1;d=e+32|0;f=v[Eb(d,e+16|0)>>2];v[b+4>>2]=f;v[e+32>>2]=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);d=v[Eb(d,b)>>2];v[b+8>>2]=d;u[b+34>>1]=x[b+34>>1]&65533|w[a+31|0]<<1&2}if(d>>>0>f>>>0&d>>>0>=2){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}f=e+16|0;zh(f,a+16|0);d=v[e+16>>2];v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);zh(f,a+20|0);d=v[e+16>>2];v[e+36>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);zh(f,a+24|0);d=v[e+16>>2];d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+40>>2]=d;v[e+8>>2]=d;d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;cl(b,1,e)}t[e+32|0]=w[a+28|0];t[e+16|0]=64;g=b,h=w[Rb(e+32|0,e+16|0)|0]<<2,u[g+30>>1]=h;d=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);v[b+24>>2]=d;b=b+24|0;e:{if(!c){break e}if(w[a|0]==2){d=d&65535;v[b>>2]=d;break e}if(y[b>>2]>=65536){v[b>>2]=65535}d=v[b>>2]}f:{g:{if(!d){a=8363;break g}a=1024;if(d>>>0>1023){break f}}v[b>>2]=a}fb=e+48|0}function G_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-368|0;fb=a;v[a+352>>2]=c;v[a+360>>2]=b;dw(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Gb(a+184|0);b=Qc(d);v[23220]=0;R(57,d|0,b|0);b=v[23220];v[23220]=0;a:{b:{c:{if((b|0)!=1){c=Fc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[23220]=0;b=Q(1109,a+360|0,a+352|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+180>>2];b=Bb(d);if((g|0)==(b+c|0)){v[23220]=0;R(57,d|0,b<<1);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Fc(d,0);v[a+180>>2]=b+c}v[23220]=0;b=T(1111,v[a+360>>2])|0;g=v[23220];v[23220]=0;if((g|0)==1){break d}if(cw(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23220]=0;T(1113,a+360|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=TF(c,v[a+180>>2],e),A[j>>3]=k;pf(a+200|0,a+16|0,v[a+12>>2],e);v[23220]=0;b=Q(1110,a+360|0,a+352|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];ub(d);ub(a+200|0);fb=a+368|0;break a}}b=P()|0;O()|0;ub(d);ub(a+200|0);S(b|0);L()}return b|0}
function P_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-272|0;fb=a;v[a+256>>2]=c;v[a+264>>2]=b;hw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Gb(a+192|0);b=Qc(d);v[23220]=0;R(57,d|0,b|0);b=v[23220];v[23220]=0;a:{b:{c:{if((b|0)!=1){c=Fc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=t[a+222|0];i=t[a+223|0];while(1){d:{v[23220]=0;b=Q(1093,a+264|0,a+256|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+188>>2];b=Bb(d);if((g|0)==(b+c|0)){v[23220]=0;R(57,d|0,b<<1);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Fc(d,0);v[a+188>>2]=b+c}v[23220]=0;b=T(1095,v[a+264>>2])|0;g=v[23220];v[23220]=0;if((g|0)==1){break d}if(gw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23220]=0;T(1097,a+264|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=TF(c,v[a+188>>2],e),A[j>>3]=k;pf(a+208|0,a+16|0,v[a+12>>2],e);v[23220]=0;b=Q(1094,a+264|0,a+256|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];ub(d);ub(a+208|0);fb=a+272|0;break a}}b=P()|0;O()|0;ub(d);ub(a+208|0);S(b|0);L()}return b|0}function GH(a){var b=0,c=0,d=0,e=0;oe(v[a+80>>2],v[a+20>>2]);while(1){c=v[a+28>>2];if((b|0)<v[a+24>>2]){oe(v[a+80>>2],v[c+(b<<2)>>2]);b=b+1|0;continue}break}oe(v[a+80>>2],c);a:{if(!v[a+396>>2]){break a}c=0;while(1){if(v[a+264>>2]<=(c|0)){break a}e=v[a+396>>2]+B(c,24)|0;d=v[e+16>>2];if(d){b=0;while(1){if((b|0)<v[(v[a+124>>2]+B(w[e+13|0],2096)|0)+4>>2]){oe(v[a+80>>2],v[(b<<2)+d>>2]);b=b+1|0;d=v[e+16>>2];continue}break}oe(v[a+80>>2],d)}oe(v[a+80>>2],v[e+20>>2]);c=c+1|0;continue}}d=v[a+124>>2];if(d){c=0;while(1){if((c|0)<v[a+120>>2]){b=B(c,2096)+d|0;oe(v[a+80>>2],v[b+8>>2]);oe(v[a+80>>2],v[b+28>>2]);oe(v[a+80>>2],v[b+32>>2]);oe(v[a+80>>2],v[b+2084>>2]);b=v[b+2088>>2];oe(v[a+80>>2],b?b-4|0:0);c=c+1|0;d=v[a+124>>2];continue}break}oe(v[a+80>>2],d)}oe(v[a+80>>2],v[a+260>>2]);oe(v[a+80>>2],v[a+396>>2]);c=v[a+404>>2];if(c){b=0;while(1){if((b|0)<v[a+400>>2]){oe(v[a+80>>2],v[(B(b,40)+c|0)+4>>2]);b=b+1|0;c=v[a+404>>2];continue}break}oe(v[a+80>>2],c)}c=0;b=0;while(1){if(!(v[a+4>>2]<=(b|0)|b>>>0>15)){d=(b<<2)+a|0;oe(v[a+80>>2],v[d+800>>2]);oe(v[a+80>>2],v[d+928>>2]);oe(v[a+80>>2],v[d+996>>2]);b=b+1|0;continue}break}while(1){if((c|0)!=2){b=(c<<2)+a|0;oe(v[a+80>>2],v[b+1068>>2]);oe(v[a+80>>2],v[b+1076>>2]);oe(v[a+80>>2],v[b+1084>>2]);oe(v[a+80>>2],v[b+1092>>2]);oe(v[a+80>>2],v[b+1100>>2]);c=c+1|0;continue}break}}function Naa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;f=fb-16|0;fb=f;s=v[a+16>>2];u=Zf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){k=v[a+8>>2];l=v[a+12>>2];e=v[a>>2];b=v[a+4>>2];m=0;break a}k=v[a+8>>2];l=v[a+12>>2];o=_f(k,l,n);p=ib;g=v[a+76>>2];e=v[a>>2];b=v[a+4>>2];Df(e,b,af(k,l,d),ib);m=g>>>0<ib>>>0?d:0}h=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[f>>2]=e;v[f+4>>2]=b;while(1){if(d){d=d-1|0;v[f+8>>2]=e;v[f+12>>2]=0;m=m-1|0;g=m;o=g?o:0;p=g?p:0;r=(((b&2147483647)<<1|e>>>31)&-2)+s|0;g=n;b:{c:while(1){d:{if((g|0)<=0){Ob(h,v[a+120>>2],v[a+124>>2]);g=v[a+116>>2];if(!g){break b}q=((v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31)&-2;e=0;b=0;break d}q=((v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31)&-2;b=0;e=0;while(1)if((b|0)==2){Hd(h,(e|0)/8<<16>>16);Gd(h,4);Ob(f+8|0,o,p);g=g-1|0;continue c}else{e=(t[(b+q|0)+r|0]<<8)+e|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){e=(t[(b+q|0)+r|0]<<8)+e|0;b=b+1|0;continue}break}Hd(h,(e|0)/8<<16>>16);Gd(h,g);v[h>>2]=v[h>>2];v[h+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;g=Yf(h,u);v[c>>2]=B(j>>12,g)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(g,i>>12);Ob(f,k,l);c=c+8|0;e=v[f>>2];b=v[f+4>>2];continue}break}v[a>>2]=e;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;fb=f+16|0}function _O(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-240|0;fb=e;if(!w[93040]){if(!w[92916]){c=fb-16|0;fb=c;Gb(92892);v[23226]=0;t[92908]=0;v[23228]=0;v[23220]=0;b=ha(26)|0;a=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{if((a|0)!=1){v[c+8>>2]=b;b=c+8|0;Jt(92904,Ud(b));qS(b);t[92908]=0;break f}a=Da(91480,92052)|0;b=O()|0;if((ea(91480)|0)==(b|0)){_(a|0)|0;v[23220]=0;Z(27);c=v[23220];v[23220]=0;if((c|0)==1){break d}L()}if((ea(92052)|0)!=(b|0)){break c}_(a|0)|0;v[23220]=0;t[92908]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)==1){a=P()|0;O()|0;break c}if(w[92908]){break e}}v[23220]=0;Y(28,92888);b=v[23220];v[23220]=0;if((b|0)!=1){break e}a=P()|0;O()|0;break c}fb=c+16|0;break a}a=P()|0;O()|0;v[23220]=0;Z(17);c=v[23220];v[23220]=0;if((c|0)==1){break b}}$n(92912);qS(92904);ub(92892);S(a|0);L()}V(0)|0;O()|0;Tb();L()}t[92916]=1}c=fb+-64|0;fb=c;b=c+16|0;g=fb-16|0;fb=g;h=WO(g+8|0);j=e+120|0;while(1){if((i|0)==12){fb=g+16|0}else{f=fb-48|0;fb=f;a=v[h+4>>2];d=v[h>>2];g:{if((a|0)==(d|0)){break g}a=(a-d|0)+1|0;if(!a){a=UO(VO(f+8|0,32));break g}d=E(a);d=VO(f+8|0,(a<<d+1?32:31)-d|0);while(1){k=UO(d);if(a>>>0<=k>>>0){continue}break}a=v[h>>2]+k|0}fb=f+48|0;l=zb(b,i),m=a,v[l>>2]=m;i=i+1|0;continue}break}b=YO(c,b,ZO(b));XO(j,b);bm(b);fb=c- -64|0;nc(92920,nc(e,j,120),116);t[93040]=1}fb=e+240|0}function E3(a){a=a|0;var b=0,c=0,d=0,e=0;e=fb-160|0;fb=e;d=Qb(e,11574);v[23220]=0;b=d+12|0;Q(52,b|0,10912)|0;c=v[23220];v[23220]=0;a:{b:{if((c|0)==1){break a}v[23220]=0;b=d+24|0;Q(52,b|0,11404)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}v[23220]=0;b=d+36|0;Q(52,b|0,10904)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}v[23220]=0;b=d+48|0;Q(52,b|0,8230)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}v[23220]=0;b=d+60|0;Q(52,b|0,10889)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}v[23220]=0;b=d+72|0;Q(52,b|0,8296)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}v[23220]=0;b=d+84|0;Q(52,b|0,5581)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}v[23220]=0;b=d+96|0;Q(52,b|0,11978)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}v[23220]=0;b=d+108|0;Q(52,b|0,11347)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}v[23220]=0;b=d+120|0;Q(52,b|0,12179)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}v[23220]=0;b=d+132|0;Q(52,b|0,5433)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}v[23220]=0;b=d+144|0;Q(52,b|0,7253)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}v[23220]=0;W(985,a|0,d|0,13)|0;a=v[23220];v[23220]=0;if((a|0)==1){break b}b=d+156|0;while(1){b=ub(b-12|0);if((d|0)!=(b|0)){continue}break}fb=e+160|0;return}b=d+156|0}a=P()|0;O()|0;while(1){b=ub(b-12|0);if((d|0)!=(b|0)){continue}break}S(a|0);L()}function K_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=fb-352|0;fb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Si(d);i=Wo(d,a+224|0);Vo(a+208|0,d,a+332|0);d=Gb(a+192|0);c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;a:{b:{c:{if((c|0)!=1){c=Fc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23220]=0;g=Q(1109,a+344|0,a+336|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Bb(d);if((h|0)==(g+c|0)){v[23220]=0;R(57,d|0,g<<1);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Fc(d,0);v[a+188>>2]=g+c}v[23220]=0;g=T(1111,v[a+344>>2])|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(Vm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23220]=0;T(1113,a+344|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=_F(c,v[a+188>>2],e,b),v[k>>2]=l;v[f+4>>2]=ib;pf(a+208|0,a+16|0,v[a+12>>2],e);v[23220]=0;b=Q(1110,a+344|0,a+336|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];ub(d);ub(a+208|0);fb=a+352|0;break a}}b=P()|0;O()|0;ub(d);ub(a+208|0);S(b|0);L()}return b|0}function I_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=fb-352|0;fb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Si(d);i=Wo(d,a+224|0);Vo(a+208|0,d,a+332|0);d=Gb(a+192|0);c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;a:{b:{c:{if((c|0)!=1){c=Fc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23220]=0;g=Q(1109,a+344|0,a+336|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Bb(d);if((h|0)==(g+c|0)){v[23220]=0;R(57,d|0,g<<1);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Fc(d,0);v[a+188>>2]=g+c}v[23220]=0;g=T(1111,v[a+344>>2])|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(Vm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23220]=0;T(1113,a+344|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=WF(c,v[a+188>>2],e,b),v[k>>2]=l;v[f+4>>2]=ib;pf(a+208|0,a+16|0,v[a+12>>2],e);v[23220]=0;b=Q(1110,a+344|0,a+336|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];ub(d);ub(a+208|0);fb=a+352|0;break a}}b=P()|0;O()|0;ub(d);ub(a+208|0);S(b|0);L()}return b|0}function cea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[Cb(a)>>2]){c=fb-16|0;fb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+56;a=v[c+4>>2];v[23220]=0;R(620,a|0,b|0);a=v[23220];v[23220]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+56;hc(c);fb=c+16|0;break a}a=P()|0;O()|0;hc(c);S(a|0);L()}return}h=fb-32|0;fb=h;i=Cb(a);f=h+8|0;g=Lp(v[a>>2],v[a+4>>2])+1|0;d=fb-16|0;fb=d;v[d+12>>2]=g;e=fb-16|0;fb=e;v[e+12>>2]=76695844;v[e+8>>2]=2147483647;c=v[Eb(e+12|0,e+8|0)>>2];fb=e+16|0;b:{if(c>>>0>=g>>>0){e=EQ(a);if(e>>>0<c>>>1>>>0){v[d+8>>2]=e<<1;c=v[Sc(d+8|0,d+12|0)>>2]}fb=d+16|0;break b}od();L()}e=Lp(v[a>>2],v[a+4>>2]);Gf(f+12|0,i);if(c){if(c>>>0>=76695845){xf(11129);L()}d=tc(B(c,56))}else{d=0}v[f>>2]=d;e=d+B(e,56)|0;v[f+8>>2]=e;v[f+4>>2]=e;j=vc(f),k=d+B(c,56)|0,v[j>>2]=k;c=v[f+8>>2];v[23220]=0;R(620,c|0,b|0);b=v[23220];v[23220]=0;c:{if((b|0)!=1){v[f+8>>2]=v[f+8>>2]+56;e=v[a>>2];b=v[a+4>>2];d=f+4|0;while(1){if((b|0)!=(e|0)){b=b-56|0;c=Wj(v[d>>2]-56|0,b);Wj(c+12|0,b+12|0);Nz(c+24|0,b+24|0);u[c+52>>1]=x[b+52>>1];g=v[b+48>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=g;g=v[b+40>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=g;v[d>>2]=v[d>>2]-56;continue}break}kc(a,d);kc(a+4|0,f+8|0);kc(Cb(a),vc(f));v[f>>2]=v[f+4>>2];DQ(f);fb=h+32|0;break c}a=P()|0;O()|0;DQ(f);S(a|0);L()}}function xca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=fb-48|0;fb=d;l=a+480190|0;c=x[l>>1];t[d+32|0]=0;TN(b,c+1|0,d+32|0);a:{j=a+480192|0;if(!x[j>>1]){break a}h=Ib(d+32|0);p=d,q=Ab(v[a+484344>>2]),v[p+24>>2]=q;o=Ab(v[a+484348>>2]);m=a+480188|0;while(1){i=v[d+24>>2];if(!Nb(i,o)){c=x[a+480190>>1];while(1)if(c){xb(d+8|0,v[b>>2],c);if(!yb(v[v[d+8>>2]>>2],v[d+12>>2])){e=f;f=B(c,104)+a|0;f=e+Md(v[f+484380>>2],v[f+484400>>2])|0}c=c-1|0;continue}else{$b(h);break a}}b:{if(!Nb(v[i>>2],v[i+4>>2])){break b}c=x[m>>1];v[23220]=0;t[d+8|0]=0;U(718,h|0,c|0,d+8|0);c=v[23220];v[23220]=0;if((c|0)!=1){p=d,q=Ab(v[i>>2]),v[p+16>>2]=q;k=0;c:while(1){f=0;if(y[i+12>>2]<=k>>>0){break b}while(1){if(x[m>>1]<=f>>>0){k=k+1|0;continue c}d:{c=v[d+16>>2];if(!Oc(w[c|0])){break d}e:{f:{c=w[c+1|0];if(c){g=x[j>>1];break f}g=x[j>>1];c=w[Hb(v[h>>2],f)|0];if(c){break f}c=1;break e}p=Hb(v[h>>2],f),q=c,t[p|0]=q;g=g&65535;e=g>>>0<c>>>0;g=e?g:c;c=e?1:c}while(1){e=c&65535;if(e>>>0>(g&65535)>>>0){break d}e=v[((e<<2)+a|0)+900380>>2];g:{if(!e){break g}e=x[ac(e+236|0,w[v[d+16>>2]]-1|0)>>1];if(e>>>0>x[l>>1]){break g}n=d+8|0;xb(n,v[b>>2],e);sg(n,1)}c=c+1|0;continue}}f=f+1|0;Vz(d+16|0);continue}}}a=P()|0;O()|0;$b(h);S(a|0);L()}_L(d+24|0);continue}}fb=d+48|0;return f&65535}function Bga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=fb-16|0;fb=i;c=bf(a,c);Yd(i,v[a+28>>2]);a:{if(!c){if(cd(a,5)){break a}}e=fb-160|0;fb=e;g=yl(e+56|0,v[a+28>>2]);v[23220]=0;f=Q(404,e+40|0,43971)|0;d=v[23220];v[23220]=0;b:{c:{d:{e:{if((d|0)!=1){v[23220]=0;v[e+24>>2]=19923968;v[e+28>>2]=0;U(405,g|0,f|0,e+24|0);d=v[23220];v[23220]=0;if((d|0)==1){break e}Pb(f);if(!(w[g+3|0]&64)){break d}break b}d=P()|0;O()|0;break c}d=P()|0;O()|0;Pb(f);break c}k=e,l=lf(v[b>>2],v[b+4>>2]),u[k+38>>1]=l;u[e+36>>1]=65535;v[23220]=0;f=Q(404,e+24|0,10066)|0;d=v[23220];v[23220]=0;f:{if((d|0)!=1){v[23220]=0;d=W(434,g|0,e+36|0,f|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break f}Pb(f);if((d|0)!=1){u[e+38>>1]=x[e+36>>1]}qg(e+38|0,4e3);f=x[e+38>>1];g:{if(lf(v[b>>2],v[b+4>>2])>>>0>=f>>>0){break g}v[23220]=0;R(212,b|0,f|0);d=v[23220];v[23220]=0;if((d|0)!=1){break g}d=P()|0;O()|0;break c}d=0;h:{while(1){if((d|0)==(f|0)){break b}h=v[b>>2];v[23220]=0;R(435,e+8|0,d|0);j=v[23220];v[23220]=0;if((j|0)!=1){v[23220]=0;X(436,g|0,Xb(h,d)|0,e+8|0,437);h=v[23220];v[23220]=0;if((h|0)==1){break h}d=d+1|0;Pb(e+8|0);continue}break}d=P()|0;O()|0;break c}d=P()|0;O()|0;Pb(e+8|0);break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;Pb(f)}Ug(g);S(d|0);L()}Ug(g);fb=e+160|0;e=c}We(a,e);fb=i+16|0}function NF(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=fb-352|0;fb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Si(d);i=Wo(d,a+224|0);Vo(a+208|0,d,a+332|0);d=Gb(a+192|0);c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;a:{b:{c:{if((c|0)!=1){c=Fc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23220]=0;g=Q(1109,a+344|0,a+336|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Bb(d);if((h|0)==(g+c|0)){v[23220]=0;R(57,d|0,g<<1);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Fc(d,0);v[a+188>>2]=g+c}v[23220]=0;g=T(1111,v[a+344>>2])|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(Vm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23220]=0;T(1113,a+344|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=XF(c,v[a+188>>2],e,b),v[k>>2]=l;pf(a+208|0,a+16|0,v[a+12>>2],e);v[23220]=0;b=Q(1110,a+344|0,a+336|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];ub(d);ub(a+208|0);fb=a+352|0;break a}}b=P()|0;O()|0;ub(d);ub(a+208|0);S(b|0);L()}return b|0}function L_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=fb-352|0;fb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Si(d);i=Wo(d,a+224|0);Vo(a+208|0,d,a+332|0);d=Gb(a+192|0);c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;a:{b:{c:{if((c|0)!=1){c=Fc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23220]=0;g=Q(1109,a+344|0,a+336|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Bb(d);if((h|0)==(g+c|0)){v[23220]=0;R(57,d|0,g<<1);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Fc(d,0);v[a+188>>2]=g+c}v[23220]=0;g=T(1111,v[a+344>>2])|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(Vm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23220]=0;T(1113,a+344|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=$F(c,v[a+188>>2],e,b),v[k>>2]=l;pf(a+208|0,a+16|0,v[a+12>>2],e);v[23220]=0;b=Q(1110,a+344|0,a+336|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];ub(d);ub(a+208|0);fb=a+352|0;break a}}b=P()|0;O()|0;ub(d);ub(a+208|0);S(b|0);L()}return b|0}function J_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=fb-352|0;fb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Si(d);i=Wo(d,a+224|0);Vo(a+208|0,d,a+332|0);d=Gb(a+192|0);c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;a:{b:{c:{if((c|0)!=1){c=Fc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23220]=0;g=Q(1109,a+344|0,a+336|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Bb(d);if((h|0)==(g+c|0)){v[23220]=0;R(57,d|0,g<<1);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Fc(d,0);v[a+188>>2]=g+c}v[23220]=0;g=T(1111,v[a+344>>2])|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(Vm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23220]=0;T(1113,a+344|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=ZF(c,v[a+188>>2],e,b),u[k>>1]=l;pf(a+208|0,a+16|0,v[a+12>>2],e);v[23220]=0;b=Q(1110,a+344|0,a+336|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];ub(d);ub(a+208|0);fb=a+352|0;break a}}b=P()|0;O()|0;ub(d);ub(a+208|0);S(b|0);L()}return b|0}function rY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=fb-16|0;fb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;c=v[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=x[c>>1];c:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<=0){break a}v[a+8>>2]=c+1;t[c|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break e}if((g-v[a+8>>2]|0)<4){break a}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;t[f|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;continue}break}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];fb=a+16|0;return f|0}function ie(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0),k=0;f=(p(b),j(2));d=XE(f);a:{b:{c:{d:{c=(p(a),j(2));e:{if(c-2139095040>>>0>=2164260864){if(d){break e}break c}if(!d){break d}}i=C(1);if((c|0)==1065353216){break b}e=f<<1;if(!e){break b}d=e>>>0<4278190081;e=c<<1;a=C(a+b);if(!(d&e>>>0<=4278190080)){break a}if((e|0)==2130706432){break b}a=((f^-1)>>>31|0)==(e>>>0<2130706432|0)?C(0):C(b*b);break a}if(XE(c)){i=C(a*a);if((c|0)<0){i=(WE(f)|0)==1?C(-i):i}if((f|0)>=0){break b}a=lH(C(C(1)/i));break a}if((c|0)<0){e=WE(f);if(!e){a=DJ(a);break a}c=c&2147483647;e=((e|0)==1)<<16}if(c>>>0>8388607){break c}c=((p(C(a*C(8388608))),j(2))&2147483647)-192937984|0}f=c-1060306944|0;d=f>>>15&240;g=+(l(2,c-(f&-8388608)|0),q())*A[d+92096>>3]+-1;h=g*g;h=((g*.288457581109214+-.36092606229713164)*(h*h)+((g*.480898481472577+-.7213474675006291)*h+(g*1.4426950408774342+(A[d+92104>>3]+ +(f>>23)))))*+b;o(+h);d=j(1)|0;j(0)|0;f:{d=d&2147450880;if((d|0)==1079967744|d>>>0<1079967744){break f}if(h>127.99999995700433){a=HD(e);break a}if(!(h<=-150)){break f}a=kD(e);break a}k=h;g=A[160];h=g+h;g=k-(h-g);k=(A[161]*g+A[162])*(g*g)+(A[163]*g+1);o(+h);j(1)|0;c=j(0)|0;f=e+c|0;f=f<<15;d=((c&31)<<3)+1024|0;e=v[d>>2];c=e;d=v[d+4>>2]+f|0;l(0,c|0);l(1,(c>>>0<c>>>0?d+1|0:d)|0);i=C(k*+n())}a=i}return a}function T_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-240|0;fb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Si(d);Xo(a+208|0,d,a+223|0);d=Gb(a+192|0);c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;a:{b:{c:{if((c|0)!=1){c=Fc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23220]=0;g=Q(1093,a+232|0,a+224|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Bb(d);if((h|0)==(g+c|0)){v[23220]=0;R(57,d|0,g<<1);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Fc(d,0);v[a+188>>2]=g+c}v[23220]=0;g=T(1095,v[a+232>>2])|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(Xm(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,82816)){break c}v[23220]=0;T(1097,a+232|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=_F(c,v[a+188>>2],e,b),v[j>>2]=k;v[f+4>>2]=ib;pf(a+208|0,a+16|0,v[a+12>>2],e);v[23220]=0;b=Q(1094,a+232|0,a+224|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];ub(d);ub(a+208|0);fb=a+240|0;break a}}b=P()|0;O()|0;ub(d);ub(a+208|0);S(b|0);L()}return b|0}function R_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-240|0;fb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Si(d);Xo(a+208|0,d,a+223|0);d=Gb(a+192|0);c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;a:{b:{c:{if((c|0)!=1){c=Fc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23220]=0;g=Q(1093,a+232|0,a+224|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Bb(d);if((h|0)==(g+c|0)){v[23220]=0;R(57,d|0,g<<1);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Fc(d,0);v[a+188>>2]=g+c}v[23220]=0;g=T(1095,v[a+232>>2])|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(Xm(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,82816)){break c}v[23220]=0;T(1097,a+232|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=WF(c,v[a+188>>2],e,b),v[j>>2]=k;v[f+4>>2]=ib;pf(a+208|0,a+16|0,v[a+12>>2],e);v[23220]=0;b=Q(1094,a+232|0,a+224|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];ub(d);ub(a+208|0);fb=a+240|0;break a}}b=P()|0;O()|0;ub(d);ub(a+208|0);S(b|0);L()}return b|0}function Xaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;h=fb-16|0;fb=h;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+32>>2];o=v[a+28>>2];p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){b=e;if(d){e=Ub(b,-16777216,16776704);e=Bia(s,t,e,e>>31);g=ib;f=Ub(f,-16777216,16776704);k=Bia(q,r,f,f>>31);e=k+e|0;f=ib+g|0;f=e>>>0<k>>>0?f+1|0:f;A=e;e=(v[h+12>>2]<<1)+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(u[e+4>>1],u[g+10>>1])+B(u[e+2>>1],u[g+8>>1])|0)+B(u[e+6>>1],u[g+12>>1])|0)+B(u[e+8>>1],u[g+14>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+2>>1])+B(u[e-6>>1],u[g>>1])|0)+B(u[e-2>>1],u[g+4>>1])|0)+B(u[e>>1],u[g+6>>1])|0)/2|0)|0)/16384<<8;e=g;k=Bia(e,e>>31,w,x);e=A+k|0;f=ib+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Lc(e,f,24);e=(f|0)/256|0;j=j+o|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+n|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Ob(h+8|0,y,z);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;fb=h+16|0}function jK(a){var b=0,c=C(0),d=0,e=0,f=0,g=C(0),h=0,i=0,k=C(0),m=0,n=0,o=C(0);d=fb-16|0;fb=d;b=v[v[a+16>>2]+24620>>2];e=a+4208|0;n=a,o=ie(C(10),C(C(C(z[zb(e,0)>>2]*C(120))+C(-60))/C(20))),z[n+4232>>2]=o;k=C(C(b>>>0)/C(1e3));n=a,o=ie(C(10),C(C(-1)/C(k*C(C(z[zb(e,1)>>2]*C(499.989990234375))+C(.009999999776482582))))),z[n+4236>>2]=o;n=a,o=ie(C(10),C(C(-1)/C(k*C(C(z[zb(e,2)>>2]*C(2950))+C(50))))),z[n+4240>>2]=o;v[d+12>>2]=1325400064;c=C(ie(C(10),C(C(C(z[zb(e,3)>>2]*C(60))+C(-60))/C(20)))*C(2147483648));b=(p(c),j(2));g=C(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){f=b<<1;if(!f){b=fb-16|0;z[b+12>>2]=-1;g=C(z[b+12>>2]/C(0));break a}if((b|0)==2139095040){break b}if(!(f>>>0<4278190080&(b|0)>=0)){g=DJ(c);break a}b=(p(C(c*C(8388608))),j(2))-192937984|0}f=b-1060306944|0;h=f>>>15&240;i=+(l(2,b-(f&-8388608)|0),q())*A[h+3568>>3]+-1;m=i*i;c=C((A[479]*m+(A[480]*i+A[481]))*m+(+(f>>23)*A[478]+A[h+3576>>3]+i))}g=c}z[d+8>>2]=C(C(g*C(67108864))/C(.6931471824645996))+C(67108864);n=a,o=C(z[Hl(d+12|0,d+8|0)>>2]*C(4.656612873077393e-10)),z[n+4244>>2]=o;n=a,o=C(C(C(-1)/C(C(z[zb(e,4)>>2]*C(99))+C(1)))+C(1)),z[n+4248>>2]=o;c=C(C(C(z[zb(e,5)>>2]*C(4))*k)+C(2));c:{if(C(D(c))<C(2147483648)){h=~~c;break c}h=-2147483648}v[a+4252>>2]=h;fb=d+16|0}function EV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=fb-1088|0;fb=f;a=xh(a);Sb(a+20|0,0,1040);v[a+1064>>2]=0;v[a+1068>>2]=0;v[a+1060>>2]=c;t[a+1084|0]=d;d=a+1072|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1080>>2]=0;i=a+1064|0;d=c;a:{b:{c:while(1){if(Cd(x[d+34>>1])>>>0<=g>>>0){break a}v[a+1064>>2]=0;v[a+1068>>2]=0;d=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(y[c>>2]<=d>>>0){break j}d=v[b+8>>2];e=v[b>>2];v[23220]=0;d=W(143,e|0,d|0,2)|0;e=v[23220];v[23220]=0;if((e|0)==1){break i}if(!d){break j}v[23220]=0;d=T(181,b|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break h}if(!d){break e}v[23220]=0;U(177,f|0,b|0,d|0);d=v[23220];v[23220]=0;if((d|0)==1){break g}d=Yq(f+24|0,f);e=Yc(a,d);nc(e+20|0,d+20|0,1040);wb(d);wb(f);v[a+1076>>2]=0;v[a+1080>>2]=0;h=v[a+1060>>2];d=v[h+20>>2];if(ym(x[h+34>>1])>>>0>=2){v[23220]=0;R(182,e|0,d+(g<<1)|0);d=v[23220];v[23220]=0;if((d|0)!=1){break e}break f}v[23220]=0;R(183,e|0,d+g|0);d=v[23220];v[23220]=0;if((d|0)==1){break f}break e}g=g+1|0;d=v[a+1060>>2];continue c}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=V(30480)|0;if((O()|0)!=(ea(30480)|0)){break b}_(d|0)|0;v[23220]=0;Z(17);d=v[23220];v[23220]=0;if((d|0)==1){break d}}d=v[i>>2];continue}break}break}d=P()|0;O()|0}wb(a);S(d|0);L()}fb=f+1088|0;return a|0}function r_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=fb-16|0;fb=k;l=yw(g);g=fw(g);Gg(k,g);a:{b:{if(ze(k)){v[23220]=0;X(1116,l|0,a|0,c|0,d|0);g=v[23220];v[23220]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[23220]=0;j=Q(1122,l|0,h<<24>>24)|0;h=v[23220];v[23220]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[23220]=0;h=Q(1122,l|0,48)|0;i=v[23220];v[23220]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[23220]=0;h=Q(1122,l|0,h|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}ul(j,c);i=0;v[23220]=0;o=T(1114,g|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){ur((j-a<<2)+d|0,v[f>>2]);g=v[f>>2];break a}e:{if(!w[Fc(k,h)|0]){break e}if(t[Fc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=o;h=(Bb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[23220]=0;n=Q(1122,l|0,n|0)|0;m=v[23220];v[23220]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+4;v[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;O()|0;ub(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;ub(k);fb=k+16|0}function YF(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-240|0;fb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Si(d);Xo(a+208|0,d,a+223|0);d=Gb(a+192|0);c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;a:{b:{c:{if((c|0)!=1){c=Fc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23220]=0;g=Q(1093,a+232|0,a+224|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Bb(d);if((h|0)==(g+c|0)){v[23220]=0;R(57,d|0,g<<1);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Fc(d,0);v[a+188>>2]=g+c}v[23220]=0;g=T(1095,v[a+232>>2])|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(Xm(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,82816)){break c}v[23220]=0;T(1097,a+232|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=XF(c,v[a+188>>2],e,b),v[j>>2]=k;pf(a+208|0,a+16|0,v[a+12>>2],e);v[23220]=0;b=Q(1094,a+232|0,a+224|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];ub(d);ub(a+208|0);fb=a+240|0;break a}}b=P()|0;O()|0;ub(d);ub(a+208|0);S(b|0);L()}return b|0}function U_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-240|0;fb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Si(d);Xo(a+208|0,d,a+223|0);d=Gb(a+192|0);c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;a:{b:{c:{if((c|0)!=1){c=Fc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23220]=0;g=Q(1093,a+232|0,a+224|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Bb(d);if((h|0)==(g+c|0)){v[23220]=0;R(57,d|0,g<<1);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Fc(d,0);v[a+188>>2]=g+c}v[23220]=0;g=T(1095,v[a+232>>2])|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(Xm(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,82816)){break c}v[23220]=0;T(1097,a+232|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=$F(c,v[a+188>>2],e,b),v[j>>2]=k;pf(a+208|0,a+16|0,v[a+12>>2],e);v[23220]=0;b=Q(1094,a+232|0,a+224|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];ub(d);ub(a+208|0);fb=a+240|0;break a}}b=P()|0;O()|0;ub(d);ub(a+208|0);S(b|0);L()}return b|0}function S_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-240|0;fb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Si(d);Xo(a+208|0,d,a+223|0);d=Gb(a+192|0);c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;a:{b:{c:{if((c|0)!=1){c=Fc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23220]=0;g=Q(1093,a+232|0,a+224|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Bb(d);if((h|0)==(g+c|0)){v[23220]=0;R(57,d|0,g<<1);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Qc(d);v[23220]=0;R(57,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}c=Fc(d,0);v[a+188>>2]=g+c}v[23220]=0;g=T(1095,v[a+232>>2])|0;h=v[23220];v[23220]=0;if((h|0)==1){break d}if(Xm(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,82816)){break c}v[23220]=0;T(1097,a+232|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=ZF(c,v[a+188>>2],e,b),u[j>>1]=k;pf(a+208|0,a+16|0,v[a+12>>2],e);v[23220]=0;b=Q(1094,a+232|0,a+224|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];ub(d);ub(a+208|0);fb=a+240|0;break a}}b=P()|0;O()|0;ub(d);ub(a+208|0);S(b|0);L()}return b|0}function vH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=C(0);d=(b<<2)+a|0;h=d+1068|0;k=c<<1&-4;p=h,q=_d(a,k),v[p>>2]=q;g=d+1076|0;p=g,q=_d(a,k),v[p>>2]=q;i=_d(a,c&-4);v[d+1084>>2]=i;a:{h=v[h>>2];if(!h){break a}g=v[g>>2];if(!g|!i){break a}d=c>>2;o=(d|0)>0?d:0;j=C(c|0);d=0;while(1){if((e|0)==(o|0)){d=0;e=c>>3;h=(e|0)>0?e:0;e=0;while(1){if((d|0)!=(h|0)){g=e|1;f=+C(C(C(g<<1)*C(3.1415927410125732))/j);p=i+(e<<2)|0,r=C(Me(f)),z[p>>2]=r;p=i+(g<<2)|0,r=C(-C(qi(f))),z[p>>2]=r;e=e+2|0;d=d+1|0;continue}break}}else{l=d<<2;f=+C(C(C(e<<2)*C(3.1415927410125732))/j);p=h+l|0,r=C(Me(f)),z[p>>2]=r;m=d|1;n=m<<2;p=h+n|0,r=C(-C(qi(f))),z[p>>2]=r;f=+C(C(C(C(m|0)*C(3.1415927410125732))/j)*C(.5));p=g+l|0,r=C(C(Me(f))*C(.5)),z[p>>2]=r;p=g+n|0,r=C(C(qi(f))*C(.5)),z[p>>2]=r;d=d+2|0;e=e+1|0;continue}break}i=(b<<2)+a|0;d=_d(a,k);v[i+1092>>2]=d;if(!d){break a}b=0;e=c>>1;k=(e|0)>0?e:0;f=+(e|0);while(1){if((b|0)!=(k|0)){j=C(qi((+(b|0)+.5)/f*.5*3.1415927410125732));p=d+(b<<2)|0,r=C(qi(+C(j*j)*1.5707963705062866)),z[p>>2]=r;b=b+1|0;continue}break}b=_d(a,c>>2&-2);v[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-El(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=Cl(a)>>>c<<2,u[p>>1]=q;a=a+1|0;continue}break}return 1}Zb(a,3);return 0}function Yaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0;h=fb-16|0;fb=h;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+32>>2];o=v[a+28>>2];p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){e=Ub(b,-16777216,16776704);e=Bia(s,w,e,e>>31);g=ib;f=Ub(f,-16777216,16776704);k=Bia(q,r,f,f>>31);e=k+e|0;f=ib+g|0;f=e>>>0<k>>>0?f+1|0:f;C=e;e=v[h+12>>2]+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(t[e+2|0],u[g+10>>1])+B(t[e+1|0],u[g+8>>1])|0)+B(t[e+3|0],u[g+12>>1])|0)+B(t[e+4|0],u[g+14>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+2>>1])+B(t[e-3|0],u[g>>1])|0)+B(t[e-1|0],u[g+4>>1])|0)+B(t[e|0],u[g+6>>1])<<8)/2|0)|0)/16384<<8;e=g;k=Bia(e,e>>31,x,y);e=C+k|0;f=ib+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Lc(e,f,24);e=(f|0)/256|0;j=j+o|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+n|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Ob(h+8|0,z,A);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;fb=h+16|0}function Lg(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;v[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=v[a+480180>>2];if(!em(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=x[((B(a,-12)+e&255)<<1)+33408>>1]<<4>>>a|0;break a}if(!d){v[f+12>>2]=8363;d=8363}if(cj(a)){a=((e&255)>>>0)/12|0;b=Bia(v[(B(a,-12)+e<<6&960)+37296>>2]<<a,0,d,0);a=ib;c=a>>>21|0;h=f,i=Pc((a&2097151)<<11|b>>>21,c),v[h>>2]=i;uc(f,2147483647);e=v[f>>2];break a}if(w[a+480208|0]&16){a=e&255;e=x[((a>>>0)%12<<1)+33408>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;uc(f+12|0,-1>>>a|0);e=Pc(Eia(Bia(x[((B(a,-12)+e&255)<<1)+33408>>1],0,267616,0),ib,v[f+12>>2]<<a,0),ib);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{xb(f,a+1074312|0,76);b=yb(v[v[f>>2]>>2],v[f+4>>2])?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;e=(a|0)>1?a:1;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(B(c,-12)+a<<3&248)|0;v[f>>2]=d+8;ee(f,0,103);a=b>>31;b=(a^b)-a&15;a=d+(a|1)|0;a=(a|0)>-8?a:-8;e=B(b,x[(((a|0)<95?a:95)<<1)+33904>>1])+B(x[(v[f>>2]<<1)+33888>>1],16-b|0)<<1>>>c|0;break a}if(!((c&255)>>>0<16&b-25>>>0<=83)){a=((e&255)>>>0)/12|0;e=x[(B((c&240)>>>4|0,12)+(B(a,-12)+e&255)<<1)+33008>>1]<<5>>>a|0;break a}e=x[(b<<1)+32782>>1]<<2}fb=f+16|0;return e}function SL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;f=a+484376|0;while(1){a:{c=Vb(v[a+484360>>2],w[f|0]);d=b&65535;if(Ic(v[c>>2],v[c+4>>2])>>>0>d>>>0){if(!iq(c,d)){break a}c=Vb(v[a+484360>>2],w[a+484376|0])}if(Ic(v[c>>2],v[c+4>>2])>>>0>d>>>0){f=a+1074312|0;g=a+1074992|0;d=0;b:{while(1){c:{if((d|0)==256){RL(a);if(b&65535){break c}b=0;while(1){if((b|0)==256){Mn(a+1298264|0,1);v[a+1074456>>2]=v[a+480200>>2];v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];v[a+480208>>2]=v[a+480208>>2]&-769;Fy(a+1074376|0);u[a+1074450>>1]=0;v[a+1074392>>2]=-2;b=a+1074428|0;v[b>>2]=0;v[b+4>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074376>>2]=0;v[a+1074380>>2]=0}else{Qn((B(b,872)+a|0)+1074992|0,a,b&65535,134217728);b=b+1|0;continue}break}break b}c=B(d,872)+g|0;t[c+797|0]=0;v[c+700>>2]=0;t[c+841|0]=0;t[c+805|0]=0;v[c+708>>2]=0;t[c+821|0]=0;v[c+764>>2]=0;t[c+819|0]=0;t[c+820|0]=0;xb(e+8|0,f,23);if(yb(v[v[e+8>>2]>>2],v[e+12>>2])){t[c+807|0]=1;t[c+808|0]=0}t[c+839|0]=0;d=d+1|0;continue}break}u[a+1074450>>1]=b;u[a+1074446>>1]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074392>>2]=-2;v[a+1074432>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}fb=e+16|0;return}b=b+1|0;continue}}function iS(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;d=w[a|0];a:{if(d>>>0>21){break a}t[a|0]=w[d+26672|0];b:{switch(d-8|0){case 0:t[b|0]=w[b|0]<<1;break a;case 4:t[b|0]=w[b|0]+1>>>1;break a;case 5:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);break a;case 6:c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{d=w[b|0];switch((d>>>4|0)-1|0){case 11:case 12:case 13:break a;case 9:break e;case 8:break f;case 6:break g;case 5:break h;case 4:break i;case 3:break j;case 1:break k;case 0:break l;case 14:break c;case 10:break d;default:break m}}t[a|0]=0;break a}t[a|0]=29;t[c+15|0]=w[b|0]&15;t[c+14|0]=14;e=b,f=w[Rb(c+15|0,c+14|0)|0]<<4|15,t[e|0]=f;break a}t[a|0]=29;t[c+13|0]=w[b|0]&15;t[c+12|0]=14;e=b,f=w[Rb(c+13|0,c+12|0)|0]|240,t[e|0]=f;break a}t[b|0]=d&15|48;break a}t[a|0]=35;t[b|0]=w[b|0]<<4^128;break a}t[b|0]=d&15|176;break a}t[b|0]=d&15|64;break a}t[a|0]=15;t[b|0]=w[b|0]&15;break a}t[a|0]=24;t[b|0]=(w[b|0]<<3&120)+8&240;break a}t[a|0]=24;t[b|0]=(w[b|0]&15)+1>>>1;break a}t[a|0]=10;break a;case 8:a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?-16:a<<2&240;break a}if(a>>>0<=239){t[b|0]=a<<2&48|15;break a}t[b|0]=a<<4|15;break a;case 9:break b;default:break a}}a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?15:a>>>2|0;break a}if(a>>>0>239){break a}t[b|0]=a>>>2&3|240}fb=c+16|0}function yR(a,b){var c=0;a:{b:{c:{d:{if(ce(a,16671)){break d}if(ce(a,17440)){break d}if(ce(a,13553)){break d}if(ce(a,13670)){break d}if(!ce(a,14235)){break c}}u[b+10>>1]=4;v[b>>2]=12010;break b}e:{f:{if(ce(a,17435)){break f}if(ce(a,13563)){break f}if(!ce(a,16656)){break e}}t[b+12|0]=1;v[b>>2]=8378;u[b+10>>1]=4;return 1}g:{if(!ce(a,14281)){if(!ce(a,14286)){break g}}u[b+10>>1]=8;v[b>>2]=8156;break b}h:{if(!ce(a,15326)){if(!ce(a,15331)){break h}}v[b>>2]=17043;u[b+10>>1]=t[a+2|0]-48;break b}i:{if(!ce(a,26874)){if(!ce(a,26879)){break i}}v[b+4>>2]=1;v[b>>2]=16849;u[b+10>>1]=w[a|0]==56?8:4;return 1}if(!(Mb(a,15432,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=8496;a=t[a+3|0];u[b+8>>1]=1088;u[b+10>>1]=a-48;break b}j:{if(Mb(a,13598,3)){if(Mb(a,13732,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+15|0]=1;t[b+13|0]=1;v[b>>2]=8255;u[b+10>>1]=t[a+3|0]-48;return 1}k:{if((w[a|0]-49&255)>>>0>8){break k}if(!Mb(a+1|0,13756,3)){t[b+14|0]=1;v[b>>2]=8544;u[b+10>>1]=t[a|0]-48;return 1}if((w[a+1|0]-48&255)>>>0>9){break k}c=a+2|0;if(Mb(c,14084,2)){if(Mb(c,13760,2)){break k}}t[b+14|0]=1;v[b>>2]=8544;u[b+10>>1]=(t[a+1|0]+B(t[a|0],10)|0)-528;return 1}c=0;if(Mb(a,13419,3)|(w[a+3|0]-49&255)>>>0>8){break a}v[b>>2]=8405;u[b+10>>1]=t[a+3|0]-48}c=1}return c}function CZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=fb-496|0;fb=a;g=a+488|0;Xc(g,d);v[23220]=0;m=T(1104,g|0)|0;g=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Bb(f)){g=v[ej(f,0)>>2];v[23220]=0;h=Q(1122,m|0,45)|0;k=v[23220];v[23220]=0;if((k|0)==1){break g}n=(g|0)==(h|0)}k=Gb(a+456|0);g=Gb(a+440|0);h=Gb(a+424|0);v[23220]=0;ma(1143,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,g|0,h|0,a+420|0);c=v[23220];v[23220]=0;if((c|0)==1){break f}v[a+4>>2]=1091;c=he(a+8|0,0,a+4|0);j=Bb(f);l=v[a+420>>2];h:{if((j|0)>(l|0)){i=((Bb(h)+(j-l<<1)|0)+Bb(g)|0)+1|0;break h}i=(Bb(h)+Bb(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}Je(c,Fd(i<<2));j=v[c>>2];if(j){break e}v[23220]=0;Z(1092);b=v[23220];v[23220]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}o=v[d+4>>2];i=pc(f);f=Bb(f);v[23220]=0;oa(1144,j|0,a+4|0,a|0,o|0,i|0,i+(f<<2)|0,m|0,n|0,a+480|0,v[a+476>>2],v[a+472>>2],k|0,g|0,h|0,l|0);f=v[23220];v[23220]=0;if((f|0)!=1){v[23220]=0;b=la(1125,b|0,j|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Kc(c)}Nc(h);Nc(g);ub(k)}Wb(a+488|0);S(f|0);L()}Kc(c);Nc(h);Nc(g);ub(k);Wb(a+488|0);fb=a+496|0;return b|0}function B_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=fb-16|0;fb=k;l=Tu(g);g=kw(g);Gg(k,g);a:{b:{if(ze(k)){v[23220]=0;X(1102,l|0,a|0,c|0,d|0);g=v[23220];v[23220]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[23220]=0;j=Q(19,l|0,h<<24>>24)|0;h=v[23220];v[23220]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[23220]=0;h=Q(19,l|0,48)|0;i=v[23220];v[23220]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[23220]=0;h=Q(19,l|0,h|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}ul(j,c);i=0;v[23220]=0;o=T(1100,g|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){ul((j-a|0)+d|0,v[f>>2]);g=v[f>>2];break a}e:{if(!w[Fc(k,h)|0]){break e}if(t[Fc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(Bb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[23220]=0;n=Q(19,l|0,n|0)|0;m=v[23220];v[23220]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;O()|0;ub(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;ub(k);fb=k+16|0}function pG(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{g:{c=v[a+4>>2];h:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break h}c=jd(a)}switch(c-43|0){case 0:case 2:break g;default:break f}}f=(c|0)==45;g=!b;c=v[a+4>>2];i:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break i}c=jd(a)}b=c-58|0;if(g|b>>>0>4294967285){break e}b=v[a+116>>2];if((b|0)>0|(b|0)>=0){break d}break a}b=c-58|0}if(b>>>0<4294967286){break c}b=c-48|0;if(b>>>0<10){while(1){e=(B(e,10)+c|0)-48|0;d=(e|0)<214748364;c=v[a+4>>2];j:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break j}c=jd(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}k:{if(b>>>0>=10){break k}while(1){b=Bia(e,d,10,0);c=b+c|0;d=ib;d=b>>>0>c>>>0?d+1|0:d;b=c;e=b-48|0;d=d-(b>>>0<48)|0;b=v[a+4>>2];l:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break l}c=jd(a)}b=c-48|0;if(b>>>0>9){break k}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=v[a+4>>2];m:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;b=w[b|0];break m}b=jd(a)}if(b-48>>>0<10){continue}break}}b=v[a+116>>2];if((b|0)>0|(b|0)>=0){v[a+4>>2]=v[a+4>>2]-1}ib=f?0-(((e|0)!=0)+d|0)|0:d;return f?0-e|0:e}v[a+4>>2]=v[a+4>>2]-1;break b}if(v[a+116>>2]<0){break a}}v[a+4>>2]=v[a+4>>2]-1}ib=-2147483648;return 0}function E2(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=fb-80|0;fb=d;a:{b:{c:{d:{e:{if(Nb(v[a+36>>2],v[a+40>>2])){mf(d+72|0);break e}c=d+32|0;qn(c,a);v[23220]=0;c=T(978,c|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break d}v[d+72>>2]=c;Tf(d+32|0)}c=(k=a+36|0,l=v[d+72>>2],m=Nb(v[a+36>>2],v[a+40>>2]),m?k:l);e=v[a+8>>2];if((e|0)==-1){f=v[c+4>>2];e=f-24|0;g=v[c>>2];i=pn(g,f);j=A[e>>3];f=0;while(1){if((f|0)==(i|0)){c=e;break c}c=Zk(g,f);if(h+A[c>>3]>b){break c}f=f+1|0;h=h+j;continue}}c=Zk(v[c>>2],e);break b}f=P()|0;O()|0;Tf(d+32|0);break a}b=b-h}e=x[c+12>>1];f=v[a+24>>2];v[23220]=0;R(1011,f|0,e|0);e=v[23220];v[23220]=0;if((e|0)!=1){f:{e=v[a+24>>2];f=w[a+64|0];c=KL(qR(d+32|0,b),w[c+16|0],x[c+12>>1],v[c+8>>2]);v[23220]=0;g=v[c+12>>2];v[d+16>>2]=v[c+8>>2];v[d+20>>2]=g;g=v[c+20>>2];v[d+24>>2]=v[c+16>>2];v[d+28>>2]=g;g=v[c+4>>2];v[d+8>>2]=v[c>>2];v[d+12>>2]=g;X(1012,d+56|0,e|0,(f?7:1)|0,d+8|0);c=v[23220];v[23220]=0;if((c|0)==1){break f}c=LL(v[d+60>>2]);e=t[c+26|0]&1;f=v[(e?c+8|0:c+12|0)>>2];e=x[(e?c+20|0:c+22|0)>>1];b=A[c>>3];ti(d+56|0);c=v[a+24>>2];u[c+1074450>>1]=e;u[c+1074448>>1]=e;v[c+1074428>>2]=f;v[c+1074392>>2]=-2;b=h+b;A[a+16>>3]=b;Fk(d+72|0);fb=d+80|0;return+b}}f=P()|0;O()|0;Fk(d+72|0)}S(f|0);L()}function GZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=fb-192|0;fb=a;g=a+184|0;Xc(g,d);v[23220]=0;m=T(18,g|0)|0;g=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Bb(f)){g=w[Vf(f,0)|0];v[23220]=0;h=Q(19,m|0,45)|0;k=v[23220];v[23220]=0;if((k|0)==1){break g}n=(g|0)==(h&255)}k=Gb(a+160|0);g=Gb(a+144|0);h=Gb(a+128|0);v[23220]=0;ma(1141,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,k|0,g|0,h|0,a+124|0);c=v[23220];v[23220]=0;if((c|0)==1){break f}v[a+4>>2]=1091;c=he(a+8|0,0,a+4|0);j=Bb(f);l=v[a+124>>2];h:{if((j|0)>(l|0)){i=((Bb(h)+(j-l<<1)|0)+Bb(g)|0)+1|0;break h}i=(Bb(h)+Bb(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}Je(c,Fd(i));j=v[c>>2];if(j){break e}v[23220]=0;Z(1092);b=v[23220];v[23220]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}o=v[d+4>>2];i=Ec(f);f=Bb(f);v[23220]=0;oa(1142,j|0,a+4|0,a|0,o|0,i|0,f+i|0,m|0,n|0,a+176|0,t[a+175|0],t[a+174|0],k|0,g|0,h|0,l|0);f=v[23220];v[23220]=0;if((f|0)!=1){v[23220]=0;b=la(14,b|0,j|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Kc(c)}ub(h);ub(g);ub(k)}Wb(a+184|0);S(f|0);L()}Kc(c);ub(h);ub(g);ub(k);Wb(a+184|0);fb=a+192|0;return b|0}function rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;f=fb-16|0;fb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){h=v[f+8>>2];o=((((v[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+l|0;e=(h>>>16&65520)+b|0;p=u[e+14>>1];q=u[e+12>>1];r=u[e+10>>1];s=u[e+8>>1];t=u[e+6>>1];w=u[e+4>>1];x=u[e+2>>1];y=u[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+o|0;v[(h<<2)+f>>2]=(((((((B(u[e-8>>1],x)+B(u[e-12>>1],y)|0)+B(u[e-4>>1],w)|0)+B(u[e>>1],t)|0)+B(u[e+4>>1],s)|0)+B(u[e+8>>1],r)|0)+B(u[e+12>>1],q)|0)+B(u[e+16>>1],p)|0)/32768;h=h+1|0;continue}break}k=k+n|0;v[c>>2]=v[c>>2]+B(v[f>>2],k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],j>>12);Ob(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;fb=f+16|0}function daa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;k=fb-32|0;fb=k;h=k+28|0;f=k+24|0;g=fb-16|0;fb=g;a:{b:{if(!rc(b,v[dc(g+8|0,Hf(a))>>2])){e=x[c>>1];i=v[c+4>>2];j=pd(b);m=x[j>>1];j=v[j+4>>2];if(!Sk(e,i,m,j)){break b}}v[g+8>>2]=b;e=dc(g,Ab(v[a>>2]));c:{f=v[g+8>>2];if(!rc(f,v[e>>2])){f=v[Yy(g+8|0)>>2];e=pd(f);j=x[e>>1];m=v[e+4>>2];e=x[c>>1];i=v[c+4>>2];if(!Sk(j,m,e,i)){break c}}if(!v[b>>2]){v[h>>2]=b;break a}v[h>>2]=f;b=f+4|0;break a}b=Xy(a,h,e,i);break a}if(Sk(m,j,e,i)){d:{f=Wy(b);if(!rc(f,v[dc(g+8|0,Hf(a))>>2])){e=x[c>>1];i=v[c+4>>2];j=pd(f);if(!Sk(e,i,x[j>>1],v[j+4>>2])){break d}}if(!v[b+4>>2]){v[h>>2]=b;b=b+4|0;break a}v[h>>2]=f;b=f;break a}b=Xy(a,h,e,i);break a}v[h>>2]=b;v[f>>2]=b;b=f}fb=g+16|0;f=b;b=v[b>>2];if(!b){b=fb-16|0;fb=b;g=fc(a);h=k+8|0;e=oh(h,tc(36),ph(b+8|0,g));g=v[e>>2]+16|0;i=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=i;Wj(g+8|0,d);o=fc(e),p=1,t[o+4|0]=p;fb=b+16|0;Tg(a,v[k+28>>2],f,v[k+8>>2]);b=Ud(h);MN(h);n=1}Sg(l,v[dc(k+8|0,b)>>2],n);fb=k+32|0;if(!w[fc(l)|0]){a=pd(v[l>>2])+8|0;LN(a);v[a>>2]=v[d>>2];v[a+4>>2]=v[d+4>>2];b=Cb(d);o=Cb(a),p=v[b>>2],v[o>>2]=p;v[b>>2]=0;v[d>>2]=0;v[d+4>>2]=0}a=v[dc(l+8|0,v[l>>2])>>2];fb=l+16|0;return a|0}function zia(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{e=b;if(e){if(!c){break j}f=d;if(!f){break i}e=E(f)-E(e)|0;if(e>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;gb=a-B(b,c)|0;hb=0;ib=0;return b}f=d;if(!a){break g}if(!f){break f}g=f-1|0;if(g&f){break f}gb=a;hb=e&g;a=e>>>Aia(f)|0;ib=0;return a}f=c-1|0;if(!(f&c)){break e}h=(E(c)+33|0)-E(e)|0;g=0-h|0;break c}h=e+1|0;g=63-e|0;break c}gb=0;a=(e>>>0)/(f>>>0)|0;hb=e-B(a,f)|0;ib=0;return a}e=E(f)-E(e)|0;if(e>>>0<31){break d}break b}gb=a&f;hb=0;if((c|0)==1){break a}d=a;c=Aia(c);a=c&31;if((c&63)>>>0>=32){e=0;a=b>>>a|0}else{e=b>>>a|0;a=((1<<a)-1&b)<<32-a|d>>>a}ib=e;return a}h=e+1|0;g=63-e|0}i=a;e=h&63;f=e&31;if((e&63)>>>0>=32){e=0;k=b>>>f|0}else{e=b>>>f|0;k=((1<<f)-1&b)<<32-f|i>>>f}f=e;e=g&63;a=e&31;if((e&63)>>>0>=32){e=i<<a;a=0}else{e=(1<<a)-1&i>>>32-a|b<<a;a=i<<a}b=e;if(h){e=d-1|0;g=c-1|0;e=(g|0)!=-1?e+1|0:e;i=e;while(1){j=k;e=f<<1|j>>>31;f=j<<1;j=e;f=b>>>31|f;e=i-((f>>>0>g>>>0)+e|0)>>31;l=e;m=c&e;k=f-m|0;f=j-((d&e)+(f>>>0<m>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;j=0;l=l&1;n=l;h=h-1|0;if(h){continue}break}}gb=k;hb=f;e=b<<1|a>>>31;a=l|a<<1;ib=e|j;return a}gb=a;hb=b;a=0;b=0}ib=b;return a}function Saa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;e=fb-16|0;fb=e;q=v[a+16>>2];r=Zf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){j=v[a+8>>2];k=v[a+12>>2];f=v[a>>2];g=v[a+4>>2];i=0;break a}j=v[a+8>>2];k=v[a+12>>2];m=_f(j,k,l);n=ib;b=v[a+76>>2];f=v[a>>2];g=v[a+4>>2];Df(f,g,af(j,k,d),ib);i=b>>>0<ib>>>0?d:0}h=a+112|0;s=v[a+24>>2];u=v[a+20>>2];v[e>>2]=f;v[e+4>>2]=g;while(1){if(d){b=v[e+4>>2];f=v[e>>2];v[e+8>>2]=f;v[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;p=(((b&2147483647)<<1|f>>>31)&-2)+q|0;f=l;b:{c:while(1){d:{if((f|0)<=0){Ob(h,v[a+120>>2],v[a+124>>2]);f=v[a+116>>2];if(!f){break b}o=((v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31)&-2;g=0;b=0;break d}o=((v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Hd(h,(g|0)/8<<16>>16);Gd(h,4);Ob(e+8|0,m,n);f=f-1|0;continue c}else{g=(t[(b+o|0)+p|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(t[(b+o|0)+p|0]<<8)+g|0;b=b+1|0;continue}break}Hd(h,(g|0)/8<<16>>16);Gd(h,f);v[h>>2]=v[h>>2];v[h+4>>2]=0}f=v[c>>2];b=Yf(h,r);v[c>>2]=f+B(b,u);v[c+4>>2]=v[c+4>>2]+B(b,s);Ob(e,j,k);c=c+8|0;continue}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;fb=e+16|0}function n_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-384|0;fb=f;v[f+376>>2]=37;v[f+380>>2]=0;h=rr(f+376|1,21598,v[c+4>>2]);v[f+332>>2]=f+336;a=wd();a:{if(h){g=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=g;g=Fg(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;g=Fg(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=1091;i=he(f+320|0,0,f+80|0);j=f+336|0;a=j;b:{c:{d:{if((g|0)>=30){a=wd();e:{if(h){g=v[c+8>>2];A[f+8>>3]=e;v[f>>2]=g;g=Oi(f+332|0,a,f+376|0,f);break e}A[f+16>>3]=e;g=Oi(f+332|0,a,f+376|0,f+16|0)}if((g|0)==-1){v[23220]=0;Z(1092);a=v[23220];v[23220]=0;if((a|0)==1){break c}break d}a=v[f+332>>2];Je(i,a)}k=a+g|0;l=Pi(a,k,c);v[f+68>>2]=1091;h=he(f+72|0,0,f+68|0);f:{g:{if((f+336|0)==(a|0)){g=f+80|0;break g}g=Fd(g<<3);if(!g){v[23220]=0;Z(1092);a=v[23220];v[23220]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Je(h,g);j=a}a=f+56|0;Xc(a,c);v[23220]=0;ja(1124,j|0,l|0,k|0,g|0,f+68|0,f- -64|0,a|0);a=v[23220];v[23220]=0;h:{if((a|0)!=1){Wb(f+56|0);v[23220]=0;a=la(1125,b|0,g|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break h}Kc(h);Kc(i);fb=f+384|0;return a|0}c=P()|0;O()|0;Wb(f+56|0);break f}c=P()|0;O()|0}Kc(h);break b}L()}c=P()|0;O()|0}Kc(i);S(c|0);L()}function vX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(Eg(a,v[b+8>>2],e)){Vv(b,c,d);return}a:{if(Eg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;if(v[b+44>>2]!=4){f=a+16|0;h=f+(v[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}u[b+52>>1]=0;Rv(v[f>>2],v[f+4>>2],b,c,c,1,e);if(w[b+54|0]){break d}e:{if(!w[b+53|0]){break e}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break c}g=1;if(w[a+8|0]&2){break e}break c}g=1;if(!(t[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}v[b+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}f=v[a+12>>2];lr(v[a+16>>2],v[a+20>>2],b,c,d,e);if((f|0)<2){break a}g=(a+16|0)+(f<<3)|0;f=a+24|0;a=v[a+8>>2];if(!(!(a&2)&v[b+36>>2]!=1)){while(1){if(w[b+54|0]){break a}lr(v[f>>2],v[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}lr(v[f>>2],v[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|v[b+36>>2]==1&v[b+24>>2]==1){break a}lr(v[f>>2],v[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function x_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-208|0;fb=f;v[f+200>>2]=37;v[f+204>>2]=0;h=rr(f+200|1,21598,v[c+4>>2]);v[f+156>>2]=f+160;a=wd();a:{if(h){g=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=g;g=Fg(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;g=Fg(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=1091;i=he(f+144|0,0,f+80|0);j=f+160|0;a=j;b:{c:{d:{if((g|0)>=30){a=wd();e:{if(h){g=v[c+8>>2];A[f+8>>3]=e;v[f>>2]=g;g=Oi(f+156|0,a,f+200|0,f);break e}A[f+16>>3]=e;g=Oi(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){v[23220]=0;Z(1092);a=v[23220];v[23220]=0;if((a|0)==1){break c}break d}a=v[f+156>>2];Je(i,a)}k=a+g|0;l=Pi(a,k,c);v[f+68>>2]=1091;h=he(f+72|0,0,f+68|0);f:{g:{if((f+160|0)==(a|0)){g=f+80|0;break g}g=Fd(g<<1);if(!g){v[23220]=0;Z(1092);a=v[23220];v[23220]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Je(h,g);j=a}a=f+56|0;Xc(a,c);v[23220]=0;ja(1119,j|0,l|0,k|0,g|0,f+68|0,f- -64|0,a|0);a=v[23220];v[23220]=0;h:{if((a|0)!=1){Wb(f+56|0);v[23220]=0;a=la(14,b|0,g|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break h}Kc(h);Kc(i);fb=f+208|0;return a|0}c=P()|0;O()|0;Wb(f+56|0);break f}c=P()|0;O()|0}Kc(h);break b}L()}c=P()|0;O()|0}Kc(i);S(c|0);L()}function Maa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=fb-16|0;fb=f;q=v[a+16>>2];r=Zf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){l=v[a+8>>2];m=v[a+12>>2];e=v[a>>2];b=v[a+4>>2];h=0;break a}l=v[a+8>>2];m=v[a+12>>2];o=_f(l,m,n);p=ib;h=v[a+76>>2];e=v[a>>2];b=v[a+4>>2];Df(e,b,af(l,m,d),ib);h=h>>>0<ib>>>0?d:0}g=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[f>>2]=e;v[f+4>>2]=b;b:while(1){if(d){d=d-1|0;v[f+8>>2]=e;v[f+12>>2]=0;h=h-1|0;o=h?o:0;p=h?p:0;e=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+q|0;b=n;while(1)if((b|0)<=0){Ob(g,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){k=(v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31;Hd(g,(u[(k<<1|2)+e>>1]+u[e+((k&2147483646)<<1)>>1]|0)/8<<16>>16);Gd(g,b);v[g>>2]=v[g>>2];v[g+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;e=Yf(g,r);v[c>>2]=B(j>>12,e)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(e,i>>12);Ob(f,l,m);c=c+8|0;e=v[f>>2];b=v[f+4>>2];continue b}else{k=(v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31;Hd(g,(u[(k<<1|2)+e>>1]+u[e+((k&2147483646)<<1)>>1]|0)/8<<16>>16);Gd(g,4);Ob(f+8|0,o,p);b=b-1|0;continue}}break}v[a>>2]=e;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;fb=f+16|0}function sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;f=fb-16|0;fb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){h=v[f+8>>2];o=(((v[f+12>>2]&2147483647)<<1|h>>>31)&-2)+l|0;e=(h>>>16&65520)+b|0;p=u[e+14>>1];q=u[e+12>>1];r=u[e+10>>1];s=u[e+8>>1];w=u[e+6>>1];x=u[e+4>>1];y=u[e+2>>1];z=u[e>>1];h=0;while(1){if((h|0)!=2){e=h+o|0;v[(h<<2)+f>>2]=(((((((B(t[e-4|0],y)+B(t[e-6|0],z)|0)+B(t[e-2|0],x)|0)+B(t[e|0],w)|0)+B(t[e+2|0],s)|0)+B(t[e+4|0],r)|0)+B(t[e+6|0],q)|0)+B(t[e+8|0],p)<<8)/32768;h=h+1|0;continue}break}k=k+n|0;v[c>>2]=v[c>>2]+B(v[f>>2],k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],j>>12);Ob(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;fb=f+16|0}function Cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=fb-288|0;fb=f;Lf(b);a:{if(!Lb(v[a>>2],v[a+8>>2],1)){break a}while(1){d=f+32|0;_m(f+8|0,d,$p(d));k=v[a>>2];g=v[a+8>>2];d=fb-32|0;fb=d;Hg(d+16|0,v[f+8>>2],v[f+12>>2]);e=v[v[k>>2]+28>>2];l=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=l;jb[e|0](d+24|0,k,g,d+8|0);Hg(f+16|0,v[d+24>>2],v[d+28>>2]);fb=d+32|0;v[f+28>>2]=v[f+20>>2];o=f,p=c-Bb(b)|0,v[o+4>>2]=p;d=v[Eb(f+28|0,f+4|0)>>2];if(!d){break a}t[f+16|0]=0;k=f+32|0;m=k+d|0;d=f+16|0;l=mi(k,m,d);o=f,p=ih(b),v[o+16>>2]=p;e=v[Ef(f,d)>>2];g=fb-32|0;fb=g;v[g+24>>2]=e;o=g,p=Td(b),v[o+8>>2]=p;h=bk(g+24|0,g+8|0);b:{c:{d=k;i=oi(d,l);if(!i){break c}if(!Cs(b,d)){e=Bb(b);j=Qc(b);d:{if(i>>>0<=j-e>>>0){j=pc(b);if((e|0)==(h|0)){break d}n=h+j|0;pj(i+n|0,n,e-h|0);break d}Ll(b,j,(e+i|0)-j|0,e,h,0,i);j=v[b>>2]}e=e+i|0;hh(b,e);t[g+8|0]=0;bd(e+j|0,g+8|0);e=h+j|0;while(1){if((d|0)==(l|0)){break c}bd(e,d);d=d+1|0;e=e+1|0;continue}}d=Xf(g+8|0,d,l);h=Ec(d);i=Bb(d);v[23220]=0;fa(349,b|0,e|0,h|0,h+i|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){ub(d);break b}a=P()|0;O()|0;ub(d);S(a|0);L()}Td(b)}fb=g+32|0;Yb(a,l-k|0);if(l>>>0>=m>>>0){continue}break}Yb(a,1)}fb=f+288|0}function uY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=fb-16|0;fb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{while(1){j=v[a+12>>2];if(!(j>>>0>=d>>>0|f>>>0>=g>>>0)){i=t[j|0];c=i&255;c:{if((i|0)>=0){i=1;break c}b=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-j|0)<2){break b}i=w[j+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-j|0)<3){break b}k=w[j+2|0];i=w[j+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-j|0)<4){break b}l=w[j+3|0];m=w[j+2|0];k=w[j+1|0];f:{g:{switch(c-240|0){case 0:if((k+112&255)>>>0<48){break f}break a;case 4:if((k&240)==128){break f}break a;default:break g}}if((k&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(k&63)<<12));if(c>>>0>1114111){break a}}v[f>>2]=c;v[a+12>>2]=i+j;f=v[a+8>>2]+4|0;v[a+8>>2]=f;continue}break}b=d>>>0>j>>>0;break a}b=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];fb=a+16|0;return b|0}function X5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=C(0),r=0,s=0,t=0,u=C(0),w=0;i=fb-16|0;fb=i;a:{if(!Th(a+44|0)){break a}n=v[a+44>>2];j=zc(n,0);k=zc(n,1);n=v[a+56>>2];t=zc(n,0);n=zc(n,1);u=z[zb(a+4208|0,1)>>2];v[i+12>>2]=d;s=v[a+4220>>2];q=C(C(1)/C(s>>>0));w=v[a+4216>>2];o=d;f=n;g=t;while(1){if(!o){hi(a,b,c,t,n,d);break a}h=v[a+4224>>2];b:{if(s>>>0>h>>>0){v[i+8>>2]=s-h;r=v[Eb(i+12|0,i+8|0)>>2];m=0;c:{if(u<C(1)){l=h+r|0;e=h>>>0>l>>>0?h:l;while(1){if((h|0)==(e|0)){break c}p=C(h>>>0);z[g>>2]=q*C(z[j>>2]*p);z[f>>2]=q*C(z[k>>2]*p);h=h+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((m|0)!=(r|0)){z[g>>2]=z[j>>2];z[f>>2]=z[k>>2];m=m+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}break}l=h+r|0}o=o-r|0;v[i+12>>2]=o;break b}m=w-h|0;v[i+4>>2]=m;l=v[Eb(i+12|0,i+4|0)>>2];e=0;d:{if(u<C(1)){e=m-l|0;while(1){if(e>>>0>=m>>>0){break d}p=C(m>>>0);z[g>>2]=q*C(z[j>>2]*p);z[f>>2]=q*C(z[k>>2]*p);m=m-1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){v[g>>2]=0;v[f>>2]=0;e=e+1|0;f=f+4|0;g=g+4|0;continue}break}e=l<<2;k=e+k|0;j=j+e|0}o=o-l|0;v[i+12>>2]=o;e=h+l|0;l=e>>>0<w>>>0?e:0}v[a+4224>>2]=l;continue}}fb=i+16|0}function v9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=fb-16|0;fb=l;v[l+8>>2]=b;q=wf(a);while(1){if(vg(b,c)){b=v[dc(l,q)>>2];k=pd(v[l+8>>2]);o=fb-16|0;fb=o;p=0;m=fb-16|0;fb=m;i=fb-32|0;fb=i;g=i+28|0;d=i+24|0;e=fb-16|0;fb=e;a:{b:{if(!rc(b,v[dc(e+8|0,Hf(a))>>2])){f=w[k|0];j=v[k+4>>2];h=pd(b);n=w[h|0];h=v[h+4>>2];if(!An(f,j,n,h)){break b}}v[e+8>>2]=b;f=dc(e,Ab(v[a>>2]));c:{d=v[e+8>>2];if(!rc(d,v[f>>2])){d=v[Yy(e+8|0)>>2];f=pd(d);h=w[f|0];n=v[f+4>>2];f=w[k|0];j=v[k+4>>2];if(!An(h,n,f,j)){break c}}if(!v[b>>2]){v[g>>2]=b;break a}v[g>>2]=d;b=d+4|0;break a}b=xy(a,g,f,j);break a}if(An(n,h,f,j)){d:{d=Wy(b);if(!rc(d,v[dc(e+8|0,Hf(a))>>2])){f=w[k|0];j=v[k+4>>2];h=pd(d);if(!An(f,j,w[h|0],v[h+4>>2])){break d}}if(!v[b+4>>2]){v[g>>2]=b;b=b+4|0;break a}v[g>>2]=d;b=d;break a}b=xy(a,g,f,j);break a}v[g>>2]=b;v[d>>2]=b;b=d}fb=e+16|0;d=b;b=v[b>>2];if(!b){b=fb-16|0;fb=b;e=fc(a);g=i+8|0;e=oh(g,tc(28),ph(b+8|0,e));Jz(v[e>>2]+16|0,k);r=fc(e),s=1,t[r+4|0]=s;fb=b+16|0;Tg(a,v[i+28>>2],d,v[i+8>>2]);b=Ud(g);_k(g);p=1}Sg(m+8|0,v[dc(i+8|0,b)>>2],p);fb=i+32|0;fb=m+16|0;dc(o+8|0,v[m+8>>2]);fb=o+16|0;b=v[Rg(l+8|0)>>2];continue}else{fb=l+16|0}break}}function sfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;kd(b,0);to(b);f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=f;break a}g=b,h=Ee(Kj(+(f+1408|0)/1536)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?f:f^128;t[b+36|0]=w[a+4|0]}t[e+15|0]=w[a+5|0];t[e+14|0]=64;g=b,h=w[Rb(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;d=w[a+6|0]|w[a+7|0]<<8;if(d>>>0<=256){u[b+28>>1]=d;u[b+34>>1]=x[b+34>>1]|32}v[b>>2]=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);v[b+4>>2]=w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24);v[b+8>>2]=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);d=w[a+20|0]|w[a+21|0]<<8;if(d&16){u[b+34>>1]=x[b+34>>1]|2;d=w[a+20|0]|w[a+21|0]<<8}if(d&32){u[b+34>>1]=x[b+34>>1]|4;d=w[a+20|0]|w[a+21|0]<<8}if(d&256){u[b+34>>1]=x[b+34>>1]|8;d=w[a+20|0]|w[a+21|0]<<8}if(d&512){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+39856|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[e+13|0]=w[a+26|0];t[e+12|0]=64;g=b,h=w[Rb(e+13|0,e+12|0)|0],u[g+32>>1]=h}v[b+12>>2]=w[a+27|0]|w[a+28|0]<<8|(w[a+29|0]<<16|w[a+30|0]<<24);v[b+16>>2]=w[a+31|0]|w[a+32|0]<<8|(w[a+33|0]<<16|w[a+34|0]<<24);fb=e+16|0}function LP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=v[a>>2];e=mh(c,v[a+4>>2]);if(e>>>0<b>>>0){g=fb-32|0;fb=g;f=b-e|0;b=v[Cb(a)>>2];c=v[a+4>>2];a:{if(f>>>0<=b-c>>8>>>0){b=fb-16|0;fb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(f<<8);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){hc(b);fb=b+16|0}else{zz(a);a=a+256|0;v[b+4>>2]=a;continue}break}break a}i=Cb(a);b=g+8|0;e=a;h=mh(v[a>>2],c)+f|0;c=fb-16|0;fb=c;v[c+12>>2]=h;d=fb-16|0;fb=d;v[d+12>>2]=16777215;v[d+8>>2]=2147483647;a=v[Eb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(a>>>0>=h>>>0){d=Az(e);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Sc(c+8|0,c+12|0)>>2]}fb=c+16|0;break b}od();L()}d=mh(v[e>>2],v[e+4>>2]);Gf(b+12|0,i);if(a){if(a>>>0>=16777216){xf(11129);L()}c=tc(a<<8)}else{c=0}v[b>>2]=c;d=c+(d<<8)|0;v[b+8>>2]=d;v[b+4>>2]=d;j=vc(b),k=c+(a<<8)|0,v[j>>2]=k;a=fb-16|0;fb=a;v[a>>2]=v[b+8>>2];c=v[b+8>>2];v[a+8>>2]=b+8;v[a+4>>2]=c+(f<<8);c=v[a>>2];while(1){if(v[a+4>>2]!=(c|0)){zz(c);c=v[a>>2]+256|0;v[a>>2]=c;continue}break}Ed(a);fb=a+16|0;vd(e,b);e=v[b+4>>2];a=v[b+8>>2];while(1){if((a|0)!=(e|0)){a=a-256|0;v[b+8>>2]=a;continue}break}a=v[b>>2];if(a){vc(b);Fb(a)}}fb=g+32|0;return}if(b>>>0<e>>>0){Jd(a,c+(b<<8)|0)}}function m9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-16|0;fb=i;e=v[b+1298304>>2];if(!sd(e)){d=fb-16|0;fb=d;c=tc(12);v[23220]=0;e=T(880,c|0)|0;f=v[23220];v[23220]=0;a:{if((f|0)!=1){c=v[uf(d+8|0,e)>>2];fb=d+16|0;break a}a=P()|0;O()|0;Fb(c);S(a|0);L()}v[i+8>>2]=c;c=b+1298304|0;d=i+8|0;hM(c,Ud(d));py(d);e=v[c>>2]}f=fb-48|0;fb=f;c=f+16|0;XL(c,a);v[23220]=0;U(8,f+32|0,0,c|0);c=v[23220];v[23220]=0;b:{c:{if((c|0)!=1){vb(f+16|0);m=f,n=Ab(v[e>>2]),v[m+8>>2]=n;l=Ab(v[e+4>>2]);c=0;e=0;d:{while(1){e:{h=v[f+8>>2];if(!Nb(h,l)){if(!e){break e}c=v[e+4>>2];if(!c){break e}v[23220]=0;W(c|0,e|0,b|0,a|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break e}break d}j=0;d=v[h>>2];if(v[d+32>>2]==v[a+16>>2]){j=v[d+36>>2]==v[a+20>>2]}v[23220]=0;R(881,f+16|0,d+8|0);d=v[23220];v[23220]=0;if((d|0)==1){break d}g=fb-16|0;fb=g;k=f+16|0;re(g+8|0,k);re(g,f+32|0);d=iM(v[g+8>>2],v[g+12>>2],v[g>>2],v[g+4>>2]);fb=g+16|0;ub(k);f:{if(!(!j|(d|0)!=0)){e=v[h>>2];c=3;break f}if((c|0)<2&j){e=v[h>>2];c=2;break f}d=!d&(c|0)<=0;e=d?v[h>>2]:e;c=d?1:c}ye(f+8|0);continue}break}ub(f+32|0);fb=f+48|0;break b}e=P()|0;O()|0;ub(f+32|0);break c}e=P()|0;O()|0;vb(f+16|0)}S(e|0);L()}fb=i+16|0}function zV(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-32|0;fb=d;if(!Mb(a,13628,4)){kd(b,32);to(b);Sh(d,1,a+4|0);c=d+16|0;Ac(c,d);ue(b+43|0,c);ub(c);u[b+30>>1]=w[a+19|0]<<2;qg(b+30|0,256);u[b+32>>1]=w[a+17|0];qg(b+32|0,64);u[b+28>>1]=(w[a+47|0]&127)<<2;qg(b+28|0,256);if(t[a+47|0]<0){u[b+34>>1]=x[b+34>>1]|32}c=w[a+18|0];if(c&16){u[b+34>>1]=x[b+34>>1]|2;c=w[a+18|0]}if(c&32){u[b+34>>1]=x[b+34>>1]|8;c=w[a+18|0]}if(c&64){u[b+34>>1]=x[b+34>>1]|4;c=w[a+18|0]}if(c<<24>>24<0){u[b+34>>1]=x[b+34>>1]|16}c=w[a+60|0]|w[a+61|0]<<8|(w[a+62|0]<<16|w[a+63|0]<<24);v[b+24>>2]=c?c>>>0>256?c:256:8363;v[b>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[b+4>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);v[b+8>>2]=w[a+56|0]|w[a+57|0]<<8|(w[a+58|0]<<16|w[a+59|0]<<24);v[b+12>>2]=w[a+64|0]|w[a+65|0]<<8|(w[a+66|0]<<16|w[a+67|0]<<24);v[b+16>>2]=w[a+68|0]|w[a+69|0]<<8|(w[a+70|0]<<16|w[a+71|0]<<24);hk(b);t[b+38|0]=w[(w[a+79|0]&7)+39856|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=w[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}u[b+34>>1]=c|x[b+34>>1]}c=w[a+72|0]|w[a+73|0]<<8|(w[a+74|0]<<16|w[a+75|0]<<24)}fb=d+32|0;return c|0}function Pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=fb-48|0;fb=k;if(lf(v[b>>2],v[b+4>>2])>>>0>c>>>0){while(1){i=m&65535;if(i>>>0<=c>>>0){g=Nf(v[b>>2],i);e=v[g>>2];if(Nb(e,v[g+4>>2])){n=k+24|0;e=Ab(e);o=Ab(v[Nf(v[b>>2],i)+4>>2]);f=oP(k,d);l=fb-16|0;fb=l;v[l+8>>2]=e;while(1){if(Nb(e,o)){j=fb-16|0;fb=j;if(!(w[e+5|0]|w[e+3|0]!=4)){g=j+8|0;xb(g,v[f>>2],x[f+14>>1]);sg(g,0);t[e+3|0]=0}h=w[e+2|0];if(!(w[e+4|0]|(h|0)!=11)){g=j+8|0;xb(g,v[f>>2],x[f+14>>1]);sg(g,0);t[e+2|0]=0;h=0}a:{b:{if(!w[e|0]){xb(j+8|0,v[f>>2],x[f+14>>1]);if(yb(v[v[j+8>>2]>>2],v[j+12>>2])){break b}h=w[e+2|0]}i=w[e+3|0];g=j+8|0;xb(g,v[f>>2],x[f+14>>1]);sg(g,(i|0)==4|(h|0)==11);h=w[e+3|0];break a}h=w[e+3|0];g=w[e+2|0];if(!(h|(g|0)==11)){t[e+5|0]=0;h=4;t[e+3|0]=4;break a}if(g|(h|0)==4){break a}t[e+4|0]=0;t[e+2|0]=11}c:{d:{e:{if(!(!w[f+16|0]|h)){t[e+3|0]=17;i=0;h=125;break e}i=0;f:{switch(h-16|0){case 1:break d;case 0:break f;default:break c}}if(w[e+5|0]){break c}i=1;h=6}t[e+5|0]=h}t[f+16|0]=i}u[f+14>>1]=(x[f+14>>1]+1>>>0)%x[f+12>>1];fb=j+16|0;e=v[gk(l+8|0)>>2];continue}break}mP(n,f);fb=l+16|0;Ie(n);Ie(f)}m=m+1|0;continue}break}}mP(a,d);fb=k+48|0}function fG(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=fb-16|0;fb=l;f=w[a|0];a:{if(!f){g=a;break a}g=a;b:{while(1){if(!wk(f<<24>>24)){break b}f=w[g+1|0];g=g+1|0;if(f){continue}break}break a}c:{f=f&255;switch(f-43|0){case 0:case 2:break c;default:break a}}m=(f|0)==45?-1:0;g=g+1|0}d:{if(!(c&-17|w[g|0]!=48)){o=1;if((w[g+1|0]&223)==88){g=g+2|0;j=16;break d}g=g+1|0;j=c?c:8;break d}j=c?c:10}p=j>>31;c=0;while(1){e:{f=-48;i=t[g|0];f:{if((i-48&255)>>>0<10){break f}f=-87;if((i-97&255)>>>0<26){break f}f=-55;if((i-65&255)>>>0>25){break e}}i=f+i|0;if((i|0)>=(j|0)){break e}gf(l,j,p,0,0,k,h,0,0);f=1;g:{if(v[l+8>>2]|v[l+12>>2]){break g}q=Bia(k,h,j,p);n=ib;r=i>>31;s=r^-1;if((n|0)==(s|0)&(i^-1)>>>0<q>>>0|n>>>0>s>>>0){break g}h=n+r|0;f=i+q|0;h=f>>>0<i>>>0?h+1|0:h;k=f;o=1;f=c}g=g+1|0;c=f;continue}break}if(b){v[b>>2]=o?g:a}h:{i:{j:{if(c){v[115696]=68;a=d&1;m=a?0:m;k=d;h=e;break j}if((e|0)==(h|0)&d>>>0>k>>>0|e>>>0>h>>>0){break i}a=d&1}if(!(a|m)){v[115696]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(h|0)&d>>>0>=k>>>0|e>>>0>h>>>0){break i}v[115696]=68;break h}a=m;b=a^k;d=b-a|0;c=a>>31;e=(c^h)-((a>>>0>b>>>0)+c|0)|0}fb=l+16|0;ib=e;return d}function A2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=fb-2144|0;fb=b;Fx(b+96|0);a:{b:{c:{f=v[c+4>>2];if(!f){a=aa(8)|0;v[23220]=0;b=Q(52,b+80|0,10414)|0;c=v[23220];v[23220]=0;if((c|0)==1){break c}a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}c=P()|0;O()|0;ub(b);break b}g=v[c>>2];d=v[c+12>>2];c=v[c+8>>2];v[b+72>>2]=c;v[b+76>>2]=d;e=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=e;v[b+68>>2]=f;v[b+64>>2]=g;e=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=e;h=wI(b+16|0);if(h){v[b+48>>2]=c;v[b+52>>2]=d;c=v[b+52>>2];v[b+8>>2]=v[b+48>>2];v[b+12>>2]=c;v[b+44>>2]=f;v[b+40>>2]=g;c=v[b+44>>2];v[b>>2]=v[b+40>>2];v[b+4>>2]=c;c=rI(b)}else{c=0}v[b+56>>2]=c;v[b+60>>2]=0;d=0;c=2048;while(1){if(c){e=jb[f|0](g,(b+96|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}c=a;a=cc(b+32|0,b+96|0,d);a=Fs(c,v[a>>2],v[a+4>>2],h?b+56|0:0);if(a+1>>>0>=3){a=aa(8)|0;v[23220]=0;b=Q(52,b+80|0,8044)|0;c=v[23220];v[23220]=0;if((c|0)!=1){a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}c=P()|0;O()|0;ub(b);break b}c=P()|0;O()|0;ba(a|0);break b}fb=b+2144|0;return a|0}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}function zd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb+-64|0;fb=d;v[a+480180>>2]=b;b=Zp(a);Iz(d,b);e=v[d+12>>2];c=a+1074320|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074312>>2]=v[d>>2];v[a+1074316>>2]=c;Gs(a+8|0,b);b=1;while(1){c=b&65535;if(c>>>0>x[a+480192>>1]){v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074304>>2]=0;v[a+1074308>>2]=0;u[a+480192>>1]=0;ly(a,4);e=fb+-64|0;fb=e;b=a+484344|0;Is(b);f=ek(v[b>>2],v[b+4>>2]);c=Px(e+8|0,b);v[23220]=0;U(786,b|0,f|0,c|0);b=v[23220];v[23220]=0;a:{if((b|0)!=1){Mk(c);fb=e- -64|0;break a}a=P()|0;O()|0;Mk(c);S(a|0);L()}BO(a+484360|0);Lf(a+1298308|0);eA(a+1298320|0);Lf(a+1298332|0);c=Sb(d,0,64);b=oM(c);d=Db(a+1298344|0,b);Db(d+12|0,b+12|0);Db(d+24|0,b+24|0);Db(d+36|0,b+36|0);Db(d+48|0,b+48|0);v[d+60>>2]=v[b+60>>2];qy(b);Bc(a+1298408|0);Bc(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}fb=c- -64|0;return}c=((c<<2)+a|0)+900380|0;e=v[c>>2];if(e){Fb(Ht(e))}v[c>>2]=0;b=b+1|0;continue}}function $aa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;h=fb-16|0;fb=h;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+72>>2];b=v[a+68>>2];o=b;p=b>>31;b=v[a+64>>2];q=b;r=b>>31;b=v[a+60>>2];s=b;t=b>>31;w=v[a+8>>2];x=v[a+12>>2];while(1){b=e;if(d){e=Ub(b,-16777216,16776704);e=Bia(q,r,e,e>>31);g=ib;f=Ub(f,-16777216,16776704);i=Bia(o,p,f,f>>31);e=i+e|0;f=ib+g|0;f=e>>>0<i>>>0?f+1|0:f;y=e;e=(v[h+12>>2]<<1)+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(u[e+4>>1],u[g+10>>1])+B(u[e+2>>1],u[g+8>>1])|0)+B(u[e+6>>1],u[g+12>>1])|0)+B(u[e+8>>1],u[g+14>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+2>>1])+B(u[e-6>>1],u[g>>1])|0)+B(u[e-2>>1],u[g+4>>1])|0)+B(u[e>>1],u[g+6>>1])|0)/2|0)|0)/16384<<8;e=g;i=Bia(e,e>>31,s,t);e=y+i|0;f=ib+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Lc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Ob(h+8|0,w,x);e=f-(g&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;fb=h+16|0}function aba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;h=fb-16|0;fb=h;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+72>>2];b=v[a+68>>2];o=b;p=b>>31;b=v[a+64>>2];q=b;r=b>>31;b=v[a+60>>2];s=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Ub(b,-16777216,16776704);e=Bia(q,r,e,e>>31);g=ib;f=Ub(f,-16777216,16776704);i=Bia(o,p,f,f>>31);e=i+e|0;f=ib+g|0;f=e>>>0<i>>>0?f+1|0:f;z=e;e=v[h+12>>2]+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(t[e+2|0],u[g+10>>1])+B(t[e+1|0],u[g+8>>1])|0)+B(t[e+3|0],u[g+12>>1])|0)+B(t[e+4|0],u[g+14>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+2>>1])+B(t[e-3|0],u[g>>1])|0)+B(t[e-1|0],u[g+4>>1])|0)+B(t[e|0],u[g+6>>1])<<8)/2|0)|0)/16384<<8;e=g;i=Bia(e,e>>31,s,w);e=z+i|0;f=ib+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Lc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Ob(h+8|0,x,y);e=f-(g&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;fb=h+16|0}function Bba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;h=fb-16|0;fb=h;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;o=v[a+32>>2];p=v[a+28>>2];q=v[a+72>>2];b=v[a+68>>2];r=b;s=b>>31;b=v[a+64>>2];t=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){e=Ub(b,-16777216,16776704);e=Bia(t,w,e,e>>31);k=ib;C=e;e=(v[h+12>>2]<<1)+n|0;g=v[h+8>>2]>>>21&2040;l=(((B(u[e>>1],u[g+39874>>1])+B(u[e-2>>1],u[g+39872>>1])|0)+B(u[e+2>>1],u[g+39876>>1])|0)+B(u[e+4>>1],u[g+39878>>1])|0)/16384<<8;e=l;m=Bia(e,e>>31,x,y);g=C+m|0;e=ib+k|0;e=g>>>0<m>>>0?e+1|0:e;f=Ub(f,-16777216,16776704);k=Bia(r,s,f,f>>31);g=k+g|0;f=ib+e|0;f=g>>>0<k>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Lc(e,f,24);e=(f|0)/256|0;j=j+p|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+o|0;v[c+4>>2]=v[c+4>>2]+B(e,i>>12);Ob(h+8|0,z,A);e=f-(q&l)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;fb=h+16|0}function gda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=fb-16|0;fb=f;u[f+12>>1]=c;u[f+14>>1]=b;u[f+10>>1]=d;h=x[v[v[a+24>>2]+8>>2]+12>>1];a:{if(h>>>0<=b>>>0){break a}if(!c|hj(a)>>>0>=h>>>0){break a}qg(f+12|0,h-b&65535);p=f,q=al(v[a>>2],v[a+4>>2]),u[p+8>>1]=q;g=x[f+12>>1];UR(a,g+x[Re(f+14|0,f+8|0)>>1]|0);c=v[a>>2];e=a;if(Ic(c,v[a+4>>2])>>>0<b>>>0){gg(e,b);c=v[e>>2]}a=Ab(c);c=fb-16|0;fb=c;v[c+8>>2]=a;a=v[EO(c+8|0,b)>>2];fb=c+16|0;a=v[dc(f,a)>>2];i=f+10|0;l=fb-32|0;fb=l;b=a;a=v[e>>2];d=(jo(b,Ab(a))<<1)+a|0;a=g;b:{if(!a){break b}b=v[Cb(e)>>2];g=v[e+4>>2];if(a>>>0<=b-g>>1>>>0){b=a;c=g-d>>1;if(c>>>0<a>>>0){po(e,a-c|0,i);b=c;if((d|0)==(g|0)){break b}}m=fb-16|0;fb=m;c=g;o=v[e+4>>2];g=(o-((a<<1)+d|0)|0)+d|0;n=Ci(m,e,c-g>>1);j=v[n+4>>2];k=g;while(1){if(c>>>0<=k>>>0){hc(n);cq(d,g,o);fb=m+16|0}else{Ai(j,x[k>>1]);j=j+2|0;v[n+4>>2]=j;k=k+2|0;continue}break}Et(d,b,((d>>>0<=i>>>0?y[e+4>>2]>i>>>0?a:0:0)<<1)+i|0);break b}b=Cb(e);b=vj(l+8|0,wj(e,Ic(v[e>>2],g)+a|0),d-v[e>>2]>>1,b);wC(b,a,i);d=CO(e,b,d);Di(b)}Ab(d);fb=l+32|0;if(Ic(v[e>>2],v[e+4>>2])>>>0<=h>>>0){break a}gg(e,h)}fb=f+16|0}function v7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;if(!w[a+4242|0]){Cx(a);a:{if(!w[a+4240|0]){break a}e=TL(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;us(a)}f=a+4256|0;b:{if(w[a+4244|0]){if(A[f>>3]>1){v[f>>2]=0;v[f+4>>2]=1072693248}break b}i=(v[a+4232>>2]&-2)!=4;e=A[f>>3];c:{if(D(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){Ax(a);e=A[a+4256>>3]}A[f>>3]=e-+(g|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=qi(A[f>>3]*6.283185307179586);break d;case 1:e=D(A[f>>3]+-.5)*-4+1;break d;case 2:e=A[f>>3];e=e+e+-1;break d;case 3:e=A[f>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=A[a+4280>>3]*e+A[a+4272>>3]*(1-e)}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];wN(h+8|0,1);g=Nj(a);f:{if(!g){break f}f=v[a+4236>>2];if(w[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|Yn(A[h+8>>3]*127)<<16,j=v[v[g>>2]+68>>2],jb[j](k|0,l|0)|0;break f}jb[v[v[g>>2]+44>>2]](g,f,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4264>>3]*+(d>>>0)+A[a+4256>>3]}g=a;a=v[a+44>>2];hi(g,b,c,zc(a,0),zc(a,1),d);fb=h+16|0}function Cba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0;g=fb-16|0;fb=g;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+32>>2];n=v[a+28>>2];o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){b=e;if(d){e=Ub(b,-16777216,16776704);e=Bia(r,s,e,e>>31);h=ib;f=Ub(f,-16777216,16776704);k=Bia(p,q,f,f>>31);e=k+e|0;f=ib+h|0;f=e>>>0<k>>>0?f+1|0:f;A=e;e=v[g+12>>2]+l|0;h=v[g+8>>2]>>>21&2040;h=(((B(t[e|0],u[h+39874>>1])+B(t[e-1|0],u[h+39872>>1])|0)+B(t[e+1|0],u[h+39876>>1])|0)+B(t[e+2|0],u[h+39878>>1])<<8)/16384<<8;e=h;k=Bia(e,e>>31,w,x);e=A+k|0;f=ib+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Lc(e,f,24);e=(f|0)/256|0;j=j+n|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+m|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Ob(g+8|0,y,z);e=f-(h&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;fb=g+16|0}function Qaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-16|0;fb=e;o=v[a+16>>2];p=Zf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){j=v[a+8>>2];k=v[a+12>>2];f=v[a>>2];g=v[a+4>>2];i=0;break a}j=v[a+8>>2];k=v[a+12>>2];m=_f(j,k,l);n=ib;b=v[a+76>>2];f=v[a>>2];g=v[a+4>>2];Df(f,g,af(j,k,d),ib);i=b>>>0<ib>>>0?d:0}h=a+112|0;q=v[a+24>>2];r=v[a+20>>2];v[e>>2]=f;v[e+4>>2]=g;b:while(1){if(d){b=v[e+4>>2];f=v[e>>2];v[e+8>>2]=f;v[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;f=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+o|0;b=l;while(1)if((b|0)<=0){Ob(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){g=(v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31;Hd(h,(u[(g<<1|2)+f>>1]+u[((g&2147483646)<<1)+f>>1]|0)/8<<16>>16);Gd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}f=v[c>>2];b=Yf(h,p);v[c>>2]=f+B(b,r);v[c+4>>2]=v[c+4>>2]+B(b,q);Ob(e,j,k);c=c+8|0;continue b}else{g=(v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31;Hd(h,(u[(g<<1|2)+f>>1]+u[((g&2147483646)<<1)+f>>1]|0)/8<<16>>16);Gd(h,4);Ob(e+8|0,m,n);b=b-1|0;continue}}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;fb=e+16|0}function vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;f=fb-16|0;fb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=((((v[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+j|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];t=u[e+2>>1];w=u[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+m|0;v[(h<<2)+f>>2]=(((((((B(u[e-8>>1],t)+B(u[e-12>>1],w)|0)+B(u[e-4>>1],s)|0)+B(u[e>>1],r)|0)+B(u[e+4>>1],q)|0)+B(u[e+8>>1],p)|0)+B(u[e+12>>1],o)|0)+B(u[e+16>>1],n)|0)/32768;h=h+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],k);Ob(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;fb=f+16|0}function yia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;t[d+24|0]=44;v[d+16>>2]=-1;v[d+20>>2]=0;v[d+8>>2]=1058;v[d+12>>2]=2;c=fb+-64|0;fb=c;h=v[d+8>>2]&2?16:10;f=fb-32|0;fb=f;e=Ge(f+16|0,1,0);a:{b:{c:{while(1){g=pc(e);WI(f+8|0,g,Bb(e)+g|0,v[b>>2],h);if(!v[f+12>>2]){break c}g=Ff(Bb(e));v[23220]=0;R(56,e|0,g|0);g=v[23220];v[23220]=0;if((g|0)!=1){continue}break}break b}b=v[f+8>>2];h=pc(e);v[23220]=0;R(57,e|0,b-h|0);b=v[23220];v[23220]=0;d:{if((b|0)!=1){v[23220]=0;R(58,c|0,e|0);b=v[23220];v[23220]=0;if((b|0)!=1){break d}break b}break b}ub(e);fb=f+32|0;break a}a=P()|0;O()|0;ub(e);S(a|0);L()}b=c+16|0;is(b,c,v[d+8>>2]);e=v[d+12>>2];f=v[d+8>>2];v[23220]=0;X(71,c+32|0,b|0,f|0,e|0);b=v[23220];v[23220]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=w[d+24|0];e=v[d+20>>2];v[23220]=0;X(72,c+48|0,c+32|0,e|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break i}v[23220]=0;R(55,a|0,c+48|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}ub(c+48|0);ub(c+32|0);ub(c+16|0);ub(c);fb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;ub(c+48|0)}ub(c+32|0)}ub(c+16|0);ub(c);S(a|0);L()}fb=d+32|0}function Dt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;t[d+24|0]=44;v[d+16>>2]=-1;v[d+20>>2]=0;v[d+8>>2]=1058;v[d+12>>2]=2;c=fb+-64|0;fb=c;h=v[d+8>>2]&2?16:10;f=fb-32|0;fb=f;e=Ge(f+16|0,1,0);a:{b:{c:{while(1){g=pc(e);_I(f+8|0,g,Bb(e)+g|0,w[b|0],h);if(!v[f+12>>2]){break c}g=Ff(Bb(e));v[23220]=0;R(56,e|0,g|0);g=v[23220];v[23220]=0;if((g|0)!=1){continue}break}break b}b=v[f+8>>2];h=pc(e);v[23220]=0;R(57,e|0,b-h|0);b=v[23220];v[23220]=0;d:{if((b|0)!=1){v[23220]=0;R(58,c|0,e|0);b=v[23220];v[23220]=0;if((b|0)!=1){break d}break b}break b}ub(e);fb=f+32|0;break a}a=P()|0;O()|0;ub(e);S(a|0);L()}b=c+16|0;is(b,c,v[d+8>>2]);e=v[d+12>>2];f=v[d+8>>2];v[23220]=0;X(71,c+32|0,b|0,f|0,e|0);b=v[23220];v[23220]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=w[d+24|0];e=v[d+20>>2];v[23220]=0;X(72,c+48|0,c+32|0,e|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break i}v[23220]=0;R(55,a|0,c+48|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}ub(c+48|0);ub(c+32|0);ub(c+16|0);ub(c);fb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;ub(c+48|0)}ub(c+32|0)}ub(c+16|0);ub(c);S(a|0);L()}fb=d+32|0}function f7(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb+-64|0;fb=b;g=Ib(a);v[23220]=0;Y(882,g|0);a=v[23220];v[23220]=0;a:{if((a|0)!=1){a=44720;b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((a|0)==45032){fb=b- -64|0;return g|0}k:{h=Es(44);if(h){d=v[a>>2];e=v[a+4>>2];v[23220]=0;e=Q(52,b+32|0,e|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break k}v[23220]=0;R(883,b+48|0,e|0);c=v[23220];v[23220]=0;if((c|0)==1){break j}c=v[a+8>>2];v[23220]=0;c=Q(52,b|0,c|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break i}v[23220]=0;R(883,b+16|0,c|0);f=v[23220];v[23220]=0;if((f|0)==1){break h}v[23220]=0;d=fa(884,h|0,d|0,b+48|0,b+16|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break g}Pb(b+16|0);ub(c);Pb(b+48|0);ub(e);v[b+60>>2]=d;v[23220]=0;R(885,g|0,b+60|0);e=v[23220];v[23220]=0;if((e|0)==1){break b}v[d+32>>2]=v[a+12>>2];v[d+36>>2]=v[a+16>>2];t[d+40|0]=w[a+20|0];t[d+41|0]=w[d+41|0]&253|w[a+21|0]<<1}a=a+24|0;continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;Pb(b+16|0)}ub(c)}Pb(b+48|0)}ub(e)}Fb(h);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}lc(g);S(a|0);L()}function Rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=fb-1072|0;fb=d;v[d+1068>>2]=c;o=d,p=Ae(b),t[o+8|0]=p;t[d+4|0]=1;c=d+8|0;g=w[$e(c,d+4|0)|0];f=hB(c,b);l=eq(f);v[23220]=0;c=T(189,b|0)|0;e=v[23220];v[23220]=0;a:{if((e|0)!=1){v[d+4>>2]=c;v[d>>2]=536870911;uc(d+1068|0,v[Eb(d+4|0,d)>>2]<<3);v[23220]=0;m=v[d+1068>>2];k=Q(326,a|0,m|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){v[23220]=0;c=8;h=Q(151,f|0,8)|0;a=v[23220];v[23220]=0;b:{if((a|0)!=1){c:{o=Hb(v[k>>2],0),p=h,t[o|0]=p;i=1;a=g;while(1){c=c&255;n=c>>>0>9?c:9;e=a;d:{e:{while(1){if(i>>>0>=m>>>0){break d}v[23220]=0;j=Q(151,f|0,c|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=g;continue}break}break c}a=j>>>1|0;h=(j&1?0-a|0:a)+h|0;o=Hb(v[k>>2],i),p=h,t[o|0]=p;i=i+1|0;a=g;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:g;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=eq(f);v[23220]=0;Q(142,b|0,((a-l|0)+3&-4)+l|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break b}}}c=P()|0;O()|0;$b(k);break a}wb(f);fb=d+1072|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0}wb(f);S(c|0);L()}function MZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=fb-448|0;fb=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=1126;b=he(a+24|0,a+32|0,a+20|0);h=a+16|0;Xc(h,e);v[23220]=0;h=T(1104,h|0)|0;i=v[23220];v[23220]=0;if((i|0)!=1){a:{t[a+15|0]=0;e=v[e+4>>2];v[23220]=0;c=pa(1134,a+440|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+432|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(ve(g)){td(v[g>>2],0);Bd(g,0);break d}td(g,0);ae(g,0)}if(w[a+15|0]){v[23220]=0;c=Q(1122,h|0,45)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}v[23220]=0;R(46,g|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break a}}v[23220]=0;c=Q(1122,h|0,48)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}d=v[a+20>>2];h=d-4|0;e=v[b>>2];while(1){if(!((c|0)!=v[e>>2]|e>>>0>=h>>>0)){e=e+4|0;continue}break}v[23220]=0;W(1139,g|0,e|0,d|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break c}break a}v[23220]=0;c=Q(1110,a+440|0,a+432|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}if(c){v[f>>2]=v[f>>2]|2}c=v[a+440>>2];Wb(a+16|0);Kc(b);fb=a+448|0;return c|0}}}c=P()|0;O()|0;Wb(a+16|0);Kc(b);S(c|0);L()}function qn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-80|0;fb=c;g=Ib(a);a=v[b+24>>2];a:{b:{if(gj(v[a+484360>>2],v[a+484364>>2])){c:{d:{e:while(1){if(gj(v[a+484360>>2],v[a+484364>>2])>>>0<=f>>>0){break d}d=KL(rR(c+40|0,1),f&255,0,0);v[23220]=0;e=v[d+12>>2];v[c+16>>2]=v[d+8>>2];v[c+20>>2]=e;e=v[d+20>>2];v[c+24>>2]=v[d+16>>2];v[c+28>>2]=e;e=v[d+4>>2];v[c+8>>2]=v[d>>2];v[c+12>>2]=e;X(1012,c- -64|0,a|0,0,c+8|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}j=c,k=Ab(v[c+64>>2]),v[j+32>>2]=k;d=Ab(v[c+68>>2]);while(1){a=v[c+32>>2];if(!Nb(a,d)){f=f+1|0;ti(c- -64|0);a=v[b+24>>2];continue e}h=A[a>>3];e=v[a+16>>2];i=x[a+24>>1];a=c+40|0;v[a+16>>2]=f;v[a+12>>2]=i;v[a+8>>2]=e;A[a>>3]=h;v[23220]=0;R(1031,g|0,a|0);a=v[23220];v[23220]=0;if((a|0)!=1){lz(c+32|0);continue}break}break}a=P()|0;O()|0;ti(c- -64|0);break b}fb=c+80|0;return}a=P()|0;O()|0;break b}b=aa(8)|0;v[23220]=0;d=Q(52,c+40|0,7228)|0;a=v[23220];v[23220]=0;if((a|0)!=1){a=qc(b,d);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ub(d);break b}a=P()|0;O()|0;ba(b|0)}Tf(g);S(a|0)}L()}function hE(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;t[e+24|0]=44;v[e+16>>2]=-1;v[e+20>>2]=0;v[e+8>>2]=1058;v[e+12>>2]=c;c=fb+-64|0;fb=c;g=e+8|0;i=v[g>>2]&2?16:10;f=fb-32|0;fb=f;d=Ge(f+16|0,1,0);a:{b:{c:{while(1){h=pc(d);lx(f+8|0,h,Bb(d)+h|0,v[b>>2],i);if(!v[f+12>>2]){break c}h=Ff(Bb(d));v[23220]=0;R(56,d|0,h|0);h=v[23220];v[23220]=0;if((h|0)!=1){continue}break}break b}b=v[f+8>>2];i=pc(d);v[23220]=0;R(57,d|0,b-i|0);b=v[23220];v[23220]=0;d:{if((b|0)!=1){v[23220]=0;R(58,c|0,d|0);b=v[23220];v[23220]=0;if((b|0)!=1){break d}break b}break b}ub(d);fb=f+32|0;break a}a=P()|0;O()|0;ub(d);S(a|0);L()}b=c+16|0;is(b,c,v[g>>2]);d=v[g+4>>2];f=v[g>>2];v[23220]=0;X(71,c+32|0,b|0,f|0,d|0);b=v[23220];v[23220]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=w[g+16|0];d=v[g+12>>2];v[23220]=0;X(72,c+48|0,c+32|0,d|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break i}v[23220]=0;R(55,a|0,c+48|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}ub(c+48|0);ub(c+32|0);ub(c+16|0);ub(c);fb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;ub(c+48|0)}ub(c+32|0)}ub(c+16|0);ub(c);S(a|0);L()}fb=e+32|0}function y9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=fb-16|0;fb=i;v[i+8>>2]=b;o=wf(a);while(1){if(vg(b,c)){b=v[dc(i,o)>>2];j=pd(v[i+8>>2]);m=fb-16|0;fb=m;n=0;k=fb-16|0;fb=k;h=fb-32|0;fb=h;f=h+28|0;d=h+24|0;e=fb-16|0;fb=e;a:{b:{if(!rc(b,v[dc(e+8|0,Hf(a))>>2])){g=w[j|0];l=w[pd(b)|0];if(!Bn(g,l)){break b}}v[e+8>>2]=b;g=dc(e,Ab(v[a>>2]));c:{d=v[e+8>>2];if(!rc(d,v[g>>2])){d=v[Yy(e+8|0)>>2];l=w[pd(d)|0];g=w[j|0];if(!Bn(l,g)){break c}}if(!v[b>>2]){v[f>>2]=b;break a}v[f>>2]=d;b=d+4|0;break a}b=yy(a,f,g);break a}if(Bn(l,g)){d:{d=Wy(b);if(!rc(d,v[dc(e+8|0,Hf(a))>>2])){g=w[j|0];if(!Bn(g,w[pd(d)|0])){break d}}if(!v[b+4>>2]){v[f>>2]=b;b=b+4|0;break a}v[f>>2]=d;b=d;break a}b=yy(a,f,g);break a}v[f>>2]=b;v[d>>2]=b;b=d}fb=e+16|0;d=b;b=v[b>>2];if(!b){b=fb-16|0;fb=b;e=fc(a);f=h+8|0;e=oh(f,tc(24),ph(b+8|0,e));GM(v[e>>2]+16|0,v[j>>2],v[j+4>>2]);p=fc(e),q=1,t[p+4|0]=q;fb=b+16|0;Tg(a,v[h+28>>2],d,v[h+8>>2]);b=Ud(f);_k(f);n=1}Sg(k+8|0,v[dc(h+8|0,b)>>2],n);fb=h+32|0;fb=k+16|0;dc(m+8|0,v[k+8>>2]);fb=m+16|0;b=v[Rg(i+8|0)>>2];continue}else{fb=i+16|0}break}}function GR(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;a:{if((d&255)>>>0<=4){while(1){d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!Ye(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!Ye(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){d=Ye(a,f+13|0);if(d){g=w[f+13|0];u[c>>1]=g<<1|1;t[b|0]=g>>>7;u[c>>1]=w[c|0]}if(!d){break a}if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!Ye(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){d=Ye(a,f+11|0);if(d){g=w[f+11|0];u[c>>1]=g<<1|1;t[b|0]=g>>>7;u[c>>1]=w[c|0]}if(!d){break a}if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}fb=f+16|0}function IU(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=fb-32|0;fb=g;t[g+12|0]=0;m=GB(g+16|0,d,g+12|0);f=v[m>>2];v[g+12>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=w[a|0];if(!(!i|(k|0)!=(e&255))){v[g+8>>2]=w[a+1|0];i=a+2|0;j=Eb(g+8|0,g+12|0);b:{k=b-2|0;if(!k){break b}j=v[j>>2];if(!(j&255)){break b}i=w[i|0];while(1){if(!(j&255)){break a}t[f|0]=i;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;j=j-1|0;continue}}t[f|0]=e;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;t[f|0]=k;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=v[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=t[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;t[c|0]=k;e=e-1|0;c=c+1|0;continue}break}$b(m);fb=g+32|0;return}n=w[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;t[l|0]=w[l|0]|B(f&n,257)>>>(h-j&7);l=b+1|0;b=d>>>0>l>>>0?l:0;j=j+1|0;h=(d>>>0<=l>>>0)+h|0;f=(f<<8|f)>>>1&255;continue}}}function zM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;f=B(b,872)+a|0;a:{if(c){xb(g+8|0,a+1074312|0,90);if(!yb(v[v[g+8>>2]>>2],v[g+12>>2])){t[(B(b,872)+a|0)+1075803|0]=c}t[(B(b,872)+a|0)+1075804|0]=c;break a}c=w[f+1075804|0]}f=f+1074992|0;h=c&255;i=0-h|0;e=a+480180|0;j=!(v[e>>2]&204473357)&(d^-1);uM(a,b,i,j);e=v[e>>2];b:{c:{if((e|0)!=268435456){if((e|0)!=16777216){break c}k=v[(B(b,872)+a|0)+1075648>>2];if(!k|!v[k+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){tM(v[a+1074392>>2],v[a+1074416>>2],f,240-h|0);break b}if(!(b>>>0<224|d)){sM(f,224-h|0);break b}rM(f,i);break b}v[(B(b,872)+a|0)+1075700>>2]=65535}d:{if(!((c&255)>>>0>223&j)){break d}e:{d=h&15;if(!d){break e}c=c&240;if((c|0)!=224){if((c|0)!=240){break e}ry(a,f,d);break b}if((e|0)==524288){break d}wM(a,f,d);break b}if((e|0)!=524288){break b}}f:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break f}if(v[a+1074416>>2]==1){xb(g+8|0,a+1074312|0,6);if(yb(v[v[g+8>>2]>>2],v[g+12>>2])){break f}e=v[a+480180>>2]}if(e&32832){break f}if(!(v[a+480208>>2]&2)|(e|0)!=8){break b}}Pj(a,f,(B(b,872)+a|0)+1075692|0,0-(h<<2)|0,0)}fb=g+16|0}function hr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;t[e+24|0]=44;v[e+16>>2]=-1;v[e+20>>2]=0;v[e+8>>2]=c;v[e+12>>2]=d;c=fb+-64|0;fb=c;g=e+8|0;i=v[g>>2]&2?16:10;f=fb-32|0;fb=f;d=Ge(f+16|0,1,0);a:{b:{c:{while(1){h=pc(d);lx(f+8|0,h,Bb(d)+h|0,v[b>>2],i);if(!v[f+12>>2]){break c}h=Ff(Bb(d));v[23220]=0;R(56,d|0,h|0);h=v[23220];v[23220]=0;if((h|0)!=1){continue}break}break b}b=v[f+8>>2];i=pc(d);v[23220]=0;R(57,d|0,b-i|0);b=v[23220];v[23220]=0;d:{if((b|0)!=1){v[23220]=0;R(69,c|0,d|0);b=v[23220];v[23220]=0;if((b|0)!=1){break d}break b}break b}ub(d);fb=f+32|0;break a}a=P()|0;O()|0;ub(d);S(a|0);L()}b=c+16|0;bs(b,c,v[g>>2]);d=v[g+4>>2];f=v[g>>2];v[23220]=0;X(73,c+32|0,b|0,f|0,d|0);b=v[23220];v[23220]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=w[g+16|0];d=v[g+12>>2];v[23220]=0;X(74,c+48|0,c+32|0,d|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break i}v[23220]=0;R(68,a|0,c+48|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);fb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}fb=e+32|0}function Fv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;t[e+24|0]=44;v[e+16>>2]=-1;v[e+20>>2]=0;v[e+8>>2]=c;v[e+12>>2]=d;c=fb+-64|0;fb=c;g=e+8|0;i=v[g>>2]&2?16:10;f=fb-32|0;fb=f;d=Ge(f+16|0,1,0);a:{b:{c:{while(1){h=pc(d);WI(f+8|0,h,Bb(d)+h|0,v[b>>2],i);if(!v[f+12>>2]){break c}h=Ff(Bb(d));v[23220]=0;R(56,d|0,h|0);h=v[23220];v[23220]=0;if((h|0)!=1){continue}break}break b}b=v[f+8>>2];i=pc(d);v[23220]=0;R(57,d|0,b-i|0);b=v[23220];v[23220]=0;d:{if((b|0)!=1){v[23220]=0;R(69,c|0,d|0);b=v[23220];v[23220]=0;if((b|0)!=1){break d}break b}break b}ub(d);fb=f+32|0;break a}a=P()|0;O()|0;ub(d);S(a|0);L()}b=c+16|0;bs(b,c,v[g>>2]);d=v[g+4>>2];f=v[g>>2];v[23220]=0;X(73,c+32|0,b|0,f|0,d|0);b=v[23220];v[23220]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=w[g+16|0];d=v[g+12>>2];v[23220]=0;X(74,c+48|0,c+32|0,d|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break i}v[23220]=0;R(68,a|0,c+48|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);fb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}fb=e+32|0}function Kv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;t[e+24|0]=44;v[e+16>>2]=-1;v[e+20>>2]=0;v[e+8>>2]=c;v[e+12>>2]=d;c=fb+-64|0;fb=c;g=e+8|0;i=v[g>>2]&2?16:10;f=fb-32|0;fb=f;d=Ge(f+16|0,1,0);a:{b:{c:{while(1){h=pc(d);_I(f+8|0,h,Bb(d)+h|0,w[b|0],i);if(!v[f+12>>2]){break c}h=Ff(Bb(d));v[23220]=0;R(56,d|0,h|0);h=v[23220];v[23220]=0;if((h|0)!=1){continue}break}break b}b=v[f+8>>2];i=pc(d);v[23220]=0;R(57,d|0,b-i|0);b=v[23220];v[23220]=0;d:{if((b|0)!=1){v[23220]=0;R(69,c|0,d|0);b=v[23220];v[23220]=0;if((b|0)!=1){break d}break b}break b}ub(d);fb=f+32|0;break a}a=P()|0;O()|0;ub(d);S(a|0);L()}b=c+16|0;bs(b,c,v[g>>2]);d=v[g+4>>2];f=v[g>>2];v[23220]=0;X(73,c+32|0,b|0,f|0,d|0);b=v[23220];v[23220]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=w[g+16|0];d=v[g+12>>2];v[23220]=0;X(74,c+48|0,c+32|0,d|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break i}v[23220]=0;R(68,a|0,c+48|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);fb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}fb=e+32|0}function B8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=fb-32|0;fb=j;e=b;b=v[a>>2];f=B(Bs(e,Ab(b)),6)+b|0;a:{if(!c){break a}b=v[Cb(a)>>2];g=v[a+4>>2];if((b-g|0)/6>>>0>=c>>>0){b=c;e=(g-f|0)/6|0;if(e>>>0<c>>>0){HA(a,c-e|0,d);b=e;if((f|0)==(g|0)){break a}}k=fb-16|0;fb=k;m=v[a+4>>2];h=B((m-(B(c,6)+f|0)|0)/6|0,6)+f|0;l=gq(k,a,(g-h|0)/6|0);i=v[l+4>>2];e=h;while(1){if(e>>>0>=g>>>0){hc(l);if((f|0)!=(h|0)){e=h-f|0;Zi(m+B((e|0)/-6|0,6)|0,f,e)}fb=k+16|0}else{Ot(i,e);i=i+6|0;v[l+4>>2]=i;e=e+6|0;continue}break}e=f;a=B(e>>>0<=d>>>0?y[a+4>>2]>d>>>0?c:0:0,6)+d|0;while(1){if(b){c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[e|0]=c;t[e+1|0]=c>>>8;t[e+2|0]=c>>>16;t[e+3|0]=c>>>24;c=w[a+4|0]|w[a+5|0]<<8;t[e+4|0]=c;t[e+5|0]=c>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=Cb(a);e=CS(j+8|0,DA(a,$j(v[a>>2],g)+c|0),(f-v[a>>2]|0)/6|0,b);BS(e,c,d);b=v[e+4>>2];d=e+4|0;zS(v[a>>2],f,d);h=v[a+4>>2];c=e+8|0;while(1){if((f|0)!=(h|0)){Ot(v[c>>2],f);v[c>>2]=v[c>>2]+6;f=f+6|0;continue}break}kc(a,d);kc(a+4|0,c);kc(Cb(a),vc(e));v[e>>2]=v[e+4>>2];f=b;AS(e)}Ab(f);fb=j+32|0}function LA(a,b){a:{b:{switch((w[a+3|0]|64)+-64|0){case 0:t[a+3|0]=w[a+5|0]?37:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(b){break a}b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=b?32:31;return;case 29:t[a+3|0]=b?33:0;return;case 27:t[a+3|0]=b?34:0;return;case 30:t[a+3|0]=b?35:0;return;case 31:t[a+3|0]=b?36:0;return;case 50:t[a+3|0]=b?25:0;return;case 51:t[a+3|0]=b?30:0;return;default:break b}}t[a+3|0]=0}}function wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;f=fb-16|0;fb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=(((v[f+12>>2]&2147483647)<<1|h>>>31)&-2)+j|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];w=u[e+2>>1];x=u[e>>1];h=0;while(1){if((h|0)!=2){e=h+m|0;v[(h<<2)+f>>2]=(((((((B(t[e-4|0],w)+B(t[e-6|0],x)|0)+B(t[e-2|0],s)|0)+B(t[e|0],r)|0)+B(t[e+2|0],q)|0)+B(t[e+4|0],p)|0)+B(t[e+6|0],o)|0)+B(t[e+8|0],n)<<8)/32768;h=h+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],k);Ob(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;fb=f+16|0}function X6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=0,x=0,y=0,A=C(0);h=v[a+44>>2];g=zc(h,0);h=zc(h,1);j=v[a+56>>2];n=zc(j,0);j=zc(j,1);e=sc(v[a+4208>>2],v[a+4212>>2]);o=B(v[v[a+16>>2]+1074404>>2],w[a+4233|0]);k=o<<1;if(e>>>0<k>>>0){Oj(a+4208|0,k)}l=w[a+4232|0];a:{if(l){e=v[a+4220>>2];k=v[a+4208>>2];u=l-1|0;l=0;while(1){if((d|0)==(l|0)){break a}r=z[h>>2];e=e>>>0<o>>>0?e:0;i=e-o|0;i=((i|0)<0?e:i)<<1;x=zb(k,i);f=z[zb(k,i|1)>>2];s=z[g>>2];t=z[x>>2];p=C(s+t);z[n>>2]=p;q=C(r+f);z[j>>2]=q;f=C(0);m=C(0);b:{c:{switch(u|0){case 0:f=z[a+4224>>2];m=C(q*f);f=C(p*f);break b;case 1:case 2:f=z[a+4224>>2];m=C(p*f);f=C(q*f);break b;case 3:break c;default:break b}}f=C(C(C(C(s+r)*C(.5))+t)*z[a+4224>>2]);m=f}j=j+4|0;n=n+4|0;h=h+4|0;g=g+4|0;i=e<<1;y=zb(k,i),A=C(D(f))<C(1.0000000195414814e-24)?C(0):f,z[y>>2]=A;y=zb(k,i|1),A=C(D(m))<C(1.0000000195414814e-24)?C(0):m,z[y>>2]=A;e=e+1|0;v[a+4220>>2]=e;l=l+1|0;continue}}e=g;g=d<<2;Yg(e,e+g|0,n);Yg(h,h+g|0,j)}g=a;a=v[a+56>>2];hi(g,b,c,zc(a,0),zc(a,1),d)}function AM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;f=B(b,872)+a|0;a:{if(c){xb(g+8|0,a+1074312|0,90);if(!yb(v[v[g+8>>2]>>2],v[g+12>>2])){t[(B(b,872)+a|0)+1075804|0]=c}t[(B(b,872)+a|0)+1075803|0]=c;break a}c=w[f+1075803|0]}f=f+1074992|0;h=c&255;e=a+480180|0;i=!(v[e>>2]&204473357)&(d^-1);uM(a,b,h,i);e=v[e>>2];b:{c:{if((e|0)!=268435456){if((e|0)!=16777216){break c}j=v[(B(b,872)+a|0)+1075648>>2];if(!j|!v[j+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){tM(v[a+1074392>>2],v[a+1074416>>2],f,h-240|0);break b}if(!(b>>>0<224|d)){sM(f,h-224|0);break b}rM(f,h);break b}v[(B(b,872)+a|0)+1075700>>2]=1}d:{if(!((c&255)>>>0>223&i)){break d}e:{d=h&15;if(!d){break e}c=c&240;if((c|0)!=224){if((c|0)!=240){break e}sy(a,f,d);break b}if((e|0)==524288){break d}vM(a,f,d);break b}if((e|0)!=524288){break b}}f:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break f}if(v[a+1074416>>2]==1){xb(g+8|0,a+1074312|0,6);if(yb(v[v[g+8>>2]>>2],v[g+12>>2])){break f}e=v[a+480180>>2]}if(e&32832){break f}if(!(v[a+480208>>2]&2)|(e|0)!=8){break b}}Pj(a,f,(B(b,872)+a|0)+1075692|0,h<<2,0)}fb=g+16|0}function SW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;f=Ib(a);a=0;a:{b:{c:{d:{e:{while(1){if((yv(b,c,a)|0)==-1){break b}e=yv(b,c,a);v[23220]=0;X(109,d|0,b|0,a|0,e-a|0);e=v[23220];v[23220]=0;if((e|0)!=1){v[23220]=0;R(110,d+16|0,d|0);e=v[23220];v[23220]=0;if((e|0)==1){break e}v[23220]=0;R(111,f|0,d+16|0);e=v[23220];v[23220]=0;if((e|0)==1){break d}vb(d+16|0);vb(d);a=yv(b,c,a)+nl(v[c+4>>2],w[c+11|0])|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(d+16|0)}vb(d);break a}f:{g:{h:{i:{j:{k:{if(rc(v[f>>2],v[f+4>>2])){v[23220]=0;X(109,d+16|0,b|0,a|0,-1);c=v[23220];v[23220]=0;if((c|0)==1){break j}c=nl(v[d+20>>2],w[d+27|0]);vb(d+16|0);if(!c){break k}}v[23220]=0;X(109,d|0,b|0,a|0,-1);a=v[23220];v[23220]=0;if((a|0)==1){break i}v[23220]=0;R(110,d+16|0,d|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}v[23220]=0;R(111,f|0,d+16|0);a=v[23220];v[23220]=0;if((a|0)==1){break g}vb(d+16|0);vb(d)}fb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+16|0)}vb(d)}rl(f);S(a|0);L()}function B6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),t=0,u=0,w=0,x=0,y=0,A=C(0);a:{j=v[a+4272>>2];if(!j){break a}if(!Th(a+44|0)){break a}f=v[a+44>>2];l=zc(f,0);m=zc(f,1);u=v[a+4252>>2]-1|0;i=v[a+4268>>2];k=v[a+4256>>2];n=d;f=v[a+56>>2];q=zc(f,0);o=q;r=zc(f,1);p=r;while(1){if(n){e=z[m>>2];f=i<<1;h=zb(k,f);g=z[l>>2];z[h>>2]=g;y=zb(k,f|1),A=e,z[y>>2]=A;s=z[a+4276>>2];e=C(C(D(iK(C(C(C(D(g))+C(D(e)))*C(536870912)),31,5)))*C(4.656612873077393e-10));e=C(C(C(s-e)*z[(e>=s?4236:4240)+a>>2])+e);z[a+4276>>2]=e;g=z[a+4244>>2];e=C(C(C(C(g-(e<g?g:e))*z[a+4248>>2])+C(.9999998807907104))*C(2147483648));b:{if(e<C(4294967296)&e>=C(0)){f=~~e>>>0;break b}f=0}t=((((i<<12)+u|0)+j|0)/4096|0)%(j|0)<<1;g=z[zb(k,t)>>2];h=f<<5;w=h;x=h|-2147483648;h=f>>>0<67108864;e=C(z[a+4232>>2]*C(C((h?w:x)>>>(h?31:32-(f>>>26|0)|0)>>>0)*C(4.656612873077393e-10)));z[o>>2]=g*e;y=p,A=C(z[zb(k,t|1)>>2]*e),z[y>>2]=A;i=((i?0:j)+i|0)-1|0;v[a+4268>>2]=i;n=n-1|0;p=p+4|0;o=o+4|0;m=m+4|0;l=l+4|0;continue}else{hi(a,b,c,q,r,d)}break}}}function kM(a){var b=0,c=0,d=0,e=0,f=0,g=0;while(1){if((f|0)!=4e3){g=fb-32|0;fb=g;b=ft(g);d=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);c=(f<<5)+a|0;e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[c|0]=e;t[c+1|0]=e>>>8;t[c+2|0]=e>>>16;t[c+3|0]=e>>>24;t[c+4|0]=d;t[c+5|0]=d>>>8;t[c+6|0]=d>>>16;t[c+7|0]=d>>>24;d=w[b+28|0]|w[b+29|0]<<8|(w[b+30|0]<<16|w[b+31|0]<<24);e=w[b+24|0]|w[b+25|0]<<8|(w[b+26|0]<<16|w[b+27|0]<<24);t[c+24|0]=e;t[c+25|0]=e>>>8;t[c+26|0]=e>>>16;t[c+27|0]=e>>>24;t[c+28|0]=d;t[c+29|0]=d>>>8;t[c+30|0]=d>>>16;t[c+31|0]=d>>>24;d=w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24);e=w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24);t[c+16|0]=e;t[c+17|0]=e>>>8;t[c+18|0]=e>>>16;t[c+19|0]=e>>>24;t[c+20|0]=d;t[c+21|0]=d>>>8;t[c+22|0]=d>>>16;t[c+23|0]=d>>>24;d=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);b=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[c+8|0]=b;t[c+9|0]=b>>>8;t[c+10|0]=b>>>16;t[c+11|0]=b>>>24;t[c+12|0]=d;t[c+13|0]=d>>>8;t[c+14|0]=d>>>16;t[c+15|0]=d>>>24;fb=g+32|0;f=f+1|0;continue}break}}function Sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0;g=fb-16|0;fb=g;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+32>>2];n=v[a+28>>2];o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];u=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Ub(b,-16777216,16776704);e=Bia(r,s,e,e>>31);i=ib;f=Ub(f,-16777216,16776704);h=Bia(p,q,f,f>>31);e=h+e|0;f=ib+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=v[g+12>>2]+l|0;e=t[h|0];z=i;i=((B(t[h+1|0]-e|0,v[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=Bia(e,e>>31,u,w);e=z+h|0;f=ib+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Lc(e,f,24);e=(f|0)/256|0;k=k+n|0;v[c>>2]=B(e,k>>12)+v[c>>2];j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Ob(g+8|0,x,y);e=f-(i&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=j>>12;fb=g+16|0}function BH(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=C(0),p=0;a:{if(w[b+21|0]){p=B(d,g);j=v[e>>2];l=v[f>>2];m=v[b>>2];b:{while(1){if((h|0)>0){if(v[a+1396>>2]<=9){Dk(a)}g=v[a+1392>>2];k=u[(((g&1023)<<1)+b|0)+36>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=w[k+v[b+8>>2]|0];v[a+1392>>2]=i>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;k=(g|0)>=0?k:-1;break c}k=Dl(a,b)}if((k|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((k|0)<0){if(!w[a+1376|0]){b=0;if(v[a+1384>>2]){break b}}Zb(a,21);return 0}g=0;n=B(d,l);m=((m+n|0)+j|0)>(p|0)?(p-n|0)+j|0:m;n=(m|0)>0?m:0;k=B(k,v[b>>2]);o=C(0);d:{if(w[b+22|0]){while(1){if((g|0)==(n|0)){break d}o=C(o+z[v[b+28>>2]+(g+k<<2)>>2]);i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=o+z[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(n|0)){break d}i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+C(z[v[b+28>>2]+(g+k<<2)>>2]+C(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}h=h-m|0;continue}break}v[e>>2]=j;v[f>>2]=l;b=1}return b}Zb(a,21);return 0}ca(7470,13164,1887,6512);L()}function nN(a,b){var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{switch(w[a+480224|0]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=Bia(c,c>>31,5e4,0);e=ib;b=v[Sc(d+12|0,d+8|0)>>2];c=Dc(Cia(c,e,b,b>>31),ib);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=Bia(c,c>>31,1e4,0);e=ib;b=v[Sc(d+12|0,d+8|0)>>2];c=Dc(Cia(c,e,b,b>>31),ib);break a;case 1:break b}}f=60/(+y[b+44>>2]/1e4*(+(Bia(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(ib>>>0)*4294967296))*+y[a+24620>>2];c:{d:{c=v[a+484344>>2];e=x[b+70>>1];if(!ke(c,v[a+484348>>2],e)){break d}c=Xb(c,e);if(!Nb(v[c+24>>2],v[c+28>>2])){break d}c=c+24|0;break c}c=a+480248|0}e=v[c>>2];c=v[c+4>>2];if(!rc(e,c)){f=f*+y[zb(e,y[b+48>>2]%(sc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(D(f)<2147483648){c=~~f;break e}c=-2147483648}f=A[b+8>>3]+(f-+(c>>>0));A[b+8>>3]=f;if(f>=1){A[b+8>>3]=f+-1;c=c+1|0;break a}if(!(A[a+1074384>>3]<=-1)){break a}A[b+8>>3]=f+1;c=c-1|0}b=Bia(v[a+480244>>2],0,c,0)+32768|0;a=ib;a=b>>>0<32768?a+1|0:a;a=Pc((a&65535)<<16|b>>>16,a>>>16|0);fb=d+16|0;return a?a:1}function k8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=C(0);h=u[d>>1];j=u[d+2>>1];a:{if((h|0)>(j|0)){break a}k=v[b>>2];g=sc(k,v[b+4>>2]);if(!g){break a}i=u[e>>1];if((i|0)<(h|0)|(i|0)>(j|0)|(g-1&65535)>>>0>(j-i&65535)>>>0|y[a+36>>2]>65535){break a}b:{while(1){if((f|0)==(g|0)){break b}i=zb(k,f);f=f+1|0;if(!(z[i>>2]<C(0))){continue}break}return 0}i=(f|0)!=(g|0);f=0;if(i){break a}l=z[c>>2];if(l<=C(0)){break a}u[a+28>>1]=h;u[a>>1]=1;m=a,n=$K(g),u[m+30>>1]=n;z[a+32>>2]=D(l);Oj(a+4|0,(j-h|0)+1|0);Yg(Ab(v[b>>2]),Ab(v[b+4>>2]),Yl(Ab(v[a+4>>2]),u[e>>1]-u[d>>1]|0));c=v[a+4>>2];g=u[a+30>>1];h=u[a+28>>1];b=u[e>>1];f=b;while(1){if((b&65535)!=32768&(f|0)>(h|0)){f=f-1|0;b=f-h|0;j=zb(c,b+g|0);m=zb(c,b),o=C(z[j>>2]/z[a+32>>2]),z[m>>2]=o;b=u[e>>1];continue}else{c=u[a+30>>1];e=u[a+28>>1];h=c+e|0;f=g;g=b<<16>>16;f=f+g|0;b=v[a+4>>2];d=u[d+2>>1];c=(g|0)<=(32767-c|0);while(1){if(c&(d|0)>=(f|0)){g=zb(b,f-h|0);m=zb(b,f-e|0),o=C(z[a+32>>2]*z[g>>2]),z[m>>2]=o;f=f+1|0;continue}else{kp(a)}break}}break}f=1}return f|0}function SZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=fb-160|0;fb=a;v[a+144>>2]=c;v[a+152>>2]=b;v[a+20>>2]=1126;b=he(a+24|0,a+32|0,a+20|0);h=a+16|0;Xc(h,e);v[23220]=0;h=T(18,h|0)|0;i=v[23220];v[23220]=0;if((i|0)!=1){a:{t[a+15|0]=0;e=v[e+4>>2];v[23220]=0;c=pa(1127,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}Lf(g);if(w[a+15|0]){v[23220]=0;c=Q(19,h|0,45)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}v[23220]=0;R(44,g|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break a}}v[23220]=0;c=Q(19,h|0,48)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}d=v[a+20>>2];h=d-1|0;e=v[b>>2];c=c&255;while(1){if(!((c|0)!=w[e|0]|e>>>0>=h>>>0)){e=e+1|0;continue}break}v[23220]=0;W(1133,g|0,e|0,d|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break c}break a}v[23220]=0;c=Q(1094,a+152|0,a+144|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}if(c){v[f>>2]=v[f>>2]|2}c=v[a+152>>2];Wb(a+16|0);Kc(b);fb=a+160|0;return c|0}}}c=P()|0;O()|0;Wb(a+16|0);Kc(b);S(c|0);L()}function Rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;g=fb-16|0;fb=g;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+32>>2];n=v[a+28>>2];o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];t=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Ub(b,-16777216,16776704);e=Bia(r,s,e,e>>31);i=ib;f=Ub(f,-16777216,16776704);h=Bia(p,q,f,f>>31);e=h+e|0;f=ib+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=(v[g+12>>2]<<1)+l|0;e=u[h>>1];z=i;i=e+((B(u[h+2>>1]-e|0,v[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=Bia(e,e>>31,t,w);e=z+h|0;f=ib+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Lc(e,f,24);e=(f|0)/256|0;k=k+n|0;v[c>>2]=B(e,k>>12)+v[c>>2];j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Ob(g+8|0,x,y);e=f-(i&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=j>>12;fb=g+16|0}function Hy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;f=a+1074312|0;xb(e+8|0,f,77);a:{if(j=yb(v[v[e+8>>2]>>2],v[e+12>>2]),k=0,l=v[c+88>>2]&134218752,l?j:k){break a}b:{c:{if(d){g=w[c+841|0];if(!g){break c}d=g-1|0;t[c+841|0]=d;if(d&255){break b}xb(e+8|0,f,16);if(!yb(v[v[e+8>>2]>>2],v[e+12>>2])&v[a+480180>>2]!=2){break a}a=v[b+48>>2]+1|0}else{a=v[b+48>>2]}v[c+764>>2]=a;break a}xb(e+8|0,f,17);d:{if(yb(v[v[e+8>>2]>>2],v[e+12>>2])|v[a+480180>>2]&3){break d}g=b+616|0;i=x[a+480188>>1];while(1){if((h&65535)>>>0>=i>>>0){break d}if(w[g+841|0]?(c|0)!=(g|0):0){break a}g=g+872|0;h=h+1|0;continue}}t[c+841|0]=d}d=v[c+764>>2];v[b+56>>2]=d;e:{if((d|0)==-1){break e}f:{if(v[b+60>>2]==-1){break f}xb(e+8|0,f,68);if(!yb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}v[b+60>>2]=d}v[b+64>>2]=d;xb(e+8|0,f,103);if(!yb(v[v[e+8>>2]>>2],v[e+12>>2])){break e}u[b+68>>1]=65535}if(v[a+480180>>2]!=2){break a}d=x[a+480188>>1];a=0;while(1){if((a|0)==(d|0)){break a}f=B(a,872)+b|0;v[f+1380>>2]=v[c+764>>2];t[f+1457|0]=w[c+841|0];a=a+1|0;continue}}fb=e+16|0}function $ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-48|0;fb=d;i=a+480280|0;while(1){a:{if(Lb(v[b>>2],v[b+8>>2],9)){e=d+44|0;eo(b,e);c=mg(b);b:{if(!Mb(e,13972,4)){break b}if(!Mb(d+44|0,13628,4)){break b}if(!Mb(d+44|0,13804,4)){break b}if(!Mb(d+44|0,13809,4)){break b}if(Lb(v[b>>2],v[b+8>>2],c)){break a}}jg(b,8)}fb=d+48|0;return j|0}Qd(d,b,c);e=gc(d+24|0,d);wb(d);c:{d:{e:{if(!Mb(d+44|0,13532,4)){c=0;while(1){if((c|0)==127){break c}v[23220]=0;f=T(144,e|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break e}t[((c<<5)+i|0)+8|0]=f;c=c+1|0;continue}}if(w[d+44|0]!=70){break d}f=w[d+45|0];h=(f|0)==88;f:{if(!h){if((f-48&255)>>>0>9){break d}c=t[d+46|0];if((c|0)>47){break f}break d}c=t[d+46|0];if((c|0)<48){break d}}if(c>>>0>57){break d}g=t[d+47|0];if((g|0)<48|(g|0)>57){break d}c=(g+(h?-16:B(f,100)+48|0)|0)+B(c,10)&255;if(c>>>0>249){break c}v[23220]=0;R(393,e|0,(B(c,160)+a|0)+906300|0);c=v[23220];v[23220]=0;if((c|0)!=1){break c}}a=P()|0;O()|0;wb(e);S(a|0);L()}if(Mb(d+44|0,13548,4)){break c}v[a+1074308>>2]=0;j=1}wb(e);continue}}function pQ(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-80|0;fb=c;v[c+72>>2]=0;v[c+76>>2]=0;b=c- -64|0;v[b>>2]=0;v[b+4>>2]=0;v[c+56>>2]=0;v[c+60>>2]=0;v[c+48>>2]=0;v[c+52>>2]=0;rz(a,sz(a),c+48|0);b=oc(c+40|0,14165);Te(le(a,0),v[b>>2],v[b+4>>2]);b=oc(c+32|0,14269);Te(le(a,1),v[b>>2],v[b+4>>2]);b=oc(c+24|0,5457);Te(le(a,3),v[b>>2],v[b+4>>2]);b=oc(c+16|0,15650);Te(le(a,4),v[b>>2],v[b+4>>2]);b=oc(c+8|0,9236);Te(le(a,8),v[b>>2],v[b+4>>2]);e=le(a+288|0,0);b=fb-16|0;fb=b;d=e;e=oc(b+8|0,4893);Te(d,v[e>>2],v[e+4>>2]);fb=b+16|0;e=a+800|0;b=0;a=fb-80|0;fb=a;a:{b:{while(1){if((b|0)==128){break a}v[a+76>>2]=b<<3;c:{d:{if(b>>>0<=15){ku(a+32|0,4045);v[23220]=0;R(277,a+16|0,a+76|0);d=v[23220];v[23220]=0;if((d|0)==1){break c}v[23220]=0;U(278,a+48|0,a+32|0,a+16|0);d=v[23220];v[23220]=0;if((d|0)!=1){d=a+48|0;re(a- -64|0,d);Te(le(e,b),v[a+64>>2],v[a+68>>2]);ub(d);ub(a+16|0);Pb(a+32|0);break d}b=P()|0;O()|0;ub(a+16|0);break b}d=oc(a+8|0,21598);Te(le(e,b),v[d>>2],v[a+12>>2])}b=b+1|0;continue}break}b=P()|0;O()|0}Pb(a+32|0);S(b|0);L()}fb=a+80|0;fb=c+80|0}function wH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-208|0;fb=d;v[d+8>>2]=1;v[d+12>>2]=0;h=b<<2;a:{if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;g=4;e=2;while(1){f=b;b=(b+g|0)+4|0;v[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;g=f;if(b>>>0<h>>>0){continue}break}f=(a+h|0)-4|0;b:{if(f>>>0<=a>>>0){e=1;b=1;f=0;break b}e=1;b=1;while(1){c:{if((e&3)==3){Mw(a,c,b,d+16|0);Sr(d+8|0,2);b=b+2|0;break c}g=b-1|0;d:{if(y[(d+16|0)+(g<<2)>>2]>=f-a>>>0){Rr(a,c,e,v[d+12>>2],b,0,d+16|0);break d}Mw(a,c,b,d+16|0)}if((b|0)==1){Qr(d+8|0,1);b=0;break c}Qr(d+8|0,g);b=1}e=v[d+8>>2]|1;v[d+8>>2]=e;a=a+4|0;if(f>>>0>a>>>0){continue}break}f=v[d+12>>2]}Rr(a,c,e,f,b,0,d+16|0);e=v[d+8>>2];g=v[d+12>>2];if(!(g?1:(b|0)!=1|(e|0)!=1)){break a}while(1){e:{if((b|0)<=1){f=pH(e,g);Sr(d+8|0,f);b=b+f|0;break e}g=d+8|0;Qr(g,2);v[d+8>>2]=v[d+8>>2]^7;Sr(g,1);h=a-4|0;e=d+16|0;f=b-2|0;Rr(h-v[e+(f<<2)>>2]|0,c,v[d+8>>2],v[d+12>>2],b-1|0,1,e);Qr(g,1);b=v[d+8>>2]|1;v[d+8>>2]=b;Rr(h,c,b,v[d+12>>2],f,1,e);b=f}a=a-4|0;g=v[d+12>>2];e=v[d+8>>2];if(g|((b|0)!=1|(e|0)!=1)){continue}break}}fb=d+208|0}function Qn(a,b,c,d){var e=0;e=fb-16|0;fb=e;t[a+841|0]=0;v[a+708>>2]=0;t[a+797|0]=0;v[a+764>>2]=0;u[a+802>>1]=0;u[a+804>>1]=0;v[a+696>>2]=0;v[a+668>>2]=0;v[a+88>>2]=v[a+88>>2]|6144;xb(e+8|0,b+1074312|0,23);if(yb(v[v[e+8>>2]>>2],v[e+12>>2])){t[a+807|0]=1;t[a+808|0]=0}t[a+846|0]=0;t[a+839|0]=0;u[a+774>>1]=0;t[a+850|0]=255;v[a+660>>2]=0;t[a+851|0]=w[a+851|0]&224;Vn(a+788|0);v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;t[a+845|0]=0;t[a+838|0]=0;t[a+821|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+836>>1]=32512;t[a+819|0]=0;t[a+820|0]=0;u[a+842>>1]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+852>>2]=0;v[a+856>>2]=0;t[a+851|0]=w[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=v[b+480280>>2];v[a+88>>2]=c;v[a+692>>2]=x[b+480284>>1];v[a+748>>2]=x[b+480286>>1];if(!(c&1024)){break a}v[a+88>>2]=c&-1025|d;break a}v[a+748>>2]=64;v[a+692>>2]=128;v[a+88>>2]=0}u[a+784>>1]=0;t[a+795|0]=0;t[a+796|0]=0;fb=e+16|0}function FN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-32|0;fb=f;n=Zy(v[a+24>>2],w[a+32|0]);o=hj(n);a:{while(1){b:{u[b>>1]=m;d=m&65535;if(d>>>0>=o>>>0){break b}c:{if(!iq(n,d)){break c}d=v[a>>2];h=rd(d,v[a+4>>2]);e=x[b>>1];if(h>>>0<=e>>>0){v[c>>2]=0;break a}k=Dd(d,e);Xk(f+16|0,v[k>>2]);$l(f+8|0,v[k>>2],v[k+4>>2]);i=f+24|0;d=v[f+16>>2];g=v[f+20>>2];e=Wk(v[f+8>>2],v[f+12>>2],d,g);j=fb-16|0;fb=j;v[j+12>>2]=e;d:{if(g){h=32-g|0;v[j+8>>2]=h;l=h;h=v[Eb(j+8|0,j+12|0)>>2];l=-1<<g&-1>>>l-h&v[d>>2];if(l){cc(i,d,Aia(l));break d}if((e|0)==(h|0)){v[i>>2]=d;v[i+4>>2]=g;eP(i,e);break d}e=e-h|0;d=d+4|0}while(1){if(e>>>0>=32){g=v[d>>2];if(g){cc(i,d,Aia(g));break d}else{e=e-32|0;v[j+12>>2]=e;d=d+4|0;continue}}break}if(!e){cc(i,d,0);break d}g=v[d>>2]&-1>>>32-e;if(!g){cc(i,d,e);break d}cc(i,d,Aia(g))}fb=j+16|0;$l(f,v[k>>2],v[k+4>>2]);if(!(v[f+24>>2]==v[f>>2]&v[f+28>>2]==v[f+4>>2])){break c}v[c>>2]=0;break a}m=x[b>>1]+1|0;continue}break}u[b>>1]=65535;v[c>>2]=-1}fb=f+32|0;return(m&65535)>>>0<o>>>0|0}function j7(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0;c=fb-32|0;fb=c;a:{d=v[a+20>>2];b:{if(!d){break b}v[d+148>>2]=-1;h=c,i=jb[v[v[a>>2]+40>>2]](a)|0,v[h+16>>2]=i;v[c+8>>2]=1073741822;f=v[Eb(c+16|0,c+8|0)>>2];b=f<<2;if(!b){break b}e=v[a+20>>2];d=0;v[23220]=0;R(275,e+4|0,b+4|0);b=v[23220];v[23220]=0;c:{d:{if((b|0)!=1){b=v[a+20>>2];ge(c+8|0,v[b+4>>2],v[b+8>>2]);v[c>>2]=0;v[c+4>>2]=0;e=v[c+12>>2];b=c+16|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=e;e=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=e;e=fb-16|0;fb=e;v[e+8>>2]=0;zK(b,e+8|0);fb=e+16|0;b=v[v[a>>2]+180>>2];v[23220]=0;R(b|0,a|0,-1);b=v[23220];v[23220]=0;if((b|0)==1){break d}while(1){if((d|0)==(f|0)){d=v[v[a>>2]+184>>2];v[23220]=0;Y(d|0,a|0);d=v[23220];v[23220]=0;if((d|0)!=1){break b}break d}b=v[v[a>>2]+48>>2];v[23220]=0;g=C(Xa(b|0,a|0,d|0));b=v[23220];v[23220]=0;if((b|0)!=1){z[c+8>>2]=g;d=d+1|0;zK(c+16|0,c+8|0);continue}break}d=V(91480)|0;break c}d=V(91480)|0;break c}d=V(91480)|0}if((O()|0)!=(ea(91480)|0)){break a}_(d|0)|0;Bc(v[a+20>>2]+4|0);$()}fb=c+32|0;return}S(d|0);L()}function tU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=fb-32|0;fb=h;e=b;b=v[a>>2];b=(jo(e,Ab(b))<<1)+b|0;a:{b:{f=v[a+4>>2];if(f>>>0<y[Cb(a)>>2]){if((b|0)!=(f|0)){break b}d=fb-16|0;fb=d;a=Ci(d,a,1);mq(v[a+4>>2],w[c|0]|w[c+1|0]<<8);v[a+4>>2]=v[a+4>>2]+2;hc(a);fb=d+16|0;break a}d=Cb(a);d=vj(h+8|0,wj(a,Ic(v[a>>2],f)+1|0),b-v[a>>2]>>1,d);v[23220]=0;R(282,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)!=1){c=v[d+4>>2];f=d+4|0;Ip(v[a>>2],b,f);g=v[a+4>>2];e=d+8|0;while(1){if((b|0)!=(g|0)){mq(v[e>>2],w[b|0]|w[b+1|0]<<8);v[e>>2]=v[e>>2]+2;b=b+2|0;continue}break}kc(a,f);kc(a+4|0,e);kc(Cb(a),vc(d));v[d>>2]=v[d+4>>2];b=c;Di(d);break a}a=P()|0;O()|0;Di(d);S(a|0);L()}i=fb-16|0;fb=i;j=v[a+4>>2];e=(j-(b+2|0)|0)+b|0;k=Ci(i,a,f-e>>1);g=v[k+4>>2];d=e;while(1){if(d>>>0>=f>>>0){hc(k);while(1){if((b|0)!=(e|0)){e=e-2|0;j=lU(j-2|0,e);continue}break}fb=i+16|0}else{mq(g,w[d|0]|w[d+1|0]<<8);g=g+2|0;v[k+4>>2]=g;d=d+2|0;continue}break}a=((b>>>0<=c>>>0&y[a+4>>2]>c>>>0)<<1)+c|0;c=w[a|0];t[b+1|0]=w[a+1|0];t[b|0]=c}Ab(b);fb=h+32|0}function Oaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;p=v[a+16>>2];q=Zf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){k=v[a+8>>2];m=v[a+12>>2];f=v[a>>2];b=v[a+4>>2];h=0;break a}b=v[a+12>>2];m=b;k=v[a+8>>2];n=_f(k,b,l);o=ib;h=v[a+76>>2];f=v[a>>2];b=v[a+4>>2];Df(f,b,af(k,m,d),ib);h=h>>>0<ib>>>0?d:0}g=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[e>>2]=f;v[e+4>>2]=b;b:while(1){if(d){d=d-1|0;v[e+8>>2]=f;v[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;f=(b<<1)+p|0;b=l;while(1)if((b|0)<=0){Ob(g,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Hd(g,u[f+(v[e+12>>2]<<1)>>1]/4<<16>>16);Gd(g,b);v[g>>2]=v[g>>2];v[g+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;f=Yf(g,q);v[c>>2]=B(j>>12,f)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(f,i>>12);Ob(e,k,m);c=c+8|0;f=v[e>>2];b=v[e+4>>2];continue b}else{Hd(g,u[f+(v[e+12>>2]<<1)>>1]/4<<16>>16);Gd(g,4);Ob(e+8|0,n,o);b=b-1|0;continue}}break}v[a>>2]=f;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;fb=e+16|0}function tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){e=(v[f+12>>2]<<1)+l|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(u[e-4>>1],u[h+2>>1])+B(u[e-6>>1],u[h>>1])|0)+B(u[e-2>>1],u[h+4>>1])|0)+B(u[e>>1],u[h+6>>1])|0)+B(u[e+2>>1],u[h+8>>1])|0)+B(u[e+4>>1],u[h+10>>1])|0)+B(u[e+6>>1],u[h+12>>1])|0)+B(u[e+8>>1],u[h+14>>1])|0)/32768|0;k=k+n|0;v[c>>2]=v[c>>2]+B(e,k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(e,j>>12);Ob(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;fb=f+16|0}function PO(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0;i=fb-16|0;fb=i;if(lj(v[a+656>>2])){e=w[a+797|0];g=Oc(e);f=w[a+799|0];xb(i+8|0,d+1074312|0,34);d=g?e:f;a:{if(!yb(v[v[i+8>>2]>>2],v[i+12>>2])){break a}e=d&255;if(!e|e>>>0>120){break a}d=w[Hb(v[a+656>>2]+108|0,e-1|0)|0]}l=C(C(v[a+704>>2])*b);e=v[v[a+656>>2]+44>>2];f=((d&255)+c<<16)-3997696>>16;b:{c:{c=v[a+852>>2]+u[a+772>>1]|0;if(c){h=v[e+36>>2];if(h){break c}}b=Kl(e,c+f<<16>>16);break b}k=h+1|0;j=Kx(c,k);d=xn(c,k);b=C(1);g=u[e+28>>1];c=f+j<<16>>16;d:{if((g|0)>(c|0)){break d}f=v[e+4>>2];if((c|0)>(sc(f,v[e+8>>2])+g<<16)-65536>>16){break d}if(!d){b=z[zb(f,c-g|0)>>2];break b}e:{f:{g:{switch(x[e>>1]-1|0){case 2:h=v[e+16>>2];if(!sc(h,v[e+20>>2])){break f}b=z[zb(h,d-1|0)>>2];break e;case 0:break g;default:break f}}j=v[e+16>>2];if(!sc(j,v[e+20>>2])){break f}b=z[zb(j,(d+B(h,xn(c,x[e+30>>1])<<16>>16)|0)-1|0)>>2];break e}b=ie(C(Kl(e,(c<<16)+65536>>16)/Kl(e,c)),C(C(d|0)/C(k|0)))}b=C(b*z[zb(f,c-g|0)>>2])}}m=a,n=kj(C(C(l*b)*C(16))),v[m+700>>2]=n}fb=i+16|0}function F8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;kd(c,0);u[d+14>>1]=w[a+36|0]|w[a+37|0]<<8;u[d+12>>1]=32767;g=c,h=(x[Tc(d+14|0,d+12|0)>>1]<<8>>>0)/32767|0,u[g+28>>1]=h;u[d+10>>1]=w[a+38|0]|w[a+39|0]<<8;u[d+8>>1]=32767;g=c,h=(x[Tc(d+10|0,d+8|0)>>1]<<8>>>0)/32767|0,u[g+30>>1]=h;u[c+32>>1]=64;v[c>>2]=w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24);v[c+4>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[c+8>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);v[c+24>>2]=w[a+56|0]|w[a+57|0]<<8|(w[a+58|0]<<16|w[a+59|0]<<24);e=w[b+166|0];if(e>>>0<=4){t[c+38|0]=w[e+42874|0]}e=w[b+167|0]|w[b+168|0]<<8;t[c+39|0]=e;f=(w[b+171|0]|w[b+172|0]<<8)>>>4|0;t[c+41|0]=f;b=(w[b+169|0]|w[b+170|0]<<8)>>>2|0;t[c+40|0]=b;if((b|f)&255){t[c+39|0]=e^-1}b=w[a+40|0]|w[a+41|0]<<8;if(b&4){u[c+34>>1]=x[c+34>>1]|1;b=w[a+40|0]|w[a+41|0]<<8}if(b&8){u[c+34>>1]=x[c+34>>1]|2;b=w[a+40|0]|w[a+41|0]<<8}if(b&16){u[c+34>>1]=x[c+34>>1]|4;b=w[a+40|0]|w[a+41|0]<<8}if(b&32){u[c+34>>1]=x[c+34>>1]|32}fb=d+16|0}function AH(a,b,c,d,e){var f=C(0),g=0,h=C(0),i=0,j=C(0),k=C(0);if(!(a&3)){b=(c<<2)+b|0;c=b+(d<<2)|0;a=a>>2;while(1){if((a|0)>0){d=c-4|0;h=z[d>>2];j=z[b>>2];k=z[c>>2];z[b>>2]=j+k;g=b-4|0;f=z[g>>2];z[g>>2]=f+z[d>>2];j=C(j-k);f=C(f-h);z[c>>2]=C(j*z[e>>2])-C(z[e+4>>2]*f);z[d>>2]=C(f*z[e>>2])+C(j*z[e+4>>2]);d=c-12|0;j=z[d>>2];g=b-8|0;f=z[g>>2];i=g;g=c-8|0;k=z[g>>2];z[i>>2]=f+k;i=b-12|0;h=z[i>>2];z[i>>2]=h+z[d>>2];f=C(f-k);h=C(h-j);z[g>>2]=C(f*z[e+32>>2])-C(z[e+36>>2]*h);z[d>>2]=C(h*z[e+32>>2])+C(f*z[e+36>>2]);d=c-20|0;j=z[d>>2];g=b-16|0;f=z[g>>2];i=g;g=c-16|0;k=z[g>>2];z[i>>2]=f+k;i=b-20|0;h=z[i>>2];z[i>>2]=h+z[d>>2];f=C(f-k);h=C(h-j);z[g>>2]=C(f*z[e+64>>2])-C(z[e+68>>2]*h);z[d>>2]=C(h*z[e+64>>2])+C(f*z[e+68>>2]);d=c-28|0;j=z[d>>2];g=b-24|0;f=z[g>>2];i=g;g=c-24|0;k=z[g>>2];z[i>>2]=f+k;i=b-28|0;h=z[i>>2];z[i>>2]=h+z[d>>2];f=C(f-k);h=C(h-j);z[g>>2]=C(f*z[e+96>>2])-C(z[e+100>>2]*h);z[d>>2]=C(h*z[e+96>>2])+C(f*z[e+100>>2]);a=a-1|0;c=c-32|0;b=b-32|0;e=e+128|0;continue}break}return}ca(15739,13164,2423,9182);L()}function Fba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;h=fb-16|0;fb=h;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];t=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Ub(b,-16777216,16776704);e=Bia(r,s,e,e>>31);i=ib;z=e;e=(v[h+12>>2]<<1)+n|0;g=v[h+8>>2]>>>21&2040;j=(((B(u[e>>1],u[g+39874>>1])+B(u[e-2>>1],u[g+39872>>1])|0)+B(u[e+2>>1],u[g+39876>>1])|0)+B(u[e+4>>1],u[g+39878>>1])|0)/16384<<8;e=j;k=Bia(e,e>>31,t,w);g=z+k|0;e=ib+i|0;e=g>>>0<k>>>0?e+1|0:e;f=Ub(f,-16777216,16776704);i=Bia(p,q,f,f>>31);g=i+g|0;f=ib+e|0;f=g>>>0<i>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Lc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Ob(h+8|0,x,y);e=f-(o&j)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;fb=h+16|0}function H6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;e=fb-160|0;fb=e;d=e+24|0;f=d+56|0;c=ss(f);v[d>>2]=77028;v[c>>2]=77048;v[d+56>>2]=77088;v[d>>2]=77068;h=f;f=d+4|0;sn(h,f);v[d>>2]=77028;v[c>>2]=77048;c=ms(f);v[c>>2]=76512;Gb(c+32|0);v[c+44>>2]=0;v[c+48>>2]=16;c=v[v[d>>2]-12>>2];v[23220]=0;f=ha(59)|0;h=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{if((h|0)==1){break f}v[23220]=0;U(60,e+16|0,c+d|0,f|0);c=v[23220];v[23220]=0;if((c|0)==1){break f}Wb(e+16|0);c=fb-16|0;fb=c;v[c+8>>2]=17;fb=c+16|0;Gl(v[v[d>>2]-12>>2]+d|0,v[c+8>>2]);i=A[b>>3];v[23220]=0;b=Ya(61,d|0,+i)|0;c=v[23220];v[23220]=0;if((c|0)==1){break e}v[23220]=0;R(62,e|0,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break d}v[23220]=0;R(58,g|0,e|0);c=v[23220];v[23220]=0;if((c|0)==1){break c}ub(e);fp(b);fb=e+160|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;ub(e)}fp(d);S(a|0);L()}v[23220]=0;R(55,a|0,g|0);a=v[23220];v[23220]=0;if((a|0)!=1){ub(g);fb=g+16|0;return}a=P()|0;O()|0;ub(g);S(a|0);L()}function uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){e=v[f+12>>2]+l|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(t[e-2|0],u[h+2>>1])+B(t[e-3|0],u[h>>1])|0)+B(t[e-1|0],u[h+4>>1])|0)+B(t[e|0],u[h+6>>1])|0)+B(t[e+1|0],u[h+8>>1])|0)+B(t[e+2|0],u[h+10>>1])|0)+B(t[e+3|0],u[h+12>>1])|0)+B(t[e+4|0],u[h+14>>1])<<8)/32768|0;k=k+n|0;v[c>>2]=v[c>>2]+B(e,k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(e,j>>12);Ob(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;fb=f+16|0}function rz(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a|0]=e;t[a+1|0]=e>>>8;t[a+2|0]=e>>>16;t[a+3|0]=e>>>24;t[a+4|0]=d;t[a+5|0]=d>>>8;t[a+6|0]=d>>>16;t[a+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[a+24|0]=e;t[a+25|0]=e>>>8;t[a+26|0]=e>>>16;t[a+27|0]=e>>>24;t[a+28|0]=d;t[a+29|0]=d>>>8;t[a+30|0]=d>>>16;t[a+31|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[a+16|0]=e;t[a+17|0]=e>>>8;t[a+18|0]=e>>>16;t[a+19|0]=e>>>24;t[a+20|0]=d;t[a+21|0]=d>>>8;t[a+22|0]=d>>>16;t[a+23|0]=d>>>24;d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);e=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+8|0]=e;t[a+9|0]=e>>>8;t[a+10|0]=e>>>16;t[a+11|0]=e>>>24;t[a+12|0]=d;t[a+13|0]=d>>>8;t[a+14|0]=d>>>16;t[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function Gj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=fb-32|0;fb=i;v[i+16>>2]=c;v[i+24>>2]=b;c=i+8|0;Xc(c,d);b=0;v[23220]=0;j=T(18,c|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){Wb(i+8|0);v[e>>2]=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(Ij(i+24|0,i+16|0)){break b}c:{if((Um(j,t[g|0])|0)==37){b=g+1|0;if((h|0)==(b|0)){break b}d:{e:{c=Um(j,t[b|0]);if((c|0)==69){break e}k=0;if((c&255)==48){break e}b=g;break d}if((g+2|0)==(h|0)){break b}k=c;c=Um(j,t[g+2|0])}l=i,m=jb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,c,k)|0,v[l+24>>2]=m;g=b+2|0;break c}b=v[j+8>>2];if(eh(b,8192,t[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(eh(b,8192,t[g|0])){continue}}break}while(1){if(!Zo(i+24|0,i+16|0)){break c}b=Ak(v[i+24>>2]);if(!eh(v[j+8>>2],8192,b)){break c}Al(i+24|0);continue}}if((iw(j,Ak(v[i+24>>2]))|0)==(iw(j,t[g|0])|0)){g=g+1|0;Al(i+24|0);break c}v[e>>2]=4}b=v[e>>2];continue}break}v[e>>2]=4}if(Ij(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}fb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Wb(i+8|0);S(a|0);L()}function Ac(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=v[b>>2];e=fb-48|0;fb=e;f=v[b+4>>2];b=w[b+8|0];d=f-(((b|0)==1|(b|0)==4)&(f|0)!=0)|0;f=Gb(a);b:{c:{d:{e:{f:{g:{h:{if((b-1&255)>>>0<=1){t[e+32|0]=0;a=mi(c,c+d|0,e+32|0);v[23220]=0;W(50,f|0,c|0,a|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}if((b-3&255)>>>0>1){break h}v[23220]=0;b=W(50,f|0,c|0,c+d|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break g}c=Td(b);d=ih(b);g=Td(b);a=fb-32|0;fb=a;v[a+16>>2]=d;v[a+24>>2]=c;v[a+8>>2]=g;while(1){if(Kh(a+24|0,a+16|0)){c=a+8|0;d=a+24|0;g=t[v[d>>2]];t[v[c>>2]]=g?g:32;xe(d);xe(c);continue}break}fb=a+32|0;v[23220]=0;c=Q(51,e+16|0,b|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break f}v[23220]=0;d=Q(52,e|0,17769)|0;a=v[23220];v[23220]=0;if((a|0)==1){break e}v[23220]=0;U(53,e+32|0,c|0,d|0);a=v[23220];v[23220]=0;if((a|0)==1){break d}a=e+32|0;xc(b,a);ub(a);ub(d);ub(c)}fb=e+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;ub(d)}ub(c)}ub(f);S(a|0);L()}}function M_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=jb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Xc(g,d);v[23220]=0;b=T(1104,g|0)|0;a=v[23220];v[23220]=0;d:{e:{f:{g:{if((a|0)!=1){Wb(g);Xc(g,d);v[23220]=0;a=T(1105,g|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break g}Wb(g);v[23220]=0;R(1106,g|0,a|0);d=v[23220];v[23220]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[23220]=0;R(1107,g|12,a|0);a=v[23220];v[23220]=0;if((a|0)==1){break f}v[23220]=0;d=g+24|0;a=ua(1108,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[23220];v[23220]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Nc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;Nc(g);break d}b=P()|0;O()|0;while(1){d=Nc(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}fb=g+32|0;return b|0}function X_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=jb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Xc(g,d);v[23220]=0;b=T(18,g|0)|0;a=v[23220];v[23220]=0;d:{e:{f:{g:{if((a|0)!=1){Wb(g);Xc(g,d);v[23220]=0;a=T(1087,g|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break g}Wb(g);v[23220]=0;R(1088,g|0,a|0);d=v[23220];v[23220]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[23220]=0;R(1089,g|12,a|0);a=v[23220];v[23220]=0;if((a|0)==1){break f}v[23220]=0;d=g+24|0;a=ua(1090,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[23220];v[23220]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=ub(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;ub(g);break d}b=P()|0;O()|0;while(1){d=ub(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}fb=g+32|0;return b|0}function Kj(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;o(+a);b=j(1)|0;e=j(0)|0;f=b>>>20&2047;a:{if(f-969>>>0>=63){if(f>>>0<=968){return a+1}b:{if(f>>>0<1033){break b}c=0;if(!e&(b|0)==-1048576){break a}if((f|0)==2047){return a+1}if((b|0)>0|(b|0)>=0){return kr(3.105036184601418e231)}if(b>>>0<3230714880){break b}return kr(1.2882297539194267e-231)}b=b<<1|e>>>31;e=e<<1;f=(b|0)==-2129002496&(e|0)!=0|b>>>0>2165964800?0:f}c=A[177];g=c+a;a=a-(g-c);c=a*a;h=c*c*(a*A[182]+A[181]);c=c*(a*A[180]+A[179]);a=a*A[178];o(+g);j(1)|0;e=j(0)|0;d=e<<4&2032;a=h+(c+(a+A[d+1464>>3]));d=d+1472|0;i=v[d>>2];b=v[d+4>>2];d=i;i=0;d=d+i|0;b=(e<<13)+b|0;b=d>>>0<i>>>0?b+1|0:b;if(!f){c:{if(!(e&-2147483648)){l(0,d|0);l(1,b+-1048576|0);c=+n();a=c*a+c;a=a+a;break c}e=fb-16|0;l(0,d|0);l(1,b+1071644672|0);c=+n();g=c*a;a=g+c;if(a<1){b=e;v[b+8>>2]=0;v[b+12>>2]=1048576;A[b+8>>3]=A[b+8>>3]*2.2250738585072014e-308;h=a+1;a=h+(g+(c-a)+(a+(1-h)))+-1;a=a==0?0:a}a=a*2.2250738585072014e-308}return a}l(0,d|0);l(1,b|0);c=+n();c=c*a+c}return c}function wU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-144|0;fb=f;v[23220]=0;l=T(261,a|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){m=c+480192|0;while(1){a:{if((j&65535)>>>0>=l>>>0){wb(a);fb=f+144|0;return}v[23220]=0;R(280,a|0,f+8|0);e=v[23220];v[23220]=0;if((e|0)!=1){b:{e=Jb(x[f+8>>1]);if(!e|e>>>0>x[m>>1]){break b}e=v[((e<<2)+c|0)+900380>>2];if(!e){break b}e=Bi(e,b);g=w[f+11|0];c:{if(!g){break c}h=w[f+10|0];if(h&1){t[e+12|0]=w[e+12|0]|1}if(h&2){t[e+12|0]=w[e+12|0]|4}if(!(h&4)){break c}t[e+12|0]=w[e+12|0]|2}t[f+4|0]=g;t[f+7|0]=31;h=w[Rb(f+4|0,f+7|0)|0];v[23220]=0;h=h+1&255;R(281,e|0,h|0);g=v[23220];v[23220]=0;if((g|0)==1){break a}t[e+13|0]=w[f+13|0];t[e+14|0]=w[f+14|0];g=w[f+12|0];t[e+15|0]=g;t[e+16|0]=g;g=v[e>>2];e=0;while(1){if((e|0)==(h|0)){break b}i=(f+8|0)+(e<<2)|0;n=Jb(x[i+8>>1]);k=zb(g,e);u[k>>1]=n;i=Jb(x[i+10>>1]);u[f+4>>1]=d?i+128>>>2|0:i;qg(f+4|0,64);t[k+2|0]=w[f+4|0];e=e+1|0;continue}}j=j+1|0;continue}}break}}b=P()|0;O()|0;wb(a);S(b|0);L()}function Gba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=fb-16|0;fb=g;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+72>>2];b=v[a+68>>2];n=b;o=b>>31;b=v[a+64>>2];p=b;q=b>>31;b=v[a+60>>2];r=b;s=b>>31;w=v[a+8>>2];x=v[a+12>>2];while(1){b=e;if(d){e=Ub(b,-16777216,16776704);e=Bia(p,q,e,e>>31);h=ib;f=Ub(f,-16777216,16776704);i=Bia(n,o,f,f>>31);e=i+e|0;f=ib+h|0;f=e>>>0<i>>>0?f+1|0:f;y=e;e=v[g+12>>2]+l|0;h=v[g+8>>2]>>>21&2040;h=(((B(t[e|0],u[h+39874>>1])+B(t[e-1|0],u[h+39872>>1])|0)+B(t[e+1|0],u[h+39876>>1])|0)+B(t[e+2|0],u[h+39878>>1])<<8)/16384<<8;e=h;i=Bia(e,e>>31,r,s);e=y+i|0;f=ib+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Lc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Ob(g+8|0,w,x);e=f-(h&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;fb=g+16|0}function tw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;p=a;i=fb-1040|0;fb=i;q=v[115696];a:{b:{a=i+16|0;l=x[((b>>>0>149?0:b)<<1)+90416>>1]+88592|0;c=v[v[115701]+20>>2];if(c){j=v[c+4>>2];c=v[c>>2];e=v[c>>2]+1794895138|0;h=zl(v[c+8>>2],e);f=zl(v[c+12>>2],e);d=zl(v[c+16>>2],e);c:{if(j>>>2>>>0<=h>>>0){break c}k=j-(h<<2)|0;if((d|f)&3|(k>>>0<=f>>>0|d>>>0>=k>>>0)){break c}r=d>>>2|0;s=f>>>2|0;f=0;while(1){k=h>>>1|0;m=k+f|0;n=m<<1;d=c+(n+s<<2)|0;o=zl(v[d>>2],e);d=zl(v[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|w[c+(d+o|0)|0]){break c}d=bj(l,c+d|0);if(!d){f=c+(r+n<<2)|0;h=zl(v[f>>2],e);e=zl(v[f+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break c}g=w[c+(e+h|0)|0]?0:c+e|0;break c}if((h|0)==1){break c}d=(d|0)<0;h=d?k:h-k|0;f=d?f:m;continue}}}g=g?g:l;c=Cf(g);d:{if(c>>>0>=1024){nc(a,g,1023);t[a+1023|0]=0;g=68;break d}nc(a,g,c+1|0);g=0}if(g){if((g|0)!=28){break b}a=21598}break a}wa();L()}if(!w[a|0]){v[i>>2]=b;a=i+16|0;ow(a,1024,12981,i)}v[115696]=q;Qb(p,a);fb=i+1040|0}function Paa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;p=v[a+16>>2];q=Zf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){k=v[a+8>>2];m=v[a+12>>2];f=v[a>>2];b=v[a+4>>2];h=0;break a}b=v[a+12>>2];m=b;k=v[a+8>>2];n=_f(k,b,l);o=ib;h=v[a+76>>2];f=v[a>>2];b=v[a+4>>2];Df(f,b,af(k,m,d),ib);h=h>>>0<ib>>>0?d:0}g=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[e>>2]=f;v[e+4>>2]=b;b:while(1){if(d){d=d-1|0;v[e+8>>2]=f;v[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;f=b+p|0;b=l;while(1)if((b|0)<=0){Ob(g,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Hd(g,t[f+v[e+12>>2]|0]<<6);Gd(g,b);v[g>>2]=v[g>>2];v[g+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;f=Yf(g,q);v[c>>2]=B(j>>12,f)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(f,i>>12);Ob(e,k,m);c=c+8|0;f=v[e>>2];b=v[e+4>>2];continue b}else{Hd(g,t[f+v[e+12>>2]|0]<<6);Gd(g,4);Ob(e+8|0,n,o);b=b-1|0;continue}}break}v[a>>2]=f;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;fb=e+16|0}function rJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;a:{b:{c:{d:{e:{f:{g:{h:{if(Nb(v[a+36>>2],v[a+40>>2])){mf(d+24|0);break h}c=d+8|0;qn(c,a);v[23220]=0;c=T(978,c|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break g}v[d+24>>2]=c;Tf(d+8|0)}e=(h=a+36|0,i=v[d+24>>2],j=Nb(v[a+36>>2],v[a+40>>2]),j?h:i);if((b|0)==-1){f=v[e>>2];g=4194304;c=0;break e}if((b|0)>=0){c=b;f=v[e>>2];if((pn(f,v[e+4>>2])|0)>(b|0)){break e}}b=aa(8)|0;v[23220]=0;c=Q(52,d+8|0,10873)|0;a=v[23220];v[23220]=0;if((a|0)==1){break f}a=qc(b,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}a=P()|0;O()|0;ub(c);break d}a=P()|0;O()|0;Tf(d+8|0);break c}a=P()|0;O()|0;ba(b|0);break d}v[a+8>>2]=b;b=v[a+24>>2];v[b+480208>>2]=v[b+480208>>2]&-4194305|g;xi(b+484360|0,w[Zk(f,c)+16|0]);b=Zk(v[e>>2],c);c=v[b+8>>2];b=v[b+12>>2];v[23220]=0;+ya(1009,a|0,b|0,c|0);b=v[23220];v[23220]=0;if((b|0)!=1){break a}a=P()|0;O()|0}Fk(d+24|0)}S(a|0)}L()}v[a+16>>2]=0;v[a+20>>2]=0;Fk(d+24|0);fb=d+32|0}function bf(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-80|0;fb=d;c=v[a+28>>2];Nm(v[v[c>>2]-12>>2]+c|0,0);if(!cd(a,4)){Qv(a)}a:{if(!v[a+4>>2]){break a}if(cd(a,6)){break a}if(cd(a,7)){break a}f=v[a+28>>2];c=v[a+84>>2];g=B(v[a+20>>2],v[a+4>>2]);e=g+v[a+80>>2]|0;c=ch(d- -64|0,e,e>>>0<g>>>0?c+1|0:c);e=v[c+12>>2];v[d+24>>2]=v[c+8>>2];v[d+28>>2]=e;e=v[c+4>>2];v[d+16>>2]=v[c>>2];v[d+20>>2]=e;Ej(f,d+16|0)}e=0;b:{if(!cd(a,5)){break b}f=bh(v[a+44>>2],v[a+48>>2]);c=0;while(1){if((c|0)==(f|0)){break b}g=(v[a+96>>2]+c>>>0)%(f>>>0)|0;i=_c(v[a+44>>2],g);h=v[i>>2];c:{j=v[a+32>>2];if(Wc(j,v[a+36>>2])>>>0<=h>>>0){break c}h=Rm(d+48|0,Hb(j,h),x[i+12>>1]);i=Yv(b,h);Pb(h);if(!i){break c}v[a+96>>2]=(g+1>>>0)%(f>>>0);e=_c(v[a+44>>2],g);b=v[e+4>>2];if(!b){break b}f=v[a+28>>2];c=v[a+12>>2];e=b+v[a+8>>2]|0;c=e>>>0<b>>>0?c+1|0:c;b=ch(d+32|0,e,c);c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;Ej(f,d);e=_c(v[a+44>>2],g);break b}c=c+1|0;continue}}fb=d+80|0;return e}function bba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;e=fb-16|0;fb=e;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){f=v[e+8>>2];o=((((v[e+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;p=u[b+14>>1];q=u[b+12>>1];r=u[b+10>>1];s=u[b+8>>1];t=u[b+6>>1];w=u[b+4>>1];x=u[b+2>>1];y=u[b>>1];f=0;while(1){if((f|0)!=2){b=(f<<1)+o|0;v[(f<<2)+e>>2]=(((((B(u[b+8>>1],r)+B(u[b+4>>1],s)|0)+B(u[b+12>>1],q)|0)+B(u[b+16>>1],p)|0)/2|0)+((((B(u[b-8>>1],x)+B(u[b-12>>1],y)|0)+B(u[b-4>>1],w)|0)+B(u[b>>1],t)|0)/2|0)|0)/16384;f=f+1|0;continue}break}h=h+l|0;v[c>>2]=v[c>>2]+B(v[e>>2],h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g>>12);Ob(e+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;fb=e+16|0}function Ww(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=d<<4|c>>>28;f=c<<4|b>>>28;c=e;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){e=c+1073741824|0;a=f+1|0;e=a?e:e+1|0;f=a;break a}e=c+1073741824|0;if(a|(b|0)!=134217728){break a}b=f&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){e=c;c=d<<4|e>>>28;f=e<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;vf(g+16|0,a,b,c,e,h-15233|0);cm(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;b=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){a=f+1|0;e=a?e:e+1|0;f=a;break a}if(b|(a|0)!=134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}fb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function Fj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=fb-32|0;fb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;Xc(b,d);c=0;v[23220]=0;j=T(1104,b|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){Wb(i+8|0);v[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(xk(i+24|0,i+16|0)){break b}c:{if((Tm(j,v[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){break b}d:{e:{b=Tm(j,v[c>>2]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+8|0)==(h|0)){break b}k=b;b=Tm(j,v[g+8>>2])}l=i,m=jb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+8|0;break c}if(yk(j,8192,v[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(yk(j,8192,v[g>>2])){continue}}break}while(1){if(!Ir(i+24|0,i+16|0)){break c}if(!yk(j,8192,zk(v[i+24>>2]))){break c}bn(i+24|0);continue}}if((fl(j,zk(v[i+24>>2]))|0)==(fl(j,v[g>>2])|0)){g=g+4|0;bn(i+24|0);break c}v[e>>2]=4}c=v[e>>2];continue}break}v[e>>2]=4}if(xk(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}fb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Wb(i+8|0);S(a|0);L()}function nP(a,b,c){var d=0,e=0;d=w[a|0]&15;t[a|0]=w[d+27072|0];a:{b:{c:{switch(d|0){case 0:if(w[b|0]?c>>>0>=51:0){break b}t[a|0]=0;return;case 5:d:{e:{d=w[b|0];e=d&15;f:{if(!((e|0)!=2&(d&240)!=32)){t[a|0]=20;d=159;t[b|0]=159;break f}if((e|0)==12){break e}}if(c>>>0<51){break b}if((d&240)==192){break d}break b}if(c>>>0<51){break b}}t[a|0]=25;t[b|0]=0;return;case 7:if(c>>>0>51){break b}t[a|0]=0;return;case 10:a=w[b|0]&240;if(!a){break b}t[b|0]=a;return;case 11:t[b|0]=B(w[b|0]&15,17);return;case 12:t[b|0]=w[b|0]>>>2;return;case 13:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);return;case 14:g:{switch((w[b|0]>>>4|0)-1|0){case 0:t[a|0]=2;break a;case 1:t[a|0]=3;break a;case 7:if(c>>>0<52){break b}t[a|0]=20;t[b|0]=w[b|0]&15|96;return;case 8:t[a|0]=15;t[b|0]=w[b|0]&15;return;case 9:t[a|0]=11;t[b|0]=w[b|0]<<4|15;return;case 10:t[a|0]=11;break a;case 11:case 12:break g;default:break b}}t[a|0]=20;return;case 15:break c;default:break b}}if(w[b|0]<48){break b}t[a|0]=17}return}t[b|0]=w[b|0]|240}function E4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23220]=0;Y(944,a|0);e=v[23220];v[23220]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[23220]=0;Y(920,b|0);e=v[23220];v[23220]=0;if((e|0)==1){break e}e=0;v[23220]=0;Y(945,c|0);f=v[23220];v[23220]=0;if((f|0)==1){break e}a=Sb(c,0,d);if(!w[b|0]){break b}if(bj(b,7184)|(d|0)!=8){break d}v[a+4>>2]=946;v[a>>2]=947;break c}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,12250,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();return 0}if(!(bj(b,11215)|(d|0)!=64)){v[a+60>>2]=948;v[a+56>>2]=949;v[a+52>>2]=950;v[a+48>>2]=951;v[a+44>>2]=952;v[a+40>>2]=953;v[a+36>>2]=954;v[a+32>>2]=955;v[a+28>>2]=956;v[a+24>>2]=957;v[a+20>>2]=958;v[a+16>>2]=959;v[a+12>>2]=960;v[a+8>>2]=961;v[a+4>>2]=962;v[a>>2]=963;break c}if(bj(b,15162)|(d|0)!=24){break b}v[a+20>>2]=964;v[a+16>>2]=965;v[a+12>>2]=966;v[a+8>>2]=967;v[a+4>>2]=968;v[a>>2]=969}e=1}return e|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=fb-16|0;fb=g;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;o=v[a+32>>2];p=v[a+28>>2];q=v[a+72>>2];b=v[a+68>>2];r=b;s=b>>31;b=v[a+64>>2];t=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){l=u[(v[g+12>>2]<<1)+n>>1]<<8;e=l;e=Bia(e,e>>31,x,y);k=ib;h=e;e=Ub(b,-16777216,16776704);m=Bia(t,w,e,e>>31);h=h+m|0;e=ib+k|0;e=h>>>0<m>>>0?e+1|0:e;f=Ub(f,-16777216,16776704);k=Bia(r,s,f,f>>31);h=k+h|0;f=ib+e|0;f=h>>>0<k>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Lc(e,f,24);e=(f|0)/256|0;j=j+p|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+o|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Ob(g+8|0,z,A);e=f-(q&l)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;fb=g+16|0}function Hha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;kd(b,32);g=b,h=_b(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24)),v[g>>2]=h;f=_b(w[a+10|0]|w[a+11|0]<<8|(w[a+12|0]<<16|w[a+13|0]<<24));v[b+4>>2]=f;g=b,h=_b(w[a+14|0]|w[a+15|0]<<8|(w[a+16|0]<<16|w[a+17|0]<<24))+f|0,v[g+8>>2]=h;if(!(d?0:c)){c=_b(w[a+46|0]|w[a+47|0]<<8|(w[a+48|0]<<16|w[a+49|0]<<24))}v[b+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=Jb(w[a+42|0]|w[a+43|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}aq(b,+(c|0)*.0006510416666666666);t[e+15|0]=w[a+9|0];t[e+14|0]=64;g=b,h=w[Rb(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}fb=e+16|0}function gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=fb-16|0;fb=g;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;o=v[a+32>>2];p=v[a+28>>2];q=v[a+72>>2];b=v[a+68>>2];r=b;s=b>>31;b=v[a+64>>2];u=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){l=t[v[g+12>>2]+n|0]<<16;e=l;e=Bia(e,e>>31,x,y);k=ib;h=e;e=Ub(b,-16777216,16776704);m=Bia(u,w,e,e>>31);h=h+m|0;e=ib+k|0;e=h>>>0<m>>>0?e+1|0:e;f=Ub(f,-16777216,16776704);k=Bia(r,s,f,f>>31);h=k+h|0;f=ib+e|0;f=h>>>0<k>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Lc(e,f,24);e=(f|0)/256|0;j=j+p|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+o|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Ob(g+8|0,z,A);e=f-(q&l)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;fb=g+16|0}function Tha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-32|0;fb=h;e=b;b=v[a>>2];b=Se(e,Ab(b))+b|0;e=yT(c,d);a:{if((e|0)<=0){break a}f=v[Cb(a)>>2];g=v[a+4>>2];if((f-g|0)>=(e|0)){v[h+8>>2]=d;j=g-b|0;if((j|0)<(e|0)){v[h+8>>2]=c;$A(h+8|0,j);f=v[h+8>>2];l=fb-16|0;fb=l;i=vk(l,a,e-j|0);k=fb-16|0;fb=k;v[k+8>>2]=f;while(1){if(Nb(f,d)){Hj(v[i+4>>2],w[f|0]);f=xe(k+8|0);v[i+4>>2]=v[i+4>>2]+1;f=v[f>>2];continue}break}fb=k+16|0;hc(i);fb=l+16|0;if((j|0)<=0){break a}}f=fb-16|0;fb=f;j=v[a+4>>2];d=(j-(b+e|0)|0)+b|0;i=vk(f,a,g-d|0);e=v[i+4>>2];a=d;while(1){if(a>>>0>=g>>>0){hc(i);cq(b,d,j);fb=f+16|0}else{Hj(e,w[a|0]);e=e+1|0;v[i+4>>2]=e;a=a+1|0;continue}break}Yg(c,v[h+8>>2],b);break a}f=Cb(a);g=wl(h+8|0,tl(a,Wc(v[a>>2],g)+e|0),b-v[a>>2]|0,f);e=fb-32|0;fb=e;v[e+24>>2]=c;c=Iv(e+8|0,g+8|0,yT(c,d));d=v[c>>2];while(1){if(v[c+4>>2]!=(d|0)){Hj(d,w[v[e+24>>2]]);d=v[c>>2]+1|0;v[c>>2]=d;xe(e+24|0);continue}break}Ed(c);fb=e+32|0;b=xT(a,g,b);vl(g)}Ab(b);fb=h+32|0}function $ha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-2608|0;fb=g;d=hB(g,a);v[d+1060>>2]=0;v[d+1064>>2]=0;e=d+1068|0;a=0;while(1){f=e+B(a,6)|0;t[f+4|0]=0;u[f>>1]=0;u[f+2>>1]=0;a=a+1|0;if((a|0)!=256){continue}break}v[23220]=0;Y(309,d|0);a=v[23220];v[23220]=0;a:{b:{if((a|0)!=1){if((u[d+1068>>1]|u[d+1070>>1])<0){break a}c:{while(1){if((c|0)==(h|0)){break a}v[23220]=0;k=Q(151,d|0,1)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}a=0;d:{while(1){v[23220]=0;f=Q(151,d|0,1)|0;e=v[23220];v[23220]=0;if((e|0)==1){break d}a=u[(d+B(a,6)|0)+(f?1070:1068)>>1];e:{if((a|0)>255){break e}e=d+B(a,6)|0;i=w[e+1072|0];if(u[e+1068>>1]<0){break e}if(u[e+1070>>1]>=0){continue}}break}i=(k?-1:0)^i;j=(j&255)+(i&255)|0;t[b+h|0]=j;h=h+1|0;continue}break}a=V(30480)|0;break b}a=V(30480)|0;break b}a=V(30480)|0}if((O()|0)==(ea(30480)|0)){_(a|0)|0;v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0}wb(d);S(a|0);L()}a=eq(d);wb(d);fb=g+2608|0;return a|0}function $o(a,b,c,d,e,f){var g=C(0),h=0,i=C(0),j=0,k=C(0),l=C(0);b=(c<<2)+b|0;c=b+(d<<2)|0;a=a>>2;d=f<<2;while(1){if((a|0)>0){f=c-4|0;i=z[f>>2];k=z[b>>2];l=z[c>>2];z[b>>2]=k+l;h=b-4|0;g=z[h>>2];z[h>>2]=g+z[f>>2];k=C(k-l);g=C(g-i);z[c>>2]=C(k*z[e>>2])-C(z[e+4>>2]*g);z[f>>2]=C(g*z[e>>2])+C(k*z[e+4>>2]);f=c-12|0;k=z[f>>2];h=b-8|0;g=z[h>>2];j=h;h=c-8|0;l=z[h>>2];z[j>>2]=g+l;j=b-12|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=d+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);f=c-20|0;k=z[f>>2];h=b-16|0;g=z[h>>2];j=h;h=c-16|0;l=z[h>>2];z[j>>2]=g+l;j=b-20|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=d+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);f=c-28|0;k=z[f>>2];h=b-24|0;g=z[h>>2];j=h;h=c-24|0;l=z[h>>2];z[j>>2]=g+l;j=b-28|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=d+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);e=d+e|0;a=a-1|0;c=c-32|0;b=b-32|0;continue}break}}function Mf(a){var b=0;a:{b:{switch(w[a+3|0]){case 0:if(!w[a+5|0]){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 14:t[a+3|0]=19;return;case 15:if(w[a+5|0]<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=37;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 37:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function CW(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb+-64|0;fb=b;e=Gb(a);v[23220]=0;a=ha(113)|0;c=v[23220];v[23220]=0;a:{b:{if((c|0)==1){break b}c:{d:{if(!a){break d}v[23220]=0;c=Q(1,b+32|0,8934)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}v[23220]=0;a=ha(113)|0;d=v[23220];v[23220]=0;e:{f:{g:{h:{if((d|0)==1){break h}v[23220]=0;v[b+12>>2]=a;R(119,b+16|0,b+12|0);a=v[23220];v[23220]=0;if((a|0)==1){break h}v[23220]=0;U(2,b+48|0,c|0,b+16|0);a=v[23220];v[23220]=0;if((a|0)==1){break g}d=b+48|0;a=Db(e,d);vb(d);vb(b+16|0);vb(c);v[23220]=0;c=ha(115)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}if(!c){break e}v[23220]=0;Q(120,a|0,17443)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break e}break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(b+16|0)}vb(c);break a}v[23220]=0;c=ha(114)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}if(!c){break d}v[23220]=0;Q(120,a|0,16745)|0;a=v[23220];v[23220]=0;if((a|0)==1){break b}}fb=b- -64|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}vb(e);S(a|0);L()}function II(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=fb-32|0;fb=c;e=v[a>>2];a=v[e>>2];rf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[e+4>>2];j=v[a+8>>2];h=v[a+4>>2];l=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=fb-32|0;fb=a;a:{b:{if(y[c+4>>2]>=h>>>0){k=v[c+12>>2];if(Se(v[c+8>>2],k)>>>0<j>>>0){break b}m=b+12|0;n=v[c>>2];c:while(1){e=0;if((f|0)==(j|0)){break a}while(1)if((e|0)==(h|0)){f=f+1|0;continue c}else{i=Jg(l,h,e,f);d=zb(v[b>>2],e);g=de($f(A[i>>3])*134217728);i=d;d=(v[d>>2]>>1)+Wl(g)|0;o=d;d=$r(m)+d&-4096;v[i>>2]=o-d;A[a+24>>3]=+(d|0)*7.450580596923828e-9;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;g=de(A[ug(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(g)<2147483648){d=~~g;break d}d=-2147483648}d=Rc(d);p=mn(n,k,e,f),q=d,u[p>>1]=q;e=e+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}fb=a+32|0;fb=c+32|0}function cba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;e=fb-16|0;fb=e;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){f=v[e+8>>2];o=(((v[e+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;p=u[b+14>>1];q=u[b+12>>1];r=u[b+10>>1];s=u[b+8>>1];w=u[b+6>>1];x=u[b+4>>1];y=u[b+2>>1];z=u[b>>1];f=0;while(1){if((f|0)!=2){b=f+o|0;v[(f<<2)+e>>2]=(((((B(t[b+4|0],r)+B(t[b+2|0],s)|0)+B(t[b+6|0],q)|0)+B(t[b+8|0],p)<<8)/2|0)+((((B(t[b-4|0],y)+B(t[b-6|0],z)|0)+B(t[b-2|0],x)|0)+B(t[b|0],w)<<8)/2|0)|0)/16384;f=f+1|0;continue}break}h=h+l|0;v[c>>2]=v[c>>2]+B(v[e>>2],h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g>>12);Ob(e+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;fb=e+16|0}function vY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=fb-16|0;fb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=v[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=v[a+8>>2];if((g-f|0)<=0){break a}v[a+8>>2]=f+1;t[f|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}c=v[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if((f|0)<4){break b}v[a+8>>2]=c+1;t[c|0]=b>>>18|240;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>12&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;continue}break}c=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];fb=a+16|0;return c|0}function Ex(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0);d=fb-48|0;fb=d;a:{b=v[a+20>>2];b:{if(!b){break b}e=v[b+4>>2];b=v[b+8>>2];if(Wc(e,b)>>>0<4){break b}ge(d+16|0,e,b);b=Xd(d+8|0);e=BT(d+24|0,v[d+16>>2],v[d+20>>2],v[b>>2],v[b+4>>2]);v[23220]=0;b=T(144,e|0)|0;f=v[23220];v[23220]=0;c:{if((f|0)!=1){if(b){break c}b=v[v[a>>2]+40>>2];v[23220]=0;f=T(b|0,a|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break a}b=v[a+20>>2];if(Wc(v[b+4>>2],v[b+8>>2])-4>>>0<f<<2>>>0){break c}c=v[v[a>>2]+172>>2];b=0;v[23220]=0;R(c|0,a|0,-1);c=v[23220];v[23220]=0;if((c|0)==1){break a}while(1){if((b|0)==(f|0)){b=v[v[a>>2]+176>>2];v[23220]=0;Y(b|0,a|0);a=v[23220];v[23220]=0;if((a|0)!=1){break c}break a}v[23220]=0;g=C(Ca(416,e|0));c=v[23220];v[23220]=0;d:{if((c|0)==1){break d}c=v[v[a>>2]+44>>2];v[23220]=0;Ba(c|0,a|0,b|0,C(Il(g)?g:C(0)));c=v[23220];v[23220]=0;if((c|0)==1){break d}b=b+1|0;continue}break}break a}break a}wb(e)}fb=d+48|0;return}a=P()|0;O()|0;wb(e);S(a|0);L()}function n6(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;v[23220]=0;g=Q(12,d+24|0,a|0)|0;c=v[23220];v[23220]=0;a:{b:{c:{if((c|0)!=1){d:{if(!w[g|0]){break d}c=d+16|0;Xc(c,v[v[a>>2]-12>>2]+a|0);v[23220]=0;c=T(65,c|0)|0;e=v[23220];v[23220]=0;e:{f:{if((e|0)!=1){Wb(d+16|0);e=qm(d+8|0,a);f=v[v[a>>2]-12>>2];v[23220]=0;f=a+f|0;h=T(13,f|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break f}e=v[e>>2];v[23220]=0;c=Qa(66,c|0,e|0,f|0,h|0,+b)|0;e=v[23220];v[23220]=0;if((e|0)==1){break f}v[d+16>>2]=c;if(!Iu(d+16|0)){break d}c=v[v[a>>2]-12>>2];v[23220]=0;R(15,a+c|0,5);c=v[23220];v[23220]=0;if((c|0)!=1){break d}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;Wb(d+16|0);break e}c=V(0)|0;O()|0}fk(g);break c}fk(g);break b}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[23220]=0;Y(16,a+c|0);c=v[23220];v[23220]=0;if((c|0)==1){break a}$()}fb=d+32|0;return a|0}a=P()|0;O()|0;v[23220]=0;Z(17);d=v[23220];v[23220]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function PI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;v[a+4>>2]=b;v[a>>2]=92920;e=(b>>>0)/48|0;d=((0-b|0)!=(B(e,-48)|0))+e|0;v[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;v[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){g=-1<<c}else{g=(1<<c)-1&-1>>>32-c|-1<<c}c=0;v[a+24>>2]=c;f=f?g&65536:0;v[a+28>>2]=f;g=0-c|0;h=Eia(c,f,d,0);c=65536-(f+((c|0)!=0)|0)|0;f=ib;if((c|0)==(f|0)&g>>>0>h>>>0|c>>>0>f>>>0){d=d+1|0;v[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;v[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){c=-1<<c}else{c=(1<<c)-1&-1>>>32-c|-1<<c}v[a+24>>2]=0;v[a+28>>2]=f?c&65536:0}v[a+16>>2]=d-((b>>>0)%(d>>>0)|0);b=e>>>0<63;d=63-e|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}v[a+48>>2]=b?c:-1;v[a+52>>2]=b?d:-1;d=64-e|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}v[a+40>>2]=e?c:0;v[a+44>>2]=e?d:0;c=e+1|0;e=c&31;if((c&63)>>>0>=32){d=-1<<e}else{d=(1<<e)-1&-1>>>32-e|-1<<e}v[a+32>>2]=0;v[a+36>>2]=b?d&65536:0;return a}function lfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-48|0;fb=f;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;c=f+44|0;eo(b,c);a:{if(!bP(c)){break a}d=w[f+46|0];g=w[f+47|0];e=w[f+45|0];t[a+4|0]=1;h=e>>>3&3;c=(h|0)!=3;e=(e>>>1^-1)&3;g=g>>>0<192;u[a+2>>1]=x[(B(c,6)+(e<<1)|0)+27368>>1]<<g;i=B(B(w[(e+B(c,3)|0)+27144|0],x[((B(c,90)+B(e,30)|0)+(d>>>3&30)|0)+27152>>1]),1e3);d=d>>>1|0;d=B(((i>>>0)/x[(B(h,6)+(d&6)|0)+27344>>1]|0)+(d&1)|0,e?1:4);u[a>>1]=d;e=w[(g|c<<1)+27380|0];if(e+8>>>0>(d&65535)>>>0){break a}c=fb-32|0;fb=c;v[c+28>>2]=e+4;v[c+8>>2]=36;g=v[b>>2];h=v[b+8>>2];d=v[Eb(c+28|0,c+8|0)>>2];if(!Lb(g,h,d)){d=Ze(b)}h=c+8|0;Oq(h,f);g=cc(c+16|0,v[c+8>>2],d);jc(c,v[b>>2],v[b+8>>2],v[g>>2],v[g+4>>2]);Oq(h,f);Sb(v[c+8>>2]+d|0,0,36-d|0);Yb(b,v[c+28>>2]);fb=c+32|0;b=2;c=e>>>0>2?e:2;while(1){if((b|0)!=(c|0)){d=b+f|0;b=b+1|0;if(!w[d|0]){continue}break a}break}b=e+f|0;if(Mb(b,9537,4)){b=Mb(b,11034,4)}else{b=0}t[a+5|0]=!b}fb=f+48|0;return a|0}function Rx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;d=w[a+2|0];if(!(!d|(d|0)==255)){v[e+12>>2]=d+1;v[e+8>>2]=10;Zg(b,v[nd(e+12|0,e+8|0)>>2]);i=w[a+3|0];t[b+15|0]=i;t[b+16|0]=i;j=w[a+4|0];t[b+13|0]=j;l=w[a+5|0];t[b+14|0]=l;g=511;d=0;a:{b:{switch(c-1|0){case 1:d=4096;g=128;break a;case 0:break b;default:break a}}d=32768;g=1024}o=g>>>1|d;c=v[b>>2];k=ne(c,v[b+4>>2]);d=0;c:{while(1){if((d|0)==(k|0)){d:{c=w[b+12|0]&-2|t[a|0]&1;t[b+12|0]=c;if(w[a|0]&2){break d}c=c&251;break c}}else{m=zb(c,d);h=(d<<2)+a|0;f=(w[h+6|0]|w[h+7|0]<<8)>>>4|0;u[m>>1]=f;e:{if(d){n=x[zb(c,d-1|0)>>1];if(f>>>0>=n>>>0){break e}f=n+1|0}else{f=0}p=zb(c,d),q=f,u[p>>1]=q}v[e+12>>2]=(((w[h+8|0]|w[h+9|0]<<8)<<16>>16)+o|0)/(g|0);v[e+8>>2]=0;v[e+4>>2]=64;p=m,q=v[uj(e+12|0,e+8|0,e+4|0)>>2],t[p+2|0]=q;d=d+1|0;continue}break}c=c&-5|(k>>>0>=i>>>0)<<2}t[b+12|0]=c;t[b+12|0]=(j>>>0<=l>>>0?w[a|0]&4:0)?c&-3|(k>>>0>=j>>>0)<<1:c&253}fb=e+16|0}function AI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-32|0;fb=c;e=v[a>>2];a=v[e>>2];rf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[e+4>>2];j=v[a+8>>2];h=v[a+4>>2];k=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=fb-32|0;fb=a;a:{b:{if(y[c+4>>2]>=h>>>0){if(Se(v[c+8>>2],v[c+12>>2])>>>0<j>>>0){break b}l=b+12|0;c:while(1){e=0;if((f|0)==(j|0)){break a}while(1)if((e|0)==(h|0)){f=f+1|0;continue c}else{i=Jg(k,h,e,f);d=zb(v[b>>2],e);g=de($f(A[i>>3])*134217728);i=d;d=(v[d>>2]>>1)+Wl(g)|0;m=d;d=$r(l)+d&-4096;v[i>>2]=m-d;A[a+24>>3]=+(d|0)*7.450580596923828e-9;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;g=de(A[ug(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(g)<2147483648){d=~~g;break d}d=-2147483648}d=Rc(d);n=ln(c,e,f),o=d,u[n>>1]=o;e=e+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}fb=a+32|0;fb=c+32|0}function Zp(a){var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}d=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}d=b;if((b|0)==16777216){break a}}d=32;break a}d=b;break a}d=4;if(x[a+480192>>1]){break a}c=Ab(v[a+484344>>2]);v[e+8>>2]=c;a=Ab(v[a+484348>>2]);while(1){if(!Nb(c,a)){d=1;break a}if(!(!Nb(v[c>>2],v[c+4>>2])|v[c+12>>2]==64)){break a}c=v[_L(e+8|0)>>2];continue}}d=16777216;break a}d=32;f=x[a+480188>>1];if(f>>>0>16){break a}while(1){if((c|0)==(f|0)){break b}b=(c<<5)+a|0;if(t[b+480281|0]&1){break a}c=c+1|0;if(x[b+480286>>1]==64){continue}break}break a}d=2}fb=e+16|0;return d}function f2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if(y[a+4>>2]<y[Cb(a)>>2]){c=fb-16|0;fb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+24;jJ(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+24;hc(c);fb=c+16|0;return}g=fb-32|0;fb=g;h=Cb(a);c=g+8|0;e=pn(v[a>>2],v[a+4>>2])+1|0;d=fb-16|0;fb=d;v[d+12>>2]=e;a:{f=Ah(178956970);if(e>>>0<=f>>>0){e=Ct(a);if(e>>>0<f>>>1>>>0){v[d+8>>2]=e<<1;f=v[Sc(d+8|0,d+12|0)>>2]}fb=d+16|0;break a}od();L()}e=pn(v[a>>2],v[a+4>>2]);Gf(c+12|0,h);if(f){if(f>>>0>=178956971){xf(11129);L()}d=tc(B(f,24))}else{d=0}v[c>>2]=d;e=d+B(e,24)|0;v[c+8>>2]=e;v[c+4>>2]=e;i=vc(c),j=d+B(f,24)|0,v[i>>2]=j;jJ(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+24;b=c+4|0;e=v[a>>2];f=v[a+4>>2]-e|0;d=v[b>>2]+B((f|0)/-24|0,24)|0;v[b>>2]=d;if((f|0)>0){nc(d,e,f)}kc(a,b);kc(a+4|0,c+8|0);kc(Cb(a),vc(c));v[c>>2]=v[c+4>>2];a=v[c+4>>2];b=v[c+8>>2];while(1){if((a|0)!=(b|0)){b=b-24|0;v[c+8>>2]=b;continue}break}a=v[c>>2];if(a){vc(c);Fb(a)}fb=g+32|0}function tx(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;o(+a);e=j(1)|0;c=j(0)|0;a:{b:{d=e>>>20&2047;if(d-969>>>0<63){k=d;break b}if(d>>>0<=968){return a+1}if(d>>>0<1033){break b}b=0;if(!c&(e|0)==-1048576){break a}if((d|0)==2047){return a+1}if((e|0)<0){return kr(1.2882297539194267e-231)}return kr(3.105036184601418e231)}b=A[170];f=A[169]*a+b;b=f-b;b=b*A[172]+(b*A[171]+a);a=b*b;g=a*a*(b*A[176]+A[175]);a=a*(b*A[174]+A[173]);o(+f);j(1)|0;h=j(0)|0;c=h<<4&2032;b=g+(a+(A[c+1464>>3]+b));d=c+1472|0;c=h<<13;e=0;i=v[d>>2]+e|0;c=c+v[d+4>>2]|0;c=e>>>0>i>>>0?c+1|0:c;d=i;if(!k){c:{if(!(h&-2147483648)){l(0,d|0);l(1,c-1058013184|0);a=+n();a=(a*b+a)*5.486124068793689e303;break c}e=fb-16|0;l(0,d|0);l(1,c+1071644672|0);g=+n();f=g*b;a=f+g;if(a<1){v[e+8>>2]=0;v[e+12>>2]=1048576;A[e+8>>3]=A[e+8>>3]*2.2250738585072014e-308;b=a+1;a=b+(f+(g-a)+(a+(1-b)))+-1;a=a==0?0:a}a=a*2.2250738585072014e-308}return a}l(0,d|0);l(1,c|0);a=+n();b=a*b+a}return b}function Taa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;n=v[a+16>>2];o=Zf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);k=v[a+128>>2];a:{if(!k){i=v[a+8>>2];j=v[a+12>>2];g=v[a>>2];b=v[a+4>>2];h=0;break a}i=v[a+8>>2];j=v[a+12>>2];l=_f(i,j,k);m=ib;h=v[a+76>>2];g=v[a>>2];b=v[a+4>>2];Df(g,b,af(i,j,d),ib);h=h>>>0<ib>>>0?d:0}f=a+112|0;p=v[a+24>>2];q=v[a+20>>2];v[e>>2]=g;v[e+4>>2]=b;b:while(1){if(d){b=v[e+4>>2];v[e+8>>2]=v[e>>2];v[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=(b<<1)+n|0;b=k;while(1)if((b|0)<=0){Ob(f,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Hd(f,u[(v[e+12>>2]<<1)+g>>1]/4<<16>>16);Gd(f,b);v[f>>2]=v[f>>2];v[f+4>>2]=0}g=v[c>>2];b=Yf(f,o);v[c>>2]=g+B(b,q);v[c+4>>2]=v[c+4>>2]+B(b,p);Ob(e,i,j);c=c+8|0;continue b}else{Hd(f,u[(v[e+12>>2]<<1)+g>>1]/4<<16>>16);Gd(f,4);Ob(e+8|0,l,m);b=b-1|0;continue}}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;fb=e+16|0}function Q7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];c=xj(d,v[a+4>>2]);if(c>>>0<b>>>0){g=fb-32|0;fb=g;e=b-c|0;b=v[Cb(a)>>2];c=v[a+4>>2];a:{if(e>>>0<=b-c>>11>>>0){b=fb-16|0;fb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(e<<11);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=b+16|0}else{Fx(a);a=a+2048|0;v[b+4>>2]=a;continue}break}break a}h=Cb(a);i=g+8|0;b=a;f=xj(v[a>>2],c)+e|0;c=fb-16|0;fb=c;v[c+12>>2]=f;d=fb-16|0;fb=d;v[d+12>>2]=2097151;v[d+8>>2]=2147483647;a=v[Eb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(a>>>0>=f>>>0){d=Gx(b);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Sc(c+8|0,c+12|0)>>2]}fb=c+16|0;break b}od();L()}d=NK(i,a,xj(v[b>>2],v[b+4>>2]),h);c=d;a=fb-16|0;fb=a;v[a>>2]=v[c+8>>2];f=v[c+8>>2];v[a+8>>2]=c+8;v[a+4>>2]=f+(e<<11);c=v[a>>2];while(1){if(v[a+4>>2]!=(c|0)){Fx(c);c=v[a>>2]+2048|0;v[a>>2]=c;continue}break}Ed(a);fb=a+16|0;vd(b,d);MK(d)}fb=g+32|0;return}if(b>>>0<c>>>0){Jd(a,d+(b<<11)|0)}}function Wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0;g=fb-16|0;fb=g;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+72>>2];b=v[a+68>>2];n=b;o=b>>31;b=v[a+64>>2];p=b;q=b>>31;b=v[a+60>>2];r=b;s=b>>31;u=v[a+8>>2];w=v[a+12>>2];while(1){b=e;if(d){e=Ub(b,-16777216,16776704);e=Bia(p,q,e,e>>31);i=ib;f=Ub(f,-16777216,16776704);h=Bia(n,o,f,f>>31);e=h+e|0;f=ib+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=v[g+12>>2]+l|0;e=t[h|0];x=i;i=((B(t[h+1|0]-e|0,v[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=Bia(e,e>>31,r,s);e=x+h|0;f=ib+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Lc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Ob(g+8|0,u,w);e=f-(i&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;fb=g+16|0}function Vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=fb-16|0;fb=g;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+72>>2];b=v[a+68>>2];n=b;o=b>>31;b=v[a+64>>2];p=b;q=b>>31;b=v[a+60>>2];r=b;s=b>>31;t=v[a+8>>2];w=v[a+12>>2];while(1){b=e;if(d){e=Ub(b,-16777216,16776704);e=Bia(p,q,e,e>>31);i=ib;f=Ub(f,-16777216,16776704);h=Bia(n,o,f,f>>31);e=h+e|0;f=ib+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=(v[g+12>>2]<<1)+l|0;e=u[h>>1];x=i;i=e+((B(u[h+2>>1]-e|0,v[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=Bia(e,e>>31,r,s);e=x+h|0;f=ib+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Lc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Ob(g+8|0,t,w);e=f-(i&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;fb=g+16|0}function l6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,t=C(0),u=C(0),x=C(0),y=C(0),A=0,B=0,E=0,F=0,G=0,H=C(0);g=fb-16|0;fb=g;m=v[a+4240>>2];a:{if(!m){break a}if(!Th(a+44|0)){break a}n=z[a+4220>>2];e=v[a+44>>2];F=g,G=zc(e,0),v[F+8>>2]=G;F=g,G=zc(e,1),v[F+12>>2]=G;e=v[a+56>>2];o=zc(e,0);v[g>>2]=o;p=zc(e,1);v[g+4>>2]=p;y=C(C(1)-n);q=v[a+4208>>2];A=w[a+4264|0];e=d;b:while(1){if(e){k=v[a+4244>>2];B=k<<1;f=0;l=0;while(1)if((f|0)==2){f=k+1|0;v[a+4244>>2]=(f|0)==(m|0)?0:f;e=e-1|0;continue b}else{h=(A?1-l|0:f)&255;j=v[((h<<2)+a|0)+4248>>2];E=v[a+4240>>2];r=f<<2;s=r+(g+8|0)|0;i=v[s>>2];v[s>>2]=i+4;j=k-j|0;t=z[zb(q,h+((j>>31&E)+j<<1)|0)>>2];u=z[i>>2];x=C(C(t*z[a+4224>>2])+C(u*z[a+4260>>2]));F=zb(q,f+B|0),H=C(D(x))<C(1.0000000195414814e-24)?C(0):x,z[F>>2]=H;h=g+r|0;i=v[h>>2];v[h>>2]=i+4;z[i>>2]=C(u*y)+C(n*t);l=l+1|0;f=f+1|0;continue}}break}hi(a,b,c,o,p,d)}fb=g+16|0}function dga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=Kt(c,d);d=b&63;if(e>>>0>d>>>0){c=jS(c,d);d=0;g=fb-16|0;fb=g;t[a+12|0]=0;Bc(a);e=fb-32|0;fb=e;if(si(a)>>>0<=14){f=Cb(a);f=cg(e+8|0,15,sc(v[a>>2],v[a+4>>2]),f);vd(a,f);bg(f)}fb=e+32|0;h=0-w[c+1|0]|0;while(1){a:{if((d|0)==15){break a}e=c+(d<<1)|0;f=w[e+1|0];if(!f){break a}t[g+7|0]=64;h=f+(h<<16>>16)|0;f=_n(g+8|0,h&65535,w[Rb(e+2|0,g+7|0)|0]);b:{if(y[a+4>>2]<y[Cb(a)>>2]){fS(a,f);break b}i=fb-32|0;fb=i;e=Cb(a);e=cg(i+8|0,Pg(a,sc(v[a>>2],v[a+4>>2])+1|0),sc(v[a>>2],v[a+4>>2]),e);Zn(v[e+8>>2],x[f>>1]|x[f+2>>1]<<16);v[e+8>>2]=v[e+8>>2]+4;vd(a,e);bg(e);fb=i+32|0}d=d+1|0;continue}break}d=w[c+32|0];t[a+14|0]=d>>>4;t[a+13|0]=d&15;c=w[c+31|0];d=c&15;t[a+15|0]=d;t[a+16|0]=d;if(c&16){t[a+12|0]=w[a+12|0]|4}if(c&32){t[a+12|0]=w[a+12|0]|2}fb=g+16|0}c:{if(b<<24>>24>=0){c=w[a+12|0]&-2;a=a+12|0;break c}c=w[a+12|0]&-2|rc(v[a>>2],v[a+4>>2])^1;a=a+12|0}t[a|0]=c}function gw(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=fb-16|0;fb=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Bb(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Bb(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=mi(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+82816|0];d:{e:{switch((f&-2)-22|0){case 2:b=v[e>>2];if((b|0)!=(d|0)&(w[b-1|0]&95)!=(w[c|0]&127)){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Bb(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}fb=m+16|0;return a}function nw(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;a:{if(b&3){while(1){c=w[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=v[b>>2];d=(c^-1)&-2139062144;b:{if(d&c-16843009|d&(c^1027423549)-16843009){break b}while(1){c=v[b+4>>2];b=b+4|0;d=(c^-1)&-2139062144;if(d&c-16843009){break b}if(!(d&(c^1027423549)-16843009)){continue}break}}c=c&255;if(!c|(c|0)==61){break a}while(1){c:{c=b+1|0;d=w[b+1|0];if((d|0)==61){break c}b=c;if(d){continue}}break}b=c}if((a|0)==(b|0)){return 0}g=b-a|0;d:{if(w[g+a|0]){break d}f=v[116606];if(!f){break d}b=v[f>>2];if(!b){break d}while(1){e:{c=a;d=b;i=0;h=g;e=0;f:{if(!g){break f}e=w[c|0];g:{if(!e){break g}while(1){h:{j=w[d|0];if(!j){break h}h=h-1|0;if(!h|(e|0)!=(j|0)){break h}d=d+1|0;e=w[c+1|0];c=c+1|0;if(e){continue}break g}break}i=e}e=(i&255)-w[d|0]|0}if(!e){b=b+g|0;if(w[b|0]==61){break e}}b=v[f+4>>2];f=f+4|0;if(b){continue}break d}break}k=b+1|0}return k}function d5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-80|0;fb=e;v[e+72>>2]=c;a=Rf(a,e+72|0);c=mf(a+4|0);h=mf(a+24|0);i=mf(a+32|0);j=Ib(a+36|0);v[a+56>>2]=3;k=Ib(a+68|0);v[23220]=0;R(914,a|0,d|0);f=v[23220];v[23220]=0;a:{b:{c:{d:{if((f|0)!=1){f=v[b>>2];g=v[b+4>>2];l=v[b+12>>2];v[e+40>>2]=v[b+8>>2];v[e+44>>2]=l;v[e+32>>2]=f;v[e+36>>2]=g;b=Xd(e+24|0);f=v[b+4>>2];b=v[b>>2];g=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=g;v[23220]=0;g=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=g;X(903,e+48|0,e+8|0,b|0,f|0);b=v[23220];v[23220]=0;if((b|0)==1){break d}v[23220]=0;U(915,a|0,e+48|0,d|0);b=v[23220];v[23220]=0;if((b|0)==1){break c}wb(e+48|0);v[23220]=0;Y(916,a|0);b=v[23220];v[23220]=0;if((b|0)==1){break b}pe(e+72|0);fb=e+80|0;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;wb(e+48|0);break a}b=P()|0;O()|0}De(k);Tf(j);es(i);$i(h);_i(c);pe(a);pe(e+72|0);S(b|0);L()}function uga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=fb-32|0;fb=e;b=fb-32|0;fb=b;v[b+16>>2]=1073741824;u[b+22>>1]=12;c=tc(64);v[23220]=0;d=T(807,c|0)|0;f=v[23220];v[23220]=0;a:{b:{c:{if((f|0)!=1){c=uf(b+8|0,d);d=v[c>>2];v[23220]=0;R(808,d|0,a|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}a=v[c>>2];v[23220]=0;a=W(809,a|0,b+22|0,b+16|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}d:{if(!a){mf(b+24|0);break d}a=v[c>>2];v[23220]=0;R(810,a|0,15);a=v[23220];v[23220]=0;if((a|0)==1){break c}Rf(b+24|0,c)}fg(c);fb=b+32|0;b=v[b+24>>2];break a}a=P()|0;O()|0;Fb(c);break b}a=P()|0;O()|0;fg(c)}S(a|0);L()}v[e+24>>2]=b;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}v[23220]=0;c=Q(1,e+8|0,(a<<2)+32160|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){v[23220]=0;U(441,b|0,a|0,c|0);d=v[23220];v[23220]=0;if((d|0)==1){break g}vb(c);a=a+1|0;continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c)}fg(e+24|0);S(a|0);L()}fb=e+32|0;return b|0}function kp(a){a=a|0;var b=0,c=0,d=C(0),e=C(0),f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=C(0);b=v[a+36>>2];if(!b){Bc(a+16|0);return}a:{b:{switch(x[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Bc(c);return}Oj(c,b);b=u[a+28>>1];d=C(Kl(a,(b<<16)+65536>>16)/Kl(a,b));c=v[a+36>>2]+1|0;d=ie(d,C(C(1)/C(c>>>0)));a=v[a+16>>2];b=1;while(1){if((b|0)==(c|0)){break a}e=ie(d,C(b>>>0));n=zb(a,b-1|0),o=e,z[n>>2]=o;b=b+1|0;continue};case 1:c=a+16|0;f=x[a+30>>1];if(f>>>0>1e3/(b>>>0)>>>0){Bc(c);return}Oj(c,B(b,f));h=x[a+30>>1];j=xn(u[a+28>>1],h);i=v[a+36>>2];d=C(C(1)/C(i+1>>>0));c=0;c:while(1){if((c&65535)>>>0>=f>>>0){break a}b=xn(c+j<<16>>16,h)<<16;e=Kl(a,b+65536>>16);b=b>>16;e=ie(C(e/Kl(a,b)),d);k=B(b,v[a+36>>2]);l=v[a+16>>2];b=1;while(1){g=b&65535;if(i>>>0<g>>>0){c=c+1|0;continue c}else{m=ie(e,C(g>>>0));n=zb(l,(g+k|0)-1|0),o=m,z[n>>2]=o;b=b+1|0;continue}}};case 0:Bc(a+16|0);return;default:break b}}Bc(a+16|0);v[a+36>>2]=0}}function xba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){e=(v[f+12>>2]<<1)+j|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(u[e-4>>1],u[h+2>>1])+B(u[e-6>>1],u[h>>1])|0)+B(u[e-2>>1],u[h+4>>1])|0)+B(u[e>>1],u[h+6>>1])|0)+B(u[e+2>>1],u[h+8>>1])|0)+B(u[e+4>>1],u[h+10>>1])|0)+B(u[e+6>>1],u[h+12>>1])|0)+B(u[e+8>>1],u[h+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(e,l);v[c+4>>2]=v[c+4>>2]+B(e,k);Ob(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;fb=f+16|0}function L7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=0,s=0,t=0,u=C(0),w=C(0),x=C(0),y=C(0),A=0,B=0,E=0,F=C(0);r=v[a+4220>>2];if(r){f=v[a+44>>2];k=zc(f,0);l=zc(f,1);g=v[a+56>>2];s=zc(g,0);j=v[a+4208>>2];A=v[a+4228>>2];f=d;t=zc(g,1);m=t;g=s;while(1){if(f){h=v[a+4224>>2];e=h-A|0;e=(v[a+4220>>2]&e>>31)+e<<1;B=zb(j,e);n=z[zb(j,e|1)>>2];u=z[a+4244>>2];o=z[B>>2];w=z[a+4252>>2];p=z[l>>2];x=z[a+4248>>2];q=z[k>>2];y=z[a+4256>>2];i=C(C(n*u)+C(C(o*w)+C(C(p*x)+C(q*y))));e=h<<1;E=zb(j,e),F=C(D(i))<C(1.0000000195414814e-24)?C(0):i,z[E>>2]=F;i=C(C(o*u)+C(C(n*w)+C(C(q*x)+C(p*y))));E=zb(j,e|1),F=C(D(i))<C(1.0000000195414814e-24)?C(0):i,z[E>>2]=F;h=h+1|0;v[a+4224>>2]=(h|0)==(r|0)?0:h;z[g>>2]=C(q*z[a+4240>>2])+C(o*z[a+4236>>2]);z[m>>2]=C(p*z[a+4240>>2])+C(n*z[a+4236>>2]);f=f-1|0;m=m+4|0;g=g+4|0;l=l+4|0;k=k+4|0;continue}else{hi(a,b,c,s,t,d)}break}}}function uG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[Ke(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=Cr(v[a+32>>2]);if((g|0)==-1){break a}t[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];g=v[d>>2];j=v[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(GG(v[a+36>>2],d,i,f,c+16|0,c+23|0,h,c+12|0)-1|0){case 2:break d;case 0:break e;case 1:break b;default:break c}}d=v[a+40>>2];v[d>>2]=g;v[d+4>>2]=j;if((e|0)==8){break b}d=Cr(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((Br(Jf(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break a}}d=Jf(t[c+23|0]);v[a+48>>2]=d;break a}d=Jf(t[c+23|0]);break a}d=-1}fb=c+32|0;return d}function Uaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;n=v[a+16>>2];o=Zf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);k=v[a+128>>2];a:{if(!k){i=v[a+8>>2];j=v[a+12>>2];g=v[a>>2];b=v[a+4>>2];h=0;break a}i=v[a+8>>2];j=v[a+12>>2];l=_f(i,j,k);m=ib;h=v[a+76>>2];g=v[a>>2];b=v[a+4>>2];Df(g,b,af(i,j,d),ib);h=h>>>0<ib>>>0?d:0}f=a+112|0;p=v[a+24>>2];q=v[a+20>>2];v[e>>2]=g;v[e+4>>2]=b;b:while(1){if(d){b=v[e+4>>2];v[e+8>>2]=v[e>>2];v[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=b+n|0;b=k;while(1)if((b|0)<=0){Ob(f,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Hd(f,t[v[e+12>>2]+g|0]<<6);Gd(f,b);v[f>>2]=v[f>>2];v[f+4>>2]=0}g=v[c>>2];b=Yf(f,o);v[c>>2]=g+B(b,q);v[c+4>>2]=v[c+4>>2]+B(b,p);Ob(e,i,j);c=c+8|0;continue b}else{Hd(f,t[v[e+12>>2]+g|0]<<6);Gd(f,4);Ob(e+8|0,l,m);b=b-1|0;continue}}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;fb=e+16|0}function zu(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;a:{if(w[a+3|0]!=19){break a}t[a+3|0]=20;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=w[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}t[a+3|0]=0;break a}t[a+3|0]=2;t[a+5|0]=b|240;break a}t[a+3|0]=3;t[a+5|0]=b|240;break a}t[a+5|0]=b&15|16;break a}t[a+5|0]=b&3|48;break a}t[a+5|0]=b&15|32;break a}t[a+5|0]=b&15|176;break a}t[a+5|0]=b&3|64;break a}t[a+3|0]=15;t[a+5|0]=b&15;break a}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;break a}t[a+3|0]=0;break a}b=b&15;if(b){t[a+3|0]=11;v[c+12>>2]=b;v[c+8>>2]=14;d=a,e=w[nd(c+12|0,c+8|0)|0]|240,t[d+5|0]=e;break a}t[a+3|0]=0;break a}if((b|0)!=192){break a}t[a|0]=254;t[a+3|0]=0;break a}if((b|0)!=208){break a}t[a+3|0]=0}fb=c+16|0}function N1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-32|0;fb=c;d=v[a>>2];a=v[d>>2];rf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];g=v[a+8>>2];d=v[a+4>>2];j=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=fb-32|0;fb=a;a:{b:{if(d>>>0<=y[c+4>>2]){h=v[c+12>>2];if(Se(v[c+8>>2],h)>>>0<g>>>0){break b}k=b+12|0;l=v[c>>2];c:while(1){b=0;if((e|0)==(g|0)){break a}while(1)if((b|0)==(d|0)){e=e+1|0;continue c}else{m=a,n=+(Wl(de($f(A[Jg(j,d,b,e)>>3])*134217728))+dd(_r(k),21)|0)*7.450580596923828e-9,A[m+24>>3]=n;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;i=de(A[ug(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(i)<2147483648){f=~~i;break d}f=-2147483648}f=Rc(f);m=mn(l,h,b,e),o=f,u[m>>1]=o;b=b+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}fb=a+32|0;fb=c+32|0}function pY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=t[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((w[a+1|0]&192)==128){break b}break a}g=f&255;c:{d:{if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=w[a+3|0];i=w[a+2|0];f=w[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4;break b}if((f&224)!=128){break a}}g=3;if((h&192)!=128){break a}}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function vG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[Ke(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=Cr(v[a+32>>2]);if((g|0)==-1){break a}t[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];g=v[d>>2];j=v[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(GG(v[a+36>>2],d,i,f,c+16|0,c+20|0,h,c+12|0)-1|0){case 2:break d;case 0:break e;case 1:break b;default:break c}}d=v[a+40>>2];v[d>>2]=g;v[d+4>>2]=j;if((e|0)==8){break b}d=Cr(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((Br(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break a}}d=v[c+20>>2];v[a+48>>2]=d;break a}d=v[c+20>>2];break a}d=-1}fb=c+32|0;return d}function yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){e=v[f+12>>2]+j|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(t[e-2|0],u[h+2>>1])+B(t[e-3|0],u[h>>1])|0)+B(t[e-1|0],u[h+4>>1])|0)+B(t[e|0],u[h+6>>1])|0)+B(t[e+1|0],u[h+8>>1])|0)+B(t[e+2|0],u[h+10>>1])|0)+B(t[e+3|0],u[h+12>>1])|0)+B(t[e+4|0],u[h+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,l);v[c+4>>2]=v[c+4>>2]+B(e,k);Ob(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;fb=f+16|0}function pfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;u[e+12>>1]=0;v[e+8>>2]=0;j=8;n=B(c,d)<<1;while(1){if((d|0)!=(l|0)){h=(l<<1)+b|0;o=n+h|0;while(1){if(h>>>0<o>>>0){u[e+6>>1]=0;GR(a,e+15|0,e+12|0,j,e+6|0);g=x[e+6>>1];c=j;while(1){a:{if(!(c&255)){break a}f=x[e+12>>1]<<1;i=f&254;u[e+12>>1]=i;if(i){f=(f&65534)>>>0>255}else{if(!Ye(a,e+5|0)){break a}f=w[e+5|0];u[e+12>>1]=f<<1&254|1;f=f>>>7|0}c=c-1|0;g=f|g<<1;continue}break}c=1;i=g&65535;b:{if(i>>>0<4){break b}f=15;while(1){c=f;m=f&255;if(i>>>m&1){break b}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;g=f-1^(g&65534)>>>1;f=g+x[e+8>>1]|0;u[e+6>>1]=f;u[h>>1]=f;v[e+8>>2]=((g>>1)-(k<<16>>16)|0)+(f<<16>>16<<1);h=(d<<1)+h|0;j=(c+j&254)>>>1|0;c=-32768;k=v[e+8>>2];c:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break c}}v[e+8>>2]=c}k=f;continue}break}l=l+1|0;continue}break}fb=e+16|0}function sY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=t[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((w[a+1|0]&192)==128){break b}break a}g=b&255;c:{d:{if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=w[a+2|0];b=w[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((b&224)==160){break c}break a}if((b&192)!=128){break a}break c}if((d-a|0)<4|b>>>0>4294967284){break a}f=w[a+3|0];h=w[a+2|0];b=w[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0<48){break e}break a;case 4:if((b&240)==128){break e}break a;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}break b}if((b&224)!=128){break a}}f=3;if((h&192)!=128){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function NB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-560|0;fb=f;u[f+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}e=((b<<2)+a|0)+900380|0;b=v[e>>2];b:{if(b){c=NO(f,c);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;d=w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24);e=w[c+7|0]|w[c+8|0]<<8|(w[c+9|0]<<16|w[c+10|0]<<24);t[b+7|0]=e;t[b+8|0]=e>>>8;t[b+9|0]=e>>>16;t[b+10|0]=e>>>24;t[b+11|0]=d;t[b+12|0]=d>>>8;t[b+13|0]=d>>>16;t[b+14|0]=d>>>24;t[b+15|0]=w[c+15|0];d=v[c+44>>2];v[b+40>>2]=v[c+40>>2];v[b+44>>2]=d;d=v[c+36>>2];v[b+32>>2]=v[c+32>>2];v[b+36>>2]=d;d=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=d;d=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=d;hy(b+48|0,c+48|0);hy(b+68|0,c+68|0);hy(b+88|0,c+88|0);nc(b+108|0,c+108|0,448);d=b;Ht(c);break b}b=Es(556);if(!b){v[e>>2]=0;break a}d=NO(b,c);v[e>>2]=d}g=a,h=x[Re(a+480192|0,f+558|0)>>1],u[g+480192>>1]=h}fb=f+560|0;return d|0}function NV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=fb-32|0;fb=j;d=Am(j+8|0,a);c=fb-48|0;fb=c;k=-1;a:{if(!YC(d,c+8|0)){break a}k=0;if(!bD(c+8|0)){break a}n=v[d+12>>2];b:{if(!Yk(d,w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24))){break b}while(1){c:{if((w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24))>>>0>m>>>0){if(Sf(d,5)){break c}}g=l&1;break b}g=0;h=1;d:{if((w[c+12|0]|w[c+13|0]<<8)>>>0>=64){f=uq(d);a=f&63;e:{if(!(f&64)){break e}e=6;while(1){i=uq(d);a=(i&127)<<e|a;if(!(i&128)){break e}i=e>>>0<25;e=e+7|0;if(i){continue}break}}e=f>>>7|0;f=e?-2147483648:a;if(((e?(a|0)>=0?0-a|0:f:f)|0)<=0){break d}}while(1){e=uq(d);if(e){f=g>>>0>4;a=f&h;if(!((h^1)&1|f)){a=(sp(e<<24>>24)&255)==w[g+13071|0]}h=a;g=g+1|0;continue}break}Zc(d,4);l=(g|0)==5?h&1?1:l:l}m=m+1|0;continue}}Yk(d,n);if(!g){break a}k=Ce(d,b,aD(c+8|0),0)}fb=c+48|0;fb=j+32|0;return k|0}function ZM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{g=b;c=fb-16|0;fb=c;d=Gb(a);while(1){b:{c:{d:{if(Bb(g)>>>0>f>>>0){b=v[ej(g,f)>>2];if(b>>>0>=2097152){v[23220]=0;R(48,d|0,63);a=v[23220];v[23220]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;t[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=w[c+10|0]|64}else{a=w[c+10|0]}v[23220]=0;R(48,d|0,a<<24>>24);a=v[23220];v[23220]=0;if((a|0)!=1){break c}break b}fb=c+16|0;break a}i=(-1<<b^-1)<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=w[j|0];v[23220]=0;R(48,d|0,(a|i)<<24>>24);h=v[23220];v[23220]=0;a=e;break e}v[23220]=0;a=a-1|0;R(48,d|0,t[a+(c+10|0)|0]|-128);h=v[23220];v[23220]=0}if((h|0)!=1){continue}break}break b}f=f+1|0;continue}break}a=P()|0;O()|0;vb(d);S(a|0);L()}}function baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;l=fb-16|0;fb=l;d=v[dc(l+8|0,Ab(v[a+4>>2]))>>2];i=fb-32|0;fb=i;e=d;d=v[a>>2];h=(jo(e,Ab(d))<<1)+d|0;g=Ty(b,c);a:{if((g|0)<=0){break a}e=v[Cb(a)>>2];d=v[a+4>>2];if((g|0)<=e-d>>1){f=d-h|0;j=f>>1;b:{if((j|0)>=(g|0)){e=c;break b}v[i+8>>2]=b;v[i+8>>2]=v[i+8>>2]+(j<<1);e=v[i+8>>2];wO(a,e,c,g-j|0);if((f|0)<=0){break a}}m=fb-16|0;fb=m;j=v[a+4>>2];f=(j-((g<<1)+h|0)|0)+h|0;g=Ci(m,a,d-f>>1);k=v[g+4>>2];c=f;while(1){if(c>>>0>=d>>>0){hc(g);cq(h,f,j);fb=m+16|0}else{Ai(k,x[c>>1]);k=k+2|0;v[g+4>>2]=k;c=c+2|0;continue}break}Ln(b,e,h);break a}f=Cb(a);f=vj(i+8|0,wj(a,Ic(v[a>>2],d)+g|0),h-v[a>>2]>>1,f);d=fb-16|0;fb=d;e=wo(d,f+8|0,Ty(b,c));c=v[e>>2];while(1){if(v[e+4>>2]!=(c|0)){Ai(c,x[b>>1]);c=v[e>>2]+2|0;v[e>>2]=c;b=b+2|0;continue}break}Ed(e);fb=d+16|0;h=CO(a,f,h);Di(f)}Ab(h);fb=i+32|0;fb=l+16|0;return a|0}function yaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;v[e+12>>2]=1;a:{if(Xn(a)){c=v[a>>2];j=dg(c,v[a+4>>2]);v[e+8>>2]=j;k=v[Eb(e+12|0,e+8|0)>>2];while(1){if(k){k=k-1|0;if((b|0)!=(c|0)){f=Ab(v[b>>2]);g=Ab(v[b+4>>2]);d=fb-16|0;fb=d;h=pB(f,g);b:{if(h>>>0<=wm(c)>>>0){v[d+8>>2]=g;l=v[c>>2];i=Ic(l,v[c+4>>2]);m=i>>>0>=h>>>0;if(m){i=g}else{v[d+8>>2]=f;EO(d+8|0,i);i=v[d+8>>2]}f=Gi(f,i,l);if(!m){GO(c,v[d+8>>2],g,h-Ic(v[c>>2],v[c+4>>2])|0);break b}Jd(c,f);break b}FO(c);Tz(c,wj(c,h));GO(c,f,g,h)}fb=d+16|0;Ho(c+12|0,b+12|0);u[c+28>>1]=x[b+28>>1]}c=c+32|0;continue}break}if(!j){kz(a,1-j|0,b);break a}xO(a,v[a>>2]+32|0);break a}if(v[a>>2]){zO(a);c=v[a>>2];Xn(a);Fb(c);n=Cb(a),o=0,v[n>>2]=o;v[a>>2]=0;v[a+4>>2]=0}c=Hp(a,1);if(Ah(134217727)>>>0<c>>>0){od();L()}d=sP(c);v[a>>2]=d;v[a+4>>2]=d;n=Cb(a),o=d+(c<<5)|0,v[n>>2]=o;kz(a,1,b)}fb=e+16|0}function yF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=fb-32|0;fb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;i=e;h=c&33554431;if(!(!e&(h|0)==16777216?!(a|b):!e&h>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(h^16777216|a|(b|i)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;vf(g+16|0,a,b,c,e,f-16129|0);cm(g,a,b,c,e,16257-f|0);b=v[g+8>>2];e=(v[g+12>>2]&33554431)<<7|b>>>25;h=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;f=v[g+4>>2];a=0;b=b&33554431;if(!(!a&(b|0)==16777216?!(h|f):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|h|(a|f)){break a}e=(e&1)+e|0}fb=g+32|0;return l(2,d&-2147483648|e),q()}function E1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb-32|0;fb=c;d=v[a>>2];a=v[d>>2];rf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];g=v[a+8>>2];d=v[a+4>>2];i=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=fb-32|0;fb=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(Se(v[c+8>>2],v[c+12>>2])>>>0<g>>>0){break b}j=b+12|0;c:while(1){b=0;if((e|0)==(g|0)){break a}while(1)if((b|0)==(d|0)){e=e+1|0;continue c}else{k=a,l=+(Wl(de($f(A[Jg(i,d,b,e)>>3])*134217728))+dd(_r(j),21)|0)*7.450580596923828e-9,A[k+24>>3]=l;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;h=de(A[ug(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(h)<2147483648){f=~~h;break d}f=-2147483648}f=Rc(f);k=ln(c,b,e),m=f,u[k>>1]=m;b=b+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}fb=a+32|0;fb=c+32|0}function E5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0),x=C(0);i=fb-16|0;fb=i;h=a+44|0;if(Th(h)){f=v[a+44>>2];e=zc(f,0);v[i+8>>2]=e;f=zc(f,1);v[i+12>>2]=f;j=v[a+56>>2];k=zc(j,0);v[i>>2]=k;j=zc(j,1);v[i+4>>2]=j;a:{if(z[zb(a+4208|0,2)>>2]!=C(.5)){h=d;b:while(1){f=0;if(!h){break a}while(1)if((f|0)==2){h=h-1|0;continue b}else{l=f<<2;e=l+(i+8|0)|0;g=v[e>>2];v[e>>2]=g+4;e=a+l|0;n=e+4248|0;q=z[n>>2];m=z[g>>2];r=z[a+4236>>2];s=z[a+4232>>2];t=z[a+4228>>2];u=z[a+4220>>2];w=z[a+4224>>2];g=e+4240|0;o=z[g>>2];z[n>>2]=o;z[g>>2]=m;g=e+4264|0;x=z[g>>2];e=e+4256|0;p=z[e>>2];z[g>>2]=p;m=C(C(C(C(t*q)+C(C(u*m)+C(w*o)))-C(s*p))-C(r*x));z[e>>2]=m;l=i+l|0;e=v[l>>2];v[l>>2]=e+4;z[e>>2]=m;f=f+1|0;continue}}}g=k;k=d<<2;nc(g,e,k);nc(j,f,k);h=v[h+12>>2];k=zc(h,0);j=zc(h,1)}hi(a,b,c,k,j,d)}fb=i+16|0}function p8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=v[a>>2];d=ek(e,v[a+4>>2]);if(d>>>0<b>>>0){h=fb-32|0;fb=h;a:{b:{e=b-d|0;b=v[Cb(a)>>2];f=v[a+4>>2];c:{if(e>>>0<=(b-f|0)/52>>>0){Ox(a,e,c);break c}d=Cb(a);f=fL(a,ek(v[a>>2],f)+e|0);g=ek(v[a>>2],v[a+4>>2]);b=h+8|0;Gf(b+12|0,d);if(f){d=eL(f)}else{d=0}v[b>>2]=d;g=d+B(g,52)|0;v[b+8>>2]=g;v[b+4>>2]=g;i=vc(b),j=d+B(f,52)|0,v[i>>2]=j;v[23220]=0;U(851,b|0,e|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}f=v[a>>2];c=v[a+4>>2];e=b+4|0;while(1){if((c|0)!=(f|0)){c=c-52|0;d=Wj(v[e>>2]-52|0,c);v[d+20>>2]=v[c+20>>2];g=v[c+16>>2];v[d+12>>2]=v[c+12>>2];v[d+16>>2]=g;Wj(d+24|0,c+24|0);Mc(d+36|0,c+36|0);v[d+48>>2]=v[c+48>>2];v[e>>2]=v[e>>2]-52;continue}break}kc(a,e);kc(a+4|0,b+8|0);kc(Cb(a),vc(b));v[b>>2]=v[b+4>>2];cL(b)}fb=h+32|0;break a}a=P()|0;O()|0;cL(b);S(a|0);L()}return}if(b>>>0<d>>>0){gL(a,e+B(b,52)|0)}}function mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;u[e+12>>1]=0;v[e+8>>2]=0;n=B(c,d);k=4;a:while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){t[e+7|0]=0;FR(a,e+15|0,e+12|0,e+7|0);g=w[e+7|0];f=x[e+12>>1];c=k;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!Ye(a,e+6|0)){break c}f=w[e+6|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}u[e+12>>1]=f;break b}l=l+1|0;continue a}u[e+12>>1]=0}c=1;h=g&255;e:{if(h>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;g=f-1^(g&254)>>>1;f=g+w[e+8|0]|0;t[e+7|0]=f;t[i|0]=f;v[e+8>>2]=((g>>1)-(j<<24>>24)|0)+(f<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=v[e+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}v[e+8>>2]=c}j=f;continue}}break}fb=e+16|0}function fba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=fb-16|0;fb=e;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){f=v[e+8>>2];m=((((v[e+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;n=u[b+14>>1];o=u[b+12>>1];p=u[b+10>>1];q=u[b+8>>1];r=u[b+6>>1];s=u[b+4>>1];t=u[b+2>>1];w=u[b>>1];f=0;while(1){if((f|0)!=2){b=(f<<1)+m|0;v[(f<<2)+e>>2]=(((((B(u[b+8>>1],p)+B(u[b+4>>1],q)|0)+B(u[b+12>>1],o)|0)+B(u[b+16>>1],n)|0)/2|0)+((((B(u[b-8>>1],t)+B(u[b-12>>1],w)|0)+B(u[b-4>>1],s)|0)+B(u[b>>1],r)|0)/2|0)|0)/16384;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g);Ob(e+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;fb=e+16|0}function Lda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-144|0;fb=g;mo(a);a:{b:{if(!Sf(a,64)){break b}c:{d:{if(!Yk(a,60)){break d}if(!lQ(a,14115)){break d}c=15;d=450;break c}mo(a);if(!Sf(a,128)){break b}b=0;if(!Yk(a,124)){break a}if(!lQ(a,15336)){break a}c=31;d=930}mo(a);b=0;e:{while(1){if((b&65535)>>>0>=c>>>0){break e}b=b+1|0;if(jQ(a)>>>0<=131072){continue}break}b=0;break a}Zc(a,4);if(!Sf(a,2)){break b}b=0;e=fb-16|0;fb=e;c=fb-16|0;fb=c;kl(c+8|0,e+8|0);f=v[c+12>>2];hd(c,a,v[c+8>>2],f);h=v[c+4>>2];if((f|0)==(h|0)){Zc(a,v[c+12>>2])}fb=c+16|0;if((f|0)==(h|0)){i=Jb(x[e+8>>1])}fb=e+16|0;if(i>>>0<178){break a}b=-1;if(!Sf(a,d)){break a}Zc(a,d);d=fb-16|0;fb=d;e=g+8|0;nR(d+8|0,e);c=v[d+12>>2];hd(d,a,v[d+8>>2],c);f=v[d+4>>2];if((f|0)==(c|0)){Zc(a,v[d+12>>2])}fb=d+16|0;a=(c|0)==(f|0);if(!a){Xz(e)}if(!a){break a}b=kQ(w[g+8|0]);break a}b=-1}fb=g+144|0;return b|0}function Bl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;v[a+4>>2]=0;if(Nd(w[fn(d+8|0,a,1)|0])){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23220]=0;b=T(90,b|0)|0;c=v[23220];v[23220]=0;d:{if((c|0)!=1){if(!rc(b,-1)){break d}break b}break c}v[a+4>>2]=v[a+4>>2]+1;continue}}if(v[a+4>>2]>=(b|0)){break a}e:{while(1){c=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23220]=0;c=T(90,c|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break e}if(rc(c,-1)){break b}c=v[a+4>>2]+1|0;v[a+4>>2]=c;if((b|0)>(c|0)){continue}break}c=0;break a}}b=V(0)|0;O()|0;_(b|0)|0;c=1;en(v[v[a>>2]-12>>2]+a|0,1);f:{g:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23220]=0;Z(91);a=v[23220];v[23220]=0;if((a|0)!=1){break f}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)==1){break g}S(a|0);L()}$();break a}V(0)|0;O()|0;Tb()}L()}c=2}tj(v[v[a>>2]-12>>2]+a|0,c)}fb=d+16|0;return a|0}function Bda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=rd(d,v[a+4>>2]);if(c>>>0<b>>>0){f=fb-32|0;fb=f;c=b-c|0;b=v[Cb(a)>>2];d=v[a+4>>2];a:{if(c>>>0<=(b-d|0)/12>>>0){d=fb-16|0;fb=d;b=st(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=d+16|0}else{OP(a);a=a+12|0;v[b+4>>2]=a;continue}break}break a}b=Cb(a);b=kk(f+8|0,Jm(a,rd(v[a>>2],d)+c|0),rd(v[a>>2],v[a+4>>2]),b);e=fb-16|0;fb=e;d=PP(e,b+8|0,c);c=v[d>>2];while(1){if(v[d+4>>2]!=(c|0)){OP(c);c=v[d>>2]+12|0;v[d>>2]=c;continue}break}Ed(d);fb=e+16|0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;Wj(v[d>>2]-12|0,c);v[d>>2]=v[d>>2]-12;continue}break}kc(a,d);kc(a+4|0,b+8|0);kc(Cb(a),vc(b));v[b>>2]=v[b+4>>2];a=v[b+4>>2];while(1){c=v[b+8>>2];if((c|0)!=(a|0)){c=c-12|0;v[b+8>>2]=c;QP(c);continue}break}a=v[b>>2];if(a){Jo(b);Fb(a)}}fb=f+32|0;return}if(b>>>0<c>>>0){RP(a,d+B(b,12)|0)}}function cw(a,b,c,d,e,f,g,h,i,j,k,l){a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break a}f=0;t[b|0]=0;a=v[e>>2];v[e>>2]=a+1;t[a|0]=46;if(!Bb(h)){break b}a=v[j>>2];if((a-i|0)>159){break b}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Bb(h)){break c}if(!w[b|0]){break a}f=0;a=v[j>>2];if((a-i|0)>159){break b}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b;v[k>>2]=0;return 0}f=-1;a=ew(l,l+128|0,a)-l|0;if((a|0)>124){break b}g=w[(a>>2)+82816|0];d:{e:{f=a&-5;if((f|0)!=88){if((f|0)!=96){break e}a=v[e>>2];if((a|0)!=(d|0)){f=-1;if((w[a-1|0]&95)!=(w[c|0]&127)){break b}}v[e>>2]=a+1;t[a|0]=g;return 0}t[c|0]=80;break d}d=t[c|0];if((d|0)!=(g&95)){break d}t[c|0]=d|128;if(!w[b|0]){break d}t[b|0]=0;if(!Bb(h)){break d}b=v[j>>2];if((b-i|0)>159){break d}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c}b=v[e>>2];v[e>>2]=b+1;t[b|0]=g;f=0;if((a|0)>84){break b}v[k>>2]=v[k>>2]+1}return f}return-1}function jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;g=fb-16|0;fb=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];t=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){j=u[(v[g+12>>2]<<1)+n>>1]<<8;e=j;e=Bia(e,e>>31,t,w);i=ib;h=e;e=Ub(b,-16777216,16776704);k=Bia(r,s,e,e>>31);h=h+k|0;e=ib+i|0;e=h>>>0<k>>>0?e+1|0:e;f=Ub(f,-16777216,16776704);i=Bia(p,q,f,f>>31);h=i+h|0;f=ib+e|0;f=h>>>0<i>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Lc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Ob(g+8|0,x,y);e=f-(o&j)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;fb=g+16|0}function bA(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=fb-32|0;fb=i;pR(a,b);h=fb-16|0;fb=h;kd(c,1);g=Jb(w[b+22|0]|w[b+23|0]<<8)<<1;v[c>>2]=g;t[c+37|0]=w[b+24|0]<<4;t[h+15|0]=w[b+25|0];t[h+14|0]=64;l=c,m=w[Rb(h+15|0,h+14|0)|0]<<2,u[l+30>>1]=m;f=Jb(w[b+26|0]|w[b+27|0]<<8);a=f<<1;j=f;k=Jb(w[b+28|0]|w[b+29|0]<<8);f=k<<1;a=k>>>0>=2?a+f>>>0<=g>>>0?a:j+f>>>0>g>>>0?a:j:a;a:{b:{switch(g|0){case 2:v[c>>2]=0;break a;case 0:break a;default:break b}}v[c+4>>2]=a;f=a+f|0;v[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;v[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){v[c+8>>2]=0;break a}if(a>>>0>=f>>>0){break a}u[c+34>>1]=x[c+34>>1]|2}fb=h+16|0;dl(i,3,b);a=i+16|0;Ac(a,i);c=yc(d,a);ub(a);d=0;while(1){if((d|0)!=32){a=c+d|0;if((w[a|0]-1&255)>>>0<=30){t[a|0]=32}d=d+1|0;continue}break}a=dA(b);fb=i+32|0;return a}function G9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;b=v[a+4>>2];if(Nd(w[b+223884|0])){tN(b+223860|0);b=v[a+4>>2]}v[a+24>>2]=0;v[a+28>>2]=0;v[b>>2]=0;c=v[a>>2];v[b+40>>2]=v[c+480196>>2];v[b+44>>2]=v[c+480204>>2];v[b+80>>2]=v[c+480200>>2];c=x[c+480188>>1];v[f+8>>2]=0;v[f+12>>2]=0;d=f+8|0;u[d+4>>1]=65280;v[d>>2]=0;e=fb-16|0;fb=e;v[e+12>>2]=c;b=a+8|0;a:{if(Hm(b)>>>0>=c>>>0){g=v[b>>2];h=Dg(g,v[b+4>>2]);v[e+8>>2]=h;i=v[Eb(e+12|0,e+8|0)>>2];while(1){if(i){v[g>>2]=v[d>>2];u[g+4>>1]=x[d+4>>1];i=i-1|0;g=g+8|0;continue}break}if(c>>>0>h>>>0){HM(b,c-h|0,d);break a}Jd(b,v[b>>2]+(c<<3)|0);break a}LN(b);YN(b,Wq(b,c));HM(b,c,d)}fb=e+16|0;b=0;while(1){c=v[a>>2];if(x[c+480188>>1]<=b>>>0){fb=f+16|0}else{d=B(b,872);Qn((d+v[a+4>>2]|0)+616|0,c,b&65535,134217728);c=d+v[a+4>>2]|0;u[c+1432>>1]=0;t[c+1418|0]=0;t[c+1415|0]=0;t[c+1413|0]=0;b=b+1|0;continue}break}}function UO(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;b=v[a>>2];dc(g+8|0,b);a:{b:{c:{d:{e:{if(sd(v[b+16>>2])){while(1){if(c>>>0>31){break e}v[23220]=0;d=ha(40)|0;e=v[23220];v[23220]=0;if((e|0)!=1){f=d|f;c=c+32|0;continue}break}c=V(92052)|0;if((O()|0)!=(ea(92052)|0)){break c}_(c|0)|0;t[b+20|0]=0;v[23220]=0;Y(28,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break d}$();break e}t[b+20|0]=0}if(!w[b+20|0]){d=v[b+24>>2];b=0;c=1;while(1){if(c){c=0;b=v[d+2496>>2];e=d+(b<<2)|0;i=v[d+((b+397>>>0)%624<<2)>>2];h=(b+1>>>0)%624|0;b=v[d+(h<<2)>>2];b=i^(b&2147483647|v[e>>2]&-2147483648)>>>1^B(b&1,-1727483681);v[e>>2]=b;v[d+2496>>2]=h;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}f=b^f}fb=g+16|0;break a}c=P()|0;O()|0;v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)==1){break b}}S(c|0);L()}V(0)|0;O()|0;Tb();L()}return v[a+28>>2]&f}function kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0;g=fb-16|0;fb=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];u=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){j=t[v[g+12>>2]+n|0]<<16;e=j;e=Bia(e,e>>31,u,w);i=ib;h=e;e=Ub(b,-16777216,16776704);k=Bia(r,s,e,e>>31);h=h+k|0;e=ib+i|0;e=h>>>0<k>>>0?e+1|0:e;f=Ub(f,-16777216,16776704);i=Bia(p,q,f,f>>31);h=i+h|0;f=ib+e|0;f=h>>>0<i>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Lc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Ob(g+8|0,x,y);e=f-(o&j)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;fb=g+16|0}function MW(){var a=0,b=0,c=0,d=0;c=fb-32|0;fb=c;a:{a=Qb(c+16|0,14944);if(!Bb(a)){break a}b:{if((pg(a,14621)|0)!=-1){b=pg(a,14621);v[23220]=0;X(117,c|0,a|0,b+1|0,-1);b=v[23220];v[23220]=0;if((b|0)==1){break b}xc(a,c);ub(c)}if((pg(a,16743)|0)!=-1){b=pg(a,16743);v[23220]=0;X(117,c|0,a|0,b+1|0,-1);b=v[23220];v[23220]=0;if((b|0)==1){break b}xc(a,c);ub(c)}if((pg(a,13838)|0)!=-1){b=pg(a,13838);v[23220]=0;X(117,c|0,a|0,0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break b}xc(a,c);ub(c)}if((pg(a,13687)|0)!=-1){b=pg(a,13687);v[23220]=0;X(117,c|0,a|0,0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break b}xc(a,c);ub(c)}if((pg(a,13730)|0)!=-1){b=pg(a,13730);v[23220]=0;X(117,c|0,a|0,0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break b}xc(a,c);ub(c)}v[23220]=0;b=T(118,a|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;ub(a);S(c|0);L()}ub(a);fb=c+32|0;return b|0}function Dl(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;Dk(a);a:{b:{c:{f=v[b+32>>2];d:{if(!f){e=v[b+2084>>2];if(e){break d}break b}c=v[b+4>>2];if((c|0)<9){break c}e=v[b+2084>>2];if(!e){break c}}h=v[a+1392>>2];j=Cl(h);d=v[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=y[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}v[a+1392>>2]=h>>>b;b=d-b|0}v[a+1396>>2]=b;return c}if(w[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=w[v[b+8>>2]+d|0];if((c|0)==255){break f}g=v[a+1392>>2];if(v[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=v[a+1396>>2];if((e|0)>=(c|0)){v[a+1392>>2]=g>>>c;v[a+1396>>2]=e-w[v[b+8>>2]+d|0];return d}v[a+1396>>2]=0;break b}d=d+1|0;continue}break}Zb(a,21);v[a+1396>>2]=0}return-1}ca(11352,13164,1705,5406);L()}function HV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-96|0;fb=d;wc(b);Fo(a);a:{if(!bv(b,d+56|0)){break a}if(!XC(d+56|0)){break a}b:{if(!c){break b}if(!Lb(v[b>>2],v[b+8>>2],_b(v[d+60>>2])-28|0)){break a}rv(a);g=d,h=qv(),v[g+32>>2]=h;e=d+32|0;pv(Aj(v[a+4>>2])+32|0,e);Zq(e);c=v[Aj(v[a+4>>2])+32>>2];v[23220]=0;R(178,e|0,b|0);b=v[23220];v[23220]=0;c:{if((b|0)==1){break c}b=v[d+32>>2];e=v[d+60>>2];f=v[d+68>>2];v[23220]=0;b=fa(179,b|0,_b(e)-28|0,c|0,_b(f)|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}e=0;if(!b){break a}ge(d+16|0,v[c>>2],v[c+4>>2]);Hg(d+24|0,v[d+16>>2],v[d+20>>2]);b=Xd(d+8|0);b=Xq(d+32|0,v[d+24>>2],v[d+28>>2],v[b>>2],v[b+4>>2]);Yc(Aj(v[a+4>>2])+12|0,b);wb(b);break b}a=Da(91480,26072)|0;b=O()|0;d:{if((ea(91480)|0)==(b|0)){break d}if((ea(26072)|0)==(b|0)){break d}S(a|0);L()}_(a|0)|0;$();e=0;break a}e=1}fb=d+96|0;return e|0}function gba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;e=fb-16|0;fb=e;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){f=v[e+8>>2];m=(((v[e+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;n=u[b+14>>1];o=u[b+12>>1];p=u[b+10>>1];q=u[b+8>>1];r=u[b+6>>1];s=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];f=0;while(1){if((f|0)!=2){b=f+m|0;v[(f<<2)+e>>2]=(((((B(t[b+4|0],p)+B(t[b+2|0],q)|0)+B(t[b+6|0],o)|0)+B(t[b+8|0],n)<<8)/2|0)+((((B(t[b-4|0],w)+B(t[b-6|0],x)|0)+B(t[b-2|0],s)|0)+B(t[b|0],r)<<8)/2|0)|0)/16384;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g);Ob(e+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;fb=e+16|0}function Hca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-32|0;fb=g;d=fb-16|0;fb=d;c=a+33|0;v[b>>2]=w[c+206|0]|w[c+207|0]<<8;sL(c,b+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);sL(c,b+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);f=b+236|0;while(1){if((e|0)==96){if(w[c+208|0]){t[b+31|0]=w[c+209|0]+1;f=w[b+31|0];a:{b:{if(!f){e=1;break b}e=16;if(f>>>0<17){break a}}t[b+31|0]=e}u[d+14>>1]=w[c+210|0]|w[c+211|0]<<8;u[d+12>>1]=127;i=b,j=w[Tc(d+14|0,d+12|0)|0]+1|0,t[i+30|0]=j}t[b+33|0]=w[c+212|0];fb=d+16|0}else{i=ac(f,e+12|0),j=w[c+e|0],u[i>>1]=j;e=e+1|0;continue}break}e=b+236|0;while(1){if((h|0)!=96){f=ac(e,h+12|0);d=w[c+h|0];u[f>>1]=d>>>0<(w[a+27|0]|w[a+28|0]<<8)>>>0?d:0;h=h+1|0;continue}break}dl(g,3,a+4|0);c=g+16|0;Ac(c,g);yc(b+492|0,c);ub(c);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}fb=g+32|0}function FB(a){var b=0,c=0,d=0,e=0,f=0,g=0;if((w[a|0]-16&255)>>>0>=241){b=a+1698|0;a:{b:{while(1){if((d|0)==256){d=0;while(1){b=32;if((e|0)==32){break a}c=B(e,13)+a|0;if(w[c+14|0]){break b}b=(e<<4)+a|0;if(w[b+418|0]|w[b+419|0]<<8|(w[b+420|0]<<16|w[b+421|0]<<24)){break b}f=w[b+422|0]|w[b+423|0]<<8|(w[b+424|0]<<16|w[b+425|0]<<24);if(w[c+942|0]|f>>>0>1048575){break b}c=B(e,11)+a|0;g=c+1346|0;if(w[g|0]>15|w[c+1351|0]>3|w[c+1356|0]>3){break b}c:{d:{e:{if(f){c=w[b+430|0]|w[b+431|0]<<8|(w[b+432|0]<<16|w[b+433|0]<<24);if(c>>>0<=1048574&(c>>>0<(w[b+426|0]|w[b+427|0]<<8|(w[b+428|0]<<16|w[b+429|0]<<24))>>>0|c>>>0>f>>>0)){break b}b=1;if(d){break c}if(f){break d}break e}b=1;if(d){break c}}if(Mb(g,26269,11)){break d}b=0;break c}b=1}d=b;e=e+1|0;continue}}f=b+d|0;d=d+1|0;if(t[f|0]>=-1){continue}break}return 0}b=e}a=b>>>0>31&d}else{a=0}return a}function VC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-32|0;fb=c;v[23220]=0;e=Q(12,c+24|0,465896)|0;d=v[23220];v[23220]=0;a:{b:{c:{if((d|0)!=1){d:{e:{if(!w[e|0]){break e}f=qm(c+8|0,465896);d=v[v[116474]-12>>2]+465896|0;g=v[d+4>>2];v[23220]=0;h=T(13,d|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break d}f=v[f>>2];v[23220]=0;b=a+b|0;a=la(14,f|0,a|0,((g&176)==32?b:a)|0,b|0,d|0,h|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break d}v[c+16>>2]=a;if(!Iu(c+16|0)){break e}a=v[v[116474]-12>>2];v[23220]=0;R(15,a+465896|0,5);a=v[23220];v[23220]=0;if((a|0)!=1){break e}break d}fk(e);break b}a=V(0)|0;O()|0;fk(e);break c}a=V(0)|0;O()|0}_(a|0)|0;a=v[v[116474]-12>>2];v[23220]=0;Y(16,a+465896|0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$()}fb=c+32|0;return}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)==1){V(0)|0;O()|0;Tb();L()}S(a|0);L()}function DP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;e=fb-16|0;fb=e;n=v[a+20>>2];f=x[a+34>>1]&65;v[e+8>>2]=f;v[e>>2]=f^65;f=b;j=a+24|0;o=d+1074992|0;k=cj(d);p=a+4|0;q=a+12|0;r=a+8|0;s=d+480180|0;while(1){if((i|0)!=256){d=B(i,872)+o|0;if(v[d+104>>2]==(a|0)){if(v[d+16>>2]){v[d+16>>2]=f}if(y[d+4>>2]>c>>>0){v[d>>2]=0;v[d+4>>2]=0}b=a;if(v[d+76>>2]){uc(d+76|0,c);b=v[d+104>>2]}g=v[d+88>>2];b=TC(g,b);h=v[(b?q:p)>>2];v[d+84>>2]=v[(b?a+16|0:r)>>2];v[d+80>>2]=h;b=g|v[e+8>>2];v[d+88>>2]=b;v[d+88>>2]=b&(v[e>>2]^-1);b=d+704|0;h=v[a+24>>2];a:{if(!v[d+704>>2]|!h){break a}if(em(v[s>>2])){break a}g=v[(k?b:j)>>2];t=d;d=Bia(v[(k?j:b)>>2],0,v[d+700>>2],0);l=d+(g>>>1|0)|0;m=ib;u=t,w=Pc(Eia(l,d>>>0>l>>>0?m+1|0:m,g,0),ib),v[u+700>>2]=w}v[b>>2]=h}i=i+1|0;continue}break}v[a>>2]=c;v[a+20>>2]=f;nz(n);fb=e+16|0}function $8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;e=Gb(d+16|0);a:{b:{c:{if(c>>>0<64){break c}v[23220]=0;c=T(176,b|0)|0;f=v[23220];v[23220]=0;d:{if((f|0)!=1){v[d+12>>2]=c;if((c|0)>0){break d}v[23220]=0;Q(52,a|0,21598)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break b}}break a}v[23220]=0;c=T(189,b|0)|0;f=v[23220];v[23220]=0;if((f|0)!=1){g=d,h=ui(c),v[g+8>>2]=h;c=v[nd(d+12|0,d+8|0)>>2];v[23220]=0;R(43,e|0,c|0);c=v[23220];v[23220]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{v[23220]=0;c=T(193,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break f}if(!c){break e}v[23220]=0;W(819,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[23220];v[23220]=0;if((c|0)!=1){continue}}break}break a}v[23220]=0;Q(175,b|0,4)|0;b=v[23220];v[23220]=0;if((b|0)==1){break a}Mc(a,e)}ub(e);fb=d+32|0;return}a=P()|0;O()|0;ub(e);S(a|0);L()}function qp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;a:{b:{switch(w[a+480224|0]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2]<<1;f=Bia(b,d,5e4,0);e=ib;b=v[Sc(c+8|0,c)>>2];b=Dc(Cia(f,e,b,b>>31),ib);v[a+1074404>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=Bia(v[a+1074420>>2],0,Bia(v[a+1074408>>2],0,v[a+1074416>>2],0),ib),v[g>>2]=h;v[c+4>>2]=ib;b=Bia(b,0,6e5,0);d=c+8|0;e=b;f=ib;b=Ru(v[d>>2],v[d+4>>2],v[c>>2],v[c+4>>2])?c:d;b=Eia(e,f,v[b>>2],v[b+4>>2]);v[a+1074404>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2];f=Bia(b,d,1e4,0);e=ib;b=v[Sc(c+8|0,c)>>2];b=Dc(Cia(f,e,b,b>>31),ib);v[a+1074404>>2]=b}e=a+1074404|0;a=v[a+480244>>2];b=Bia(a,a>>31,b,b>>31)+32768|0;a=ib;a=Dc(Cia(b,b>>>0<32768?a+1|0:a,65536,0),ib);v[e>>2]=a?a:1;fb=c+16|0}function TJ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=C(0),m=0,n=0,o=0,p=C(0);d=a+4208|0;j=C(C(z[zb(d,2)>>2]*C(2999.9990234375))+C(.0010000000474974513));l=C(z[zb(d,3)>>2]*C(.9980000257492065));f=-3e3/+C(j*C(y[v[a+16>>2]+24620>>2]));h=a+4272|0;c=Mj(10,f*+y[zb(h,4)>>2]);d=a+4232|0;o=zb(d,0),p=C(c),z[o>>2]=p;c=Mj(10,f*+y[zb(h,5)>>2]);o=zb(d,1),p=C(c),z[o>>2]=p;m=f*(1/+C(l+C(.0010000000474974513))+-1);c=0;while(1){if((e|0)==4){e=a+4208|0;f=Mj(10,+RJ(z[zb(e,0)>>2])*.05);b=4/K(c)*f;c=Mj(10,+RJ(z[zb(e,1)>>2])*.1);z[a+4228>>2]=b*K(c);z[a+4224>>2]=f*K(1-c)}else{g=zb(h,e);k=e>>>1|0;n=v[zb(h,k+4|0)>>2];g=v[g>>2];i=Mj(10,m*+(n+g>>>0));b=Mj(10,f*+(g>>>0));j=z[zb(d,k)>>2];g=e<<1;i=(1-i)*.5;o=zb(d,g+2|0),p=C(b*(1-i)),z[o>>2]=p;o=zb(d,g+3|0),p=C(b*i),z[o>>2]=p;b=b*+j;b=b*(b*(b*(b+1)+1)+1)+1;c=b*b+c;e=e+1|0;continue}break}}function oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;while(1){a:{g=c;if(!c){g=0;break a}c=g-1|0;if(!w[c+b|0]){continue}}break}b:{if((d|0)!=4){break b}c=0;while(1){if((c|0)==(g|0)){if((e|0)==(f|0)){d=2;if((e|0)==(h|0)){break b}}if(e){d=0;if(!f){break b}}d=e?3:f?1:3}else{c:{d:{e:{d=b+c|0;i=w[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}e=e+1|0;break c}f=f+1|0}h=c?(w[d-1|0]==13&(i|0)==10)+h|0:h;c=c+1|0;continue}break}}e=0;f=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){c=((f&w[b+c|0]==13)+c|0)+1|0;e=e+1|0;continue}break}Lf(a);$s(a,e);f=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){f:{g:{h:{i:{e=t[b+c|0];switch(e-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(e){break f}e=32;break f}c=c+d|0;e=f;break f}e=h}Ap(a,e);c=c+1|0;continue}break}}function T4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;v[23220]=0;Y(919,a|0);d=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[23220]=0;Y(920,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break g}v[23220]=0;Y(920,c|0);d=v[23220];v[23220]=0;if((d|0)==1){break g}f=v[a+24>>2];v[23220]=0;d=Q(52,e+16|0,b|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break g}v[23220]=0;c=Q(52,e|0,c|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break f}v[23220]=0;X(935,f|0,d|0,c|0,1);b=v[23220];v[23220]=0;if((b|0)==1){break e}ub(c);ub(d);b=1;break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;ub(c)}ub(d)}_(b|0)|0;b=0;v[23220]=0;X(906,6370,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$()}fb=e+32|0;return b|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Qm(a,b,c,d){var e=0,f=0;f=fb-16|0;fb=f;v[23220]=0;Y(919,a|0);e=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=v[a+24>>2];v[23220]=0;R(d|0,f|0,e|0);d=v[23220];v[23220]=0;if((d|0)==1){break i}d=v[f>>2];e=rd(d,v[f+4>>2]);if(e>>>0<2147483647){break h}d=aa(8)|0;v[23220]=0;b=Q(973,d|0,7347)|0;e=v[23220];v[23220]=0;if((e|0)==1){break g}v[23220]=0;U(106,b|0,91828,155);b=v[23220];v[23220]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}j:{if(!((b|0)<(e|0)&(b|0)>=0)){b=Uf(21598);break j}b=Uf(Ec(Dd(d,b)))}De(f);break d}b=V(0)|0;O()|0;ba(d|0)}De(f)}_(b|0)|0;b=0;v[23220]=0;X(906,c|0,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break c}$()}fb=f+16|0;return b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Tb()}L()}S(a|0);L()}function JH(a,b,c,d){var e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=0;e=fb-96|0;fb=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];d=0;while(1){if((d|0)!=4){i=(e+48|0)+(d<<3)|0;g=(d<<4)+a|0;h=z[g+4>>2];f=z[g+8>>2];z[i+4>>2]=h+f;k=d<<1;z[(8-k<<2)+e>>2]=h-f;h=z[g+16>>2];f=z[g+12>>2];z[(7-k<<2)+e>>2]=h-f;z[i+8>>2]=-C(h+f);d=d+1|0;continue}break}IH(e+48|0);IH(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=z[i>>2];f=z[d+(e+48|0)>>2];l=z[d+70240>>2];m=z[d+70276>>2];n=z[d+e>>2];z[i>>2]=C(f*l)-C(m*n);i=a+d|0;d=c+d|0;f=C(C(f*m)+C(n*l));z[i>>2]=C(h*z[d>>2])-C(z[d+36>>2]*f);z[(17-g<<2)+a>>2]=C(h*z[d+36>>2])+C(f*z[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}fb=e+96|0}function P1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-32|0;fb=b;c=v[a>>2];a=v[c>>2];rf(b+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[c+4>>2];g=v[a+8>>2];f=v[a+4>>2];j=v[a>>2];a=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=a;a=v[b+20>>2];v[b>>2]=v[b+16>>2];v[b+4>>2]=a;a=fb-32|0;fb=a;a:{b:{if(y[b+4>>2]>=f>>>0){h=v[b+12>>2];if(Se(v[b+8>>2],h)>>>0<g>>>0){break b}k=v[b>>2];c:while(1){c=0;if((d|0)==(g|0)){break a}while(1)if((c|0)==(f|0)){d=d+1|0;continue c}else{l=a,m=A[Jg(j,f,c,d)>>3],A[l+24>>3]=m;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;i=de(A[ug(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(i)<2147483648){e=~~i;break d}e=-2147483648}e=Rc(e);l=mn(k,h,c,d),n=e,u[l>>1]=n;c=c+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}fb=a+32|0;fb=b+32|0}function JU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;kd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=yq(a+4|0,a);d=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=d;c=yq(a+8|0,a);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+8>>2]=f;c=(w[a+15|0]|w[a+16|0]<<8)<<1;v[b+24>>2]=c;c=w[a+15|0]|w[a+16|0]<<8?c:16726;v[b+24>>2]=c;g=b,h=(B(Bu(t[a+17|0],w[a+14|0]<<28>>24),c)>>>0)/8363|0,v[g+24>>2]=h;t[e+15|0]=w[a+18|0];t[e+14|0]=127;g=b,h=(((w[Rb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[g+30>>1]=h;c=w[a+14|0];if(c>>>0>=16){u[b+34>>1]=32;u[b+28>>1]=c&240}c=w[a+19|0];if(c&4){u[b+34>>1]=x[b+34>>1]|1;c=w[a+19|0]}a:{if(!(c&8)|d>>>0>=f>>>0){break a}f=x[b+34>>1];d=f|2;u[b+34>>1]=d;c=w[a+19|0];if(c&16){d=f|6;u[b+34>>1]=d;c=w[a+19|0]}if(!(c&64)){break a}u[b+34>>1]=d|128}fb=e+16|0}function G2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb+-64|0;fb=e;a:{b:{if((b|0)>=0){d=v[a+24>>2];if(hj(Vb(v[d+484360>>2],w[d+484376|0]))>>>0>b>>>0){break b}}a=a+16|0;break a}d=0;c:{f=v[a+24>>2];g=v[f+484344>>2];i=v[f+484348>>2];h=x[ac(v[Vb(v[f+484360>>2],w[f+484376|0])>>2],b)>>1];if(!om(g,i,h)){break c}if((c|0)>=0){d=c;if((d|0)<v[Xb(g,h)+12>>2]){break c}}a=a+16|0;break a}u[f+1074448>>1]=b;c=f;f=b&65535;SL(c,f);c=v[a+24>>2];v[c+1074392>>2]=-2;v[c+1074428>>2]=d;g=w[a+64|0];b=e+24|0;u[b+4>>1]=0;t[b+6|0]=255;v[b+16>>2]=2;v[b>>2]=0;v[b+8>>2]=d;u[b+12>>1]=f;d=v[b+20>>2];v[e+16>>2]=v[b+16>>2];v[e+20>>2]=d;d=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=d;d=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=d;b=e+48|0;Bt(b,c,g?7:1,e);j=a,k=A[LL(v[e+52>>2])>>3],A[j+16>>3]=k;ti(b);a=a+16|0}fb=e- -64|0;return+A[a>>3]}function sL(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=fb-16|0;fb=k;t[k+15|0]=c;t[k+14|0]=12;Zg(b,w[Rb(k+15|0,k+14|0)|0]);c=0;l=v[b>>2];m=v[b+4>>2];p=ne(l,m);while(1){if((c|0)==(p|0)){c=0;t[b+12|0]=0;a:{if(!(d&1)){break a}if(rc(l,m)){break a}c=1;t[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;t[b+12|0]=c}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=c|2}t[b+14|0]=g;t[b+13|0]=f}fb=k+16|0}else{b:{c:{d:{switch(h|0){case 0:j=zb(l,c);i=(c<<2)+a|0;u[j>>1]=w[i+96|0]|w[i+97|0]<<8;i=i+98|0;break c;case 1:break d;default:break b}}j=zb(l,c);i=(c<<2)+a|0;u[j>>1]=w[i+144|0]|w[i+145|0]<<8;i=i+146|0}t[j+2|0]=w[i|0]}e:{if(!c){break e}i=zb(l,c);j=x[i>>1];n=zb(l,c-1|0);o=x[n>>1];if(j>>>0>255|j>>>0>=o>>>0){break e}j=j|o&65280;u[i>>1]=j;if(j>>>0>=x[n>>1]){break e}u[i>>1]=j+256}c=c+1|0;continue}break}}function VM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=-1;a:{if(!by(a,b,2)){break a}f=v[b+656>>2];g=a+1074312|0;xb(e+8|0,g,31);b:{if(yb(v[v[e+8>>2]>>2],v[e+12>>2])){d=v[b+740>>2];if(d){break b}break a}d=v[b+740>>2]}xb(e+8|0,g,31);g=d-yb(v[v[e+8>>2]>>2],v[e+12>>2])|0;i=v[a+480180>>2];d=(i|0)==4096;j=f+88|0;f=d?64:(i|0)==16384?192:512;d=Ep(j,g,f,d?255:64)-(f>>>1|0)|0;if(w[b+746|0]&16){h=yp(a,b,!(v[b+88>>2]&32768),d);break a}if(lj(v[b+656>>2])){if((d|0)==u[b+772>>1]){break a}k=b,l=Rc(d),u[k+772>>1]=l;t[b+851|0]=w[b+851|0]|64;break a}a=cj(a);v[e+8>>2]=d;c:{if((d|0)<0){v[e+8>>2]=0-d;Uh(e+8|0,255);a=(v[e+8>>2]<<2)+(a?38320:37296)|0;break c}Uh(e+8|0,255);a=(v[e+8>>2]<<2)+(a?37296:38320)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];k=c,l=Dc(Cia(Bia(b,d,a,a>>31),ib,65536,0),ib),v[k>>2]=l}fb=e+16|0;return h}function Hba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=fb-16|0;fb=b;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){f=v[b+8>>2];n=((((v[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;o=u[e+39878>>1];p=u[e+39876>>1];q=u[e+39874>>1];r=u[e+39872>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+n|0;v[(e<<2)+b>>2]=(((B(u[f>>1],q)+B(u[f-4>>1],r)|0)+B(u[f+4>>1],p)|0)+B(u[f+8>>1],o)|0)/16384;e=e+1|0;continue}break}h=h+k|0;v[c>>2]=v[c>>2]+B(v[b>>2],h>>12);g=g+j|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g>>12);Ob(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;fb=b+16|0}function J8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;kd(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;v[c>>2]=w[a+40|0]|w[a+41|0]<<8|(w[a+42|0]<<16|w[a+43|0]<<24);v[c+4>>2]=w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24);v[c+8>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[c+24>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);d=w[b+151|0];if(d>>>0<=4){t[c+38|0]=w[d+42874|0]}d=w[b+152|0]|w[b+153|0]<<8;t[c+39|0]=d;e=(w[b+156|0]|w[b+157|0]<<8)>>>4|0;t[c+41|0]=e;b=(w[b+154|0]|w[b+155|0]<<8)>>>2|0;t[c+40|0]=b;if((b|e)&255){t[c+39|0]=d^-1}b=w[a+38|0]|w[a+39|0]<<8;if(b&4){u[c+34>>1]=x[c+34>>1]|1;b=w[a+38|0]|w[a+39|0]<<8}if(b&8){u[c+34>>1]=x[c+34>>1]|2;b=w[a+38|0]|w[a+39|0]<<8}if(b&16){u[c+34>>1]=x[c+34>>1]|4;b=w[a+38|0]|w[a+39|0]<<8}if(b&32){u[c+34>>1]=x[c+34>>1]|32}}function u9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-880|0;fb=b;c=Sb(a,0,76);v[c+84>>2]=0;v[c+88>>2]=0;v[c+80>>2]=256;u[c+76>>1]=65535;v[c+92>>2]=0;v[c+96>>2]=0;t[c+100|0]=1;a=c+616|0;while(1){vP(B(d,872)+a|0);d=d+1|0;if((d|0)!=256){continue}break}e=Ib(c+223848|0);g=By(c+223860|0);f=b+8|0;Sb(f,0,108);Cz(b+120|0,48e3);Sb(b+664|0,0,72);t[b+754|0]=0;u[b+752>>1]=65535;t[b+746|0]=0;u[b+744>>1]=65535;t[b+738|0]=0;u[b+736>>1]=65535;v[b+748>>2]=0;v[b+740>>2]=0;Sb(b+756|0,0,103);v[b+868>>2]=0;v[b+872>>2]=0;t[b+875|0]=0;t[b+876|0]=0;t[b+877|0]=0;t[b+878|0]=0;v[b+860>>2]=0;v[b+864>>2]=0;t[b+859|0]=w[b+859|0]&128;d=((a+223232|0)-a|0)/872|0;while(1){if((d|0)>0){d=d-1|0;a=up(a,f)+872|0;continue}break}v[23220]=0;R(497,e|0,32);a=v[23220];v[23220]=0;if((a|0)!=1){fb=b+880|0;return c|0}a=P()|0;O()|0;vp(g);$b(e);S(a|0);L()}function wy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=x[a+480188>>1];h=d>>>0>256?d:256;f=v[a+1298300>>2];c=d;a:{while(1){if((c|0)!=(h|0)){e=B(c,872)+a|0;if(!v[e+1075068>>2]){if(!Qj(v[e+1075648>>2])|w[e+1075081|0]&24){break a}}if(w[e+1075081|0]&2){if(!sd(f)){break a}if(!EM(f,c&65535)){break a}}c=c+1|0;continue}break}e=0;f=65535;g=8388608;if(b>>>0<=255){b=B(b,872)+a|0;if(!v[b+1075688>>2]){c=65535;if(v[b+1075068>>2]){break a}}g=v[b+1075680>>2]|v[b+1075672>>2]<<9}while(1){if((d|0)==(h|0)){c=f;break a}b=B(d,872)+a|0;if(!(v[b+1075688>>2]?0:v[b+1075068>>2])){c=(v[b+1075680>>2]|v[b+1075672>>2]<<9)>>>(v[b+1075080>>2]>>>1&1)|0;b:{c:{if(c>>>0<g>>>0){b=v[(B(d,872)+a|0)+1075716>>2];break c}if((c|0)!=(g|0)){break b}b=v[(B(d,872)+a|0)+1075716>>2];if(e>>>0>=b>>>0){break b}}g=c;f=d;e=b}d=d+1|0;continue}break}c=d}return c&65535}function S5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=ji(a,b,c,d);v[b+4260>>2]=0;v[b>>2]=46860;c=b+4504|0;while(1){Ib(c+B(e,24)|0);e=e+1|0;if((e|0)!=19){continue}break}t[b+5046|0]=1;u[b+5044>>1]=0;a=b+4208|0;f=zb(a,0),g=1063675494,v[f>>2]=g;f=zb(a,1),g=1065185444,v[f>>2]=g;f=zb(a,2),g=0,v[f>>2]=g;f=zb(a,3),g=1032805417,v[f>>2]=g;f=zb(a,4),g=1053079357,v[f>>2]=g;f=zb(a,5),g=1059859440,v[f>>2]=g;f=zb(a,6),g=1047457519,v[f>>2]=g;f=zb(a,7),g=1062836634,v[f>>2]=g;f=zb(a,8),g=1038174126,v[f>>2]=g;f=zb(a,9),g=1065353216,v[f>>2]=g;f=zb(a,10),g=1065353216,v[f>>2]=g;f=zb(a,11),g=1048525618,v[f>>2]=g;f=zb(a,12),g=1059760811,v[f>>2]=g;v[23220]=0;R(870,b+44|0,2);a=v[23220];v[23220]=0;if((a|0)==1){e=c+456|0;a=P()|0;O()|0;while(1){e=lc(e-24|0);if((c|0)!=(e|0)){continue}break}sf(b);S(a|0);L()}ii(b);return b|0}function FH(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=v[a+32>>2];a:{b:{b=v[a+1380>>2];if((b|0)==-1){d=1;b=-1;break b}e=v[a+1116>>2];d=(b|0)>(e|0)?b:e;while(1){c:{if((b|0)!=(d|0)){f=w[(a+b|0)+1120|0];c=f+c|0;if((f|0)==255){break c}d=b}if(y[a+40>>2]<c>>>0){Zb(a,1);break a}b=(d|0)==(e|0)?-1:d;d=0;break b}b=b+1|0;continue}}while(1){if((b|0)!=-1){return 1}e=v[a+40>>2];if(e>>>0<=c+26>>>0){Zb(a,1);break a}if(Mb(c,92392,4)){Zb(a,21);break a}if(w[c+4|0]){Zb(a,21);break a}d:{if(d){if(!v[a+992>>2]|!(t[c+5|0]&1)){break d}Zb(a,21);break a}if(t[c+5|0]&1){break d}Zb(a,21);break a}b=0;f=c+27|0;d=w[c+26|0];c=f+d|0;if(e>>>0<c>>>0){Zb(a,1);break a}while(1){e:{if((b|0)==(d|0)){b=d;break e}g=w[b+f|0];c=g+c|0;if((g|0)!=255){break e}b=b+1|0;continue}break}b=(b|0)==(d|0)?-1:b;d=0;if(c>>>0<=e>>>0){continue}break}Zb(a,1)}return 0}function NE(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-48|0;fb=d;v[23220]=0;Y(919,a|0);e=v[23220];v[23220]=0;a:{b:{c:{if((e|0)!=1){e=Gb(d+32|0);v[23220]=0;Y(c|0,d+16|0);c=v[23220];v[23220]=0;d:{e:{if((c|0)!=1){h=d,i=Ab(v[d+16>>2]),v[h+8>>2]=i;f=1;while(1){g=Ab(v[d+20>>2]);c=v[d+8>>2];if(!Nb(c,g)){c=Uf(Ec(e));De(d+16|0);ub(e);break b}if(!f){v[23220]=0;Q(908,e|0,14596)|0;c=v[23220];v[23220]=0;if((c|0)==1){break e}c=v[d+8>>2]}v[23220]=0;Q(772,e|0,c|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break e}Sp(d+8|0);f=0;continue}}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;De(d+16|0)}ub(e);break c}c=V(0)|0;O()|0}_(c|0)|0;c=0;v[23220]=0;X(906,b|0,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$()}fb=d+48|0;return c}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)==1){V(0)|0;O()|0;Tb();L()}S(a|0);L()}function SF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=fb-32|0;fb=h;a:{b:{c:{if((b|0)!=(c|0)){j=v[115696];v[115696]=0;g=fb-16|0;fb=g;wd();e=fb-16|0;fb=e;f=fb-16|0;fb=f;lw(f,b,h+28|0,2);k=v[f>>2];i=v[f+4>>2];b=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=b;v[e>>2]=k;v[e+4>>2]=i;fb=f+16|0;i=v[e>>2];f=v[e+4>>2];b=v[e+12>>2];v[g+8>>2]=v[e+8>>2];v[g+12>>2]=b;v[g>>2]=i;v[g+4>>2]=f;fb=e+16|0;f=v[g>>2];e=v[g+4>>2];b=v[g+12>>2];v[h+16>>2]=v[g+8>>2];v[h+20>>2]=b;v[h+8>>2]=f;v[h+12>>2]=e;fb=g+16|0;i=v[h+16>>2];f=v[h+20>>2];g=v[h+8>>2];e=v[h+12>>2];b=v[115696];if(!b){break c}if(v[h+28>>2]!=(c|0)){break b}l=g;m=e;n=i;o=f;if((b|0)!=68){break a}break b}v[d>>2]=4;break a}v[115696]=j;if(v[h+28>>2]==(c|0)){break a}}v[d>>2]=4;g=l;e=m;i=n;f=o}v[a>>2]=g;v[a+4>>2]=e;v[a+8>>2]=i;v[a+12>>2]=f;fb=h+32|0}function F1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-32|0;fb=b;c=v[a>>2];a=v[c>>2];rf(b+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[c+4>>2];g=v[a+8>>2];f=v[a+4>>2];i=v[a>>2];a=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=a;a=v[b+20>>2];v[b>>2]=v[b+16>>2];v[b+4>>2]=a;a=fb-32|0;fb=a;a:{b:{if(y[b+4>>2]>=f>>>0){if(Se(v[b+8>>2],v[b+12>>2])>>>0<g>>>0){break b}c:while(1){c=0;if((d|0)==(g|0)){break a}while(1)if((c|0)==(f|0)){d=d+1|0;continue c}else{j=a,k=A[Jg(i,f,c,d)>>3],A[j+24>>3]=k;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;h=de(A[ug(a+24|0,a+16|0,a+8|0)>>3]*32768);d:{if(D(h)<2147483648){e=~~h;break d}e=-2147483648}e=Rc(e);j=ln(b,c,d),l=e,u[j>>1]=l;c=c+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}fb=a+32|0;fb=b+32|0}function Iba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=fb-16|0;fb=b;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){f=v[b+8>>2];n=(((v[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;o=u[e+39878>>1];p=u[e+39876>>1];q=u[e+39874>>1];r=u[e+39872>>1];e=0;while(1){if((e|0)!=2){f=e+n|0;v[(e<<2)+b>>2]=(((B(t[f|0],q)+B(t[f-2|0],r)|0)+B(t[f+2|0],p)|0)+B(t[f+4|0],o)<<8)/16384;e=e+1|0;continue}break}h=h+k|0;v[c>>2]=v[c>>2]+B(v[b>>2],h>>12);g=g+j|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g>>12);Ob(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;fb=b+16|0}function lt(a,b){var c=0,d=0,e=0,f=0;e=fb-48|0;fb=e;d=e+24|0;xP(d,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);xP(e,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=v[d>>2];b=Jb(w[b|0]|w[b+1|0]<<8);a=v[e>>2];a=Jb(w[a|0]|w[a+1|0]<<8);c=1;a:{if(b>>>0<a>>>0){break a}c=0;if(a>>>0<b>>>0){break a}b=v[d+4>>2];b=Jb(w[b|0]|w[b+1|0]<<8);a=v[e+4>>2];a=Jb(w[a|0]|w[a+1|0]<<8);c=1;b:{if(b>>>0<a>>>0){break b}c=0;if(a>>>0<b>>>0){break b}b=v[d+8>>2];b=Jb(w[b|0]|w[b+1|0]<<8);a=v[e+8>>2];a=Jb(w[a|0]|w[a+1|0]<<8);c=1;c:{if(b>>>0<a>>>0){break c}c=0;if(a>>>0<b>>>0){break c}b=v[d+16>>2];a=v[e+12>>2];f=v[e+16>>2];d=v[d+12>>2];d=Jb(w[d|0]|w[d+1|0]<<8)<<16>>16;a=Jb(w[a|0]|w[a+1|0]<<8)<<16>>16;c=1;d:{if((d|0)<(a|0)){break d}c=0;if((a|0)<(d|0)){break d}c=Jb(w[b|0]|w[b+1|0]<<8)>>>0<Jb(w[f|0]|w[f+1|0]<<8)>>>0}}}}a=c;fb=e+48|0;return a}function Vu(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;a:{if(!c){break a}if(d){b=cc(g+8|0,a,b);a=fb-16|0;fb=a;v[a+12>>2]=c;d=v[b+4>>2];b:{if(!d){d=v[b>>2];break b}e=32-d|0;v[a+8>>2]=e;c=v[b>>2];h=e;e=v[Eb(a+8|0,a+12|0)>>2];v[c>>2]=-1<<d&-1>>>h-e|v[c>>2];f=v[a+12>>2];d=c+4|0;v[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Sb(e,255,d);e=c&31;v[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=d+v[b>>2]|0;v[c>>2]=b;v[b>>2]=v[b>>2]|-1>>>32-e}fb=a+16|0;break a}b=cc(g,a,b);a=fb-16|0;fb=a;v[a+12>>2]=c;d=v[b+4>>2];c:{if(!d){d=v[b>>2];break c}e=32-d|0;v[a+8>>2]=e;c=v[b>>2];f=v[c>>2];h=e;e=v[Eb(a+8|0,a+12|0)>>2];v[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=v[a+12>>2];d=c+4|0;v[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Sb(e,0,d);e=c&31;v[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=d+v[b>>2]|0;v[c>>2]=b;v[b>>2]=v[b>>2]&(-1>>>32-e^-1)}fb=a+16|0}fb=g+16|0}function Qfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-432|0;fb=d;wc(b);tA(b,d+376|0,d+296|0,d+8|0);k=d,l=vi((m=w[d+427|0]+1|0,n=1,o=_b(v[d+408>>2]),o?m:n)),t[k+4|0]=l;i=w[Rb(26800,d+4|0)|0];t[d+7|0]=i;u[d+4>>1]=4;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=Jb(x[d+8>>1])<<16>>16;if(!((e|0)<0|w[d+291|0]>63)){e=e&65535;f=0;while(1){if((f|0)==(e|0)){c:{e=g;g=_b(v[d+296>>2]);if(e>>>0<g>>>0){if(Vc(b,g)){break c}}t[d+7|0]=h+1;break b}}else{d:{if(!Vc(b,_b(v[d+392>>2])+(f<<2)|0)){break d}if(!Vc(b,km(b))){break d}e:{if(!c){j=Ae(b);break e}j=qq(b)}u[d+2>>1]=j;k=d,l=x[Re(d+4|0,d+2|0)>>1],u[k+4>>1]=l}f=f+1|0;continue}break}g=_b(v[d+296>>2]);tA(b,d+376|0,d+296|0,d+8|0);h=h+1|0;continue}break}Wu(a);break a}u[a>>1]=x[d+4>>1];t[a+2|0]=w[d+7|0]}fb=d+432|0}function via(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-48|0;fb=g;h=a+8|0;c=v[a+8>>2];j=vc(a);a:{if((c|0)!=v[j>>2]){break a}i=a+4|0;e=v[a+4>>2];d=v[a>>2];if(e>>>0>d>>>0){a=e;d=((a-d>>1)+1|0)/-2<<1;e=a+d|0;while(1){if((a|0)!=(c|0)){e=lU(e,a)+2|0;a=a+2|0;continue}break}c=e;v[h>>2]=c;v[i>>2]=d+v[i>>2];break a}v[g+24>>2]=c-d;v[g+44>>2]=1;e=g+24|0;c=v[Sc(e,g+44|0)>>2];c=vj(e,c,c>>>2|0,v[a+16>>2]);d=dc(g+16|0,v[a+4>>2]);f=v[dc(g+8|0,v[a+8>>2])>>2];e=fb-32|0;fb=e;d=v[d>>2];v[e+24>>2]=d;d=wo(e+8|0,c+8|0,pB(d,f));f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){k=f;f=v[e+24>>2];mq(k,w[f|0]|w[f+1|0]<<8);f=v[d>>2]+2|0;v[d>>2]=f;Oe(e+24|0);continue}break}Ed(d);fb=e+32|0;kc(a,c);kc(i,c+4|0);kc(h,c+8|0);kc(j,vc(c));Di(c);c=v[a+8>>2]}mq(c,w[b|0]|w[b+1|0]<<8);v[h>>2]=v[h>>2]+2;fb=g+48|0}function wd(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;if(w[466708]){return v[116676]}c=fb-32|0;fb=c;a:{b:{while(1){e=(c+8|0)+(a<<2)|0;d=1<<a&2147483647;if(d|1){d=lG(a,d?14270:21598)}else{d=v[a<<2>>2]}v[e>>2]=d;if((d|0)==-1){break b}a=a+1|0;if((a|0)!=6){continue}break}if(!kG(0)){b=88544;if(!Mb(c+8|0,88544,24)){break a}b=88568;if(!Mb(c+8|0,88568,24)){break a}a=0;if(!w[466480]){while(1){f=(a<<2)+466432|0,g=lG(a,21598),v[f>>2]=g;a=a+1|0;if((a|0)!=6){continue}break}t[466480]=1;v[116614]=v[116608]}b=466432;if(!Mb(c+8|0,466432,24)){break a}b=466456;if(!Mb(c+8|0,466456,24)){break a}b=Fd(24);if(!b){break b}}a=v[c+12>>2];v[b>>2]=v[c+8>>2];v[b+4>>2]=a;a=v[c+28>>2];v[b+16>>2]=v[c+24>>2];v[b+20>>2]=a;a=v[c+20>>2];v[b+8>>2]=v[c+16>>2];v[b+12>>2]=a;break a}b=0}fb=c+32|0;t[466708]=1;v[116676]=b;return b}function dba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){b=(v[f+12>>2]<<1)+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(u[b+4>>1],u[e+10>>1])+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/2|0)+((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)/2|0)|0)/16384|0;h=h+l|0;v[c>>2]=v[c>>2]+B(b,h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(b,g>>12);Ob(f+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;fb=f+16|0}function Iz(a,b){var c=0;c=fb-16|0;fb=c;a=Qq(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(Kb(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:ky(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;zf(a,107);break a;case 3:ky(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;zf(a,4);break a;case 2:break b;case 0:break c}}Kb(a,88,1);break a}ky(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}fb=c+16|0}function KJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=fb-48|0;fb=j;k=v[a+4>>2];l=v[a>>2];a=v[a+8>>2];v[j+32>>2]=b;v[j+44>>2]=a;v[j+36>>2]=l;v[j+40>>2]=k;v[23220]=0;a=Q(899,(d?d:900)|0,e|0)|0;b=v[23220];v[23220]=0;a:{b:{c:{d:{if((b|0)!=1){v[j+16>>2]=a;a=v[Rf(j+24|0,j+16|0)>>2];b=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=b;v[23220]=0;b=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=b;c=+Aa(901,j|0,+c,a|0);a=v[23220];v[23220]=0;if((a|0)==1){break d}pe(j+16|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;pe(j+16|0)}_(a|0)|0;v[23220]=0;ja(902,15086,d|0,e|0,f|0,g|0,h|0,i|0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();c=0}fb=j+48|0;return+c}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function R7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{if((xj(v[a>>2],v[a+4>>2])|0)==2){if((xj(v[a+12>>2],v[a+16>>2])|0)==(b|0)){break b}}v[23220]=0;R(872,a|0,2);c=v[23220];v[23220]=0;c:{if((c|0)==1){break c}v[23220]=0;R(872,a+12|0,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break c}v[23220]=0;R(873,a+24|0,2);c=v[23220];v[23220]=0;if((c|0)==1){break c}v[23220]=0;R(873,a+36|0,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break c}c=a;while(1)if((d|0)==2){a=0;while(1){if((a|0)==(b|0)){break b}d=Nq(v[c+12>>2],a);f=zb(v[c+36>>2],a),g=d,v[f>>2]=g;a=a+1|0;continue}}else{e=Nq(v[a>>2],d);f=zb(v[a+24>>2],d),g=e,v[f>>2]=g;d=d+1|0;continue}}b=V(91480)|0;if((O()|0)!=(ea(91480)|0)){break a}_(b|0)|0;Bc(a);PK(a);b=a+12|0;Bc(b);PK(b);b=a+24|0;Bc(b);OK(b);a=a+36|0;Bc(a);OK(a);$()}return}S(b|0);L()}function IM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{c=fb-16|0;fb=c;e=Gb(a);g=c,h=Fi(b),v[g+8>>2]=h;g=c,h=ev(b),v[g>>2]=h;a=0;b:{while(1){c:{if(!Kh(c+8|0,c)){if(!a){break c}v[23220]=0;R(46,e|0,65533);a=v[23220];v[23220]=0;if((a|0)!=1){break c}break b}b=w[v[c+8>>2]];d:{e:{if(!a){if(!(b&128)){a=0;v[23220]=0;R(46,e|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break d}break b}if((b&224)==192){d=b&31;a=1;break d}if((b&240)==224){d=b&15;a=2;break d}d=65533;if((b&248)!=240){break e}d=b&7;a=3;break d}if((b&192)!=128){d=0;v[23220]=0;R(46,e|0,65533);f=v[23220];v[23220]=0;a=0;if((f|0)==1){break b}}d=b&63|d<<6;a=a-1|0;if(a){break d}}a=0;v[23220]=0;R(46,e|0,d|0);b=v[23220];v[23220]=0;d=0;if((b|0)==1){break b}}xe(c+8|0);continue}break}fb=c+16|0;break a}a=P()|0;O()|0;Nc(e);S(a|0);L()}}function d2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-32|0;fb=d;j=d,k=iJ(),v[j+24>>2]=k;g=a+24|0;c=d+24|0;gJ(g,Ud(c));$i(c);u[a+28>>1]=0;_O();f=fb-16|0;fb=f;e=tc(144);v[23220]=0;h=Q(1033,e|0,4)|0;i=v[23220];v[23220]=0;a:{if((i|0)!=1){e=v[uf(f+8|0,h)>>2];fb=f+16|0;break a}a=P()|0;O()|0;Fb(e);S(a|0);L()}v[d+24>>2]=e;fJ(a+32|0,Ud(c));es(c);j=d,k=hJ(v[a>>2]),v[j+24>>2]=k;eJ(a+4|0,Ud(c));_i(c);on(v[g>>2],v[a+4>>2]);v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;t[a- -64|0]=0;j=d,k=oj(v[b>>2]),v[j+24>>2]=k;e=wf(b);b:{while(1){b=v[d+24>>2];if(!vg(b,e)){break b}c=pd(b);b=Oh(d+8|0,c);v[23220]=0;X(935,a|0,b|0,c+12|0,0);c=v[23220];v[23220]=0;if((c|0)!=1){ub(b);Rg(d+24|0);continue}break}a=P()|0;O()|0;ub(b);S(a|0);L()}fb=d+32|0}function i7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);c=fb-4112|0;fb=c;h=jb[v[v[a>>2]+116>>2]](a)|0;if(!h){jb[v[v[a>>2]+120>>2]](a)}v[c+12>>2]=0;f=fb-16|0;fb=f;while(1){d=v[a+44>>2];if(xj(d,v[a+48>>2])>>>0<=e>>>0){fb=f+16|0}else{v[f+12>>2]=0;d=Nq(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){z[d>>2]=z[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}f=c+2064|0;a:while(1){if(b){v[c+8>>2]=b;uc(c+8|0,512);e=c+16|0;ny(e);d=v[c+8>>2];jb[v[v[a>>2]+60>>2]](a,e,f,d);e=0;while(1)if((e|0)==(d|0)){b=b-d|0;continue a}else{g=(c+16|0)+(e<<2)|0;z[c+4>>2]=D(z[g>>2]);i=c,j=z[xx(c+12|0,c+4|0)>>2],z[i+12>>2]=j;z[c+4>>2]=D(z[g+2048>>2]);i=c,j=z[xx(c+12|0,c+4|0)>>2],z[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){jb[v[v[a>>2]+124>>2]](a)}fb=c+4112|0;return C(z[c+12>>2])}function QK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;a:{if(sc(v[a>>2],v[a+4>>2])>>>0>511){break a}if(!Ch(v[v[b>>2]-12>>2]+b|0)){break a}d=fb-16|0;fb=d;f=tc(64);v[23220]=0;g=T(807,f|0)|0;h=v[23220];v[23220]=0;b:{c:{if((h|0)!=1){f=uf(d,g);g=v[f>>2];v[23220]=0;g=W(867,g|0,b|0,c|0)|0;h=v[23220];v[23220]=0;d:{e:{if((h|0)!=1){if((g|0)==1){break e}mf(d+8|0);break d}a=P()|0;O()|0;fg(f);break c}Rf(d+8|0,f)}fg(f);fb=d+16|0;d=v[d+8>>2];break b}a=P()|0;O()|0;Fb(f)}S(a|0);L()}v[e+8>>2]=d;f:{g:{if(!sd(d)){v[23220]=0;b=Q(866,b|0,c|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break g}v[e>>2]=b;JS(e+8|0,Ud(e));fg(e);d=v[e+8>>2]}if(!sd(d)){break f}v[23220]=0;R(442,a|0,e+8|0);a=v[23220];v[23220]=0;i=d;if((a|0)!=1){break f}}a=P()|0;O()|0;fg(e+8|0);S(a|0);L()}fg(e+8|0)}fb=e+16|0;return i}function wB(a,b){var c=0,d=0;d=w[a|0];if(d>>>0>=36){t[a|0]=0;return}c=w[d+26304|0];t[a|0]=c;a:{b:{c:{switch(c-17|0){default:d:{if(c-6>>>0<2){break d}if((c|0)==31){break b}if((c|0)==11){break d}if(w[b|0]|(c|0)!=1){break a}t[a|0]=0;return}c=w[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}t[b|0]=a;return;case 6:a=w[b|0];if(a>>>0<=64){t[b|0]=a<<1;return}t[b|0]=128;return;case 2:e:{f:{g:{h:{c=w[b|0];switch((c&240)-48>>>4|0){case 4:break e;case 2:break f;case 1:break g;case 0:break h;default:break a}}t[a|0]=20;t[b|0]=159;return}t[a|0]=20;t[b|0]=192;return}if(c&14){break a}t[a|0]=21;t[b|0]=(w[b|0]!=80)<<6;return}t[a|0]=20;t[b|0]=w[b|0]&15|160;return;case 1:case 3:case 4:case 5:break a;case 0:break c}}if(w[b|0]>31){break a}t[a|0]=16;return}t[b|0]=(d<<5|w[b|0]<<24>>>27)^128}}function jd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=v[a+112>>2];d=v[a+116>>2];e=!!(b|d);c=b;a:{i=e;f=v[a+4>>2];e=v[a+44>>2];b=f-e|0;h=b;g=b+v[a+120>>2]|0;b=v[a+124>>2]+(b>>31)|0;b=g>>>0<h>>>0?b+1|0:b;if(!(i&(c>>>0<=g>>>0&(b|0)>=(d|0)|(b|0)>(d|0)))){h=sw(a);if((h|0)>=0){break a}f=v[a+4>>2];e=v[a+44>>2]}v[a+112>>2]=-1;v[a+116>>2]=-1;v[a+104>>2]=f;c=e-f|0;d=c+g|0;b=(c>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<c>>>0?b+1|0:b;return-1}d=g+1|0;b=d?b:b+1|0;f=v[a+4>>2];e=v[a+8>>2];c=v[a+112>>2];g=v[a+116>>2];b:{if(!(c|g)){break b}i=c-d|0;c=g-(b+(d>>>0>c>>>0)|0)|0;j=e-f|0;g=j>>31;if((c|0)>=(g|0)&i>>>0>=j>>>0|(c|0)>(g|0)){break b}e=f+i|0}v[a+104>>2]=e;c=v[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){t[f-1|0]=h}return h}function eba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){b=v[f+12>>2]+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(t[b+2|0],u[e+10>>1])+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/2|0)+((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])<<8)/2|0)|0)/16384|0;h=h+l|0;v[c>>2]=v[c>>2]+B(b,h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(b,g>>12);Ob(f+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;fb=f+16|0}function Fn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=v[b+88>>2];d=c|2048;v[b+88>>2]=d;f=v[b+656>>2];if(!(!f|t[b+730|0]&1)){d=c|6144;v[b+88>>2]=d}a:{if(!v[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=v[b+104>>2];if(!c){break b}e=x[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;v[b+88>>2]=d;e=v[c>>2];v[b+76>>2]=e;g=v[c+4>>2];v[b+80>>2]=g;c=v[c+8>>2];v[b+84>>2]=c;if(c>>>0<e>>>0){v[b+76>>2]=c;h=c}else{h=e}e=v[b+4>>2];if(h>>>0>=e>>>0){break b}v[b>>2]=0;v[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;v[b+88>>2]=d;v[b+76>>2]=v[c>>2]}if(!f){break a}if(!(!(v[a+480180>>2]&1064964?1:w[f+60|0]&2)|!v[f>>2])){v[b+88>>2]=d|4096}if(w[f+65|0]==255|x[b+728>>1]!=65535){break a}i=b,j=Rc(Ep(f+48|0,v[b+724>>2],256,64)),u[i+728>>1]=j;i=b,j=x[zb(v[f+48>>2],w[f+65|0])>>1],v[i+724>>2]=j}}function t6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=0,s=0;h=fb-16|0;fb=h;if(Th(a+44|0)){g=v[a+44>>2];r=h,s=zc(g,0),v[r+8>>2]=s;r=h,s=zc(g,1),v[r+12>>2]=s;g=v[a+56>>2];l=zc(g,0);v[h>>2]=l;m=zc(g,1);v[h+4>>2]=m;p=w[a+4273|0];q=w[a+4272|0];g=d;while(1){k=0;if(g){while(1){if((k|0)!=2){j=k<<2;i=j+(h+8|0)|0;e=v[i>>2];v[i>>2]=e+4;f=C(z[e>>2]*z[a+4240>>2]);e=a+j|0;i=e+4228|0;f=C(f+C(z[i>>2]*z[a+4236>>2]));z[i>>2]=f;f=iK(C(f*C(1073741824)),q,p);i=e+4244|0;e=e+4252|0;n=z[e>>2];o=z[a+4264>>2];f=C(C(C(f*z[a+4260>>2])-C(z[a+4268>>2]*z[i>>2]))-C(n*o));z[e>>2]=f;z[i>>2]=n+C(f*o);e=h+j|0;j=v[e>>2];v[e>>2]=j+4;z[j>>2]=f*C(9.313225746154785e-10);k=k+1|0;continue}break}g=g-1|0;continue}else{hi(a,b,c,l,m,d)}break}}fb=h+16|0}function LV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;Vc(b,w[c+32|0]|w[c+33|0]<<8|(w[c+34|0]<<16|w[c+35|0]<<24));h=Ib(a);a=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);v[23220]=0;R(171,h|0,a|0);a=v[23220];v[23220]=0;if((a|0)!=1){a:{a=0;while(1){b:{if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))>>>0<=a>>>0){break b}e=v[b+8>>2];f=v[b>>2];v[23220]=0;e=W(143,f|0,e|0,4)|0;f=v[23220];v[23220]=0;if((f|0)==1){break a}if(!e){break b}e=w[c+4|0]|w[c+5|0]<<8;v[23220]=0;e=Q(172,b|0,e|0)|0;f=v[23220];v[23220]=0;c:{if((f|0)!=1){v[g+12>>2]=e;if(rd(v[d>>2],v[d+4>>2])>>>0<=e>>>0){break c}v[23220]=0;R(173,h|0,g+12|0);e=v[23220];v[23220]=0;if((e|0)!=1){break c}}break a}a=a+1|0;continue}break}fb=g+16|0;return}}a=P()|0;O()|0;lc(h);S(a|0);L()}function gp(a){var b=C(0),c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=Yh(+a);break a}if(d>>>0<=1081824209){if(d>>>0>=1075235812){b=C(-Yh(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}f=+a;if((e|0)<0){b=Zh(f+1.5707963267948966);break a}b=Zh(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=Yh(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=Zh(-4.71238898038469-+a);break a}b=Zh(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch(Jw(a,c+8|0)&3){case 0:b=Yh(A[c+8>>3]);break a;case 1:b=Zh(-A[c+8>>3]);break a;case 2:b=C(-Yh(A[c+8>>3]));break a;default:break b}}b=Zh(A[c+8>>3])}a=b;fb=c+16|0;return a}function N0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;v[c+28>>2]=0;if(Nd(w[fn(c+24|0,a,0)|0])){d=c+16|0;Xc(d,v[v[a>>2]-12>>2]+a|0);v[23220]=0;d=T(1071,d|0)|0;e=v[23220];v[23220]=0;a:{b:{if((e|0)!=1){e=qm(c+8|0,a);f=lh(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[23220]=0;ka(1074,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0);d=v[23220];v[23220]=0;if((d|0)!=1){break b}}b=V(0)|0;O()|0;Wb(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;en(v[v[a>>2]-12>>2]+a|0,b);c:{d:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23220]=0;Z(91);a=v[23220];v[23220]=0;if((a|0)!=1){break c}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)==1){break d}S(a|0);L()}$();break a}V(0)|0;O()|0;Tb()}L()}Wb(c+16|0);v[b>>2]=v[c+20>>2]}tj(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}fb=c+32|0;return a|0}function EK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;e=v[b+4220>>2];f=v[b+4224>>2];g=v[b+4228>>2];h=v[b+4232>>2];i=v[b+4240>>2];j=v[b+4236>>2];k=w[b+4244|0];Ji(b+4208|0,33);d=v[b+4208>>2];t[d+32|0]=k;t[d+24|0]=j;t[d+25|0]=j>>>8;t[d+26|0]=j>>>16;t[d+27|0]=j>>>24;t[d+28|0]=i;t[d+29|0]=i>>>8;t[d+30|0]=i>>>16;t[d+31|0]=i>>>24;t[d+16|0]=g;t[d+17|0]=g>>>8;t[d+18|0]=g>>>16;t[d+19|0]=g>>>24;t[d+20|0]=h;t[d+21|0]=h>>>8;t[d+22|0]=h>>>16;t[d+23|0]=h>>>24;t[d+8|0]=e;t[d+9|0]=e>>>8;t[d+10|0]=e>>>16;t[d+11|0]=e>>>24;t[d+12|0]=f;t[d+13|0]=f>>>8;t[d+14|0]=f>>>16;t[d+15|0]=f>>>24;t[d|0]=76;t[d+1|0]=70;t[d+2|0]=79;t[d+3|0]=32;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;ge(c+8|0,v[b+4208>>2],v[b+4212>>2]);cc(a,v[c+8>>2],v[c+12>>2]);fb=c+16|0}function mK(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=Zh(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=C(-Yh(d+1.5707963267948966));break a}a=Yh(d+-1.5707963267948966);break a}a=Zh(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){d=+a;if((e|0)<0){a=Yh(d+4.71238898038469);break a}a=C(-Yh(d+-4.71238898038469));break a}a=Zh(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch(Jw(a,b+8|0)&3){case 0:a=Zh(A[b+8>>3]);break a;case 1:a=Yh(A[b+8>>3]);break a;case 2:a=Zh(-A[b+8>>3]);break a;default:break b}}a=C(-Yh(A[b+8>>3]))}fb=b+16|0;return a}function g8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-16|0;fb=g;j=bf(a,c);Yd(g,v[a+28>>2]);k=a;a:{if(!j){c=0;if(cd(a,5)){break a}}e=fb-48|0;fb=e;h=v[a+28>>2];nk(h,e+40|0);c=v[e+44>>2];if(!c&y[e+40>>2]>=257|c){v[e+40>>2]=256;v[e+44>>2]=0}l=v[e+40>>2];m=v[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!m&c>>>0>=l>>>0){break b}If(h,e+38|0);f=Gb(e+24|0);v[23220]=0;Q(440,h|0,f|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){v[23220]=0;U(11,e+8|0,d|0,f|0);a=v[23220];v[23220]=0;if((a|0)==1){break e}v[23220]=0;a=Q(860,b|0,e+38|0)|0;i=v[23220];v[23220]=0;if((i|0)==1){break d}i=a;a=e+8|0;Db(i,a);vb(a);ub(f);c=c+1|0;continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;vb(e+8|0)}ub(f);S(c|0);L()}fb=e+48|0;c=j}We(k,c);fb=g+16|0}function IH(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);f=z[a>>2];i=z[a+24>>2];c=C(f-i);d=z[a+16>>2];b=z[a+32>>2];g=z[a+8>>2];e=C(d+C(b-g));z[a+16>>2]=c+e;j=C(c-C(e*C(.5)));c=z[a+4>>2];e=z[a+20>>2];h=z[a+28>>2];k=C(C(C(c-e)-h)*C(.8660253882408142));z[a+4>>2]=j+k;l=C(C(d-b)*C(.1736481785774231));f=C(f+C(i*C(.5)));i=C(C(g+b)*C(.7660444378852844));m=C(l+C(f-i));n=C(C(c+e)*C(.9848077297210693));b=C(z[a+12>>2]*C(.8660253882408142));c=C(C(c+h)*C(.6427876353263855));o=C(C(n-b)-c);z[a+12>>2]=m+o;z[a+20>>2]=m-o;z[a+28>>2]=j-k;d=C(C(g+d)*C(.9396926164627075));g=C(C(f+d)-l);e=C(C(e-h)*C(.3420201539993286));h=C(C(e-b)-n);z[a+32>>2]=g+h;d=C(C(f-d)+i);b=C(C(b+e)-c);z[a+24>>2]=d+b;z[a+8>>2]=d-b;z[a>>2]=g-h}function Cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;c=bf(a,c);Yd(f,v[a+28>>2]);a:{if(!c){if(cd(a,5)){break a}}d=fb-32|0;fb=d;g=v[a+28>>2];If(g,d+30|0);b:{c:{d:{e:{e=x[d+30>>1];if(e>>>0>=4001){i=v[b+12>>2];e=fb-16|0;fb=e;h=Qb(e,15875);Mc(d,h);vb(h);fb=e+16|0;v[23220]=0;U(433,d+16|0,d|0,d+30|0);e=v[23220];v[23220]=0;if((e|0)==1){break e}e=v[i+1298464>>2];v[23220]=0;U(360,e|0,2,d+16|0);e=v[23220];v[23220]=0;if((e|0)==1){break d}vb(d+16|0);bc(d);e=4e3}gg(nj(v[b>>2],0),e);b=nj(v[b>>2],0);j=d,k=Ab(v[b>>2]),v[j+16>>2]=k;b=Ab(v[b+4>>2]);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(d+16|0)}bc(d);S(a|0);L()}while(1){e=v[d+16>>2];if(Nb(e,b)){If(g,d);u[e>>1]=x[d>>1];Oe(d+16|0);continue}break}fb=d+32|0;d=c}We(a,d);fb=f+16|0}function EZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=xF(c);b:{if(b){rk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;qk(k,a);break b}nr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Fh(k,a)}Li(i,k);Nc(k);l=e,m=Qi(a),v[l>>2]=m;l=f,m=Ri(a),v[l>>2]=m;Gg(k,a);xc(g,k);ub(k);Gh(k,a);Li(h,k);Nc(k);a=pk(a);break a}a=wF(c);c:{if(b){rk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;qk(k,a);break c}nr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Fh(k,a)}Li(i,k);Nc(k);l=e,m=Qi(a),v[l>>2]=m;l=f,m=Ri(a),v[l>>2]=m;Gg(k,a);xc(g,k);ub(k);Gh(k,a);Li(h,k);Nc(k);a=pk(a)}v[j>>2]=a;fb=k+16|0}function OW(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-192|0;fb=c;b=c+16|0;ei(b,a);v[23220]=0;R(75,c+32|0,b|0);a=v[23220];v[23220]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[23220]=0;a=Q(76,c+48|0,c+32|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break e}ub(c+32|0);ub(c+16|0);b=v[v[a>>2]-12>>2];v[23220]=0;d=ha(59)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}v[23220]=0;U(60,c+8|0,a+b|0,d|0);b=v[23220];v[23220]=0;if((b|0)==1){break c}Wb(c+8|0);b=a+v[v[a>>2]-12>>2]|0;v[b+4>>2]=v[b+4>>2]&-75;v[b+4>>2]=v[b+4>>2]|8;v[23220]=0;b=Q(81,a|0,c+32|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}a=Ek(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);d=v[c+32>>2];df(b);fb=c+192|0;a=a?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;ub(c+32|0)}ub(c+16|0);break b}b=P()|0;O()|0;df(a)}S(b|0);L()}return a|0}function IZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=BF(c);b:{if(b){rk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;qk(k,a);break b}nr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Fh(k,a)}xc(i,k);ub(k);l=e,m=Qi(a),t[l|0]=m;l=f,m=Ri(a),t[l|0]=m;Gg(k,a);xc(g,k);ub(k);Gh(k,a);xc(h,k);ub(k);a=pk(a);break a}a=AF(c);c:{if(b){rk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;qk(k,a);break c}nr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Fh(k,a)}xc(i,k);ub(k);l=e,m=Qi(a),t[l|0]=m;l=f,m=Ri(a),t[l|0]=m;Gg(k,a);xc(g,k);ub(k);Gh(k,a);xc(h,k);ub(k);a=pk(a)}v[j>>2]=a;fb=k+16|0}function mR(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){if((c|0)!=20){g=b;b=t[a+c|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b;a:{if(b>>>0>5){break a}while(1){if((h|0)!=15){e=B(h,30)+a|0;f=e+20|0;c=0;b=0;while(1){if((c|0)!=22){g=b;b=t[c+f|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b+d|0;if(d>>>0>48){break a}c=w[e+45|0];if(w[e+44|0]|c>>>0>64){break a}b=Jb(w[e+42|0]|w[e+43|0]<<8);if(b>>>0>32768){break a}h=h+1|0;i=c|i;j=b+j|0;continue}break}if(!j|!(i&255)){break a}d=w[a+470|0];if(d>>>0>128){break a}b=w[a+471|0];if(b>>>0>220){break a}a=a+472|0;f=lR(a);b:{if((a|0)==(f|0)){break b}c=a;while(1){c=c+1|0;if((f|0)==(c|0)){break b}a=zr(w[a|0],w[c|0])?c:a;continue}}a=w[a|0];if(a>>>0>63){break a}k=(b|(a|d))!=0}return k}function Mo(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;v[d+28>>2]=0;a:{b:{c:{if(Nd(w[fn(d+24|0,a,0)|0])){f=d+16|0;Xc(f,v[v[a>>2]-12>>2]+a|0);v[23220]=0;f=T(1071,f|0)|0;e=v[23220];v[23220]=0;d:{e:{if((e|0)==1){break e}e=qm(d+8|0,a);g=lh(d);h=v[v[a>>2]-12>>2];g=v[g>>2];e=v[e>>2];v[23220]=0;ka(c|0,f|0,e|0,g|0,a+h|0,d+28|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break e}Wb(d+16|0);break d}b=V(0)|0;O()|0;Wb(d+16|0);_(b|0)|0;b=v[d+28>>2]|1;v[d+28>>2]=b;en(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23220]=0;Z(91);a=v[23220];v[23220]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)==1){break c}S(a|0);L()}$()}tj(v[v[a>>2]-12>>2]+a|0,v[d+28>>2])}fb=d+32|0;break a}V(0)|0;O()|0;Tb()}L()}return a}function HI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-32|0;fb=c;e=v[a>>2];a=v[e>>2];rf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[e+4>>2];g=v[a+8>>2];e=v[a+4>>2];j=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(e>>>0<=y[c+4>>2]){h=v[c+12>>2];if(Se(v[c+8>>2],h)>>>0<g>>>0){break b}k=b+12|0;l=v[c>>2];c:while(1){a=0;if((f|0)==(g|0)){break a}while(1)if((a|0)==(e|0)){f=f+1|0;continue c}else{d=Ih(j,e,a,f);i=zb(v[b>>2],a);d=v[d>>2]+(v[i>>2]>>1)|0;m=d;d=$r(k)+d&-4096;v[i>>2]=m-d;d=dd(d|2048,12);d=(d|0)<32767?d:32767;n=mn(l,h,a,f),o=(d|0)>-32768?d:-32768,u[n>>1]=o;a=a+1|0;continue}}}ca(7115,9016,34,8729);L()}ca(5828,9016,36,8729);L()}fb=c+32|0}function ofa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;t[e+15|0]=0;u[e+12>>1]=0;j=8;n=B(c,d)<<1;while(1){if((d|0)!=(k|0)){g=(k<<1)+b|0;o=n+g|0;while(1){if(g>>>0<o>>>0){u[e+10>>1]=0;GR(a,e+15|0,e+12|0,j,e+10|0);h=x[e+10>>1];c=j;while(1){a:{if(!(c&255)){break a}f=x[e+12>>1]<<1;i=f&254;u[e+12>>1]=i;if(i){f=(f&65534)>>>0>255}else{if(!Ye(a,e+9|0)){break a}f=w[e+9|0];u[e+12>>1]=f<<1&254|1;f=f>>>7|0}c=c-1|0;h=f|h<<1;continue}break}c=1;i=h&65535;b:{if(i>>>0<4){break b}f=15;while(1){c=f;m=f&255;if(i>>>m&1){break b}f=c-1|0;if(m>>>0>1){continue}break}}f=h&1;t[e+15|0]=f;l=(f-1^(h&65534)>>>1)+l|0;u[e+10>>1]=l;u[g>>1]=l;g=(d<<1)+g|0;j=(c+j&254)>>>1|0;continue}break}k=k+1|0;continue}break}fb=e+16|0}function uy(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{if(!d){break a}if(c){t[b+815|0]=c;break a}c=w[b+815|0]}f=v[a+480180>>2];d=f&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){a=v[a+480208>>2]&4096;if(!d){break h}if(!a){break b}a=0-(d>>>2|0)|0;break d}a=v[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!a){break b}c=c<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!c){break e}}c=c<<2;if(!(f&16777248)|!d){break c}break b}a=0-(d>>>2|0)|0;break d}if(w[a+480209|0]&16){break b}xb(e+8|0,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;if(!yb(v[v[e+8>>2]>>2],v[e+12>>2])){break d}a=(a|0)/4<<24>>24}c=a;if(!c){break b}}a=v[b+692>>2];u[b+784>>1]=0;g=b,h=Ub(a+c|0,0,256),v[g+692>>2]=h}fb=e+16|0}function Ep(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=fb-16|0;fb=h;f=v[a>>2];e=v[a+4>>2];i=ne(f,e)-1|0;while(1){a:{b:{if(ne(f,e)-1>>>0<=g>>>0){g=i;break b}if(x[Gc(f,e,g)>>1]<(b|0)){break a}e=v[a+4>>2];f=v[a>>2]}i=x[Gc(f,e,g)>>1];f=0;v[h+12>>2]=0;c:{if((b|0)>=(i|0)){j=h,k=(w[Gc(v[a>>2],v[a+4>>2],g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break c}e=0;if(g){e=g-1|0;f=(w[Gc(v[a>>2],v[a+4>>2],e)+2|0]<<16)/(d|0)|0;v[h+12>>2]=f;e=x[Gc(v[a>>2],v[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=i>>>0){break c}a=((w[Gc(v[a>>2],v[a+4>>2],g)+2|0]<<16)/(d|0)|0)-f|0;d=a;g=a>>31;a=b-e|0;b=Bia(d,g,a,a>>31);a=i-e|0;j=h,k=Dc(Cia(b,ib,a,a>>31),ib)+f|0,v[j+12>>2]=k}ee(h+12|0,0,65536);fb=h+16|0;return(B(v[h+12>>2],c)+32768|0)/65536|0}g=g+1|0;e=v[a+4>>2];f=v[a>>2];continue}}function ip(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;d=j(0)|0;a:{b:{c:{d:{if((b|0)>0|(b|0)>=0){f=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|d)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(f>>>0>2146435071){break a}b=1072693248;g=-1023;if((f|0)!=1072693248){b=f;break b}if(d){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;d=j(0)|0;g=-1077}b=b+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,d|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function Ik(a,b,c){var d=0,e=0,f=0,g=0;e=fb-48|0;fb=e;d=v[a+24>>2];g=v[d+24620>>2];a:{if(!((g|0)!=(b|0)|v[d+24624>>2]!=(c|0))){if(w[a+29|0]){break a}JL(d,1);break a}f=e+8|0;nc(f,d+24604|0,40);v[e+28>>2]=c;v[e+24>>2]=b;c=v[e+44>>2];fs(f,v[e+40>>2]);On(f,c);gy(d,f);if((b|0)==(g|0)){break a}c=0;d=v[a+24>>2]+906300|0;while(1){if((c|0)!=250){b=v[d+B(c,160)>>2];b:{if(!b){break b}if(!(jb[v[v[b>>2]+116>>2]](b)|0)){break b}jb[v[v[b>>2]+108>>2]](b,0);jb[v[v[b>>2]+96>>2]](b);jb[v[v[b>>2]+124>>2]](b)}c=c+1|0;continue}break}d=v[a+24>>2]+906300|0;c=0;while(1){if((c|0)!=250){b=v[d+B(c,160)>>2];c:{if(!b){break c}if(jb[v[v[b>>2]+116>>2]](b)|0){break c}jb[v[v[b>>2]+108>>2]](b,1);jb[v[v[b>>2]+120>>2]](b)}c=c+1|0;continue}break}}t[a+29|0]=1;fb=e+48|0}function lC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;e=v[b>>2];d=Ic(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=fb-32|0;fb=i;d=c-d|0;f=v[Cb(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>1>>>0){f=fb-16|0;fb=f;e=Ci(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){hc(e);fb=f+16|0}else{Aq(d);d=d+2|0;v[e+4>>2]=d;continue}break}break b}f=Cb(b);e=vj(i+8|0,wj(b,Ic(v[b>>2],e)+d|0),Ic(v[b>>2],v[b+4>>2]),f);h=fb-16|0;fb=h;d=wo(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){Aq(f);f=v[d>>2]+2|0;v[d>>2]=f;continue}break}Ed(d);fb=h+16|0;vd(b,e);Di(e)}fb=i+32|0;break a}if(c>>>0<d>>>0){Jd(b,e+(c<<1)|0)}}c=Lb(v[a>>2],v[a+8>>2],c<<1);if(c){d=v[b>>2];ec(g+8|0,d,Ic(d,v[b+4>>2])<<1);md(g,a,v[g+8>>2],v[g+12>>2])}fb=g+16|0;return c|0}function nfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;t[e+15|0]=0;u[e+12>>1]=0;n=B(c,d);j=4;a:while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){t[e+11|0]=0;FR(a,e+15|0,e+12|0,e+11|0);i=w[e+11|0];f=x[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!Ye(a,e+10|0)){break c}f=w[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}u[e+12>>1]=f;break b}k=k+1|0;continue a}u[e+12>>1]=0}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;t[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;t[e+11|0]=l;t[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}}break}fb=e+16|0}function Caa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-48|0;fb=g;h=a+8|0;c=v[a+8>>2];j=vc(a);a:{if((c|0)!=v[j>>2]){break a}i=a+4|0;d=v[a+4>>2];e=v[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=Gi(d,c,a+d|0);v[h>>2]=c;v[i>>2]=a+v[i>>2];break a}v[g+24>>2]=c-e>>1;v[g+44>>2]=1;d=g+24|0;c=v[Sc(d,g+44|0)>>2];c=cg(d,c,c>>>2|0,v[a+16>>2]);e=dc(g+16|0,v[a+4>>2]);f=v[dc(g+8|0,v[a+8>>2])>>2];d=fb-32|0;fb=d;e=v[e>>2];v[d+24>>2]=e;e=il(d+8|0,c+8|0,Gt(f,e));f=v[e>>2];while(1){if(v[e+4>>2]!=(f|0)){k=f;f=v[d+24>>2];Zn(k,x[f>>1]|x[f+2>>1]<<16);f=v[e>>2]+4|0;v[e>>2]=f;ye(d+24|0);continue}break}Ed(e);fb=d+32|0;kc(a,c);kc(i,c+4|0);kc(h,c+8|0);kc(j,vc(c));bg(c);c=v[a+8>>2]}Zn(c,x[b>>1]|x[b+2>>1]<<16);v[h>>2]=v[h>>2]+4;fb=g+48|0}function Y1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-80|0;fb=d;a=v[a+4>>2];Av(d+16|0,b);v[23220]=0;b=Q(1,d|0,17713)|0;e=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){v[23220]=0;U(2,d+32|0,d+16|0,b|0);e=v[23220];v[23220]=0;if((e|0)==1){break h}v[23220]=0;U(432,d+48|0,d+32|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break g}v[23220]=0;R(981,d- -64|0,d+48|0);c=v[23220];v[23220]=0;if((c|0)==1){break f}c=v[v[a>>2]+8>>2];v[23220]=0;R(c|0,a|0,d- -64|0);a=v[23220];v[23220]=0;if((a|0)==1){break e}ub(d- -64|0);vb(d+48|0);vb(d+32|0);vb(b);vb(d+16|0);fb=d+80|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;ub(d- -64|0)}vb(d+48|0)}vb(d+32|0)}vb(b)}vb(d+16|0);S(a|0);L()}function ZL(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:np(a,C(1));yn(a,C(3.725290298461914e-9));mp(a,C(268435456));lp(a,0);break b;case 1:np(a,C(32));yn(a,C(4.656612873077393e-10));mp(a,C(2147483648));lp(a,0);break b;case 2:np(a,C(2));yn(a,C(7.450580596923828e-9));mp(a,C(134217728));lp(a,1);break b;default:np(a,C(1));yn(a,C(7.450580596923828e-9));mp(a,C(134217728));lp(a,1);_x(a,0);Zx(a,1);Yx(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}np(a,C(.75));yn(a,C(7.450580596923828e-9));mp(a,C(134217728));lp(a,1);_x(a,0);b=(b|0)==4;Zx(a,b?2:3);Yx(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}_x(a,1);Zx(a,0);Yx(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function tR(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=v[b>>2];while(1){if((i|0)==128){gg(b,c);c=v[a+8>>2];d=c+d|0;i=x[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=($g(v[a>>2])&-2)){break c}Vc(a,c+(f<<10)|0);if(!aA(a,16,1)){break b}u[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if(($g(v[a>>2])|0)!=(d+B(f,i)|0)){break a}}Vc(a,c+B(f,x[e>>1])|0);h=aA(a,64,1)?h:k}Vc(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(B(c,x[e>>1])<<8)|0)==($g(v[a>>2])|0)){break d}}if(c>>>0>=255){$z(b,254,65534);$z(b,255,65535)}l=h}a=l&65535}else{j=x[ac(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function eH(a,b,c,d){a:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 6:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 8:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 9:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 16:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 17:jb[d|0](a,c);default:return;case 1:case 4:case 14:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function Gn(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;if(e){v[e>>2]=0}a:{h=v[a+484344>>2];if(!ke(h,v[a+484348>>2],b)){break a}i=Xb(h,b);k=v[i+48>>2];b=$c(v[i>>2],v[k+12>>2],c,d);f=w[b+5|0];b:{c:{d:{e:{j=w[b+3|0];switch(j-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(j-35>>>0>=2){break a}}v[g+12>>2]=1;h=0;if((j|0)!=17){break b}h=v[a+480180>>2]==4;break b}v[g+12>>2]=2;h=0}v[g+8>>2]=v[i+12>>2]+(c^-1);d=0;c=v[Eb(g+8|0,g+12|0)>>2];a=c;while(1){f:{if(a){b=B(zg(v[k+12>>2]),6)+b|0;if(w[b+3|0]==34){break f}c=d}f=(j-37&255)>>>0<254?f:c?f:f<<8;if(!e){break a}v[e>>2]=c;break a}i=f<<8;f=w[b+5|0]|(h?f>>>0<256?i+-8192|0:i:i);d=d+1|0;a=a-1|0;continue}}fb=g+16|0;return f}function Qca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb+-64|0;fb=c;a:{d=v[a+4>>2];b:{if(d>>>0<b>>>0){f=Xd(c+56|0);e=b-d|0;g=jt(a);c:{if(!(e>>>0>g>>>0|d>>>0>g-e>>>0)){$l(c+40|0,v[a>>2],d);cc(f,v[c+40>>2],v[c+44>>2]);v[a+4>>2]=v[a+4>>2]+e;break c}d=Sn(c+40|0);v[23220]=0;b=Q(696,a|0,b|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break a}v[23220]=0;R(697,d|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}v[d+4>>2]=v[a+4>>2]+e;Xk(c+24|0,v[a>>2]);$l(c+16|0,v[a>>2],v[a+4>>2]);Xk(c+8|0,v[d>>2]);BQ(c+32|0,v[c+24>>2],v[c+28>>2],v[c+16>>2],v[c+20>>2],v[c+8>>2],v[c+12>>2]);cc(f,v[c+32>>2],v[c+36>>2]);pt(a,d);Ie(d)}a=cc(c,v[f>>2],v[f+4>>2]);Vu(v[a>>2],v[a+4>>2],e,0);break b}v[a+4>>2]=b}fb=c- -64|0;return}a=P()|0;O()|0;Ie(d);S(a|0);L()}function bda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;e=v[b>>2];d=dg(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=fb-32|0;fb=i;d=c-d|0;f=v[Cb(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){f=fb-16|0;fb=f;e=yz(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){hc(e);fb=f+16|0}else{Rz(d);d=d+32|0;v[e+4>>2]=d;continue}break}break b}f=Cb(b);e=kt(i+8|0,Hp(b,dg(v[b>>2],e)+d|0),dg(v[b>>2],v[b+4>>2]),f);h=fb-16|0;fb=h;d=tP(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){Rz(f);f=v[d>>2]+32|0;v[d>>2]=f;continue}break}Ed(d);fb=h+16|0;vd(b,e);uP(e)}fb=i+32|0;break a}if(c>>>0<d>>>0){Jd(b,e+(c<<5)|0)}}if(Lb(v[a>>2],v[a+8>>2],c<<5)){c=v[b>>2];ec(g+8|0,c,dg(c,v[b+4>>2])<<5);md(g,a,v[g+8>>2],v[g+12>>2])}fb=g+16|0}function b5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-48|0;fb=f;v[f+40>>2]=d;a=Rf(a,f+40|0);d=mf(a+4|0);g=mf(a+24|0);h=mf(a+32|0);i=Ib(a+36|0);v[a+56>>2]=3;j=Ib(a+68|0);v[23220]=0;R(914,a|0,e|0);k=v[23220];v[23220]=0;a:{b:{c:{d:{if((k|0)!=1){ec(f+8|0,b,c);b=Xd(f);c=v[b+4>>2];b=v[b>>2];v[23220]=0;da(918,f+16|0,v[f+8>>2],v[f+12>>2],b|0,c|0);b=v[23220];v[23220]=0;if((b|0)==1){break d}v[23220]=0;U(915,a|0,f+16|0,e|0);b=v[23220];v[23220]=0;if((b|0)==1){break c}wb(f+16|0);v[23220]=0;Y(916,a|0);b=v[23220];v[23220]=0;if((b|0)!=1){break a}}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;wb(f+16|0)}De(j);Tf(i);es(h);$i(g);_i(d);pe(a);pe(f+40|0);S(e|0);L()}pe(f+40|0);fb=f+48|0;return a|0}function DK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=C(0);c=fb-80|0;fb=c;d=v[b>>2];e=v[b+4>>2];b=Xd(c+48|0);b=Xq(c+56|0,d,e,v[b>>2],v[b+4>>2]);v[23220]=0;d=T(189,b|0)|0;e=v[23220];v[23220]=0;a:{if((e|0)==1){break a}v[23220]=0;d=W(878,b|0,c+8|0,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break a}b:{if(!d){break b}if(Mb(c+8|0,17567,4)|v[c+12>>2]){break b}f=a,g=Ld(z[c+16>>2],C(0)),z[f+4220>>2]=g;f=a,g=Ld(z[c+20>>2],C(0)),z[f+4224>>2]=g;f=a,g=Ld(z[c+24>>2],C(0)),z[f+4228>>2]=g;d=v[c+28>>2];if(d>>>0<=5){v[a+4232>>2]=d}v[a+4236>>2]=v[c+32>>2];t[a+4240|0]=w[c+36|0]!=0;t[a+4241|0]=w[c+37|0]!=0;t[a+4242|0]=w[c+38|0]!=0;t[a+4243|0]=w[c+39|0]!=0;t[a+4244|0]=w[c+40|0]!=0;vs(a)}wb(b);fb=c+80|0;return}a=P()|0;O()|0;wb(b);S(a|0);L()}function $ca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;e=v[b>>2];d=bh(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=fb-32|0;fb=i;d=c-d|0;f=v[Cb(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>4>>>0){f=fb-16|0;fb=f;e=Lo(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){hc(e);fb=f+16|0}else{cu(d);d=d+16|0;v[e+4>>2]=d;continue}break}break b}f=Cb(b);e=Bv(i+8|0,Cv(b,bh(v[b>>2],e)+d|0),bh(v[b>>2],v[b+4>>2]),f);h=fb-16|0;fb=h;d=$D(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){cu(f);f=v[d>>2]+16|0;v[d>>2]=f;continue}break}Ed(d);fb=h+16|0;vd(b,e);bE(e)}fb=i+32|0;break a}if(c>>>0<d>>>0){Jd(b,e+(c<<4)|0)}}if(Lb(v[a>>2],v[a+8>>2],c<<4)){c=v[b>>2];ec(g+8|0,c,bh(c,v[b+4>>2])<<4);md(g,a,v[g+8>>2],v[g+12>>2])}fb=g+16|0}function zI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb-32|0;fb=c;e=v[a>>2];a=v[e>>2];rf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[e+4>>2];g=v[a+8>>2];e=v[a+4>>2];i=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(e>>>0<=y[c+4>>2]){if(Se(v[c+8>>2],v[c+12>>2])>>>0<g>>>0){break b}j=b+12|0;c:while(1){a=0;if((f|0)==(g|0)){break a}while(1)if((a|0)==(e|0)){f=f+1|0;continue c}else{d=Ih(i,e,a,f);h=zb(v[b>>2],a);d=v[d>>2]+(v[h>>2]>>1)|0;k=d;d=$r(j)+d&-4096;v[h>>2]=k-d;d=dd(d|2048,12);d=(d|0)<32767?d:32767;l=ln(c,a,f),m=(d|0)>-32768?d:-32768,u[l>>1]=m;a=a+1|0;continue}}}ca(7115,9016,34,8729);L()}ca(5828,9016,36,8729);L()}fb=c+32|0}function Ej(a,b){var c=0,d=0,e=0,f=0;c=fb+-64|0;fb=c;d=v[v[a>>2]-12>>2]+a|0;e=v[d+16>>2]&-3;Nm(d,e);a:{b:{if(Nd(w[fn(c+56|0,a,1)|0])){d=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23220]=0;f=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=f;f=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=f;U(95,c+40|0,d|0,c+8|0);b=v[23220];v[23220]=0;c:{if((b|0)!=1){b=ch(c+24|0,-1,-1);b=v[b+8>>2]==v[c+48>>2]&v[c+52>>2]==v[b+12>>2]?e|4:e;break c}b=V(0)|0;O()|0;_(b|0)|0;b=e|1;en(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23220]=0;Z(91);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)==1){break b}S(a|0);L()}$()}tj(v[v[a>>2]-12>>2]+a|0,b)}fb=c- -64|0;return a}V(0)|0;O()|0;Tb()}L()}function i5(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=fb-48|0;fb=b;c=Gb(b+32|0);v[23220]=0;Y(907,b+16|0);a=v[23220];v[23220]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=Ab(v[b+16>>2]),v[f+8>>2]=g;d=1;while(1){e=Ab(v[b+20>>2]);a=v[b+8>>2];if(!Nb(a,e)){a=Uf(Ec(c));De(b+16|0);ub(c);break b}if(!d){v[23220]=0;Q(908,c|0,14596)|0;a=v[23220];v[23220]=0;if((a|0)==1){break d}a=v[b+8>>2]}v[23220]=0;Q(772,c|0,a|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break d}Sp(b+8|0);d=0;continue}}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;De(b+16|0)}ub(c);_(a|0)|0;a=0;v[23220]=0;X(906,6946,0,0,0);c=v[23220];v[23220]=0;if((c|0)==1){break a}$()}fb=b+48|0;return a|0}b=P()|0;O()|0;v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)==1){V(0)|0;O()|0;Tb();L()}S(b|0);L()}function rG(a,b,c,d,e,f){var g=0;g=fb-80|0;fb=g;a:{if((f|0)>=16384){Ad(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Ad(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}Ad(g- -64|0,b,c,d,e,0,0,0,7471104);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}Ad(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)>-48920?f:-48920)+32538|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}Ad(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;fb=g+80|0}function z8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=fb-32|0;fb=f;c=zg(v[v[a+48>>2]+12>>2]);a:{if(!b){break a}c=B(b,c);b:{if(v[a+12>>2]!=(b|0)){break b}if(($j(v[a>>2],v[a+4>>2])|0)!=(c|0)){break b}b=fb-16|0;fb=b;d=Ab(v[a>>2]);a=Ab(v[a+4>>2]);sh(b+8|0);e=Bs(a,d);c=fb-16|0;fb=c;v[c+8>>2]=d;while(1){if((e|0)>0){a=v[c+8>>2];d=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;d=w[b+12|0]|w[b+13|0]<<8;t[a+4|0]=d;t[a+5|0]=d>>>8;e=e-1|0;gk(c+8|0);continue}break}fb=c+16|0;fb=b+16|0;break a}e=f+8|0;sh(e);c=TS(f+16|0,c,e);jL(a);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];e=Cb(c);g=Cb(a),h=v[e>>2],v[g>>2]=h;v[e>>2]=0;v[c>>2]=0;v[c+4>>2]=0;qh(c);v[a+12>>2]=b}fb=f+32|0}function Xba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;f=v[a+40>>2];g=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){e=v[b+8>>2];o=e>>>18|0;p=((((v[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){h=(e<<1)+p|0;i=u[h>>1];v[(e<<2)+b>>2]=i+((B(u[h+4>>1]-i|0,o)|0)/16384|0);e=e+1|0;continue}break}g=g+l|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+k|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Ob(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;fb=b+16|0}function Jw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=(p(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;A[b>>3]=d;g=d<-.7853981852531433;if(D(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,i-(c<<23)|0),q());c=kH(e+8|0,e,c,1,0);d=A[e>>3];if((g|0)<0){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}fb=e+16|0;return c}function D$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=v[b+44>>2];i=v[b+24>>2];if(h>>>0<i>>>0){v[b+44>>2]=i;h=i}l=-1;m=-1;n=f&24;a:{if(!n|(e|0)==1&(n|0)==24){break a}if(h){g=h-pc(b+32|0)|0;o=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;j=e;k=e>>31;break b}e=i-v[b+20>>2]|0;j=e;k=e>>31;break b;case 0:break b;case 2:break c;default:break a}}j=o;k=g}d=d+k|0;c=c+j|0;d=j>>>0>c>>>0?d+1|0:d;e=c;c=d;if((g|0)<=(d|0)&e>>>0>o>>>0|(d|0)>(g|0)|(d|0)<0){break a}d=f&8;d:{if(!(c|e)){break d}if(v[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!i){break a}}if(d){d=v[b+8>>2];an(b,d,d+e|0,h)}if(f&16){ww(b,v[b+20>>2],v[b+28>>2]);Gr(b,e)}l=e;m=c}ch(a,l,m)}function EE(a,b,c,d,e,f,g,h){var i=0,j=0,k=C(0),l=0;i=fb-80|0;fb=i;fy(v[a+24>>2]);t[v[a+24>>2]+1298420|0]=v[a+52>>2]!=0;v[i+76>>2]=f;v[i+72>>2]=e;v[i+68>>2]=d;v[i+64>>2]=c;e=i+16|0;c=i- -64|0;a:{d=0;while(1){b:{if((d|0)!=4){if(v[(d<<2)+c>>2]){break b}}else{d=4}break a}d=d+1|0;continue}}c=Qg(e,c,d,b);d=v[c>>2];k=z[a+48>>2];e=v[c+4>>2];f=v[c+8>>2];l=v[a+32>>2];c=LI(i+32|0);v[c+12>>2]=d;v[c+8>>2]=l;v[c+4>>2]=0;v[c>>2]=h;v[c+20>>2]=f;v[c+16>>2]=e;z[c+24>>2]=k;v[c>>2]=g;while(1){if(b){d=v[a+24>>2];v[i+8>>2]=b;v[i+12>>2]=0;v[i>>2]=134217727;v[i+4>>2]=0;d=NI(d,v[Gq(i+8|0,i)>>2],c);j=d+j|0;b=b-d|0;if(d){continue}}break}if(!(v[a+52>>2]!=1|j)){a=v[a+24>>2];v[a+480208>>2]=v[a+480208>>2]&-513}fb=i+80|0;return j}function iR(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!Lb(v[a>>2],v[a+8>>2],1024)){v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;a=64;while(1){if(a){d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}Yz(c+8|0,b);md(c+16|0,a,v[c+8>>2],v[c+12>>2])}fb=c+32|0}function YI(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;v[d+12>>2]=c;a:{b:{if(!b){a=a+120|0;nn(a);b=v[d+12>>2];a=Ib(a);c:{if(b){v[23220]=0;R(1040,a|0,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break a}TI(a,b)}break c}t[a+20|0]=0;break b}e=fb-16|0;fb=e;v[e+12>>2]=c;d:{if((b|0)==1){b=a+120|0;nn(b);g=hx(b,a,v[e+12>>2]),h=1,t[g+20|0]=h;break d}f=fb-16|0;fb=f;v[f+12>>2]=c;e:{if((b|0)==2){a=a+120|0;nn(a);b=v[f+12>>2];a=Ib(a);f:{if(b){v[23220]=0;R(1039,a|0,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break a}TI(a,b)}break f}Xd(a+12|0);t[a+20|0]=2;break e}b=fb-16|0;fb=b;v[b+12>>2]=c;c=a+120|0;nn(c);g=hx(c,a,v[b+12>>2]),h=3,t[g+20|0]=h;fb=b+16|0}fb=f+16|0}fb=e+16|0}fb=d+16|0;return}b=P()|0;O()|0;$b(a);S(b|0);L()}function Xm(a,b,c,d,e,f,g,h,i,j){var k=0,l=0,m=0,n=0;l=fb-16|0;fb=l;t[l+15|0]=a;a:{b:{c:{k=v[d>>2];if((k|0)!=(c|0)){break c}m=43;n=a&255;if((n|0)!=w[j+24|0]){m=45;if(w[j+25|0]!=(n|0)){break c}}v[d>>2]=c+1;t[c|0]=m;break b}if(!(!Bb(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=mi(j,j+26|0,l+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}if((c|0)==(k|0)|(k-c|0)>2|w[k-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=k+1;t[k|0]=w[f+82816|0];break a}v[d>>2]=k+1;t[k|0]=w[f+82816|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}fb=l+16|0;return a}function _H(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;a:{b:{c:{d:{e:{if((b|0)>=0){g=a;a=v[a+32>>2];if((zg(a)|0)>(b|0)){break e}}a=aa(8)|0;v[23220]=0;b=Q(52,f|0,10667)|0;c=v[23220];v[23220]=0;if((c|0)==1){break d}a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break b}c=P()|0;O()|0;ub(b);break c}d=(a+(b<<5)|0)+480280|0;c=c?134218752:0;v[d>>2]=c|v[d>>2]&-134218753;d=(a+B(b,872)|0)+1075080|0;v[d>>2]=c|v[d>>2]&-134218753;a=x[a+480188>>1];d=a>>>0>256?a:256;b=b+1|0;g=v[g+32>>2];while(1){if((a|0)==(d|0)){break a}e=g+B(a,872)|0;if((b|0)==x[e+1075778>>1]){e=e+1075080|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;continue}}c=P()|0;O()|0;ba(a|0)}S(c|0)}L()}fb=f+16|0}function Yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;f=v[a+40>>2];g=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){e=v[b+8>>2];o=e>>>10&4194048;p=(((v[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){h=e+p|0;i=t[h|0];v[(e<<2)+b>>2]=((B(t[h+2|0]-i|0,o)|0)/16384|0)+(i<<8);e=e+1|0;continue}break}g=g+l|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+k|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Ob(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;fb=b+16|0}function ji(a,b,c,d){var e=0,f=0,g=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=44464;b=a+24|0;v[b>>2]=0;v[b+4>>2]=0;v[b+16>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;c=Ib(a+44|0);d=Ib(c+12|0);e=Ib(c+24|0);f=Ib(c+36|0);v[23220]=0;R(870,c|0,0);g=v[23220];v[23220]=0;if((g|0)==1){a=P()|0;O()|0;lc(f);lc(e);yx(d);yx(c);S(a|0);L()}v[a+4196>>2]=1065353216;v[a+4200>>2]=0;u[a+4204>>1]=0;d=v[a+16>>2];v[d+946300>>2]=v[d+946300>>2]+1;v[23220]=0;d=T(871,a+92|0)|0;e=v[23220];v[23220]=0;a:{if((e|0)!=1){c=a+4200|0;v[b>>2]=d;b=w[a+4200|0];d=v[a+16>>2];e=v[a+20>>2];while(1){if((e|0)==((d+B(b,160)|0)+906300|0)|b>>>0>248){break a}b=b+1|0;t[c|0]=b;continue}}a=P()|0;O()|0;AK(c);S(a|0);L()}return a}function gh(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=0;f=WJ(a);h=a+4208|0;c=C(C(z[zb(h,4)>>2]*C(1.899999976158142))+C(.10000000149011612));g=z[a+4268>>2];d=ie(C(10),C(C(C(C(C(v[((b<<2)+a|0)+4292>>2])/g)*C(-60))/C(C(z[zb(h,3)>>2]*C(19.899999618530273))+C(.10000000149011612)))/C(20)));c=C(C(ie(d,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-gp(c>C(1)?C(3.1415927410125732):C(f*C(C(6.2831854820251465)/g)))));a:{if(c==C(0)){break a}if(!Il(c)){break a}g=C(c+c);f=C(C(-2)-g);c=C(C(f*f)+C(C(c*c)*C(-4)));if(c>C(0)){e=C(K(c))}c=C(C(e-f)/g);if(C(D(c))>C(1)){c=C(C(C(-f)-e)/g)}e=tf(c)}b=(b<<3)+a|0;z[b+4404>>2]=e;z[b+4400>>2]=d;c=z[a+4272>>2];c=C(c*c);e=C(C(1)-c);d=C(d*d);return C(C(C(e*C(d/C(C(1)-C(c*d))))*e)+c)}function Lba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=((((v[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;m=u[e+39878>>1];n=u[e+39876>>1];o=u[e+39874>>1];p=u[e+39872>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+l|0;v[(e<<2)+b>>2]=(((B(u[f>>1],o)+B(u[f-4>>1],p)|0)+B(u[f+4>>1],n)|0)+B(u[f+8>>1],m)|0)/16384;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g);Ob(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;fb=b+16|0}function Zda(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-192|0;fb=c;b=c+16|0;ei(b,a);v[23220]=0;R(75,c+32|0,b|0);a=v[23220];v[23220]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[23220]=0;a=Q(76,c+48|0,c+32|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break e}ub(c+32|0);ub(c+16|0);b=v[v[a>>2]-12>>2];v[23220]=0;d=ha(59)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}v[23220]=0;U(60,c+8|0,a+b|0,d|0);b=v[23220];v[23220]=0;if((b|0)==1){break c}Wb(c+8|0);v[23220]=0;b=Q(77,a|0,c+32|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}a=Ek(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);d=x[c+32>>1];df(b);fb=c+192|0;a=(a?0:d)&65535;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;ub(c+32|0)}ub(c+16|0);break b}b=P()|0;O()|0;df(a)}S(b|0);L()}return a|0}function hA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;d=w[a|0];if(d&1){t[b+12|0]=w[b+12|0]|1;d=w[a|0]}if(d&2){t[b+12|0]=w[b+12|0]|4;d=w[a|0]}if(d&4){t[b+12|0]=w[b+12|0]|2;d=w[a|0]}if(d&16){t[b+12|0]=w[b+12|0]|16;d=w[a|0]}if(d&32){t[b+12|0]=w[b+12|0]|8}t[e+15|0]=w[a+1|0];t[e+14|0]=25;Zg(b,w[Rb(e+15|0,e+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];g=v[b>>2];i=ne(g,v[b+4>>2]);b=0;while(1){if((b|0)!=(i|0)){h=zb(g,b);f=(b<<2)+a|0;d=w[f+6|0]|w[f+7|0]<<8;u[h>>1]=d;a:{if(!b){break a}j=d;d=x[zb(g,b-1|0)>>1];if(j>>>0>=d>>>0){break a}u[h>>1]=d+1}k=h,l=Ub((w[f+8|0]|w[f+9|0]<<8)<<16>>16>>c,0,64),t[k+2|0]=l;b=b+1|0;continue}break}fb=e+16|0}
function Rda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;kd(c,2);t[d+16|0]=w[b+13|0];t[d|0]=64;e=d+16|0;i=c,j=w[Rb(e,d)|0]<<2,u[i+30>>1]=j;v[c+24>>2]=(w[b+14|0]|w[b+15|0]<<8)<<1;ak(d,2,b+1|0);Ac(e,d);ue(c+43|0,e);ub(e);e=Uc(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}g=w[b+22|0]|w[b+23|0]<<8|(w[b+24|0]<<16|w[b+25|0]<<24);v[c>>2]=g;f=w[b+26|0]|w[b+27|0]<<8|(w[b+28|0]<<16|w[b+29|0]<<24);v[c+4>>2]=f;a=w[b+30|0]|w[b+31|0]<<8|(w[b+32|0]<<16|w[b+33|0]<<24);h=a-(a>>>0>f>>>0)|0;v[c+8>>2]=h;a=w[b|0];if(a&4){u[c+34>>1]=x[c+34>>1]|2;a=w[b|0]}if(a&8){u[c+34>>1]=x[c+34>>1]|4;a=w[b|0]}if(!(a&16)){break a}Eh(e,16);Qf(e,9);v[c+8>>2]=h>>>1;v[c+4>>2]=f>>>1;v[c>>2]=g>>>1}fb=d+32|0}function lG(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=nw(13840);if(w[b|0]?b:0){break a}b=nw(B(a,12)+78656|0);if(w[b|0]?b:0){break a}b=nw(14120);if(w[b|0]?b:0){break a}b=14729}b:{while(1){d=w[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14729;c:{d:{c=w[b|0];e:{f:{if(!(w[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!w[e+1|0]){break e}}if(!bj(e,14729)){break e}if(bj(e,13495)){break d}}if(!a){c=78728;if(w[e+1|0]==46){break c}}return 0}c=v[116607];if(c){while(1){if(!bj(e,c+8|0)){break c}c=v[c+32>>2];if(c){continue}break}}c=Fd(36);if(c){v[c+4>>2]=20;v[c>>2]=78624;b=c+8|0;nc(b,e,d);t[b+d|0]=0;v[c+32>>2]=v[116607];v[116607]=c}c=a|c?c:78728}return c}function Wea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=fb-528|0;fb=b;e=-1;a:{if(!Sf(a,1468)){break a}Yk(a,1464);c=b+524|0;BR(a,c);if(!ce(c,26889)){e=0;if(!ce(b+524|0,15476)){break a}}Yk(a,20);c=1;while(1){if((c&65535)>>>0<=31){if(xR(a,b)){c=c+1|0;d=dA(b)+d|0;continue}else{e=-1;break a}}break}e=0;if(d>>>0>40){break a}d=b+520|0;c=fb-16|0;fb=c;b:{if(!Sf(a,2)){t[c|0]=0;dC(d,c);break b}kl(c+8|0,d);cA(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0;if(w[b+520|0]>128){break a}d=gd(b+520|0);c=fb-16|0;fb=c;c:{if(!Sf(a,512)){hR(b);break c}ou(c+8|0,b);cA(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0;c=0;e=1;a=w[d|0];while(1){if((c|0)==512){break a}d=b+c|0;c=c+1|0;if(a>>>0>=w[d|0]){continue}break}e=0}fb=b+528|0;return e|0}function KW(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-192|0;fb=c;b=c+16|0;ei(b,a);v[23220]=0;R(75,c+32|0,b|0);a=v[23220];v[23220]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[23220]=0;a=Q(76,c+48|0,c+32|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break e}ub(c+32|0);ub(c+16|0);b=v[v[a>>2]-12>>2];v[23220]=0;d=ha(59)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}v[23220]=0;U(60,c+8|0,a+b|0,d|0);b=v[23220];v[23220]=0;if((b|0)==1){break c}Wb(c+8|0);v[23220]=0;b=Q(80,a|0,c+32|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}a=Ek(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);d=v[c+32>>2];df(b);fb=c+192|0;a=a?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;ub(c+32|0)}ub(c+16|0);break b}b=P()|0;O()|0;df(a)}S(b|0);L()}return a|0}function qea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb+-64|0;fb=c;i=c,j=Ze(a)>>>5|0,u[i+32>>1]=j;u[c+16>>1]=3999;d=x[Tc(c+32|0,c+16|0)>>1];u[b+480190>>1]=d;h=b+480190|0;g=1;while(1){f=g&65535;if(d>>>0>=f>>>0){d=Xj(b,f);e=c+32|0;zt(a,e);kd(d,0);rj(c,2,e);e=c+16|0;Ac(e,c);yc(((f<<5)+b|0)+946304|0,e);ub(e);v[d+24>>2]=8287;i=c,j=Jb(x[c+60>>1]),u[i+16>>1]=j;u[c>>1]=64;i=d,j=x[Tc(e,c)>>1]<<2,u[i+30>>1]=j;i=d,j=_b(v[c+52>>2])&-2,v[i>>2]=j;e=Jb(x[c+62>>1]);i=zb(d+68|0,0),j=e,v[i>>2]=j;e=Jb(x[c+56>>1]);f=Jb(x[c+58>>1]);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>y[d>>2]){break a}v[d+16>>2]=f;v[d+12>>2]=e<<1;u[d+34>>1]=x[d+34>>1]|8}g=g+1|0;d=x[h>>1];continue}break}fb=c- -64|0}function TU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;kd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=yq(a+4|0,a);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=f;c=yq(a+8|0,a);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+8>>2]=c;t[e+15|0]=127;t[e+14|0]=w[a+15|0];g=b,h=(((w[Rb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[g+30>>1]=h;d=w[a+12|0];if(d>>>0>=16){u[b+34>>1]=32;u[b+28>>1]=d&240}d=(w[a+13|0]|w[a+14|0]<<8)<<1;v[b+24>>2]=d;d=w[a+13|0]|w[a+14|0]<<8?d:16726;v[b+24>>2]=d;g=b,h=(B(Bu(0,w[a+12|0]<<28>>24),d)>>>0)/8363|0,v[g+24>>2]=h;if(c>>>0>f>>>0){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}fb=e+16|0}function L1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-32|0;fb=d;c=v[a>>2];a=v[c>>2];rf(d+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);c=v[c+4>>2];f=v[c+8>>2];a=v[c+4>>2];h=v[c>>2];c=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=c;c=v[d+20>>2];v[d>>2]=v[d+16>>2];v[d+4>>2]=c;a:{b:{if(a>>>0<=y[d+4>>2]){g=v[d+12>>2];if(Se(v[d+8>>2],g)>>>0<f>>>0){break b}i=b+12|0;j=v[d>>2];c:while(1){b=0;if((e|0)==(f|0)){break a}while(1)if((a|0)==(b|0)){e=e+1|0;continue c}else{c=dd((v[Ih(h,a,b,e)>>2]+dd(_r(i),21)|0)+2048|0,12);c=(c|0)<32767?c:32767;k=mn(j,g,b,e),l=(c|0)>-32768?c:-32768,u[k>>1]=l;b=b+1|0;continue}}}ca(7115,9016,34,8729);L()}ca(5828,9016,36,8729);L()}fb=d+32|0}function s1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-80|0;fb=e;v[e+76>>2]=d;v[e+72>>2]=c;v[23220]=0;c=v[b+12>>2];v[e+16>>2]=v[b+8>>2];v[e+20>>2]=c;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;c=T(1052,e+8|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){a:{b:{if(c){v[23220]=0;R(1053,e+48|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){d=e+56|0;iv(d,v[e+48>>2],v[e+52>>2]);b=ng(e- -64|0,d);c=ng(e+40|0,e+72|0);break b}break a}v[23220]=0;R(1054,e+48|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}d=e+56|0;iv(d,v[e+48>>2],v[e+52>>2]);b=ng(e+32|0,d);c=ng(e+24|0,e+72|0)}uD(a,v[b>>2],v[b+4>>2],v[c>>2],v[c+4>>2]);be(d);be(e+48|0);be(e+72|0);fb=e+80|0;return}}a=P()|0;O()|0;be(e+72|0);S(a|0);L()}function zy(a,b,c){var d=0,e=0,f=0,g=0;d=fb+-64|0;fb=d;e=v[a>>2];f=v[e-4>>2];g=v[e-8>>2];v[d+28>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+40>>2]=0;v[d+44>>2]=0;v[d+48>>2]=0;v[d+52>>2]=0;v[d+56>>2]=0;e=0;t[d+59|0]=0;t[d+60|0]=0;t[d+61|0]=0;t[d+62|0]=0;v[d+20>>2]=0;v[d+24>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;a=a+g|0;a:{if(Eg(f,c,0)){v[d+56>>2]=1;jb[v[v[f>>2]+20>>2]](f,d+8|0,a,a,1,0);e=v[d+32>>2]==1?a:0;break a}jb[v[v[f>>2]+24>>2]](f,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:e=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}e=v[d+24>>2]}fb=d- -64|0;return e}function s3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;e=Ib(a);a=v[b+24>>2];a=Zs(v[a+484344>>2],v[a+484348>>2]);v[23220]=0;R(168,e|0,a|0);a=v[23220];v[23220]=0;a:{if((a|0)!=1){a=0;b:{c:{d:{e:{while(1){d=v[b+24>>2];f=v[d+484344>>2];if(Zs(f,v[d+484348>>2])>>>0<=a>>>0){break b}v[23220]=0;R(988,c|0,Xb(f,a)|0);d=v[23220];v[23220]=0;if((d|0)!=1){d=v[b+24>>2];v[23220]=0;U(975,c+16|0,d|0,c|0);d=v[23220];v[23220]=0;if((d|0)==1){break e}v[23220]=0;R(170,e|0,c+16|0);d=v[23220];v[23220]=0;if((d|0)==1){break d}a=a+1|0;ub(c+16|0);ub(c);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;ub(c+16|0)}ub(c);break a}fb=c+32|0;return}a=P()|0;O()|0}De(e);S(a|0);L()}function Xg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb+-64|0;fb=f;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}d=v[a>>2];e=v[a+4>>2];if(ke(d,e,b)){break b}c:{d:{if(ek(d,e)>>>0<=b>>>0){d=Px(f+8|0,a);v[23220]=0;U(188,a|0,b+1|0,d|0);e=v[23220];v[23220]=0;if((e|0)==1){break d}Mk(d);d=v[a>>2]}v[23220]=0;R(198,Nf(d,b)|0,c|0);c=v[23220];v[23220]=0;e:{if((c|0)!=1){c=Nf(v[a>>2],b);v[c+16>>2]=0;v[c+20>>2]=0;c=v[a>>2];v[23220]=0;Y(199,Nf(c,b)|0);c=v[23220];v[23220]=0;if((c|0)!=1){break e}}b=V(91480)|0;a=O()|0;break c}a=Nf(v[a>>2],b);g=Nb(v[a>>2],v[a+4>>2]);break b}b=V(91480)|0;a=O()|0;Mk(d)}if((ea(91480)|0)!=(a|0)){break a}_(b|0)|0;$()}fb=f- -64|0;return g|0}S(b|0);L()}function Mba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=(((v[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;m=u[e+39878>>1];n=u[e+39876>>1];o=u[e+39874>>1];p=u[e+39872>>1];e=0;while(1){if((e|0)!=2){f=e+l|0;v[(e<<2)+b>>2]=(((B(t[f|0],o)+B(t[f-2|0],p)|0)+B(t[f+2|0],n)|0)+B(t[f+4|0],m)<<8)/16384;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g);Ob(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;fb=b+16|0}function b0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;f=b+c|0;i=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!Kw(db(v[a+60>>2],b|0,i|0,d+12|0)|0)){g=v[d+12>>2];if((g|0)==(f|0)){break d}if((g|0)>=0){break c}break b}if((f|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}h=v[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;v[e>>2]=h+v[e>>2];b=(j?12:4)+b|0;v[b>>2]=v[b>>2]-h;f=f-g|0;i=i-j|0;b=e;continue}break}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((i|0)==2){break a}a=c-v[b+4>>2]|0}fb=d+32|0;return a|0}function RE(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;v[23220]=0;Y(919,a|0);e=v[23220];v[23220]=0;a:{b:{c:{d:{e:{f:{if((e|0)==1){break f}v[23220]=0;Y(920,b|0);e=v[23220];v[23220]=0;if((e|0)==1){break f}g=v[a+24>>2];v[23220]=0;e=Q(52,f|0,b|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break e}v[23220]=0;U(d|0,f+16|0,g|0,e|0);b=v[23220];v[23220]=0;if((b|0)==1){break d}a=f+16|0;b=Uf(Ec(a));ub(a);ub(e);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;ub(e)}_(b|0)|0;b=0;v[23220]=0;X(906,c|0,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$()}fb=f+32|0;return b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Bca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;kd(b,4);u[b+30>>1]=w[a+12|0]<<2;qg(b+30|0,256);e=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=e;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=f;c=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);v[b+4>>2]=c;d=(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+c|0;v[b+8>>2]=d;e=w[a+14|0];if(e&16){d=d>>>1|0;v[b+8>>2]=d;c=c>>>1|0;v[b+4>>2]=c;f=f>>>1|0;v[b>>2]=f;e=w[a+14|0]}if(e&32){d=d>>>1|0;v[b+8>>2]=d;c=c>>>1|0;v[b+4>>2]=c;v[b>>2]=f>>>1;e=w[a+14|0]}if(!(!(e&3)|c>>>0>=d>>>0)){u[b+34>>1]=34;u[b+34>>1]=w[a+14|0]&2?38:34}a=Qb(g,21598);ue(b+43|0,a);ub(a);fb=g+16|0}function P4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;v[23220]=0;Y(919,a|0);d=v[23220];v[23220]=0;a:{b:{c:{if((d|0)==1){break c}v[23220]=0;Y(920,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break c}v[23220]=0;Y(920,c|0);f=v[23220];v[23220]=0;d=1;if((f|0)==1){break c}f=v[a+24>>2];b=oc(e+8|0,b);c=oc(e,c);g=v[c+4>>2];c=v[c>>2];h=v[b+4>>2];b=v[b>>2];v[23220]=0;ka(941,f|0,b|0,h|0,c|0,g|0,1);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,5468,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();d=0}fb=e+16|0;return d|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function LU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-208|0;fb=d;if(!ru(c,a)){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0}JB(c,d+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}c=fb-16|0;fb=c;v[c+12>>2]=64;v[c+8>>2]=255;e=w[Eb(c+12|0,c+8|0)|0];fb=c+16|0;t[d+12|0]=e;Zg(b,w[Rb(a+4|0,d+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;e=v[b>>2];f=ne(e,v[b+4>>2]);a=0;while(1){if((a|0)==(f|0)){break a}b:{if(!a){b=w[d+18|0];c=zb(e,0);break b}g=x[zb(e,a-1|0)>>1];v[d+12>>2]=1;b=(d+16|0)+B(a,3)|0;v[d+8>>2]=(t[b+1|0]&1)<<8|w[b|0];h=Ke(d+12|0,d+8|0);c=zb(e,a);u[c>>1]=x[h>>1]+g;b=w[b+2|0]}t[c+2|0]=b;a=a+1|0;continue}}fb=d+208|0}function _K(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=C(0),k=0,l=C(0);g=fb-16|0;fb=g;e=u[d>>1];f=u[d+2>>1];if(!(!x[b>>1]|(e|0)>(f|0)|(!(z[c>>2]>C(0))|(f-e|0)>32766))){u[a>>1]=3;f=a+4|0;Bc(f);u[a+28>>1]=65472;v[g+12>>2]=1065353216;bL(f,g+12|0);v[a+32>>2]=0;u[a+30>>1]=0;Bc(a+16|0);h=u[d>>1];u[a+28>>1]=h;e=fb-16|0;fb=e;u[e+14>>1]=x[b>>1];u[e+12>>1]=32767;b=u[Tc(e+14|0,e+12|0)>>1];fb=e+16|0;u[a+30>>1]=b;i=C(D(z[c>>2]));z[a+32>>2]=i;i=ie(i,C(C(1)/C(b|0)));Oj(f,(u[d+2>>1]-h|0)+1|0);b=v[a+4>>2];c=u[a+28>>1];e=u[d+2>>1];d=u[d>>1];while(1){if((d|0)>(e|0)){kp(a)}else{j=ie(i,C(d|0));k=zb(b,d-c|0),l=j,z[k>>2]=l;d=d+1|0;continue}break}h=1}fb=g+16|0;return h|0}function nW(){var a=0,b=0,c=0,d=0;a=RC(v[v[116474]-12>>2]+465896|0,10);c=fb-16|0;fb=c;v[23220]=0;b=Q(12,c+8|0,465896)|0;d=v[23220];v[23220]=0;a:{b:{c:{d:{if((d|0)!=1){e:{if(!w[b|0]){break e}d=qm(c,465896);v[23220]=0;a=Q(20,d|0,a|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){if(!Iu(a)){break e}a=v[v[116474]-12>>2];v[23220]=0;R(15,a+465896|0,1);a=v[23220];v[23220]=0;if((a|0)!=1){break e}}a=V(0)|0;O()|0;fk(b);break d}fk(b);break c}a=V(0)|0;O()|0}_(a|0)|0;b=v[v[116474]-12>>2];v[23220]=0;Y(16,b+465896|0);b=v[23220];v[23220]=0;if((b|0)==1){break b}$()}fb=c+16|0;break a}c=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(c|0);L()}V(0)|0;O()|0;Tb();L()}Yu(465896)}function Jn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){t[b+809|0]=c;break a}c=w[b+809|0]}e=v[a+480180>>2];d=e&202376205?(c&240?-16:15)&c:c;c=v[b+688>>2];b:{if(e&69206029){break b}g=d&240;f=d&15;if((f|0)==15){if(g){In(a,b,(d&240)>>>4|0,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c-60|0;break b}if((g|0)!=240){break b}if(f){Hn(a,b,f,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c+60|0}c:{if(!(!(t[b+851|0]&1)|w[a+480208|0]&2)&(v[a+1074416>>2]!=1|(e|0)!=524288)){break c}a=d&255;d=d&15;d:{if(d){if(a&240?e&16777248:0){break c}c=c-(d<<2)|0;break d}c=(a>>>2&60)+c|0}if((e|0)!=1){break c}v[b+88>>2]=v[b+88>>2]|2097152}h=b,i=Ub(c,0,256),v[h+688>>2]=i}function hba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){b=(v[f+12>>2]<<1)+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(u[b+4>>1],u[e+10>>1])+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/2|0)+((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(b,h);v[c+4>>2]=v[c+4>>2]+B(b,g);Ob(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;fb=f+16|0}function ida(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Zj(b),v[i>>2]=j;d=fb-16|0;fb=d;g=a;c=Od(a);a:{if(c){f=fc(g);while(1){a=c;c=a+13|0;if(mt(b,c)){f=a;c=v[a>>2];if(c){continue}break a}if(!mt(c,b)){break a}f=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=fc(g);f=a}v[d+12>>2]=a;b=v[f>>2];if(!b){c=fb-16|0;fb=c;a=fc(g);h=oh(d,tc(20),ph(c+8|0,a));b=v[h>>2];a=v[e>>2];a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[b+17|0]=0;t[b+13|0]=a;t[b+14|0]=a>>>8;t[b+15|0]=a>>>16;t[b+16|0]=a>>>24;i=fc(h),j=1,t[i+4|0]=j;fb=c+16|0;Tg(g,v[d+12>>2],f,v[d>>2]);b=Ud(d);_k(d);h=1}Sg(e+8|0,v[dc(d,b)>>2],h);fb=d+16|0;fb=e+16|0;return v[e+8>>2]+17|0}function Yu(a){var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[23220]=0;c=Q(12,d+8|0,a|0)|0;b=v[23220];v[23220]=0;c:{if((b|0)!=1){d:{if(!w[c|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23220]=0;b=T(21,b|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[23220]=0;R(15,a+b|0,1);b=v[23220];v[23220]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;fk(c);break c}fk(c);break b}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[23220]=0;Y(16,a+c|0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$()}fb=d+16|0;return}a=P()|0;O()|0;v[23220]=0;Z(17);c=v[23220];v[23220]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function xga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;v[d+28>>2]=0;_j(a,d+28|0);a:{b:{i=v[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Gb(d+16|0);v[23220]=0;u[d+14>>1]=0;e=W(438,a|0,g|0,255)|0;h=v[23220];v[23220]=0;if((h|0)==1){break b}if(!e){break d}v[23220]=0;R(427,a|0,d+14|0);e=v[23220];v[23220]=0;if((e|0)==1){break b}v[23220]=0;U(11,d|0,c|0,g|0);e=v[23220];v[23220]=0;if((e|0)!=1){v[23220]=0;e=Q(439,b|0,d+14|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break e}Db(e,d);vb(d);ub(g);f=f+1|0;continue}break}f=P()|0;O()|0;break a}f=P()|0;O()|0;vb(d);break a}ub(g)}fb=d+32|0;return}f=P()|0;O()|0}ub(g);S(f|0);L()}function lN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-112|0;fb=f;v[f+108>>2]=0;d=Gn(a,e&65535,d,c,f+108|0);c=w[b+790|0];if(!v[f+108>>2]){e=(c|0)==15;h=e&!w[b+792|0];d=d<<8;a:{if(d){v[b+664>>2]=d;break a}d=0;if(e){break a}d=v[b+664>>2]}h=h?0:w[b+836|0]<<16}if((c|0)==15){c=w[b+792|0];b:{if(!c){c=v[b+76>>2];v[f>>2]=1;e=v[Sc(f,f+108|0)>>2]<<3;g=Bia(c,0,d,0);d=(256<<e>>>1|0)+g|0;c=ib;c=d>>>0<g>>>0?c+1|0:c;g=d;e=e+8|0;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}d=Pc(c,e);break b}VP(f);if(c>>>0>9){break b}c=v[b+104>>2];if(!c){break b}d=v[zb(c+68|0,w[b+792|0]-1|0)>>2]+d|0}v[b+664>>2]=d}Kn(a,b,d+h|0);fb=f+112|0}function az(a,b,c){var d=0,e=0,f=0,g=0;d=Gb(a);a=Bb(b);v[23220]=0;R(43,d|0,a|0);a=v[23220];v[23220]=0;if((a|0)!=1){a:{while(1){if(Bb(b)>>>0>e>>>0){f=v[ej(b,e)>>2];g=f&-32;a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((g|0)==128|v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}else{v[23220]=0;R(44,d|0,a<<24>>24);a=v[23220];v[23220]=0;if((a|0)!=1){break b}break a}}break}d:{while(1){if((a|0)==32){break d}if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}break}v[23220]=0;R(44,d|0,a<<24>>24);a=v[23220];v[23220]=0;if((a|0)!=1){break b}break a}v[23220]=0;R(44,d|0,63);a=v[23220];v[23220]=0;if((a|0)!=1){break b}break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;ub(d);S(a|0);L()}function zha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-32|0;fb=e;v[e+24>>2]=b;j=e,k=Td(a),v[j+8>>2]=k;f=bk(e+24|0,e+8|0);a:{b:{h=oi(c,d);if(!h){break b}if(!Cs(a,c)){b=Bb(a);g=Qc(a);c:{if(g-b>>>0>=h>>>0){g=pc(a);if((b|0)==(f|0)){break c}i=f+g|0;pj(i+h|0,i,b-f|0);break c}Ll(a,g,(b+h|0)-g|0,b,f,0,h);g=v[a>>2]}b=b+h|0;hh(a,b);t[e+8|0]=0;bd(b+g|0,e+8|0);b=f+g|0;while(1){if((c|0)==(d|0)){break b}bd(b,c);c=c+1|0;b=b+1|0;continue}}d=Xf(e+8|0,c,d);c=Ec(d);f=Bb(d);v[23220]=0;c=fa(349,a|0,b|0,c|0,c+f|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){ub(d);break a}a=P()|0;O()|0;ub(d);S(a|0);L()}j=e,k=Td(a),v[j+8>>2]=k;c=Ei(e+8|0,f)}fb=e+32|0;return c|0}function wga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;u[d+30>>1]=0;If(a,d+30|0);a:{b:{i=x[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Gb(d+16|0);v[23220]=0;u[d+14>>1]=0;e=Q(440,a|0,g|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break b}if(!e){break d}v[23220]=0;R(427,a|0,d+14|0);e=v[23220];v[23220]=0;if((e|0)==1){break b}v[23220]=0;U(11,d|0,c|0,g|0);e=v[23220];v[23220]=0;if((e|0)!=1){v[23220]=0;e=Q(439,b|0,d+14|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break e}Db(e,d);vb(d);ub(g);f=f+1|0;continue}break}f=P()|0;O()|0;break a}f=P()|0;O()|0;vb(d);break a}ub(g)}fb=d+32|0;return}f=P()|0;O()|0}ub(g);S(f|0);L()}function TK(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{e=fb-48|0;fb=e;d=Gb(e+32|0);v[23220]=0;R(861,b|0,e+24|0);f=v[23220];v[23220]=0;if((f|0)!=1){b:{g=v[e+28>>2];f=v[e+24>>2];Lf(d);v[23220]=0;f=!g&f>>>0<255?f:255;R(57,d|0,f|0);g=v[23220];v[23220]=0;if((g|0)==1){break b}c:{while(1){if((f|0)==(h|0)){b=nU(Ec(d),Bb(d));if((b|0)==-1){break c}v[23220]=0;R(57,d|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break c}break b}g=Fc(d,h);v[23220]=0;Q(862,b|0,g|0)|0;g=v[23220];v[23220]=0;if((g|0)!=1){h=h+1|0;continue}break}break b}v[23220]=0;U(11,e+8|0,a|0,d|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}a=e+8|0;Db(c,a);vb(a);ub(d);fb=e+48|0;break a}}a=P()|0;O()|0;ub(d);S(a|0);L()}}function jy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-16|0;fb=e;b=v[a>>2];if(!rc(b,v[a+4>>2])){b=Ab(b);v[e+8>>2]=b;c=Ab(v[a+4>>2]);while(1){if(Nb(b,c)){xo(b,4194304,67108864);g=v[b>>2];f=g+f|0;b=d;b=f>>>0<g>>>0?b+1|0:b;d=b;b=v[ye(e+8|0)>>2];continue}else{c=v[a>>2];b=sc(c,v[a+4>>2]);l=e,m=Ab(c),v[l>>2]=m;d=Eia(f,d,b,0);h=d;g=((ib&1)<<31|d>>>1)&2147483647;f=b<<24;d=0;i=Ab(v[a+4>>2]);while(1){b=v[e>>2];if(Nb(b,i)){j=b;c=v[b>>2];b=c>>>8|0;c=g+(c<<24)|0;b=b+k|0;b=Pc(Eia(c,c>>>0<g>>>0?b+1|0:b,h,k),ib);v[j>>2]=b;c=f;f=c-b|0;d=d-(b>>>0>c>>>0)|0;ye(e);continue}else{d=v[a>>2];if(!sc(d,v[a+4>>2])){Lu();L()}v[d>>2]=f+v[d>>2]}break}}break}}fb=e+16|0}function C1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;c=v[a>>2];a=v[c>>2];rf(d+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);c=v[c+4>>2];f=v[c+8>>2];a=v[c+4>>2];g=v[c>>2];c=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=c;c=v[d+20>>2];v[d>>2]=v[d+16>>2];v[d+4>>2]=c;a:{b:{if(a>>>0<=y[d+4>>2]){if(Se(v[d+8>>2],v[d+12>>2])>>>0<f>>>0){break b}h=b+12|0;c:while(1){b=0;if((e|0)==(f|0)){break a}while(1)if((a|0)==(b|0)){e=e+1|0;continue c}else{c=dd((v[Ih(g,a,b,e)>>2]+dd(_r(h),21)|0)+2048|0,12);c=(c|0)<32767?c:32767;i=ln(d,b,e),j=(c|0)>-32768?c:-32768,u[i>>1]=j;b=b+1|0;continue}}}ca(7115,9016,34,8729);L()}ca(5828,9016,36,8729);L()}fb=d+32|0}function iba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){b=v[f+12>>2]+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(t[b+2|0],u[e+10>>1])+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/2|0)+((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(b,h);v[c+4>>2]=v[c+4>>2]+B(b,g);Ob(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;fb=f+16|0}function M1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=0;c=fb-32|0;fb=c;d=v[a>>2];a=v[d>>2];rf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];f=v[a+8>>2];d=v[a+4>>2];h=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){g=v[c+12>>2];if(Se(v[c+8>>2],g)>>>0<f>>>0){break b}i=v[c>>2];c:while(1){a=0;if((b|0)==(f|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{e=dd(v[Ih(h,d,a,b)>>2]+2048|0,12);e=(e|0)<32767?e:32767;j=mn(i,g,a,b),k=(e|0)>-32768?e:-32768,u[j>>1]=k;a=a+1|0;continue}}}ca(7115,9016,34,8729);L()}ca(5828,9016,36,8729);L()}fb=c+32|0}function aI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{c:{d:{if((b|0)>=0){a=v[a+32>>2];if((zg(a)|0)>(b|0)){break d}}a=aa(8)|0;v[23220]=0;d=Q(52,d|0,10667)|0;b=v[23220];v[23220]=0;if((b|0)==1){break c}a=qc(a,d);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}b=P()|0;O()|0;ub(d);break b}if(c<0|c>1){a=aa(8)|0;v[23220]=0;d=Q(52,d|0,11726)|0;b=v[23220];v[23220]=0;if((b|0)!=1){a=qc(a,d);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}b=P()|0;O()|0;ub(d);break b}b=P()|0;O()|0;ba(a|0);break b}e=(a+B(b,872)|0)+1075740|0,f=Xl(c*64),v[e>>2]=f;fb=d+16|0;return}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function ex(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);b=0;c=fb-32|0;fb=c;d=v[a>>2];a=v[d>>2];rf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];g=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){f=v[c+12>>2];if(Se(v[c+8>>2],f)>>>0<e>>>0){break b}h=v[c>>2];c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{i=Wl(de($f(A[Jg(g,d,a,b)>>3])*134217728));j=dx(h,f,a,b),k=C(+(i|0)*7.450580596923828e-9),z[j>>2]=k;a=a+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}fb=c+32|0}function uaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;i=fb-16|0;fb=i;c=bf(a,c);Yd(i,v[a+28>>2]);a:{if(!c){if(cd(a,5)){break a}}g=v[a+28>>2];d=fb-16|0;fb=d;v[d+12>>2]=0;cH(g,d+12|0,1);e=v[d+12>>2];f=e>>>2&3;t[d+11|0]=f;if(f){t[d+4|0]=3;f=w[Rb(d+4|0,d+11|0)|0];t[d+4|0]=0;t[d|0]=0;t[d+10|0]=0;b:{if(!f){break b}ci(g,d+4|0);if((f|0)==1){break b}ci(g,d);if(f>>>0<3){break b}ci(g,d+10|0);h=w[d+10|0]<<24}e=e&255|w[d+4|0]<<8|w[d|0]<<16|h;v[d+12>>2]=e}f=e>>>4|0;v[d+4>>2]=f;v[d>>2]=1e6;Bx(b,v[Eb(d+4|0,d)>>2]);e=0;while(1){h=Bb(b);if(h>>>0<=e>>>0){if((f|0)!=(h|0)){Bl(g,f-h|0)}fb=d+16|0}else{Bk(g,Fc(b,e),1);e=e+1|0;continue}break}d=c}We(a,d);fb=i+16|0}function nv(a,b,c,d){var e=0,f=0,g=0;e=fb-48|0;fb=e;v[e+44>>2]=d;a:{f=v[b>>2];b:{if(!(jb[v[v[f>>2]+36>>2]](f,c,d)|0)){xh(a);break b}pl(e+24|0,v[b>>2],v[b+4>>2]);b=v[b>>2];d=v[v[b>>2]+24>>2];v[23220]=0;b=T(d|0,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}v[e+20>>2]=b-c;d=v[e+24>>2];f=v[e+28>>2];g=v[Eb(e+44|0,e+20|0)>>2];b=fb-16|0;fb=b;v[b+12>>2]=f;v[b+8>>2]=d;d=pl(b,d,f);f=v[d+4>>2];d=v[d>>2];v[23220]=0;da(159,e+32|0,d|0,f|0,c|0,g|0);c=v[23220];v[23220]=0;c:{if((c|0)!=1){be(b+8|0);fb=b+16|0;break c}a=P()|0;O()|0;be(b+8|0);S(a|0);L()}b=Xd(e+8|0);uD(a,v[e+32>>2],v[e+36>>2],v[b>>2],v[b+4>>2])}fb=e+48|0;return}a=P()|0;O()|0;be(e+24|0);S(a|0);L()}function Jba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){e=(v[b+12>>2]<<1)+i|0;h=v[b+8>>2]>>>21&2040;e=(((B(u[e>>1],u[h+39874>>1])+B(u[e-2>>1],u[h+39872>>1])|0)+B(u[e+2>>1],u[h+39876>>1])|0)+B(u[e+4>>1],u[h+39878>>1])|0)/16384|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Ob(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;fb=b+16|0}function Zga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=b;c=fb-48|0;fb=c;d=a;a:{if(Nt(v[d>>2],v[d+8>>2])){v[g>>2]=0;break a}vS(c+16|0,c+32|0);jc(c+24|0,v[d>>2],v[d+8>>2],v[c+16>>2],v[c+20>>2]);h=v[c+28>>2];i=w[c+32|0];f=i&127;v[g>>2]=f;a=f;b=0;while(1){if(a){b=b+1|0;a=a>>>1|0;continue}break}a=b;e=1;while(1){b=(B(h,7)+a|0)+B(e,-7)|0;b:{while(1){if(i<<24>>24>=0|e>>>0>=h>>>0){break b}i=w[(c+32|0)+e|0];f=i&127|f<<7;v[g>>2]=f;a=a+7|0;e=e+1|0;if((h|0)!=(e|0)){continue}break}Yb(d,h);vS(c+8|0,c+32|0);jc(c+24|0,v[d>>2],v[d+8>>2],v[c+8>>2],v[c+12>>2]);h=v[c+28>>2];f=v[g>>2];e=0;a=b;continue}break}Yb(d,e);if(a>>>0<33){break a}v[g>>2]=-1}fb=c+48|0}function Vm(a,b,c,d,e,f,g,h,i,j){var k=0,l=0;a:{b:{k=v[d>>2];if((k|0)!=(c|0)){break b}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break b}}v[d>>2]=c+1;t[c|0]=l;break a}c:{if(!(!Bb(g)|(a|0)!=(f|0))){g=0;a=v[i>>2];if((a-h|0)>159){break c}b=v[e>>2];v[i>>2]=a+4;v[a>>2]=b;break a}g=-1;f=ew(j,j+104|0,a)-j|0;if((f|0)>92){break c}a=f>>2;d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<88){break d}if((c|0)==(k|0)|(k-c|0)>2|w[k-1|0]!=48){break c}v[e>>2]=0;v[d>>2]=k+1;t[k|0]=w[a+82816|0];return 0}v[d>>2]=k+1;t[k|0]=w[a+82816|0];v[e>>2]=v[e>>2]+1;g=0}return g}v[e>>2]=0;return 0}function dz(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;i=Tk(a,b);a:{if((i|0)==255){break a}if(Tj(v[a>>2])){break a}b:{if(c>>>0>6208431){f=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}c=Bia(1<<20-f,0,c,0)+24858e3|0;h=ib;c=Pc(Eia(c,c>>>0<24858e3?h+1|0:h,49716e3,0),ib)}if(e){u[g+14>>1]=(b&3)+c;u[g+12>>1]=1023;c=x[Tc(g+14|0,g+12|0)>>1]}h=ct(i);e=Hb(a+8|0,i);t[e|0]=(f<<10|c)>>>8|(d?0:32);Ng(v[a>>2],v[a+4>>2],b,h|160,c&255);Ng(v[a>>2],v[a+4>>2],b,h|176,w[e|0]);t[a+534|0]=1}fb=g+16|0}function Pl(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;f=a+1074312|0;xb(e+8|0,f,84);a:{if(yb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){xb(e+8|0,f,10);if(!yb(v[v[e+8>>2]>>2],v[e+12>>2])){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+784>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;xb(e+8|0,f,10);if(!yb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}t[b+831|0]=0;u[b+778>>1]=0}fb=e+16|0}function I3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-32|0;fb=e;f=Ib(a);a=x[v[b+24>>2]+480192>>1];v[23220]=0;R(168,f|0,a|0);a=v[23220];v[23220]=0;a:{if((a|0)!=1){a=1;b:{c:{d:{e:{while(1){c=a&65535;d=v[b+24>>2];if(c>>>0>x[d+480192>>1]){break b}d=PL(d,c);v[23220]=0;d=Q(52,e|0,d|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){c=v[b+24>>2];v[23220]=0;U(975,e+16|0,c|0,d|0);c=v[23220];v[23220]=0;if((c|0)==1){break e}v[23220]=0;R(170,f|0,e+16|0);c=v[23220];v[23220]=0;if((c|0)==1){break d}ub(e+16|0);ub(d);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;ub(e+16|0)}ub(d);break a}fb=e+32|0;return}a=P()|0;O()|0}De(f);S(a|0);L()}function E$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;a:{b:{if(!rc(b,-1)){i=v[a+8>>2];j=v[a+12>>2];d=v[a+24>>2];if((d|0)==v[a+28>>2]){e=-1;if(!(w[a+48|0]&16)){break a}h=v[a+20>>2];k=v[a+44>>2];v[23220]=0;c=a+32|0;R(44,c|0,0);f=v[23220];v[23220]=0;if((f|0)==1){break b}f=Qc(c);v[23220]=0;R(57,c|0,f|0);f=v[23220];v[23220]=0;if((f|0)==1){break b}e=pc(c);ww(a,e,Bb(c)+e|0);Gr(a,d-h|0);v[a+44>>2]=v[a+20>>2]+(k-h|0);d=v[a+24>>2]}v[g+12>>2]=d+1;d=v[Sc(g+12|0,a+44|0)>>2];v[a+44>>2]=d;if(w[a+48|0]&8){c=pc(a+32|0);an(a,c,c+(j-i|0)|0,d)}e=PG(a,rn(b));break a}e=vw(b);break a}a=V(0)|0;O()|0;_(a|0)|0;$()}fb=g+16|0;return e|0}function Y$(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;if(rH(1,e+16|0)){Nr(v[115696],12685);L()}c=Mr(e+8|0,v[e+16>>2]);g=Mr(e,v[e+20>>2]);d=fb-32|0;fb=d;b=fb-16|0;fb=b;a=fb-16|0;fb=a;h=a,i=Bia(v[c>>2],v[c+4>>2],1e9,0),v[h>>2]=i;v[a+4>>2]=ib;c=ht(a+8|0,a);f=v[c+4>>2];c=v[c>>2];fb=a+16|0;v[b+8>>2]=c;v[b+12>>2]=f;a=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=a;fb=b+16|0;f=v[d+8>>2];c=v[d+12>>2];a=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=a;a=d;c=v[a+4>>2]+c|0;b=v[a>>2];f=f+b|0;v[a+16>>2]=f;v[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=ht(a+24|0,a+16|0);b=v[a+4>>2];a=v[a>>2];fb=d+32|0;a=kn(e+24|0,a,b);b=v[a+4>>2];a=v[a>>2];fb=e+32|0;ib=b;return a|0}function R9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-80|0;fb=d;e=Kf(d+48|0);v[23220]=0;g=Q(769,b|0,e|0)|0;f=v[23220];v[23220]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23220]=0;T(770,a|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break b}}break a}g=v[e+4>>2];v[23220]=0;U(177,d|0,b|0,g|0);f=v[23220];v[23220]=0;if((f|0)==1){break a}f=gc(d+24|0,d);Yc(e+8|0,f);wb(f);wb(d);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}v[23220]=0;Q(175,b|0,2-c|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break d}break a}bl(a,e)}Id(e);fb=d+80|0;return}a=P()|0;O()|0;Id(e);S(a|0);L()}function k3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;f=Ib(a);a=x[v[b+24>>2]+480190>>1];v[23220]=0;R(168,f|0,a|0);a=v[23220];v[23220]=0;a:{if((a|0)!=1){a=1;b:{c:{d:{e:{while(1){c=a&65535;e=v[b+24>>2];if(c>>>0>x[e+480190>>1]){break b}v[23220]=0;e=Q(52,d|0,QL(e,c)|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){c=v[b+24>>2];v[23220]=0;U(975,d+16|0,c|0,e|0);c=v[23220];v[23220]=0;if((c|0)==1){break e}v[23220]=0;R(170,f|0,d+16|0);c=v[23220];v[23220]=0;if((c|0)==1){break d}ub(d+16|0);ub(e);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;ub(d+16|0)}ub(e);break a}fb=d+32|0;return}a=P()|0;O()|0}De(f);S(a|0);L()}function Vl(a,b,c){var d=0,e=0,f=0;d=Gb(a);a=Bb(b);v[23220]=0;R(43,d|0,a|0);a=v[23220];v[23220]=0;if((a|0)!=1){a:{while(1){if(Bb(b)>>>0>e>>>0){f=v[ej(b,e)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if(v[(a<<2)+c>>2]==(f|0)){v[23220]=0;R(44,d|0,a<<24>>24);a=v[23220];v[23220]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}break}v[23220]=0;R(44,d|0,a<<24>>24);a=v[23220];v[23220]=0;if((a|0)!=1){break b}break a}v[23220]=0;R(44,d|0,63);a=v[23220];v[23220]=0;if((a|0)!=1){break b}break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;ub(d);S(a|0);L()}function V0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-32|0;fb=e;h=Gb(a);f=Gb(e+16|0);a=1;a:{b:{c:{while(1){d=a&65535;c=v[b+24>>2];if(d>>>0>x[c+480192>>1]){if(!(i&1)){break c}v[23220]=0;R(237,h|0,f|0);a=v[23220];v[23220]=0;if((a|0)!=1){break c}a=P()|0;O()|0;break a}c=PL(c,d);v[23220]=0;c=Q(52,e|0,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}d=ze(c);v[23220]=0;g=Q(772,f|0,c|0)|0;j=v[23220];v[23220]=0;d:{if((j|0)==1){break d}v[23220]=0;Q(908,g|0,21568)|0;g=v[23220];v[23220]=0;if((g|0)==1){break d}i=d^1|i;ub(c);a=a+1|0;continue}break}a=P()|0;O()|0;ub(c);break a}ub(f);fb=e+32|0;return}a=P()|0;O()|0}ub(f);ub(h);S(a|0);L()}function Kba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){e=v[b+12>>2]+i|0;h=v[b+8>>2]>>>21&2040;e=(((B(t[e|0],u[h+39874>>1])+B(t[e-1|0],u[h+39872>>1])|0)+B(t[e+1|0],u[h+39876>>1])|0)+B(t[e+2|0],u[h+39878>>1])<<8)/16384|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Ob(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;fb=b+16|0}function JW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;a:{b:{c:{d:{if(h=ah(v[b+4>>2],w[b+11|0]),i=1,j=v[b+12>>2],j?h:i){Gb(a);break d}e=Gb(c+16|0);d=xd(v[b+4>>2],w[b+11|0]);f=Cf(14291);g=qd(b);v[23220]=0;X(88,e|0,g|0,d|0,d+f|0);d=v[23220];v[23220]=0;e:{if((d|0)!=1){v[23220]=0;W(89,e|0,14291,f|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;vb(e);S(a|0);L()}v[23220]=0;R(119,c|0,b+12|0);b=v[23220];v[23220]=0;if((b|0)==1){break c}v[23220]=0;U(2,a|0,c+16|0,c|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}vb(c);vb(c+16|0)}fb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(c+16|0);S(b|0);L()}function lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=v[a+40>>2];g=v[a+36>>2];h=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;i=v[a+32>>2];j=v[a+28>>2];k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){d=d-1|0;m=((((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&2147483646)<<1)+h|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=u[(e<<1)+m>>1];e=e+1|0;continue}break}g=g+j|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+i|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Ob(b+8|0,k,l);c=c+8|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;fb=b+16|0}function U0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-32|0;fb=e;h=Gb(a);f=Gb(e+16|0);a=1;a:{b:{c:{while(1){d=a&65535;c=v[b+24>>2];if(d>>>0>x[c+480190>>1]){if(!(i&1)){break c}v[23220]=0;R(237,h|0,f|0);a=v[23220];v[23220]=0;if((a|0)!=1){break c}a=P()|0;O()|0;break a}v[23220]=0;c=Q(52,e|0,QL(c,d)|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}d=ze(c);v[23220]=0;g=Q(772,f|0,c|0)|0;j=v[23220];v[23220]=0;d:{if((j|0)==1){break d}v[23220]=0;Q(908,g|0,21568)|0;g=v[23220];v[23220]=0;if((g|0)==1){break d}i=d^1|i;ub(c);a=a+1|0;continue}break}a=P()|0;O()|0;ub(c);break a}ub(f);fb=e+32|0;return}a=P()|0;O()|0}ub(f);ub(h);S(a|0);L()}function Zr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);b=0;c=fb-32|0;fb=c;d=v[a>>2];a=v[d>>2];rf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];g=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){f=v[c+12>>2];if(Se(v[c+8>>2],f)>>>0<e>>>0){break b}h=v[c>>2];c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{i=Ih(g,d,a,b);j=dx(h,f,a,b),k=C(C(v[i>>2])*C(7.450580596923828e-9)),z[j>>2]=k;a=a+1|0;continue}}}ca(7115,9016,34,8729);L()}ca(5828,9016,36,8729);L()}fb=c+32|0}function yr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;f=d?d:466420;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}if(!v[v[115701]>>2]){v[i>>2]=d&57343;e=1;break a}a=a-194|0;if(a>>>0>50){break c}d=v[(a<<2)+82608>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[115696]=25;e=-1;break a}v[f>>2]=d}fb=h+16|0;return e}function D1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=0;c=fb-32|0;fb=c;d=v[a>>2];a=v[d>>2];rf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];f=v[a+8>>2];d=v[a+4>>2];g=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(Se(v[c+8>>2],v[c+12>>2])>>>0<f>>>0){break b}c:while(1){a=0;if((b|0)==(f|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{e=dd(v[Ih(g,d,a,b)>>2]+2048|0,12);e=(e|0)<32767?e:32767;h=ln(c,a,b),i=(e|0)>-32768?e:-32768,u[h>>1]=i;a=a+1|0;continue}}}ca(7115,9016,34,8729);L()}ca(5828,9016,36,8729);L()}fb=c+32|0}function cx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);b=0;c=fb-32|0;fb=c;d=v[a>>2];a=v[d>>2];rf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];f=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(Se(v[c+8>>2],v[c+12>>2])>>>0<e>>>0){break b}c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{g=Wl(de($f(A[Jg(f,d,a,b)>>3])*134217728));h=bx(c,a,b),i=C(+(g|0)*7.450580596923828e-9),z[h>>2]=i;a=a+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}fb=c+32|0}function cha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=v[a>>2];d=fq(c,v[a+4>>2]);if(d>>>0<b>>>0){f=fb-32|0;fb=f;c=b-d|0;b=v[Cb(a)>>2];e=v[a+4>>2];a:{if(c>>>0<=(b-e|0)/48>>>0){d=fb-16|0;fb=d;b=QT(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=d+16|0}else{pS(a);a=a+48|0;v[b+4>>2]=a;continue}break}break a}b=Cb(a);d=NT(f+8|0,OT(a,fq(v[a>>2],e)+c|0),fq(v[a>>2],v[a+4>>2]),b);b=fb-16|0;fb=b;v[b>>2]=v[d+8>>2];e=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=B(c,48)+e;c=v[b>>2];while(1){if(v[b+4>>2]!=(c|0)){pS(c);c=v[b>>2]+48|0;v[b>>2]=c;continue}break}Ed(b);fb=b+16|0;MT(a,d);LT(d)}fb=f+32|0;return}if(b>>>0<d>>>0){Jd(a,c+B(b,48)|0)}}function T9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;e=Kf(d+48|0);v[23220]=0;c=Q(765,b|0,e|0)|0;f=v[23220];v[23220]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23220]=0;T(766,a|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break b}}break a}c=v[e+4>>2];v[23220]=0;c=_b(c);c=c?c:-1;U(177,d|0,b|0,c|0);f=v[23220];v[23220]=0;if((f|0)==1){break a}f=gc(d+24|0,d);Yc(e+8|0,f);wb(f);wb(d);d:{c=c&1;if(!c){break d}v[23220]=0;Q(175,b|0,2-c|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break d}break a}bl(a,e)}Id(e);fb=d+80|0;return}a=P()|0;O()|0;Id(e);S(a|0);L()}function s9(a){a=a|0;var b=0,c=0,d=0,e=0;d=a+1074992|0;while(1){if((b|0)==256){Is(a+484344|0);Lf(a+1298308|0);eA(a+1298320|0);Lf(a+1298332|0);Bc(a+1298408|0);c=a+484380|0;b=0;while(1){if((b|0)==4e3){a:{c=a+900380|0;b=0;while(1){if((b|0)==256){c=a+906300|0;b=0;while(1){if((b|0)==250){break a}tB(c+B(b,160)|0);b=b+1|0;continue}}d=c+(b<<2)|0;e=v[d>>2];if(e){Fb(Ht(e))}v[d>>2]=0;b=b+1|0;continue}}}else{am(c+B(b,104)|0);b=b+1|0;continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0}else{c=d+B(b,872)|0;v[c+104>>2]=0;v[c+656>>2]=0;v[c+76>>2]=0;v[c+16>>2]=0;b=b+1|0;continue}break}}function e5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Zj(b),v[i>>2]=j;c=fb-16|0;fb=c;g=a;d=Od(a);a:{if(d){f=fc(g);while(1){a=d;d=a+16|0;if(Ws(b,d)){f=a;d=v[a>>2];if(d){continue}break a}if(!Ws(d,b)){break a}f=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=fc(g);f=a}v[c+12>>2]=a;b=v[f>>2];if(!b){a=fb-16|0;fb=a;b=fc(g);b=oh(c,tc(40),ph(a+8|0,b));Gb(Mc(v[b>>2]+16|0,v[e>>2])+12|0);i=fc(b),j=1,t[i+4|0]=j;fb=a+16|0;Tg(g,v[c+12>>2],f,v[c>>2]);b=Ud(c);a=v[c>>2];v[c>>2]=0;if(a){if(w[fc(c)+4|0]){Rl(a+16|0)}if(a){Fb(a)}}h=1}Sg(e+8|0,v[dc(c,b)>>2],h);fb=c+16|0;a=pd(v[e+8>>2]);fb=e+16|0;return a+12|0}function Xu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;t[f+15|0]=d;t[b+12|0]=w[a|0]&15|w[b+12|0]&240;i=a+1|0;e=f+15|0;Zg(b,w[Rb(i,e)|0]);g=w[Rb(a+2|0,e)|0];t[b+13|0]=g;k=b,l=Pd(w[a+3|0],g,d),t[k+14|0]=l;e=w[Rb(a+4|0,e)|0];t[b+15|0]=e;k=b,l=Pd(w[a+5|0],e,d),t[k+16|0]=l;g=v[b>>2];b=0;while(1){t[f+14|0]=25;if(b>>>0<w[Rb(f+14|0,i)|0]){e=B(b,3)+a|0;h=Ub(w[e+6|0]+c<<24>>24,0,64);d=zb(g,b);t[d+2|0]=h;e=w[e+7|0]|w[e+8|0]<<8;u[d>>1]=e;a:{if(!b){break a}h=zb(g,b-1|0);j=x[h>>1];if(e>>>0>255|e>>>0>=j>>>0){break a}e=e|j&65280;u[d>>1]=e;if(x[h>>1]<=(e&65535)>>>0){break a}u[d>>1]=e+256}b=b+1|0;continue}break}fb=f+16|0}function E8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-80|0;fb=d;e=Kf(d+48|0);v[23220]=0;g=Q(840,b|0,e|0)|0;f=v[23220];v[23220]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23220]=0;T(841,a|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break b}}break a}g=v[e+4>>2];v[23220]=0;U(177,d|0,b|0,g|0);f=v[23220];v[23220]=0;if((f|0)==1){break a}f=gc(d+24|0,d);Yc(e+8|0,f);wb(f);wb(d);d:{if(!(g&1)|c>>>0<2){break d}v[23220]=0;Q(175,b|0,1)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break d}break a}bl(a,e)}Id(e);fb=d+80|0;return}a=P()|0;O()|0;Id(e);S(a|0);L()}function bD(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if(Mb(a,3878,4)){break a}b=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);if(b>>>0<36){break a}c=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);if(c>>>0<36){break a}d=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);if(d>>>0<36){break a}e=w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24);if(e-1>>>0>858993458){break a}f=w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24);if(f-1>>>0>536870910){break a}a=w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24);if(B(e,-5)-1>>>0<b>>>0|a-1>>>0>1073741822|(f<<3^-1)>>>0<c>>>0){break a}g=(a<<2^-1)>>>0>=d>>>0}return g}function UT(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{if(!d){break a}i=w[e|0];if(!i){break a}g=d-6|0;j=(g&255)>>>0<6&35>>>g;l=d-2|0;m=0-c|0;while(1){if(!b){break a}k=(l&255)>>>0>2;h=B(m,6);c=a;a=h+c|0;f=w[a+3|0];b:{if(!(k|(f-2&255)>>>0>2)){g=1;if(w[(c+h|0)+5|0]<224){break b}break a}g=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}g=1}c:{if(k){break c}f=c+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=c+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}b=b-1|0;if(!g){continue}c=w[(c+h|0)+5|0];if(c?(c|0)!=(i|0):0){break a}if((c|0)!=(i|0)){continue}break}t[e|0]=0}}function nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=v[a+40>>2];g=v[a+36>>2];h=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;i=v[a+32>>2];j=v[a+28>>2];k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){d=d-1|0;m=(((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&-2)+h|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=t[e+m|0]<<8;e=e+1|0;continue}break}g=g+j|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+i|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Ob(b+8|0,k,l);c=c+8|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;fb=b+16|0}function V9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;e=Kf(d+48|0);v[23220]=0;c=Q(761,b|0,e|0)|0;f=v[23220];v[23220]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23220]=0;T(762,a|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break b}}break a}c=v[e+4>>2];v[23220]=0;c=_b(c);U(177,d|0,b|0,c|0);f=v[23220];v[23220]=0;if((f|0)==1){break a}f=gc(d+24|0,d);Yc(e+8|0,f);wb(f);wb(d);d:{c=c&1;if(!c){break d}v[23220]=0;Q(175,b|0,2-c|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break d}break a}bl(a,e)}Id(e);fb=d+80|0;return}a=P()|0;O()|0;Id(e);S(a|0);L()}function dD(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-32|0;fb=f;v[f+16>>2]=c;v[f+24>>2]=b;i=f,j=Fi(a),v[i+8>>2]=j;b=f+24|0;d=bk(b,f+8|0);c=bk(f+16|0,b);a:{if(xd(v[a+4>>2],w[a+11|0])>>>0>=d>>>0){if((c|0)==-1){b=fb-16|0;fb=b;b:{if(nf(w[a+11|0])){c=v[a>>2];t[b+15|0]=0;bd(c+d|0,b+15|0);Bd(a,d);break b}t[b+14|0]=0;bd(a+d|0,b+14|0);ae(a,d)}fb=b+16|0;break a}b=a;e=fb-16|0;fb=e;v[e+12>>2]=c;if(c){g=xd(v[b+4>>2],w[b+11|0]);h=qd(b);c=g-d|0;v[e+8>>2]=c;a=v[Eb(e+12|0,e+8|0)>>2];v[e+12>>2]=a;c:{if((a|0)==(c|0)){a=c;break c}d=d+h|0;pj(d,a+d|0,c-a|0)}a=g-a|0;Yp(b,a);t[e+7|0]=0;bd(a+h|0,e+7|0)}fb=e+16|0;break a}fm();L()}fb=f+32|0}function aS(a){var b=0,c=0,d=0,e=0,f=0;b=fb-32|0;fb=b;e=b,f=_b(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788|0,v[e>>2]=f;v[b+4>>2]=0;e=b,f=_b(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24)),v[e+8>>2]=f;v[b+12>>2]=0;c=_b(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24));v[b+16>>2]=c?c:52;v[b+20>>2]=0;e=b,f=_b(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))+80|0,v[e+24>>2]=f;v[b+28>>2]=0;a=b;d=Ne(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=Ru(v[a>>2],v[a+4>>2],v[c>>2],v[c+4>>2])?c:a;continue}}fb=b+32|0;c=v[a>>2];b=c-52|0;ib=v[a+4>>2]-(c>>>0<52)|0;return b}function VY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];c=sc(d,v[a+4>>2]);if(c>>>0<b>>>0){g=fb-32|0;fb=g;d=b-c|0;b=v[Cb(a)>>2];e=v[a+4>>2];a:{if(d>>>0<=b-e>>2>>>0){it(a,d);break a}c=aw(a);e=Pg(a,sc(v[a>>2],e)+d|0);f=sc(v[a>>2],v[a+4>>2]);b=g+8|0;Gf(b+12|0,c);if(e){c=oF(v[b+16>>2],e)}else{c=0}v[b>>2]=c;f=c+(f<<2)|0;v[b+8>>2]=f;v[b+4>>2]=f;h=vc(b),i=c+(e<<2)|0,v[h>>2]=i;e=fb-16|0;fb=e;c=il(e,b+8|0,d);d=v[c>>2];while(1){if(v[c+4>>2]!=(d|0)){tz(d);d=v[c>>2]+4|0;v[c>>2]=d;continue}break}Ed(c);fb=e+16|0;vd(a,b);pP(b);a=v[b>>2];if(a){qF(v[b+16>>2],a,wz(b))}}fb=g+32|0;return}if(b>>>0<c>>>0){Jd(a,d+(b<<2)|0)}}function tX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(Eg(a,v[b+8>>2],f)){Wv(b,c,d,e);return}h=w[b+53|0];g=v[a+12>>2];t[b+53|0]=0;i=w[b+52|0];t[b+52|0]=0;Rv(v[a+16>>2],v[a+20>>2],b,c,d,e,f);j=w[b+53|0];h=h|j;k=w[b+52|0];i=i|k;a:{if((g|0)<2){break a}l=a+16|0;m=l+(g<<3)|0;g=l+8|0;while(1){if(w[b+54|0]){break a}b:{if(k){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!j){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;Rv(v[g>>2],v[g+4>>2],b,c,d,e,f);j=w[b+53|0];h=j|h;k=w[b+52|0];i=k|i;g=g+8|0;if(m>>>0>g>>>0){continue}break}}t[b+53|0]=(h&255)!=0;t[b+52|0]=(i&255)!=0}function hH(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-208|0;fb=f;v[f+204>>2]=c;c=f+160|0;Sb(c,0,40);v[f+200>>2]=v[f+204>>2];a:{if((gH(0,b,f+200|0,f+80|0,c,d,e)|0)<0){b=-1;break a}i=v[a+76>>2]>=0;g=v[a>>2];if(v[a+72>>2]<=0){v[a>>2]=g&-33}b:{c:{d:{if(!v[a+48>>2]){v[a+48>>2]=80;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;h=v[a+44>>2];v[a+44>>2]=f;break d}if(v[a+16>>2]){break c}}c=-1;if(xC(a)){break b}}c=gH(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){jb[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=h;v[a+28>>2]=0;b=v[a+20>>2];v[a+16>>2]=0;v[a+20>>2]=0;c=b?c:-1}b=a;a=v[a>>2];v[b>>2]=a|g&32;b=a&32?-1:c;if(!i){break a}}fb=f+208|0;return b}function c9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=fb-16|0;fb=h;f=c;e=fb-16|0;fb=e;g=b;d=Od(b);a:{if(d){c=fc(g);while(1){b=d;d=b+16|0;if(yL(f,d)){c=b;d=v[b>>2];if(d){continue}break a}if(!yL(d,f)){break a}c=b+4|0;d=v[b+4>>2];if(d){continue}break}break a}b=fc(g);c=b}v[e+12>>2]=b;b=v[c>>2];if(!b){b=fb-16|0;fb=b;d=fc(g);d=oh(e,tc(28),ph(b+8|0,d));i=v[d>>2];v[23220]=0;R(818,i+16|0,f|0);f=v[23220];v[23220]=0;b:{if((f|0)!=1){j=fc(d),k=1,t[j+4|0]=k;fb=b+16|0;break b}a=P()|0;O()|0;xL(d);S(a|0);L()}Tg(g,v[e+12>>2],c,v[e>>2]);b=Ud(e);xL(e);i=1}c=h+8|0;Sg(c,v[dc(e,b)>>2],i);fb=e+16|0;LO(a,c);fb=h+16|0}function OO(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+798|0]=0;return}t[a+798|0]=1;return}t[a+798|0]=2;return}t[a+798|0]=3;return}t[a+730|0]=w[a+730|0]&254;return}t[a+730|0]=w[a+730|0]|1;return}t[a+738|0]=w[a+738|0]&254;return}t[a+738|0]=w[a+738|0]|1;return}t[a+746|0]=w[a+746|0]&254;return}t[a+746|0]=w[a+746|0]|1;return}if((c|0)!=16777216){break a}c=a;a=w[a+746|0];t[c+746|0]=(b|0)==13?a&238|1:a|17}}function RA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-16|0;fb=e;d=(c<<3)+a|0;f=w[d+356|0];t[b+12|0]=w[b+12|0]&248|f&1|f<<1&4|f>>>1&2;Zg(b,Pd(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;f=((c|0)!=0)<<1;h=v[b>>2];j=ne(h,v[b+4>>2]);k=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){if((d|0)==(j|0)){QA(b,32);fb=e+16|0}else{a=k+(d<<2)|0;u[e+12>>1]=w[a+160|0]|w[a+161|0]<<8;g=Re(e+14|0,e+12|0);i=zb(h,d);g=x[g>>1];u[i>>1]=g;u[e+14>>1]=g+1;t[e+11|0]=(c^w[a+162|0])>>>f;t[e+10|0]=64;l=i,m=w[Rb(e+11|0,e+10|0)|0],t[l+2|0]=m;d=d+1|0;continue}break}}function D_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-48|0;fb=f;v[f+40>>2]=b;a:{if(!(v[c+4>>2]&1)){c=jb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;Xc(a,c);v[23220]=0;a=T(1087,a|0)|0;b=v[23220];v[23220]=0;b:{if((b|0)!=1){Wb(f+24|0);c:{if(e){Gh(f+24|0,a);break c}Fh(f+24|0,a)}g=f,h=Td(f+24|0),v[g+16>>2]=h;while(1){g=f,h=ih(f+24|0),v[g+8>>2]=h;if(!Kh(f+16|0,f+8|0)){c=v[f+40>>2];ub(f+24|0);break a}a=t[v[f+16>>2]];v[23220]=0;Q(20,f+40|0,a|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){xe(f+16|0);continue}break}c=P()|0;O()|0;ub(f+24|0);break b}c=P()|0;O()|0;Wb(f+24|0)}S(c|0);L()}fb=f+48|0;return c|0}function c2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=fb+-64|0;fb=d;f=d+16|0;h=fb-16|0;fb=h;i=WO(h+8|0);while(1){if((j|0)==12){fb=h+16|0}else{g=fb+-64|0;fb=g;c=v[i+4>>2];e=v[i>>2];a:{if((c|0)==(e|0)){break a}c=(c-e|0)+1|0;if(!c){c=OI(PI(g+8|0,32));break a}e=E(c);e=PI(g+8|0,(c<<e+1?32:31)-e|0);while(1){k=OI(e);if(c>>>0<=k>>>0){continue}break}c=v[i>>2]+k|0}fb=g- -64|0;l=zb(f,j),m=c,v[l>>2]=m;j=j+1|0;continue}break}f=YO(d,f,ZO(f));XO(a,f);bm(f);fb=d- -64|0;d=hx(a+120|0,a,b);t[d+20|0]=1;v[23220]=0;R(1041,a|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){a=P()|0;O()|0;nn(d);S(a|0);L()}return a|0}function oL(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=fb-16|0;fb=h;t[h+15|0]=b;t[h+14|0]=10;Zg(g,w[Rb(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;j=v[g>>2];k=ne(j,v[g+4>>2]);b=0;a:{while(1){if((b|0)==(k|0)){b:{b=w[g+12|0]&-2|a&1;if(a&2){break b}b=b&251;break a}}else{m=zb(j,b);l=B(b,3)+f|0;i=(w[l|0]|w[l+1|0]<<8)>>>4|0;u[m>>1]=i;c:{if(b){n=x[zb(j,b-1|0)>>1];if(i>>>0>=n>>>0){break c}i=n+1|0}else{i=0}o=zb(j,b),p=i,u[o>>1]=p}o=m,p=Pd(w[l+2|0],0,64),t[o+2|0]=p;b=b+1|0;continue}break}b=b&-5|(c>>>0<=k>>>0)<<2}t[g+12|0]=(d>>>0<=e>>>0?a&4:0)?b&-3|(d>>>0<=k>>>0)<<1:b&253;fb=h+16|0}function tT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=fb-16|0;fb=e;f=fb-32|0;fb=f;c=Ge(f+16|0,1,0);b:{c:{d:{while(1){d=pc(c);zx(f+8|0,d,Bb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break d}d=Ff(Bb(c));v[23220]=0;R(56,c|0,d|0);d=v[23220];v[23220]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=pc(c);v[23220]=0;R(57,c|0,b-d|0);b=v[23220];v[23220]=0;e:{if((b|0)!=1){v[23220]=0;R(69,e|0,c|0);b=v[23220];v[23220]=0;if((b|0)!=1){break e}break c}break c}ub(c);fb=f+32|0;break b}a=P()|0;O()|0;ub(c);S(a|0);L()}v[23220]=0;R(68,a|0,e|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(e);fb=e+16|0;break a}a=P()|0;O()|0;vb(e);S(a|0);L()}}function rD(a,b){var c=0,d=0,e=0,f=0;c=v[a>>2];d=Dg(c,v[a+4>>2]);if(d>>>0<b>>>0){f=fb-32|0;fb=f;c=b-d|0;b=v[Cb(a)>>2];e=v[a+4>>2];a:{if(c>>>0<=b-e>>3>>>0){d=fb-16|0;fb=d;b=Tq(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=d+16|0}else{ol(a);a=a+8|0;v[b+4>>2]=a;continue}break}break a}b=Cb(a);d=Vq(f+8|0,Wq(a,Dg(v[a>>2],e)+c|0),Dg(v[a>>2],v[a+4>>2]),b);b=fb-16|0;fb=b;v[b>>2]=v[d+8>>2];e=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=(c<<3)+e;c=v[b>>2];while(1){if(v[b+4>>2]!=(c|0)){ol(c);c=v[b>>2]+8|0;v[b>>2]=c;continue}break}Ed(b);fb=b+16|0;vd(a,d);Uq(d)}fb=f+32|0;return}if(b>>>0<d>>>0){Jd(a,c+(b<<3)|0)}}function Yr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);b=0;c=fb-32|0;fb=c;d=v[a>>2];a=v[d>>2];rf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];f=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(Se(v[c+8>>2],v[c+12>>2])>>>0<e>>>0){break b}c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{g=Ih(f,d,a,b);h=bx(c,a,b),i=C(C(v[g>>2])*C(7.450580596923828e-9)),z[h>>2]=i;a=a+1|0;continue}}}ca(7115,9016,34,8729);L()}ca(5828,9016,36,8729);L()}fb=c+32|0}function Io(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=fb-16|0;fb=e;f=fb-32|0;fb=f;c=Ge(f+16|0,1,0);b:{c:{d:{while(1){d=pc(c);Hx(f+8|0,d,Bb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break d}d=Ff(Bb(c));v[23220]=0;R(56,c|0,d|0);d=v[23220];v[23220]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=pc(c);v[23220]=0;R(57,c|0,b-d|0);b=v[23220];v[23220]=0;e:{if((b|0)!=1){v[23220]=0;R(69,e|0,c|0);b=v[23220];v[23220]=0;if((b|0)!=1){break e}break c}break c}ub(c);fb=f+32|0;break b}a=P()|0;O()|0;ub(c);S(a|0);L()}v[23220]=0;R(68,a|0,e|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(e);fb=e+16|0;break a}a=P()|0;O()|0;vb(e);S(a|0);L()}}function kX(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-32|0;fb=k;m=v[c>>2];l=v[c+8>>2];c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=l;v[k+24>>2]=c;v[k+28>>2]=l;v[k+20>>2]=m;v[k+16>>2]=d;v[23220]=0;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=La(1015,a|0,b|0,k|0)|0;b=v[23220];v[23220]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23220]=0;ja(902,10376,e|0,f|0,g|0,h|0,i|0,j|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}$();a=-255}fb=k+32|0;break a}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}return a|0}function I1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);b=0;c=fb-32|0;fb=c;d=v[a>>2];a=v[d>>2];rf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];g=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){f=v[c+12>>2];if(Se(v[c+8>>2],f)>>>0<e>>>0){break b}h=v[c>>2];c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{i=Jg(g,d,a,b);j=dx(h,f,a,b),k=C(A[i>>3]),z[j>>2]=k;a=a+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}fb=c+32|0}function hp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;f=fb-32|0;fb=f;c=Ge(f+16|0,1,0);a:{b:{c:{while(1){d=pc(c);Hx(f+8|0,d,Bb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break c}d=Ff(Bb(c));v[23220]=0;R(56,c|0,d|0);d=v[23220];v[23220]=0;if((d|0)!=1){continue}break}break b}b=v[f+8>>2];d=pc(c);v[23220]=0;R(57,c|0,b-d|0);b=v[23220];v[23220]=0;d:{if((b|0)!=1){v[23220]=0;R(58,e|0,c|0);b=v[23220];v[23220]=0;if((b|0)!=1){break d}break b}break b}ub(c);fb=f+32|0;break a}a=P()|0;O()|0;ub(c);S(a|0);L()}v[23220]=0;R(55,a|0,e|0);a=v[23220];v[23220]=0;if((a|0)!=1){ub(e);fb=e+16|0;return}a=P()|0;O()|0;ub(e);S(a|0);L()}function $7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;f=fb-32|0;fb=f;c=Ge(f+16|0,1,0);a:{b:{c:{while(1){d=pc(c);Hx(f+8|0,d,Bb(c)+d|0,w[b|0]);if(!v[f+12>>2]){break c}d=Ff(Bb(c));v[23220]=0;R(56,c|0,d|0);d=v[23220];v[23220]=0;if((d|0)!=1){continue}break}break b}b=v[f+8>>2];d=pc(c);v[23220]=0;R(57,c|0,b-d|0);b=v[23220];v[23220]=0;d:{if((b|0)!=1){v[23220]=0;R(58,e|0,c|0);b=v[23220];v[23220]=0;if((b|0)!=1){break d}break b}break b}ub(c);fb=f+32|0;break a}a=P()|0;O()|0;ub(c);S(a|0);L()}v[23220]=0;R(55,a|0,e|0);a=v[23220];v[23220]=0;if((a|0)!=1){ub(e);fb=e+16|0;return}a=P()|0;O()|0;ub(e);S(a|0);L()}function W9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(v[a+4>>2]!=v[Cb(a)>>2]){c=fb-16|0;fb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+7;AN(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+7;hc(c);fb=c+16|0;return}f=fb-32|0;fb=f;h=Cb(a);i=f+8|0;c=a;g=Sy(v[a>>2],v[a+4>>2])+1|0;e=fb-16|0;fb=e;v[e+12>>2]=g;d=fb-16|0;fb=d;v[d+12>>2]=613566756;v[d+8>>2]=2147483647;a=v[Eb(d+12|0,d+8|0)>>2];fb=d+16|0;a:{if(a>>>0>=g>>>0){d=Ry(c);if(d>>>0<a>>>1>>>0){v[e+8>>2]=d<<1;a=v[Sc(e+8|0,e+12|0)>>2]}fb=e+16|0;break a}od();L()}a=EN(i,a,Sy(v[c>>2],v[c+4>>2]),h);AN(v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+7;DN(c,a);CN(a);fb=f+32|0}function Vda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;kd(b,0);Sh(d,1,a);c=d+16|0;Ac(c,d);ue(b+43|0,c);ub(c);v[b>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[b+4>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);v[b+8>>2]=w[a+56|0]|w[a+57|0]<<8|(w[a+58|0]<<16|w[a+59|0]<<24);v[b+24>>2]=w[a+62|0]|w[a+63|0]<<8;aq(b,+((w[a+60|0]^8)-120|0)/192);t[d+16|0]=w[a+61|0];t[d|0]=64;f=b,g=w[Rb(c,d)|0]<<2,u[f+30>>1]=g;u[b+34>>1]=0;c=w[a+47|0];if(c&4){u[b+34>>1]=1;v[b>>2]=v[b>>2]>>>1;e=1;c=w[a+47|0]}if(c&32){e=e|4;u[b+34>>1]=e;c=w[a+47|0]}if(c<<24>>24<0){u[b+34>>1]=e|2}fb=d+32|0}function OZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=xF(b);rk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;qk(k,a);Li(i,k);Nc(k);Fh(k,a);Li(h,k);Nc(k);l=d,m=Qi(a),v[l>>2]=m;l=e,m=Ri(a),v[l>>2]=m;Gg(k,a);xc(f,k);ub(k);Gh(k,a);Li(g,k);Nc(k);a=pk(a);break a}a=wF(b);rk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;qk(k,a);Li(i,k);Nc(k);Fh(k,a);Li(h,k);Nc(k);l=d,m=Qi(a),v[l>>2]=m;l=e,m=Ri(a),v[l>>2]=m;Gg(k,a);xc(f,k);ub(k);Gh(k,a);Li(g,k);Nc(k);a=pk(a)}v[j>>2]=a;fb=k+16|0}function zK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;zh(f+8|0,b);g=fb-16|0;fb=g;Hg(g+8|0,v[f+8>>2],v[f+12>>2]);j=v[g+8>>2];e=v[g+12>>2];h=fb-16|0;fb=h;k=h,l=Ab(a),v[k+8>>2]=l;b=fb-16|0;fb=b;i=v[h+8>>2];d=i;a=v[d+12>>2];d=v[d+8>>2];a:{if((a|0)<0){break a}c=v[i+4>>2];if(!a&c>>>0<d>>>0|a){break a}v[b+8>>2]=c-d;v[b+12>>2]=0-(a+(d>>>0>c>>>0)|0);a=e;v[b>>2]=a;v[b+4>>2]=0;c=IB(b+8|0,b);if((Py(v[c>>2],v[c+4>>2])|0)!=(a|0)){break a}Gi(j,e+j|0,d+v[i>>2]|0);e=v[h+8>>2];c=e;d=a+v[c+8>>2]|0;e=v[c+12>>2];v[c+8>>2]=d;v[c+12>>2]=a>>>0>d>>>0?e+1|0:e}fb=b+16|0;fb=h+16|0;fb=g+16|0;fb=f+16|0}function sJ(a,b){var c=0,d=0,e=0,f=0;a:{e=fb-16|0;fb=e;f=fb-32|0;fb=f;c=Ge(f+16|0,1,0);b:{c:{d:{while(1){d=pc(c);ox(f+8|0,d,Bb(c)+d|0,x[b>>1]);if(!v[f+12>>2]){break d}d=Ff(Bb(c));v[23220]=0;R(56,c|0,d|0);d=v[23220];v[23220]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=pc(c);v[23220]=0;R(57,c|0,b-d|0);b=v[23220];v[23220]=0;e:{if((b|0)!=1){v[23220]=0;R(69,e|0,c|0);b=v[23220];v[23220]=0;if((b|0)!=1){break e}break c}break c}ub(c);fb=f+32|0;break b}a=P()|0;O()|0;ub(c);S(a|0);L()}v[23220]=0;R(68,a|0,e|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(e);fb=e+16|0;break a}a=P()|0;O()|0;vb(e);S(a|0);L()}}function uJ(a,b){var c=0,d=0,e=0,f=0;a:{e=fb-16|0;fb=e;f=fb-32|0;fb=f;c=Ge(f+16|0,1,0);b:{c:{d:{while(1){d=pc(c);tJ(f+8|0,d,Bb(c)+d|0,w[b|0]);if(!v[f+12>>2]){break d}d=Ff(Bb(c));v[23220]=0;R(56,c|0,d|0);d=v[23220];v[23220]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=pc(c);v[23220]=0;R(57,c|0,b-d|0);b=v[23220];v[23220]=0;e:{if((b|0)!=1){v[23220]=0;R(69,e|0,c|0);b=v[23220];v[23220]=0;if((b|0)!=1){break e}break c}break c}ub(c);fb=f+32|0;break b}a=P()|0;O()|0;ub(c);S(a|0);L()}v[23220]=0;R(68,a|0,e|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(e);fb=e+16|0;break a}a=P()|0;O()|0;vb(e);S(a|0);L()}}function Yd(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a=ch(a,-1,-1);a:{b:{if(Nd(w[fn(c+24|0,b,1)|0])){d=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[23220]=0;R(94,c+8|0,d|0);d=v[23220];v[23220]=0;c:{if((d|0)!=1){d=v[c+12>>2];v[a>>2]=v[c+8>>2];v[a+4>>2]=d;d=v[c+20>>2];v[a+8>>2]=v[c+16>>2];v[a+12>>2]=d;break c}a=V(0)|0;O()|0;_(a|0)|0;e=1;en(v[v[b>>2]-12>>2]+b|0,1);if(v[(v[v[b>>2]-12>>2]+b|0)+20>>2]&1){v[23220]=0;Z(91);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)==1){break b}S(a|0);L()}$()}tj(v[v[b>>2]-12>>2]+b|0,e)}fb=c+32|0;return}V(0)|0;O()|0;Tb()}L()}function Vr(a,b,c){var d=0,e=0;d=a,e=Yi(C(C(z[c+1792>>2]*C(75038))+C(C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489))+C(C(C(z[c+1280>>2]+z[c+2304>>2])*C(6574))+C(C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153))+C(C(C(z[c+768>>2]+z[c+2816>>2])*C(2037))+C(C(C(z[c+3072>>2]-z[c+512>>2])*C(459))+C(C(C(z[c+256>>2]+z[c+3328>>2])*C(213))+C(C(z[c+3584>>2]-z[c>>2])*C(29)))))))))),u[d>>1]=e;d=(b<<5)+a|0,e=Yi(C(C(z[c+8>>2]*C(-5))+C(C(z[c+520>>2]*C(146))+C(C(z[c+1032>>2]*C(-45))+C(C(z[c+1544>>2]*C(-9975))+C(C(z[c+2056>>2]*C(64019))+C(C(z[c+2568>>2]*C(9727))+C(C(z[c+3080>>2]*C(1567))+C(z[c+3592>>2]*C(104)))))))))),u[d>>1]=e}function VZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=BF(b);rk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;qk(k,a);xc(i,k);ub(k);Fh(k,a);xc(h,k);ub(k);l=d,m=Qi(a),t[l|0]=m;l=e,m=Ri(a),t[l|0]=m;Gg(k,a);xc(f,k);ub(k);Gh(k,a);xc(g,k);ub(k);a=pk(a);break a}a=AF(b);rk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;qk(k,a);xc(i,k);ub(k);Fh(k,a);xc(h,k);ub(k);l=d,m=Qi(a),t[l|0]=m;l=e,m=Ri(a),t[l|0]=m;Gg(k,a);xc(f,k);ub(k);Gh(k,a);xc(g,k);ub(k);a=pk(a)}v[j>>2]=a;fb=k+16|0}function j2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Cb(a)>>2]){c=fb-16|0;fb=c;a=Lo(c,a,1);kx(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+16;hc(a);fb=c+16|0;return}e=fb-32|0;fb=e;c=Cb(a);c=Bv(e+8|0,Cv(a,bh(v[a>>2],v[a+4>>2])+1|0),bh(v[a>>2],v[a+4>>2]),c);kx(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+16;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-16|0;kx(v[b>>2]-16|0,d);v[b>>2]=v[b>>2]-16;continue}break}kc(a,b);kc(a+4|0,c+8|0);kc(Cb(a),vc(c));v[c>>2]=v[c+4>>2];a=v[c+4>>2];while(1){b=v[c+8>>2];if((b|0)!=(a|0)){b=b-16|0;v[c+8>>2]=b;gs(b);continue}break}a=v[c>>2];if(a){Jo(c);Fb(a)}fb=e+32|0}function aN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;a:{if(w[b+791|0]!=27){a=t[b+831|0];break a}d=c+8|0;f=a+1074312|0;xb(d,f,21);e=a;a=w[b+821|0];a=dy(e,w[b+828|0],yb(v[v[c+8>>2]>>2],v[c+12>>2])?a:a+16>>>2|0);xb(d,f,45);b:{if(!(!yb(v[v[c+8>>2]>>2],v[c+12>>2])|w[b+828|0]!=3)){d=w[b+821|0];c:{if(!(!d|d>>>0>=w[b+829|0])){a=w[b+832|0];e=d+1|0;break c}t[b+832|0]=a;e=1}t[b+821|0]=e;a=a<<24>>24;break b}t[b+821|0]=w[b+821|0]+w[b+829|0]}xb(c+8|0,f,47);if(!yb(v[v[c+8>>2]>>2],v[c+12>>2])){break a}t[b+831|0]=a}if(a){g=b,h=Ub(v[b+684>>2]+((B(w[b+830|0],a)+2|0)/8|0)|0,0,256),v[g+684>>2]=h}fb=c+16|0}
function Jfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Zj(b),v[i>>2]=j;f=x[b>>1];d=fb-16|0;fb=d;g=a;c=Od(a);a:{if(c){b=fc(g);while(1){a=c;c=x[a+14>>1];if(bo(f,c)){b=a;c=v[a>>2];if(c){continue}break a}if(!bo(c,f)){break a}b=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=fc(g);b=a}v[d+12>>2]=a;a=v[b>>2];if(!a){a=fb-16|0;fb=a;c=fc(g);f=oh(d,tc(20),ph(a+8|0,c));c=v[f>>2];h=x[v[e>>2]>>1];u[c+16>>1]=0;u[c+14>>1]=h;i=fc(f),j=1,t[i+4|0]=j;fb=a+16|0;Tg(g,v[d+12>>2],b,v[d>>2]);a=Ud(d);_k(d);h=1}Sg(e+8|0,v[dc(d,a)>>2],h);fb=d+16|0;a=Pp(v[e+8>>2]);fb=e+16|0;return a+2|0}function YW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=fb+-64|0;fb=g;Mm(g+16|0,c);v[23220]=0;c=g+28|0;R(100,c|0,d|0);d=v[23220];v[23220]=0;b:{c:{d:{if((d|0)==1){break d}v[23220]=0;c=g+40|0;R(100,c|0,e|0);d=v[23220];v[23220]=0;if((d|0)==1){break d}v[23220]=0;c=g+52|0;R(100,c|0,f|0);d=v[23220];v[23220]=0;if((d|0)==1){break d}zv(g+8|0,g+16|0);v[23220]=0;X(101,a|0,b|0,v[g+8>>2],v[g+12>>2]);a=v[23220];v[23220]=0;if((a|0)==1){break c}XD(g+16|0);fb=g- -64|0;break a}a=P()|0;O()|0;while(1){c=vb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=P()|0;O()|0;XD(g+16|0)}S(a|0);L()}}function jk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;f=a+36|0;c=v[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=v[a+20>>2];if(d>>>0>=y[a+24>>2]){_m(e,f,yD(f));md(e+8|0,a,v[e>>2],v[e+4>>2]);c=v[e+12>>2];v[a+24>>2]=c;v[a+20>>2]=0;if(!c){break c}d=0;c=v[a+32>>2]}v[a+20>>2]=d+1;g=w[(a+d|0)+36|0];d=c+8|0;v[a+32>>2]=d;v[a+28>>2]=v[a+28>>2]|g<<c;c=d;continue}break}a=aa(8)|0;v[23220]=0;b=T(154,a|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break a}b=P()|0;O()|0;ba(a|0);S(b|0);L()}v[a+32>>2]=c-b;d=a;a=v[a+28>>2];v[d+28>>2]=a>>>b;fb=e+16|0;return a&(-1<<b^-1)}ia(b|0,30480,155);L()}function u5(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=fb-80|0;fb=d;v[d+72>>2]=c;c=v[a>>2];e=v[a+4>>2];f=v[a+12>>2];v[d+40>>2]=v[a+8>>2];v[d+44>>2]=f;v[d+32>>2]=c;v[d+36>>2]=e;a=Xd(d+24|0);c=v[a+4>>2];a=v[a>>2];e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;v[23220]=0;e=v[d+36>>2];v[d>>2]=v[d+32>>2];v[d+4>>2]=e;X(903,d+48|0,d|0,a|0,c|0);a=v[23220];v[23220]=0;a:{b:{if((a|0)!=1){a=v[Rf(d+16|0,d+72|0)>>2];v[23220]=0;b=+Aa(904,d+48|0,+b,a|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}wb(d+48|0);pe(d+72|0);fb=d+80|0;return+b}a=P()|0;O()|0;break a}a=P()|0;O()|0;wb(d+48|0)}pe(d+72|0);S(a|0);L()}function SY(a){a=a|0;if(w[466832]){return v[116707]}if(!w[467936]){a=467648;while(1){a=Gb(a)+12|0;if((a|0)!=467936){continue}break}t[467936]=1}id(467648,87816);id(467660,87848);id(467672,87884);id(467684,87908);id(467696,87932);id(467708,87948);id(467720,87968);id(467732,87988);id(467744,88016);id(467756,88056);id(467768,88088);id(467780,88124);id(467792,88160);id(467804,88176);id(467816,88192);id(467828,88208);id(467840,87932);id(467852,88224);id(467864,88240);id(467876,88256);id(467888,88272);id(467900,88288);id(467912,88304);id(467924,88320);t[466832]=1;v[116707]=467648;return 467648}function $ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>18|0;n=((((v[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){f=(e<<1)+n|0;g=u[f>>1];v[(e<<2)+b>>2]=g+((B(u[f+4>>1]-g|0,m)|0)/16384|0);e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],h);Ob(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;fb=b+16|0}function V4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;v[23220]=0;Y(919,a|0);d=v[23220];v[23220]=0;a:{b:{c:{if((d|0)==1){break c}v[23220]=0;Y(920,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break c}d=v[a+24>>2];b=oc(c+8|0,b);e=v[b+4>>2];b=v[b>>2];v[23220]=0;da(932,c+16|0,d|0,b|0,e|0,1);b=v[23220];v[23220]=0;if((b|0)==1){break c}a=c+16|0;b=Uf(Ec(a));ub(a);break b}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[23220]=0;X(906,5496,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$()}fb=c+32|0;return b|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function U7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Cb(a)>>2]){c=fb-16|0;fb=c;a=vz(c,a);Jx(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;hc(a);fb=c+16|0;return}e=fb-32|0;fb=e;c=Cb(a);c=cg(e+8|0,Pg(a,sc(v[a>>2],v[a+4>>2])+1|0),sc(v[a>>2],v[a+4>>2]),c);Jx(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-4|0;Jx(v[b>>2]-4|0,d);v[b>>2]=v[b>>2]-4;continue}break}kc(a,b);kc(a+4|0,c+8|0);kc(Cb(a),vc(c));v[c>>2]=v[c+4>>2];a=v[c+4>>2];while(1){b=v[c+8>>2];if((b|0)!=(a|0)){b=b-4|0;v[c+8>>2]=b;fg(b);continue}break}a=v[c>>2];if(a){wz(c);Fb(a)}fb=e+32|0}function RM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;v[d+12>>2]=b;if(b>>>0<4294967280){i=d,j=xd(v[a+4>>2],w[a+11|0]),v[i+8>>2]=j;e=Qh(v[Sc(d+12|0,d+8|0)>>2]);if((e|0)!=(co(a)|0)){a:{f=xd(v[a+4>>2],w[a+11|0]);b:{if((e|0)==10){g=v[a>>2];h=1;b=a;c=f;break b}b=e+1|0;c:{if(co(a)>>>0<e>>>0){b=tc(b);break c}v[23220]=0;b=T(49,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;$();break a}c=w[a+11|0];h=nf(c);g=qd(a);c=xd(v[a+4>>2],c)}b=Fe(b,g,c+1|0);if(h){Fb(g)}if((e|0)!=10){yf(a,e+1|0);Bd(a,f);td(a,b);break a}ae(a,f)}}fb=d+16|0;return}kf();L()}function Z$(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;if(rH(0,d+16|0)){Nr(v[115696],12648);L()}b=Mr(d+8|0,v[d+16>>2]);e=Mr(d,v[d+20>>2]/1e3|0);c=fb-32|0;fb=c;a=fb-16|0;fb=a;f=fb-16|0;fb=f;b=kn(f+8|0,Bia(v[b>>2],v[b+4>>2],1e6,0),ib);g=v[b+4>>2];b=v[b>>2];fb=f+16|0;v[a+8>>2]=b;v[a+12>>2]=g;b=v[a+12>>2];v[c+16>>2]=v[a+8>>2];v[c+20>>2]=b;fb=a+16|0;a=v[c+16>>2];f=v[c+20>>2];b=v[e+4>>2];v[c+8>>2]=v[e>>2];v[c+12>>2]=b;e=v[c+8>>2];b=a+e|0;a=v[c+12>>2]+f|0;a=kn(c+24|0,b,b>>>0<e>>>0?a+1|0:a);b=v[a+4>>2];a=v[a>>2];fb=c+32|0;c=kn(d+24|0,a,b);a=v[c+4>>2];c=v[c>>2];fb=d+32|0;ib=a;return c|0}function Tg(a,b,c,d){var e=0,f=0;v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;b=v[v[a>>2]>>2];if(b){v[a>>2]=b;d=v[c>>2]}f=v[fc(a)>>2];t[d+12|0]=(f|0)==(d|0);while(1){a:{if((d|0)==(f|0)){break a}c=v[d+8>>2];if(w[c+12|0]){break a}b:{if(nh(c)){b=v[c+8>>2];e=v[b+4>>2];if(!(!e|w[e+12|0])){break b}if(!nh(d)){Rp(c);c=v[c+8>>2]}t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;Qp(b);break a}b=v[c+8>>2];e=v[b>>2];if(!(!e|w[e+12|0])){break b}if(nh(d)){Qp(c);c=v[c+8>>2]}t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;Rp(b);break a}t[c+12|0]=1;d=b;t[d+12|0]=(d|0)==(f|0);t[e+12|0]=1;continue}break}a=Cb(a);v[a>>2]=v[a>>2]+1}function iX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=fb-16|0;fb=f;v[23220]=0;Y(919,a|0);e=v[23220];v[23220]=0;a:{b:{c:{d:{if((e|0)==1){break d}v[23220]=0;Y(920,b|0);e=v[23220];v[23220]=0;if((e|0)==1){break d}e=v[a+24>>2];b=oc(f+8|0,b);g=v[b+4>>2];b=v[b>>2];v[23220]=0;Na(940,e|0,b|0,g|0,c|0,d|0,1);c=v[23220];v[23220]=0;b=1;if((c|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,8613,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break b}$();b=0}fb=f+16|0;break a}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}return b|0}function gm(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function fn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;t[a|0]=0;a:{d=v[v[b>>2]-12>>2]+b|0;b:{if(Ch(d)){d=v[d+72>>2];if(d){Yu(d)}c:{if(c){break c}c=v[v[b>>2]-12>>2]+b|0;if(!(v[c+4>>2]&4096)){break c}d=e+24|0;Xc(d,c);v[23220]=0;f=T(18,d|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}Wb(e+24|0);c=qm(e+16|0,b);d=lh(e+8|0);while(1){d:{if(!Zo(c,d)){break d}g=Ak(v[c>>2]);if(!eh(v[f+8>>2],8192,g)){break d}Al(c);continue}break}if(!Ij(c,d)){break c}tj(v[v[b>>2]-12>>2]+b|0,6)}h=a,i=Ch(v[v[b>>2]-12>>2]+b|0),t[h|0]=i;break b}tj(d,4)}fb=e+32|0;return a}a=P()|0;O()|0;Wb(e+24|0);S(a|0);L()}function y1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);b=0;c=fb-32|0;fb=c;d=v[a>>2];a=v[d>>2];rf(c+16|0,v[a+12>>2],v[a+16>>2],v[a+20>>2],v[a+4>>2]);a=v[d+4>>2];e=v[a+8>>2];d=v[a+4>>2];f=v[a>>2];a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a:{b:{if(d>>>0<=y[c+4>>2]){if(Se(v[c+8>>2],v[c+12>>2])>>>0<e>>>0){break b}c:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(d|0)){b=b+1|0;continue c}else{g=Jg(f,d,a,b);h=bx(c,a,b),i=C(A[g>>3]),z[h>>2]=i;a=a+1|0;continue}}}ca(7115,9016,78,8696);L()}ca(5828,9016,80,8696);L()}fb=c+32|0}function DH(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(Le(a)){Zb(a,31);return 0}g=a,h=Le(a),t[g+1375|0]=h;d=Xi(a);b=Xi(a);Xi(a);g=a,h=Xi(a),v[g+1112>>2]=h;Xi(a);c=Le(a);v[a+1116>>2]=c;if(!Qw(a,a+1120|0,c)){Zb(a,10);return 0}v[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=v[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=d;v[a+1404>>2]=b}if(w[a+1377|0]){b=0;e=v[a+1116>>2];f=(e|0)>0?e:0;c=0;while(1){if((b|0)!=(f|0)){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;continue}break}v[a- -64>>2]=d;v[a+60>>2]=(v[a+56>>2]+(c+e|0)|0)+27}v[a+1380>>2]=0;return 1}function dw(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;g=f+8|0;Xc(g,b);v[23220]=0;b=T(1104,g|0)|0;g=v[23220];v[23220]=0;a:{if((g|0)==1){break a}v[23220]=0;X(1116,b|0,82816,82848,c|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}v[23220]=0;b=T(1105,f+8|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}v[23220]=0;c=T(1117,b|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break a}v[d>>2]=c;v[23220]=0;c=T(1114,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}v[e>>2]=c;v[23220]=0;R(1115,a|0,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break a}Wb(f+8|0);fb=f+16|0;return}a=P()|0;O()|0;Wb(f+8|0);S(a|0);L()}function aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>10&4194048;n=(((v[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){f=e+n|0;g=t[f|0];v[(e<<2)+b>>2]=((B(t[f+2|0]-g|0,m)|0)/16384|0)+(g<<8);e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],h);Ob(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;fb=b+16|0}function t_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;v[f+24>>2]=b;a:{if(!(v[c+4>>2]&1)){c=jb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+8|0;Xc(a,c);v[23220]=0;a=T(1105,a|0)|0;b=v[23220];v[23220]=0;b:{if((b|0)!=1){Wb(f+8|0);c:{if(e){Gh(f+8|0,a);break c}Fh(f+8|0,a)}g=f,h=Td(f+8|0),v[g>>2]=h;while(1){a=uk(f+8|0);b=v[f>>2];if(!Nb(b,a)){c=v[f+24>>2];Nc(f+8|0);break a}a=v[b>>2];v[23220]=0;Q(1120,f+24|0,a|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){ye(f);continue}break}c=P()|0;O()|0;Nc(f+8|0);break b}c=P()|0;O()|0;Wb(f+8|0)}S(c|0);L()}fb=f+32|0;return c|0}function fga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-48|0;fb=e;d=v[a+8>>2];c=v[a>>2];v[23220]=0;d=W(143,c|0,d|0,1)|0;c=v[23220];v[23220]=0;a:{if((c|0)==1){break a}b:{if(!d){break b}v[23220]=0;Y(459,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break a}v[23220]=0;d=T(193,a|0)|0;c=v[23220];v[23220]=0;c:{if((c|0)!=1){while(1){if(!(d&255)){break b}v[23220]=0;c=Q(460,a|0,e+8|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break c}d:{if(!c){break d}c=w[e+8|0];if(c>>>0>63){break d}nc(jS(v[b>>2],c),e+8|0,33)}d=d-1|0;continue}}break a}break a}wb(a);fb=e+48|0;return}b=P()|0;O()|0;wb(a);S(b|0);L()}function hw(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;g=f+8|0;Xc(g,b);v[23220]=0;b=T(18,g|0)|0;g=v[23220];v[23220]=0;a:{if((g|0)==1){break a}v[23220]=0;X(1102,b|0,82816,82848,c|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}v[23220]=0;b=T(1087,f+8|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}v[23220]=0;c=T(1103,b|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break a}t[d|0]=c;v[23220]=0;c=T(1100,b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}t[e|0]=c;v[23220]=0;R(1101,a|0,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break a}Wb(f+8|0);fb=f+16|0;return}a=P()|0;O()|0;Wb(f+8|0);S(a|0);L()}function gJ(a,b){var c=0,d=0;c=v[a>>2];v[a>>2]=b;if(c){v[23220]=0;Y(785,c|0);a=v[23220];v[23220]=0;a:{if((a|0)!=1){a=v[c+4>>2];if(a){if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(d|0)){b=b-4|0;fg(b);continue}break}v[a+4>>2]=d;b=v[a>>2];si(a);Fb(b)}Fb(a)}v[c+4>>2]=0;jM(c+1298408|0);qy(c+1298344|0);ub(c+1298332|0);vb(c+1298320|0);ub(c+1298308|0);py(c+1298304|0);oy(c+1298300|0);Rs(c+1298264|0);Dy(c+1074376|0);b=c+946300|0;a=c+906300|0;while(1){b=Js(b-160|0);if((a|0)!=(b|0)){continue}break}AO(c+484360|0);fM(c+484344|0);lc(c+480248|0);break a}V(0)|0;O()|0;Tb();L()}Fb(c)}}function vK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a=ji(a,b,c,d);t[a+4260|0]=e;v[a>>2]=46404;c=Ib(a+4264|0);d=Ib(a+4276|0);v[a+4328>>2]=0;b=a+4320|0;v[b>>2]=0;v[b+4>>2]=0;v[a+4312>>2]=0;v[a+4316>>2]=0;b=a+4208|0;f=zb(b,0),g=1056964608,v[f>>2]=g;f=zb(b,1),g=1036831949,v[f>>2]=g;f=zb(b,2),g=1038174126,v[f>>2]=g;f=zb(b,3),g=1065353216,v[f>>2]=g;f=zb(b,4),g=1061158912,v[f>>2]=g;f=zb(b,5),g=1059082943,v[f>>2]=g;f=zb(b,6),g=1061997773,v[f>>2]=g;v[23220]=0;R(870,a+44|0,2);b=v[23220];v[23220]=0;if((b|0)!=1){ii(a);return a|0}b=P()|0;O()|0;lc(d);lc(c);sf(a);S(b|0);L()}function Zg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=sc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=v[Cb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=fb-16|0;fb=c;b=ri(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){hc(b);fb=c+16|0}else{Wu(a);a=a+4|0;v[b+4>>2]=a;continue}break}break a}c=Cb(a);c=cg(e+8|0,Pg(a,sc(v[a>>2],d)+b|0),sc(v[a>>2],v[a+4>>2]),c);f=fb-16|0;fb=f;b=il(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){Wu(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Ed(b);fb=f+16|0;vd(a,c);bg(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Jd(a,d+(b<<2)|0)}}function aD(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;v[b+4>>2]=B(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),5)+(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24));v[b+8>>2]=(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))+((w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))<<3);v[b+12>>2]=(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))+((w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24))<<2);a=b+4|0;d=zb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=Xp(v[a>>2],v[c>>2])?c:a;continue}}fb=b+16|0;return v[a>>2]-36|0}function LY(a){a=a|0;if(w[466824]){return v[116705]}if(!w[467632]){a=467344;while(1){a=Gb(a)+12|0;if((a|0)!=467632){continue}break}t[467632]=1}ed(467344,4995);ed(467356,4986);ed(467368,10782);ed(467380,10551);ed(467392,5222);ed(467404,11626);ed(467416,5079);ed(467428,5570);ed(467440,8857);ed(467452,8840);ed(467464,8848);ed(467476,8867);ed(467488,10034);ed(467500,13229);ed(467512,8930);ed(467524,7632);ed(467536,5222);ed(467548,9723);ed(467560,10439);ed(467572,10794);ed(467584,9220);ed(467596,6424);ed(467608,5453);ed(467620,13138);t[466824]=1;v[116705]=467344;return 467344}function kda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Ib(a);a:{if(b){v[23220]=0;R(675,d|0,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break a}c=fb-16|0;fb=c;v[c>>2]=d;a=v[d+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,36);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){hc(c);fb=c+16|0}else{a=Sb(b,0,36);v[a>>2]=0;v[a+4>>2]=0;u[a+22>>1]=0;u[a+24>>1]=0;u[a+26>>1]=0;u[a+28>>1]=0;t[a+21|0]=64;t[a+19|0]=64;t[a+20|0]=100;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;v[a+8>>2]=0;v[a+12>>2]=0;u[a+30>>1]=0;u[a+32>>1]=0;b=b+36|0;v[c+4>>2]=b;continue}break}}return d|0}a=P()|0;O()|0;Fz(d);S(a|0);L()}function m$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;a:{b:{c:{if(rc(b,-1)){break c}i=c,j=rn(b),t[i+23|0]=j;if(w[a+44|0]){d=-1;if((dk(c+23|0,1,1,v[a+32>>2])|0)==1){break c}break a}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=Er(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((dk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((dk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}d=vw(b);break a}d=-1}fb=c+32|0;return d|0}function jX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;v[23220]=0;Y(919,a|0);c=v[23220];v[23220]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23220]=0;Y(920,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break d}e=v[a+24>>2];b=oc(d+8|0,b);c=v[b+4>>2];b=v[b>>2];v[23220]=0;b=UE(e,b,c,1);e=v[23220];v[23220]=0;c=ib;if((e|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,8644,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break b}$();b=0;c=0}fb=d+16|0;a=c;break a}b=P()|0;O()|0;v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Tb();L()}ra(a|0);return b|0}function hfa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=C(0),i=0,j=0,k=0,l=0,m=0;g=fb-16|0;fb=g;a:{b:{if((c|0)==(f|0)){if((b|0)!=(e|0)){break b}v[g+12>>2]=f;v[g+8>>2]=f;c=v[Eb(g+12|0,g+8|0)>>2];v[g+12>>2]=e;v[g+8>>2]=e;j=v[Eb(g+12|0,g+8|0)>>2];e=0;c:while(1){f=0;if((c|0)==(e|0)){break a}while(1)if((f|0)==(j|0)){e=e+1|0;continue c}else{k=(B(b,e)+f|0)+a|0;h=Nh(C(Ld(z[Np(d,f,e)>>2],C(-1))*C(128)));d:{if(C(D(h))<C(2147483648)){i=~~h;break d}i=-2147483648}l=k,m=DR(i),t[l|0]=m;f=f+1|0;continue}}}ca(17280,8954,27,9481);L()}ca(17230,8954,28,9481);L()}fb=g+16|0}function VQ(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1196314451){break a}c=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);if(c>>>0<1108){break a}b=a+1104|0;if((c-1108|0)!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|c>>>0>262144){break a}b=a+1094|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+1096|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-5>>>0<4294967292){break a}if(!yt(a+8|0)){break a}c=a+40|0;a=0;while(1){d=(a|0)==31;if(d){break a}b=B(a,34)+c|0;if(w[b+32|0]>15|w[b+33|0]>64){break a}a=a+1|0;if(yt(b)){continue}break}}return d}function R4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;v[23220]=0;Y(919,a|0);d=v[23220];v[23220]=0;a:{b:{c:{if((d|0)==1){break c}v[23220]=0;Y(920,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break c}d=v[a+24>>2];b=oc(e+8|0,b);f=v[b+4>>2];b=v[b>>2];v[23220]=0;da(937,d|0,b|0,f|0,(c|0)!=0|0,1);c=v[23220];v[23220]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,9966,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();b=0}fb=e+16|0;return b|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function CM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{if(v[a+480180>>2]!=1){break a}c=w[b+846|0];if(!c){break a}d=v[b+104>>2];if(!d){break a}if(!Md(v[d>>2],v[d+20>>2])){break a}f=x[d+34>>1];if(!(f&10)){break a}c=w[b+847|0]+w[(c&15)+33392|0]|0;t[b+847|0]=c;if(c<<24>>24>=0){break a}t[b+847|0]=0;h=f&2;c=v[(h?4:12)+d>>2];g=b;b=v[b+760>>2]+1|0;b=b>>>0<v[(h?8:16)+d>>2]-c>>>0?b:0;v[g+760>>2]=b;g=v[d+20>>2];c=b+c|0;b=ik(f);ec(e+8|0,g+B(c,b)|0,b);b=v[e+8>>2];f=Hb(b,v[e+12>>2]);while(1){if((b|0)==(f|0)){ij(d,a)}else{t[b|0]=w[b|0]^-1;b=b+1|0;continue}break}}fb=e+16|0}function _ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){h=v[b+12>>2]+i|0;e=t[h|0];e=((B(t[h+1|0]-e|0,v[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Ob(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;fb=b+16|0}function e$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;d=w[a+52|0];a:{if(rc(b,-1)){if(d){break a}b=v[a+48>>2];e=a,f=rc(b,-1)^1,t[e+52|0]=f;break a}b:{if(!d){break b}e=c,f=rn(v[a+48>>2]),t[e+19|0]=f;c:{d:{e:{d=c+20|0;switch(Er(v[a+36>>2],v[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((Br(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}fb=c+32|0;return b|0}function ifa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=C(0),i=0,j=0,k=0,l=0;g=fb-16|0;fb=g;a:{b:{if((c|0)==(f|0)){if((b|0)!=(e|0)){break b}v[g+12>>2]=f;v[g+8>>2]=f;i=v[Eb(g+12|0,g+8|0)>>2];v[g+12>>2]=e;v[g+8>>2]=e;j=v[Eb(g+12|0,g+8|0)>>2];e=0;c:while(1){f=0;if((e|0)==(i|0)){break a}while(1)if((f|0)==(j|0)){e=e+1|0;continue c}else{h=Nh(C(Ld(z[Np(d,f,e)>>2],C(-1))*C(32768)));d:{if(C(D(h))<C(2147483648)){c=~~h;break d}c=-2147483648}c=Rc(c);k=ER(a,b,f,e),l=c,u[k>>1]=l;f=f+1|0;continue}}}ca(17280,8954,27,9481);L()}ca(17230,8954,28,9481);L()}fb=g+16|0}function gO(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=at(b);a=Ib(a);v[23220]=0;R(735,a|0,2048);c=v[23220];v[23220]=0;a:{if((c|0)!=1){g=fb-16|0;fb=g;f=Tq(g,a,2048);c=v[f+4>>2];i=v[f+8>>2];while(1){if((c|0)==(i|0)){hc(f);fb=g+16|0}else{v[c>>2]=0;v[c+4>>2]=0;c=c+8|0;v[f+4>>2]=c;continue}break}break a}c=P()|0;O()|0;Wd(a);S(c|0);L()}while(1){b:{d=1;if((e|0)!=1024){if((e|0)==2048){break b}d=+(e-1024|0);j=at(K(d*d*-9.5367431640625e-7+1)*b);d=d*.0372006759294457;d=j*qi(d)/(h*d)}k=Ne(v[a>>2],e),l=d*.011841342921061943,A[k>>3]=l;e=e+1|0;continue}break}}function o5(a){a=a|0;var b=0;b=8003;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=21598;break a}b=8036;break a}b=17498;break a;case 0:b=4972;break a;case 9:b=8059;break a;case 10:b=8073;break a;case 11:b=5349;break a;case 12:b=5369;break a;case 19:b=8085;break a;case 20:b=8017;break a;case 21:b=12804;break a;case 22:b=12127;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=5980;break a}b=7970}return Uf(b)|0}function Zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){h=(v[b+12>>2]<<1)+i|0;e=u[h>>1];e=e+((B(u[h+2>>1]-e|0,v[b+8>>2]>>>18|0)|0)/16384|0)|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Ob(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;fb=b+16|0}function kea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;f=fb-32|0;fb=f;a:{c=v[a+12>>2];b:{if((c|0)==(b|0)){break b}d=b>>>0>c>>>0;c=B(zg(v[v[a+48>>2]+12>>2]),d?b-c|0:c-b|0);e=Ab(v[a+4>>2]);c:{if(d){e=dc(f+24|0,e);d=f+16|0;sh(d);e=v[e>>2];v[23220]=0;X(600,a|0,e|0,c|0,d|0);c=v[23220];v[23220]=0;if((c|0)!=1){break c}a=V(91480)|0;if((O()|0)!=(ea(91480)|0)){break a}_(a|0)|0;$();break b}c=dc(f+8|0,TA(e,c));e=v[dc(f,Ab(v[a+4>>2]))>>2];d=v[c>>2];c=v[a>>2];c=B(Bs(d,Ab(c)),6)+c|0;if(Nb(d,e)){Jd(a,kL(c+B(Bs(e,d),6)|0,v[a+4>>2],c))}Ab(c)}v[a+12>>2]=b}fb=f+32|0;return}S(a|0);L()}function Q4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=fb-16|0;fb=e;v[23220]=0;Y(919,a|0);d=v[23220];v[23220]=0;a:{b:{c:{if((d|0)==1){break c}v[23220]=0;Y(920,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break c}d=v[a+24>>2];b=oc(e+8|0,b);f=v[b+4>>2];b=v[b>>2];v[23220]=0;Wa(939,d|0,b|0,f|0,+c,1);d=v[23220];v[23220]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,5887,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();b=0}fb=e+16|0;return b|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Ho(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){if(!nf(w[a+11|0])){c=w[b+11|0];if(!nf(c)){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return}d=qd(b);b=xd(v[b+4>>2],c);c=fb-16|0;fb=c;a:{if(b>>>0<=10){ae(a,b);a=Fe(a,d,b);t[c+15|0]=0;bd(a+b|0,c+15|0);break a}f=a;a=Jf(w[a+11|0]);Tt(f,10,b-10|0,a,0,a,b,d)}fb=c+16|0;return}d=qd(b);b=xd(v[b+4>>2],w[b+11|0]);c=fb-16|0;fb=c;e=eB(v[a+8>>2]);b:{if(e>>>0>b>>>0){e=v[a>>2];Bd(a,b);a=Fe(e,d,b);t[c+15|0]=0;bd(a+b|0,c+15|0);break b}f=a;a=v[a+4>>2];Tt(f,e-1|0,(b-e|0)+1|0,a,0,a,b,d)}fb=c+16|0}}function N6(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=v[v[a+16>>2]+24620>>2];b=Dc(Cia(Bia(b,b>>31,3840,0),ib,1e3,0),ib);v[a+4316>>2]=b;v[23220]=0;v[c+12>>2]=0;U(876,a+4264|0,b|0,c+12|0);b=v[23220];v[23220]=0;a:{b:{c:{if((b|0)!=1){d:{if(!w[a+4260|0]){break d}b=v[a+4316>>2];v[23220]=0;v[c+12>>2]=0;U(876,a+4276|0,b|0,c+12|0);b=v[23220];v[23220]=0;if((b|0)!=1){break d}b=V(91480)|0;break c}v[c+12>>2]=0;b=c+12|0;rK(a+4288|0,b);v[c+12>>2]=0;rK(a+4300|0,b);break b}b=V(91480)|0}if((O()|0)!=(ea(91480)|0)){break a}_(b|0)|0;v[a+4316>>2]=0;$()}fb=c+16|0;return}S(b|0);L()}function ar(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;a=Gb(a);a:{b:{c:{switch(b|0){case 0:v[23220]=0;b=Q(1,d|0,15805)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}Db(a,b);vb(b);break b;case 1:v[23220]=0;b=Q(1,d|0,15830)|0;c=v[23220];v[23220]=0;if((c|0)!=1){Db(a,b);vb(b);break b}break a;case 2:v[23220]=0;b=Q(1,d|0,15778)|0;c=v[23220];v[23220]=0;if((c|0)!=1){Db(a,b);vb(b);break b}break a;case 3:break c;default:break b}}v[23220]=0;b=Q(1,d|0,15752)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}Db(a,b);vb(b)}fb=d+16|0;return}b=P()|0;O()|0;vb(a);S(b|0);L()}function Bk(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;v[a+4>>2]=0;d=4;a:{b:{c:{if(!Nd(w[fn(e+8|0,a,1)|0])){break c}d=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23220]=0;b=W(92,d|0,b|0,c|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;_(b|0)|0;d=1;en(v[v[a>>2]-12>>2]+a|0,1);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23220]=0;Z(91);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)==1){break b}S(a|0);L()}$()}tj(v[v[a>>2]-12>>2]+a|0,d);fb=e+16|0;return a}V(0)|0;O()|0;Tb()}L()}function p$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{b:{c:{if(dn(b)){break c}v[c+20>>2]=b;if(w[a+44|0]){d=-1;if((dk(c+20|0,4,1,v[a+32>>2])|0)==1){break c}break a}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=Er(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((dk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((dk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}d=dn(b)?0:b;break a}d=-1}fb=c+32|0;return d|0}function Y4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;v[23220]=0;Y(919,a|0);c=v[23220];v[23220]=0;a:{b:{c:{if((c|0)==1){break c}v[23220]=0;Y(920,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break c}c=v[a+24>>2];b=oc(d+8|0,b);f=v[b+4>>2];b=v[b>>2];v[23220]=0;e=+za(930,c|0,b|0,f|0,1);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,5924,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();e=0}fb=d+16|0;return+e}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function _4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;v[23220]=0;Y(919,a|0);c=v[23220];v[23220]=0;a:{b:{c:{if((c|0)==1){break c}v[23220]=0;Y(920,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break c}c=v[a+24>>2];b=oc(d+8|0,b);e=v[b+4>>2];b=v[b>>2];v[23220]=0;b=fa(926,c|0,b|0,e|0,1)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,9997,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();b=0}fb=d+16|0;return b|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Rr(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0;h=fb-240|0;fb=h;v[h+236>>2]=d;v[h+232>>2]=c;v[h>>2]=a;a:{b:{c:{d:{if((c|0)!=1){j=a;k=1;break d}j=a;k=1;if(d){break d}i=a;break c}while(1){i=j-v[(e<<2)+g>>2]|0;if((jb[b|0](i,a)|0)<=0){i=j;break c}e:{if(!((e|0)<2|f)){f=v[((e<<2)+g|0)-8>>2];l=j-4|0;if((jb[b|0](l,i)|0)>=0){break e}if((jb[b|0](l-f|0,i)|0)>=0){break e}}v[(k<<2)+h>>2]=i;c=pH(c,d);Sr(h+232|0,c);k=k+1|0;e=c+e|0;f=0;j=i;d=v[h+236>>2];c=v[h+232>>2];if(d|(c|0)!=1){continue}break b}break}i=j;break b}if(f){break a}}oH(h,k);Mw(i,b,e,g)}fb=h+240|0}function rH(a,b){var c=0,d=0,e=0;if(!w[462788]){d=Fa()|0;t[462788]=1;t[462789]=d}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!w[462789]){break c}e=+Ea();break a}v[115696]=28;return-1}e=+Ja()}c=e/1e3;e:{if(D(c)<0x8000000000000000){d=D(c)>=1?~~(c>0?F(H(c*2.3283064365386963e-10),4294967295):I((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;a=~~c>>>0;break e}d=-2147483648;a=0}v[b>>2]=a;c=(e-(+(Bia(a,d,1e3,0)>>>0)+ +(ib|0)*4294967296))*1e3*1e3;f:{if(D(c)<2147483648){a=~~c;break f}a=-2147483648}v[b+4>>2]=a;return 0}function DE(a,b,c,d,e,f){var g=0,h=0,i=C(0),j=0,k=0,l=0;g=fb+-64|0;fb=g;fy(v[a+24>>2]);t[v[a+24>>2]+1298420|0]=v[a+52>>2]!=0;c=Qg(g+16|0,d,c,b);d=v[c>>2];i=z[a+48>>2];j=v[c+4>>2];k=v[c+8>>2];l=v[a+32>>2];c=LI(g+32|0);v[c+12>>2]=d;v[c+8>>2]=l;v[c+4>>2]=0;v[c>>2]=f;v[c+20>>2]=k;v[c+16>>2]=j;z[c+24>>2]=i;v[c>>2]=e;while(1){if(b){d=v[a+24>>2];v[g+8>>2]=b;v[g+12>>2]=0;v[g>>2]=134217727;v[g+4>>2]=0;d=NI(d,v[Gq(g+8|0,g)>>2],c);h=d+h|0;b=b-d|0;if(d){continue}}break}if(!(v[a+52>>2]!=1|h)){a=v[a+24>>2];v[a+480208>>2]=v[a+480208>>2]&-513}fb=g- -64|0;return h}function i$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;d=w[a+52|0];a:{if(dn(b)){if(d){break a}b=v[a+48>>2];e=a,f=dn(b)^1,t[e+52|0]=f;break a}b:{if(!d){break b}v[c+16>>2]=v[a+48>>2];c:{d:{e:{d=c+20|0;switch(Er(v[a+36>>2],v[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((Br(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}fb=c+32|0;return b|0}function X7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{e=fb-48|0;fb=e;d=v[a+28>>2];Nm(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){g=v[a+28>>2];f=v[a+12>>2];h=d;d=v[a+8>>2]+d|0;f=h>>>0>d>>>0?f+1|0:f;d=ch(e+32|0,d,f);f=v[d+12>>2];v[e+8>>2]=v[d+8>>2];v[e+12>>2]=f;f=v[d+4>>2];v[e>>2]=v[d>>2];v[e+4>>2]=f;Ej(g,e)}d=e+16|0;Yd(d,v[a+28>>2]);hz(v[a+28>>2],c,v[v[b>>2]+8>>2]);b=v[b>>2];c=Rm(d,Hb(v[a+32>>2],v[b>>2]),x[b+12>>1]);v[23220]=0;Q(865,a|0,b|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){Pb(c);fb=e+48|0;break a}a=P()|0;O()|0;Pb(c);S(a|0);L()}}function KA(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=w[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!w[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=w[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=B(c>>>3|0,b);b=((d|0)==10)<<4}c=b+B(Up(w[a+1|0]),c)|0}return c}function NO(a,b){var c=0,d=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;pz(a+48|0);pz(a+68|0);pz(a+88|0);ft(a+492|0);ft(a+524|0);um(a,0,0);tm(a,0,0);v[a+40>>2]=0;v[a+44>>2]=0;It(a,b);c=a+108|0;b=0;while(1){if((b|0)!=128){d=Hb(c,b);b=b+1|0;t[d|0]=b;continue}break}return a}function Baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-16|0;fb=g;h=x[c>>1];i=c;e=fb-16|0;fb=e;f=b;d=Od(b);a:{if(d){c=fc(f);while(1){b=d;d=x[b+14>>1];if(ll(h,d)){c=b;d=v[b>>2];if(d){continue}break a}if(!ll(d,h)){break a}c=b+4|0;d=v[b+4>>2];if(d){continue}break}break a}b=fc(f);c=b}v[e+12>>2]=b;b=v[c>>2];if(!b){b=fb-16|0;fb=b;d=fc(f);d=oh(e,tc(16),ph(b+8|0,d));Ai(v[d>>2]+14|0,x[i>>1]);k=fc(d),l=1,t[k+4|0]=l;fb=b+16|0;Tg(f,v[e+12>>2],c,v[e>>2]);b=Ud(e);_k(e);j=1}c=g+8|0;Sg(c,v[dc(e,b)>>2],j);fb=e+16|0;LO(a,c);fb=g+16|0}function zC(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;v[f+8>>2]=e;v[f+12>>2]=d;Lf(a);$s(a,c);e=0;d=0;a:while(1){if(c>>>0>e>>>0){i=c-e|0;v[f+4>>2]=i;g=v[Eb(f+12|0,f+4|0)>>2];h=g+d|0;l=d>>>0>h>>>0?d:h;j=ju(mr(a,b+e|0,g),1,13);while(1)if((d|0)==(l|0)){v[f+4>>2]=i-g;d=h+1|0;e=v[Eb(f+8|0,f+4|0)>>2]+(e+g|0)|0;continue a}else{b:{c:{d:{k=t[Fc(j,d)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=Fc(j,d),n=32,t[m|0]=n}d=d+1|0;continue}}break}fb=f+16|0}function tha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;g=x[el(v[a>>2],v[a+4>>2],b)>>1];a:{b:{if(!iq(a,b)){break b}c=v[a+24>>2];d=Ab(v[c+484360>>2]);v[f+8>>2]=d;h=Ab(v[c+484364>>2]);while(1){if(!Nb(d,h)){break b}e=0;i=al(v[d>>2],v[d+4>>2]);c:{while(1){if((e|0)!=(i|0)){if(!(!((a|0)!=(d|0)|(b|0)!=(e|0))|x[ac(v[d>>2],e)>>1]!=(g|0))){c=bR(v[a+24>>2]+484344|0,g);if((c|0)!=65535){break c}}e=e+1|0;continue}break}d=v[lz(f+8|0)>>2];continue}break}j=el(v[a>>2],v[a+4>>2],b),k=c,u[j>>1]=k;break a}c=g}fb=f+16|0;return c&65535}function Q3(a){a=a|0;var b=0,c=0;v[23220]=0;Y(919,a|0);b=v[23220];v[23220]=0;if((b|0)!=1){a=v[a+24>>2];b=v[a+24>>2];c=x[b+1074448>>1];a:{if(c>>>0>=hj(Vb(v[b+484360>>2],w[b+484376|0]))>>>0){a=x[v[a+24>>2]+1074446>>1];break a}a=v[a+24>>2];b=x[ac(v[Vb(v[a+484360>>2],w[a+484376|0])>>2],c)>>1];a=om(v[a+484344>>2],v[a+484348>>2],b)?b:-1}return a|0}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,9727,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function uM(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=(d^c)-d|0;if(d>>>0<224){break c}xb(e+8|0,a+1074312|0,3);if(yb(v[v[e+8>>2]>>2],v[e+12>>2])){break c}if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,872)+a|0)+1075843|0]&1){xb(e+8|0,a+1074312|0,3);if(!yb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}}c=c<<2}if(!c){break a}f=B(b,872)+a|0;d=v[f+1075648>>2];a=Ls(a,v[f+1075080>>2],d);if(!a){break a}jb[v[v[a>>2]+84>>2]](a,c,(d?w[d+33|0]:13)<<24>>24,b)}fb=e+16|0}function YH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;a:{b:{c:{a=v[a+32>>2];e=ks(a);d:{if(!e){if(js(a)>>>0<=b>>>0){break d}a=Xj(a,b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<e>>>0){break c}}a=aa(8)|0;v[23220]=0;b=Q(52,d|0,5961)|0;c=v[23220];v[23220]=0;e:{if((c|0)!=1){a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}c=P()|0;O()|0;ub(b);break e}c=P()|0;O()|0;ba(a|0)}S(c|0);L()}a=v[(a+(b<<2)|0)+900384>>2];if(!a){break b}t[a+15|0]=w[a+15|0]&253|(c?2:0)}fb=d+16|0;return}L()}function q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-208|0;fb=e;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;kM(a+946304|0);d=e+48|0;Sb(d,0,160);d=pM(d);v[23220]=0;f=a+906300|0;U(792,f|0,f+4e4|0,d|0);f=v[23220];v[23220]=0;a:{if((f|0)!=1){Js(d);d=fe(e+24|0,b);v[23220]=0;f=v[d+12>>2];v[e+8>>2]=v[d+8>>2];v[e+12>>2]=f;v[e+16>>2]=v[d+16>>2];f=v[d+4>>2];v[e>>2]=v[d>>2];v[e+4>>2]=f;a=W(793,a|0,e|0,c|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){a=P()|0;O()|0;break a}wb(b);fb=e+208|0;return a|0}a=P()|0;O()|0;Js(d)}wb(b);S(a|0);L()}function Tw(a,b,c){var d=0,e=0,f=C(0),g=C(0),h=C(0),i=C(0),j=0,k=C(0),l=C(0),m=C(0);e=fb-32|0;fb=e;g=z[a+24>>2];f=z[a+12>>2];h=z[a+48>>2];i=z[a+36>>2];HH(C(-z[a>>2]),C(g+f),C(h+i),e+20|0);HH(z[a+60>>2],C(h-i),C(g-f),e+8|0);z[e+12>>2]=-z[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;j=d+c|0;g=z[j>>2];f=z[d+(e+20|0)>>2];h=z[d+70320>>2];i=z[d+70332>>2];k=z[d+(e+8|0)>>2];z[j>>2]=C(f*h)-C(i*k);j=b+d|0;l=z[(0-a<<2)+70328>>2];d=5-a<<2;m=z[d+70320>>2];f=C(C(f*i)+C(k*h));z[j>>2]=C(g*l)-C(m*f);z[b+d>>2]=C(g*m)+C(f*l);a=a+1|0;continue}break}fb=e+32|0}function Y7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=fb-48|0;fb=f;e=v[a+28>>2];Nm(v[v[e>>2]-12>>2]+e|0,0);e=v[v[b>>2]+4>>2];if(e){h=v[a+28>>2];g=v[a+12>>2];i=e;e=v[a+8>>2]+e|0;g=i>>>0>e>>>0?g+1|0:g;e=ch(f+32|0,e,g);g=v[e+12>>2];v[f+8>>2]=v[e+8>>2];v[f+12>>2]=g;g=v[e+4>>2];v[f>>2]=v[e>>2];v[f+4>>2]=g;Ej(h,f)}e=f+16|0;Yd(e,v[a+28>>2]);TK(d,v[a+28>>2],c);b=v[b>>2];c=Rm(e,Hb(v[a+32>>2],v[b>>2]),x[b+12>>1]);v[23220]=0;Q(865,a|0,b|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){Pb(c);fb=f+48|0;return}a=P()|0;O()|0;Pb(c);S(a|0);L()}function W7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=fb-48|0;fb=f;e=v[a+28>>2];Nm(v[v[e>>2]-12>>2]+e|0,0);e=v[v[b>>2]+4>>2];if(e){h=v[a+28>>2];g=v[a+12>>2];i=e;e=v[a+8>>2]+e|0;g=i>>>0>e>>>0?g+1|0:g;e=ch(f+32|0,e,g);g=v[e+12>>2];v[f+8>>2]=v[e+8>>2];v[f+12>>2]=g;g=v[e+4>>2];v[f>>2]=v[e>>2];v[f+4>>2]=g;Ej(h,f)}e=f+16|0;Yd(e,v[a+28>>2]);QK(c,v[a+28>>2],d);b=v[b>>2];c=Rm(e,Hb(v[a+32>>2],v[b>>2]),x[b+12>>1]);v[23220]=0;Q(865,a|0,b|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){Pb(c);fb=f+48|0;return}a=P()|0;O()|0;Pb(c);S(a|0);L()}function Pn(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0;d=x[a+24>>1];b=c+(d<<2)|0;v[a+40>>2]=((b&3)<<4)+27824;e=b>>>2|0;b=b>>>0<48;f=b?12-e|0:0;u[a+32>>1]=f;u[a+36>>1]=b?1:1<<e-12;u[a+34>>1]=-1<<f^-1;if((d|0)==15){u[a+36>>1]=4095}b=c+(x[a+26>>1]<<2)|0;v[a+52>>2]=((b&3)<<4)+27824;d=b>>>2|0;b=b>>>0<48;e=b?12-d|0:0;u[a+44>>1]=e;c=c+(x[a+30>>1]<<2)|0;v[a+64>>2]=((c&3)<<4)+27824;f=c>>>2|0;c=c>>>0<48;g=c?12-f|0:0;u[a+56>>1]=g;u[a+48>>1]=b?1:1<<d-12;u[a+60>>1]=c?1:1<<f-12;u[a+46>>1]=-1<<e^-1;u[a+58>>1]=-1<<g^-1}function aQ(a,b,c,d,e){var f=0;f=w[(w[a+3|0]&15)+27024|0];t[a+3|0]=f;a:{b:{switch(f-11|0){case 0:b=w[a+5|0];c=b&15;if(c){t[a+5|0]=c;return}t[a+5|0]=b&240;return;case 3:c=w[a+5|0];c=B(c&240,10)|c&15;t[a+5|0]=c;f=c&255;c=x[d>>1];if(!(f|(c|0)==65535)){t[a+5|0]=c;t[a+3|0]=12;u[d>>1]=65535}uc(e,b);return;case 1:u[d>>1]=w[a+5|0];v[e>>2]=63;t[a+3|0]=0;return;case 5:b=w[a+5|0];if(c>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|B(c,-10)+b;t[a+5|0]=b}if(b&255){break a}t[a+3|0]=0;return;case 7:break a;default:break b}}if(w[a+5|0]){break a}t[a+3|0]=0}}function Sd(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;v[b+4>>2]=1098;v[b>>2]=a;v[b+8>>2]=0;d=fb-16|0;fb=d;if(v[a>>2]!=-1){a:{c=dc(d,uf(d+8|0,b));while(1){if(v[a>>2]==1){continue}break}b:{if(!v[a>>2]){td(a,1);c=v[v[c>>2]>>2];v[23220]=0;Y(1099,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}v[a>>2]=-1}break a}b=V(0)|0;O()|0;_(b|0)|0;td(a,0);v[23220]=0;Z(91);a=v[23220];v[23220]=0;c:{if((a|0)==1){a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){break c}V(0)|0;O()|0;Tb()}L()}S(a|0);L()}}fb=d+16|0;fb=b+16|0;return v[a+4>>2]-1|0}function r8(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=Ib(a);b:{c:{c=$j(v[b>>2],v[b+4>>2]);if(c){v[23220]=0;R(403,a|0,c|0);d=v[23220];v[23220]=0;if((d|0)==1){break c}Qx(a,v[b>>2],v[b+4>>2],c)}break b}b=P()|0;O()|0;qh(a);S(b|0);L()}v[a+20>>2]=v[b+20>>2];c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;v[23220]=0;c=Q(850,a+24|0,b+24|0)|0;d=v[23220];v[23220]=0;d:{e:{if((d|0)!=1){v[23220]=0;Q(51,a+36|0,b+36|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break e}v[a+48>>2]=v[b+48>>2];break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;lc(c)}qh(a);S(b|0);L()}}function Nba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){e=(v[b+12>>2]<<1)+i|0;f=v[b+8>>2]>>>21&2040;e=(((B(u[e>>1],u[f+39874>>1])+B(u[e-2>>1],u[f+39872>>1])|0)+B(u[e+2>>1],u[f+39876>>1])|0)+B(u[e+4>>1],u[f+39878>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Ob(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;fb=b+16|0}function P8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{f=fb-32|0;fb=f;a=Ib(a);b:{c:{d:{e:{while(1){e=v[b+8>>2];g=v[b>>2];v[23220]=0;e=W(143,g|0,e|0,8)|0;g=v[23220];v[23220]=0;if((g|0)==1){break c}if(e){v[23220]=0;U(838,f|0,b|0,c|0);e=v[23220];v[23220]=0;if((e|0)==1){break e}v[23220]=0;R(839,a|0,f|0);e=v[23220];v[23220]=0;if((e|0)==1){break d}Id(f);e=zQ(v[a+4>>2]);wi(f,v[e>>2],v[e+4>>2]);if(v[f>>2]!=(d|0)){continue}}break}fb=f+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;Id(f);break b}b=P()|0;O()|0}Vd(a);S(b|0);L()}}function FK(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0;Cx(a);c=Ld(c,C(0));a:{switch(b|0){case 0:z[a+4220>>2]=c;return;case 1:z[a+4224>>2]=c;return;case 2:z[a+4228>>2]=c;vs(a);return;case 3:t[a+4240|0]=c>=C(.5);vs(a);return;case 4:b=fb-16|0;fb=b;e=b,f=Lh(C(c*C(32))),v[e+12>>2]=f;v[b+8>>2]=0;v[b+4>>2]=5;d=v[uj(b+12|0,b+8|0,b+4|0)>>2];fb=b+16|0;v[a+4232>>2]=d;return;case 5:t[a+4241|0]=c>=C(.5);return;case 6:t[a+4242|0]=c>=C(.5);return;case 7:t[a+4244|0]=c>=C(.5);return;case 8:if(c==C(0)){Ax(a)}A[a+4256>>3]=c;break;default:break a}}}function YZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-416|0;fb=h;d=h+416|0;v[h+12>>2]=d;c=fb-144|0;fb=c;v[c+28>>2]=c+132;i=c+32|0;FF(v[a+8>>2],i,c+28|0,e,f,g);v[c+16>>2]=0;v[c+20>>2]=0;v[c+12>>2]=i;e=h+16|0;g=sc(e,v[h+12>>2]);f=fb-16|0;fb=f;i=$h(f+8|0,v[a+8>>2]);a=gG(e,c+12|0,g,c+16|0);_h(i);fb=f+16|0;if((a|0)==-1){Ar(12567);L()}v[h+12>>2]=(a<<2)+e;fb=c+144|0;c=v[h+12>>2];a=fb-16|0;fb=a;v[a+8>>2]=b;while(1){if((c|0)!=(e|0)){IG(a+8|0,v[e>>2]);e=e+4|0;continue}break}fb=a+16|0;fb=d;return v[a+8>>2]}function W8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-48|0;fb=d;c=d+24|0;qj(c,b,1819307379);Yc(a+40|0,c);wb(c);qj(c,b,1953721961);Yc(a+60|0,c);wb(c);qj(c,b,543520099);Yc(a+120|0,c);wb(c);qj(c,b,1414744396);v[23220]=0;c=Q(355,c|0,13744)|0;e=v[23220];v[23220]=0;a:{if((e|0)!=1){b:{if(c){v[23220]=0;U(742,d|0,d+24|0,2);c=v[23220];v[23220]=0;if((c|0)==1){break b}wt(a+140|0,d);Vd(d)}v[23220]=0;U(743,d|0,b|0,1634890872);b=v[23220];v[23220]=0;if((b|0)!=1){break a}}}a=P()|0;O()|0;wb(d+24|0);S(a|0);L()}Yc(a+80|0,d);wb(d);wb(d+24|0);fb=d+48|0}function DV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;v[c+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[c+8>>2]=16384;d=v[Eb(c+12|0,c+8|0)>>2];v[a+1072>>2]=d;v[c+4>>2]=17;while(1){a:{if(!d){break a}e=v[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=jk(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Mq(c+4|0,jk(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}Mq(c+4|0,d-e|0);break b}PC(a,d,f,b);break b}e=d&(f^-1);if(d&f){v[c+4>>2]=e+1;break b}PC(a,e,0,b)}d=v[a+1072>>2];continue}break}fb=c+16|0}function YL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;v[e+12>>2]=16777216;h=e+12|0;d=v[a>>2];c=sc(d,v[a+4>>2]);a:{if(c>>>0<b>>>0){f=fb-32|0;fb=f;b=b-c|0;c=v[Cb(a)>>2];d=v[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){kC(a,b,h);break b}c=Cb(a);c=cg(f+8|0,Pg(a,sc(v[a>>2],d)+b|0),sc(v[a>>2],v[a+4>>2]),c);g=fb-16|0;fb=g;b=il(g,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){Kp(d,v[h>>2]);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Ed(b);fb=g+16|0;vd(a,c);bg(c)}fb=f+32|0;break a}if(b>>>0<c>>>0){Jd(a,d+(b<<2)|0)}}jy(a);fb=e+16|0}function CV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;v[c+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[c+8>>2]=32768;d=v[Eb(c+12|0,c+8|0)>>2];v[a+1072>>2]=d;v[c+4>>2]=9;while(1){a:{if(!d){break a}e=v[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=jk(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Mq(c+4|0,jk(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}Mq(c+4|0,d-e|0);break b}OC(a,d,f,b);break b}e=d&(f^-1);if(d&f){v[c+4>>2]=e+1;break b}OC(a,e,0,b)}d=v[a+1072>>2];continue}break}fb=c+16|0}function uea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=Kf(c+48|0);v[23220]=0;e=Q(587,b|0,d|0)|0;f=v[23220];v[23220]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23220]=0;T(588,a|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break a}}break c}e=v[d+4>>2];v[23220]=0;U(177,c|0,b|0,(e>>>0<9?0:e-8|0)|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Id(d);S(a|0);L()}b=gc(c+24|0,c);Yc(d+8|0,b);wb(b);wb(c);bl(a,d)}Id(d);fb=c+80|0}function cia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;kd(b,0);g=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=g;e=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);v[b+12>>2]=e;f=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);v[b+16>>2]=f;c=w[a+12|0]|w[a+13|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;c=w[a+14|0];u[b+30>>1]=c?c+1|0:256;d=x[b+34>>1]&32767|!w[a+14|0]<<15;u[b+34>>1]=d;c=w[a+15|0];if(!(!(c&1)|e>>>0>=f>>>0)){d=d|8;u[b+34>>1]=d;c=w[a+15|0]}if(c&2){v[b+16>>2]=f>>>1;v[b+12>>2]=e>>>1;v[b>>2]=g>>>1;u[b+34>>1]=d|1}}function Oba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){e=v[b+12>>2]+i|0;f=v[b+8>>2]>>>21&2040;e=(((B(t[e|0],u[f+39874>>1])+B(t[e-1|0],u[f+39872>>1])|0)+B(t[e+1|0],u[f+39876>>1])|0)+B(t[e+2|0],u[f+39878>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Ob(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;fb=b+16|0}function K3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb-32|0;fb=b;a:{b:{if(Nb(v[a+36>>2],v[a+40>>2])){mf(b+24|0);break b}c=b+8|0;qn(c,a);v[23220]=0;c=T(978,c|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break a}v[b+24>>2]=c;Tf(b+8|0)}c=(f=a+36|0,g=v[b+24>>2],h=Nb(v[a+36>>2],v[a+40>>2]),h?f:g);a=v[a+8>>2];c:{if((a|0)==-1){f=b,g=Ab(v[c>>2]),v[f+8>>2]=g;a=Ab(v[c+4>>2]);while(1){c=v[b+8>>2];if(!Nb(c,a)){break c}d=d+A[c>>3];pI(b+8|0);continue}}d=A[Zk(v[c>>2],a)>>3]}Fk(b+24|0);fb=b+32|0;return+d}a=P()|0;O()|0;Tf(b+8|0);S(a|0);L()}function Ti(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?E(c):E(d)+32|0;vf(f,d,e,0,0,c+49|0);i=v[f>>2];h=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=i;v[a+4>>2]=h;v[a+8>>2]=c;v[a+12>>2]=g&-2147483648|d;fb=f+16|0}function o3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0);v[23220]=0;Y(919,a|0);d=v[23220];v[23220]=0;a:{if((d|0)==1){break a}v[23220]=0;Y(990,c|0);d=v[23220];v[23220]=0;if((d|0)==1){break a}d=v[a+24>>2];e=z[d+48>>2];d=v[d+24>>2];v[23220]=0;b=Va(991,d|0,C(e),b|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,10314,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function gV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;kd(b,0);Sh(d,1,a+33|0);e=d+16|0;Ac(e,d);ue(b+43|0,e);ub(e);f=w[a+50|0]|w[a+51|0]<<8|(w[a+52|0]<<16|w[a+53|0]<<24);v[b>>2]=f;v[b+24>>2]=w[a+54|0]|w[a+55|0]<<8;t[d+16|0]=w[a+56|0];t[d|0]=64;h=b,i=w[Rb(e,d)|0]<<2,u[h+30>>1]=i;e=w[a+57|0]|w[a+58|0]<<8|(w[a+59|0]<<16|w[a+60|0]<<24);v[b+4>>2]=e;g=w[a+61|0]|w[a+62|0]<<8|(w[a+63|0]<<16|w[a+64|0]<<24);c=c?e?f:g:g;v[b+8>>2]=c;if(!(!w[a|0]|c>>>0<=e+2>>>0|c>>>0>f>>>0)){u[b+34>>1]=x[b+34>>1]|2}fb=d+32|0}function Vfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=Kf(c+48|0);v[23220]=0;e=Q(464,b|0,d|0)|0;f=v[23220];v[23220]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23220]=0;T(465,a|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break a}}break c}e=x[d+2>>1]|x[d+4>>1]<<16;v[23220]=0;U(177,c|0,b|0,e|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Id(d);S(a|0);L()}b=gc(c+24|0,c);Yc(d+8|0,b);wb(b);wb(c);cS(a,d)}Id(d);fb=c+80|0}function $3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;e=Ib(a);a=0;a:{b:{c:{d:{e:{while(1){d=v[b+24>>2];if(x[d+480188>>1]<=a>>>0){break a}v[23220]=0;R(974,c|0,(d+(a<<5)|0)+480289|0);d=v[23220];v[23220]=0;if((d|0)!=1){d=v[b+24>>2];v[23220]=0;U(975,c+16|0,d|0,c|0);d=v[23220];v[23220]=0;if((d|0)==1){break e}v[23220]=0;R(170,e|0,c+16|0);d=v[23220];v[23220]=0;if((d|0)==1){break d}a=a+1|0;ub(c+16|0);ub(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;ub(c+16|0)}ub(c)}De(e);S(a|0);L()}fb=c+32|0}function qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;f=v[a+24>>2];g=v[a+20>>2];h=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;i=v[a+8>>2];j=v[a+12>>2];while(1){if(d){k=((((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&2147483646)<<1)+h|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=u[(e<<1)+k>>1];e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],g);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f);Ob(b+8|0,i,j);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;fb=b+16|0}function dy(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;xb(e+8|0,a+1074312|0,21);a:{if(yb(v[v[e+8>>2]>>2],v[e+12>>2])){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+33600|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=EL(En(a))+-64|0;break a}d=t[(c>>>1&31)+32112|0];if(x[a+480182>>1]&1032){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+33472|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+33536|0]}a=d;fb=e+16|0;return a}function X9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;v[d+12>>2]=b;if(b>>>0<1073741808){h=d,i=Bb(a),v[h+8>>2]=i;e=xl(v[Sc(d+12|0,d+8|0)>>2]);if((e|0)!=(To(a)|0)){a:{f=1;c=To(a);g=Bb(a);b:{if((e|0)==1){b=a;c=v[a>>2];break b}b=e+1|0;c:{if(c>>>0<e>>>0){b=pi(b);break c}v[23220]=0;b=T(1178,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;$();break a}f=ve(a);c=pc(a)}bi(b,c,Bb(a)+1|0);if(f){Fb(c)}if((e|0)!=1){yf(a,e+1|0);Bd(a,g);td(a,b);break a}ae(a,g)}}fb=d+16|0;return}kf();L()}function L9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;f=Gb(a);a=0;a:{b:{c:{d:{while(1){d=v[b>>2];if(rd(d,v[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=Dd(d,0);break e}v[23220]=0;Q(772,f|0,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}d=Dd(v[b>>2],a)}v[23220]=0;R(773,e|0,d|0);d=v[23220];v[23220]=0;if((d|0)!=1){v[23220]=0;Q(772,f|0,e|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break d}a=a+1|0;ub(e);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;ub(e);break a}fb=e+16|0;return}a=P()|0;O()|0}ub(f);S(a|0);L()}function zW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;f=Gb(a);a=0;a:{b:{c:{d:{while(1){d=v[b>>2];if(rd(d,v[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=Dd(d,0);break e}v[23220]=0;Q(85,f|0,c|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break b}d=Dd(v[b>>2],a)}v[23220]=0;R(140,e|0,d|0);d=v[23220];v[23220]=0;if((d|0)!=1){v[23220]=0;Q(85,f|0,e|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break d}a=a+1|0;vb(e);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e);break a}fb=e+16|0;return}a=P()|0;O()|0}vb(f);S(a|0);L()}function l5(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;a:{b:{if(!a){a=Uf(21598);break b}v[23220]=0;c=Q(52,b|0,a|0)|0;a=v[23220];v[23220]=0;c:{d:{if((a|0)!=1){v[23220]=0;R(905,b+16|0,c|0);a=v[23220];v[23220]=0;if((a|0)==1){break d}d=b+16|0;a=Uf(Ec(d));ub(d);ub(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;ub(c)}_(a|0)|0;a=0;v[23220]=0;X(906,10922,0,0,0);c=v[23220];v[23220]=0;if((c|0)==1){break a}$()}fb=b+32|0;return a|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function $s(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-16|0;fb=c;v[c+12>>2]=b;if(b>>>0<4294967280){h=c,i=Bb(a),v[h+8>>2]=i;d=Qh(v[Sc(c+12|0,c+8|0)>>2]);if((d|0)!=(Qc(a)|0)){a:{f=Bb(a);b:{if((d|0)==10){g=1;b=a;e=v[a>>2];break b}b=d+1|0;c:{if(Qc(a)>>>0<d>>>0){b=tc(b);break c}v[23220]=0;b=T(49,b|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;$();break a}g=ve(a);e=pc(a)}b=Fe(b,e,Bb(a)+1|0);if(g){Fb(e)}if((d|0)!=10){yf(a,d+1|0);Bd(a,f);td(a,b);break a}ae(a,f)}}fb=c+16|0;return}kf();L()}function gea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=fb-32|0;fb=d;a=Ib(a);b:{c:{d:{e:{while(1){c=v[b+8>>2];e=v[b>>2];v[23220]=0;c=W(143,e|0,c|0,8)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}if(c){v[23220]=0;R(617,d|0,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break e}v[23220]=0;R(618,a|0,d|0);c=v[23220];v[23220]=0;if((c|0)==1){break d}Id(d);c=zQ(v[a+4>>2]);wi(d,v[c>>2],v[c+4>>2]);if(v[d>>2]!=1413891155){continue}}break}fb=d+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;Id(d);break b}b=P()|0;O()|0}Vd(a);S(b|0);L()}}function Ut(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;v[g+12>>2]=0;v[g+8>>2]=a;i=fb-16|0;fb=i;b=cc(i+8|0,v[g+8>>2],v[g+12>>2]);e=fb-16|0;fb=e;d=117;v[e+12>>2]=117;c=v[b+4>>2];a:{if(!c){c=v[b>>2];break a}f=32-c|0;v[e+8>>2]=f;d=v[b>>2];j=v[d>>2];h=f;f=v[Eb(e+8|0,e+12|0)>>2];v[d>>2]=(-1<<c&-1>>>h-f^-1)&j;j=v[e+12>>2];c=d+4|0;v[b>>2]=c;d=j-f|0}h=c;c=d>>>5<<2;Sb(h,0,c);f=d&31;v[e+12>>2]=f;if((d&-32)!=(d|0)){h=b;b=c+v[b>>2]|0;v[h>>2]=b;v[b>>2]=v[b>>2]&(-1>>>32-f^-1)}fb=e+16|0;fb=i+16|0;fb=g+16|0;return a}function v5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;t[a+4202|0]=1;c=kj(C(C(y[v[a+16>>2]+24620>>2])*C(.04500000178813934)));d=kj(C(C(c>>>0)*C(1.1892070770263672)));e=kj(C(C(d>>>0)*C(1.1892070770263672)));h=kj(C(C(e>>>0)*C(1.1892070770263672)));f=kj(C(C(c+e>>>0)*C(.11546666920185089)));g=kj(C(C(d+h>>>0)*C(.11546666920185089)));b=a+4272|0;i=zb(b,0),j=c-f|0,v[i>>2]=j;i=zb(b,1),j=e-f|0,v[i>>2]=j;i=zb(b,2),j=d-g|0,v[i>>2]=j;i=zb(b,3),j=h-g|0,v[i>>2]=j;i=zb(b,4),j=f,v[i>>2]=j;i=zb(b,5),j=g,v[i>>2]=j;TJ(a);SJ(a)}function s8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;v[f+12>>2]=b;a:{if(Hs(a)>>>0>=b>>>0){e=v[a>>2];g=ek(e,v[a+4>>2]);v[f+8>>2]=g;d=v[Eb(f+12|0,f+8|0)>>2];while(1){if(d){d=d-1|0;e=iL(e,c)+52|0;continue}break}if(b>>>0>g>>>0){Ox(a,b-g|0,c);break a}gL(a,v[a>>2]+B(b,52)|0);break a}if(v[a>>2]){Is(a);d=v[a>>2];Hs(a);Fb(d);h=Cb(a),i=0,v[h>>2]=i;v[a>>2]=0;v[a+4>>2]=0}d=fL(a,b);if(Ah(82595524)>>>0<d>>>0){od();L()}e=eL(d);v[a>>2]=e;v[a+4>>2]=e;h=Cb(a),i=e+B(d,52)|0,v[h>>2]=i;Ox(a,b,c)}fb=f+16|0}function d9(a){a=a|0;var b=0,c=0;b=32208;a=Ib(a);a:{b:{while(1){c:{if((b|0)==32784){b=32784;break c}d:{c=v[a+4>>2];if(!rc(v[a>>2],c)){if(!bj(v[b+8>>2],v[zn(c)>>2])){break d}}v[23220]=0;R(816,a|0,b+8|0);c=v[23220];v[23220]=0;if((c|0)!=1){break d}break b}b=b+12|0;continue}break}while(1){if((b|0)==32832){break a}e:{c=v[a+4>>2];f:{if(!rc(v[a>>2],c)){if(!bj(v[b+8>>2],v[zn(c)>>2])){break f}}v[23220]=0;R(816,a|0,b+8|0);c=v[23220];v[23220]=0;if((c|0)==1){break e}}b=b+12|0;continue}break}}b=P()|0;O()|0;lc(a);S(b|0);L()}}function sga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[a+4>>2]!=v[Cb(a)>>2]){c=fb-16|0;fb=c;a=xv(c,a);d=v[a+4>>2];v[23220]=0;R(443,d|0,b|0);b=v[23220];v[23220]=0;a:{if((b|0)!=1){v[a+4>>2]=v[a+4>>2]+12;hc(a);fb=c+16|0;break a}b=P()|0;O()|0;hc(a);S(b|0);L()}return}d=fb-32|0;fb=d;c=Cb(a);c=kk(d+8|0,Jm(a,rd(v[a>>2],v[a+4>>2])+1|0),rd(v[a>>2],v[a+4>>2]),c);e=v[c+8>>2];v[23220]=0;R(443,e|0,b|0);b=v[23220];v[23220]=0;b:{if((b|0)!=1){v[c+8>>2]=v[c+8>>2]+12;er(a,c);wv(c);fb=d+32|0;break b}a=P()|0;O()|0;wv(c);S(a|0);L()}}function zX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Eg(a,v[b+8>>2],e)){Vv(b,c,d);return}a:{if(Eg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];jb[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];jb[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function yM(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}e=v[a+480180>>2];b=e&1048580?(b&240?-16:15)&b:b;c=b&240;f=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=f>>>3&30;break d}g=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!g){break b}b=0-(b<<1)|0;break c}if(g){break b}if(c){if(b?e&59314208:0){break b}b=f>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}a=a+1074456|0;v[d+12>>2]=v[a>>2]+(b<<!(e&59314208));ee(d+12|0,0,256);v[a>>2]=v[d+12>>2]}fb=d+16|0}function XH(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;a:{b:{c:{a=v[a+32>>2];c=ks(a);d:{if(!c){if(js(a)>>>0<=b>>>0){break d}c=(w[Xj(a,b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<c>>>0){break c}}a=aa(8)|0;v[23220]=0;b=Q(52,d|0,5961)|0;c=v[23220];v[23220]=0;e:{if((c|0)!=1){a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}c=P()|0;O()|0;ub(b);break e}c=P()|0;O()|0;ba(a|0)}S(c|0);L()}a=v[(a+(b<<2)|0)+900384>>2];c=1;if(!a){break b}c=(w[a+15|0]&2)>>>1|0}fb=d+16|0;return c|0}L()}function HO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=b?33:32;c=w[a+16|0];k=c?-1:1;l=c?1:-1;e=v[a+8>>2]-1|0;m=c?e-(w[a+17|0]!=0&(e|0)!=0)|0:0;f=v[a+12>>2];n=(f|0)>0?f:0;o=c?0:e;h=v[a>>2]+B(f,62)|0;d=b?1:-1;p=B(f,d)<<1;c=e;a:while(1){if((i|0)!=(j|0)){g=B(c,f);q=v[a+4>>2];b=0;while(1)if((b|0)==(n|0)){b:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break b}}b=c+d|0;c=!c&(d|0)<0;b=c?o:b;g=c?l:d}h=h+p|0;i=i+1|0;c=b;d=g;continue a}else{u[(b<<1)+h>>1]=x[q+(b+g<<1)>>1];b=b+1|0;continue}}break}}function Z3(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;e=Ib(a);Kd(c+24|0);a=0;b=v[c+28>>2];d=v[c+24>>2];v[23220]=0;R(168,e|0,mI(d,b)|0);b=v[23220];v[23220]=0;a:{if((b|0)!=1){b:{while(1){b=v[c+24>>2];if((mI(b,v[c+28>>2])|0)<=(a|0)){fb=c+32|0;return}b=v[b+(a<<3)>>2];v[23220]=0;b=Q(52,c+8|0,b|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){v[23220]=0;R(170,e|0,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break b}ub(b);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;ub(b);break a}a=P()|0;O()|0}De(e);S(a|0);L()}function Yda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=Kf(c+48|0);v[23220]=0;e=Q(623,b|0,d|0)|0;f=v[23220];v[23220]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23220]=0;T(624,a|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break a}}break c}e=v[d+4>>2];v[23220]=0;U(177,c|0,b|0,e|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Id(d);S(a|0);L()}b=gc(c+24|0,c);Yc(d+8|0,b);wb(b);wb(c);bl(a,d)}Id(d);fb=c+80|0}function $F(a,b,c,d){var e=0,f=0,g=0;f=fb-16|0;fb=f;a:{b:{if((a|0)!=(b|0)){c:{g=v[115696];v[115696]=0;wd();d=eG(a,f+12|0,d);e=ib;d:{a=v[115696];if(a){if(v[f+12>>2]!=(b|0)){break c}if((a|0)!=68){break d}v[c>>2]=4;a=2147483647;if(!!d&(e|0)>=0|(e|0)>0){break a}break b}v[115696]=g;if(v[f+12>>2]==(b|0)){break d}break c}if((e|0)<0&d>>>0<=2147483647|(e|0)<-1){v[c>>2]=4;break b}if((e|0)>=0&d>>>0>=2147483648|(e|0)>0){v[c>>2]=4;a=2147483647;break a}a=d;break a}}v[c>>2]=4;a=0;break a}a=-2147483648}fb=f+16|0;return a}function rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;f=v[a+24>>2];g=v[a+20>>2];h=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;i=v[a+8>>2];j=v[a+12>>2];while(1){if(d){k=(((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&-2)+h|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=t[e+k|0]<<8;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],g);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f);Ob(b+8|0,i,j);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;fb=b+16|0}function SH(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-32|0;fb=d;A[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[23220]=0;d=Q(52,d+8|0,10667)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}a=qc(b,d);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ub(d);break b}a=v[a+32>>2];v[d+8>>2]=0;v[d+12>>2]=-1074790400;v[d>>2]=0;v[d+4>>2]=1072693248;e=(a+B(b,872)|0)+1075684|0,f=Xl(A[ug(d+24|0,d+8|0,d)>>3]*128+128),v[e>>2]=f;fb=d+32|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function MC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=w[a+8|0];h=v[a>>2];e=v[a+4>>2];f=Ec(b);a=Bb(b);b=fb-16|0;fb=b;v[b+8>>2]=a;v[b+12>>2]=e;a=h;g=v[Eb(b+12|0,b+8|0)>>2];c=g;while(1){a:{if(!c){c=0;break a}i=w[f|0];t[a|0]=i;if(!i){break a}f=f+1|0;a=a+1|0;c=c-1|0;continue}break}b:{if((d-1&255)>>>0<=1){t[b+7|0]=0;Jl(a,((a+e|0)-g|0)+c|0,b+7|0);break b}if((d-3&255)>>>0>1){break b}t[b+6|0]=32;Jl(a,((a+e|0)-g|0)+c|0,b+6|0)}c:{switch(d-1|0){case 0:case 3:t[(v[b+12>>2]+h|0)-1|0]=0;break;default:break c}}fb=b+16|0}function Yea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-608|0;fb=f;b=fb-16|0;fb=b;d=f+8|0;kR(b+8|0,d);c=v[b+12>>2];hd(b,a,v[b+8>>2],c);e=v[b+4>>2];if((e|0)==(c|0)){Zc(a,v[b+12>>2])}fb=b+16|0;c=(c|0)==(e|0);if(!c){jR(d)}b=-1;a:{if(!c){break a}b=0;if(!mR(f+8|0)){break a}b=-1;if(!Sf(a,1024)){break a}b=0;d=fb-1024|0;fb=d;c=fb-16|0;fb=c;Yz(c+8|0,d);e=v[c+12>>2];hd(c,a,v[c+8>>2],e);g=v[c+4>>2];if((e|0)==(g|0)){Zc(a,v[c+12>>2])}fb=c+16|0;if((e|0)==(g|0)){b=Zz(d,0)>>>0<17}fb=d+1024|0}fb=f+608|0;return b|0}function tq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){if(!ve(a)){if(!ve(b)){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return}d=Ec(b);b=Bb(b);c=fb-16|0;fb=c;a:{if(b>>>0<=10){ae(a,b);a=Fe(a,d,b);t[c+15|0]=0;bd(a+b|0,c+15|0);break a}f=a;a=w[a+11|0];Ro(f,10,b-10|0,a,0,a,b,d)}fb=c+16|0;return}d=Ec(b);b=Bb(b);c=fb-16|0;fb=c;e=hl(a);b:{if(e>>>0>b>>>0){e=v[a>>2];Bd(a,b);a=Fe(e,d,b);t[c+15|0]=0;bd(a+b|0,c+15|0);break b}f=a;a=v[a+4>>2];Ro(f,e-1|0,(b-e|0)+1|0,a,0,a,b,d)}fb=c+16|0}}function LZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;h=fb-16|0;fb=h;d=Bb(a);e=To(a);g=ne(b,c);a:{if(!g){break a}b:{f=pc(a);if(f>>>0<=b>>>0){f=(Bb(a)<<2)+f>>>0>=b>>>0}else{f=0}if(!f){if(e-d>>>0<g>>>0){uF(a,e,(d+g|0)-e|0,d,d)}e=pc(a)+(d<<2)|0;while(1){if((b|0)==(c|0)){break b}td(e,v[b>>2]);b=b+4|0;e=e+4|0;continue}}b=dG(h,b,c);c=pc(b);d=Bb(b);v[23220]=0;W(1140,a|0,c|0,d|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){Nc(b);break a}a=P()|0;O()|0;Nc(b);S(a|0);L()}td(e,0);hh(a,d+g|0)}fb=h+16|0;return a|0}function oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-16|0;fb=b;e=v[a+40>>2];f=v[a+36>>2];i=v[a+16>>2];g=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=g;g=v[a+32>>2];j=v[a+28>>2];k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){h=u[(v[b+12>>2]<<1)+i>>1];f=f+j|0;v[c>>2]=v[c>>2]+B(h,f>>12);e=e+g|0;v[c+4>>2]=v[c+4>>2]+B(e>>12,h);Ob(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=e;v[a+20>>2]=f>>12;v[a+36>>2]=f;v[a+24>>2]=e>>12;fb=b+16|0}function Yha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;kd(b,0);Sh(c,1,a);d=c+16|0;Ac(d,c);ue(b+43|0,d);ub(d);v[b+24>>2]=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);u[b+34>>1]=x[b+34>>1]&65533|(w[a+13|0]|w[a+14|0]<<8)<<1&2;v[b>>2]=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);v[b+4>>2]=w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24);v[b+8>>2]=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);t[c+16|0]=w[a+15|0];t[c|0]=64;e=b,f=w[Rb(d,c)|0]<<2,u[e+30>>1]=f;fb=c+32|0}function oE(a,b,c,d){var e=0,f=0,g=0;e=fb-80|0;fb=e;f=Kf(e+48|0);v[23220]=0;d=Q(d|0,b|0,f|0)|0;g=v[23220];v[23220]=0;a:{b:{c:{d:{if((g|0)!=1){if(d){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23220]=0;T(c|0,a|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break a}}break c}c=v[f+4>>2];v[23220]=0;U(177,e|0,b|0,_b(c)|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Id(f);S(a|0);L()}b=gc(e+24|0,e);Yc(f+8|0,b);wb(b);wb(e);bl(a,f)}Id(f);fb=e+80|0}function cm(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function cl(a,b,c){var d=0;d=512;a:{if(b){break a}d=0;if(!(w[a+35|0]&2)){break a}to(a)}d=x[a+34>>1]&-513|d;u[a+34>>1]=d;if(b){v[a>>2]=4;u[a+34>>1]=d&65470;wg(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}}function X3(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=C(0);v[23220]=0;Y(919,a|0);d=v[23220];v[23220]=0;if((d|0)!=1){a=v[v[a+24>>2]+24>>2];if(!((b|0)<0|x[a+480188>>1]<=b>>>0)){a=a+B(b,872)|0;c=C(C(w[a+1075834|0])*C(.0078125));e=C(c*c);c=C(C(w[a+1075835|0])*C(.0078125));c=C(K(C(e+C(c*c))))}return C(c)}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,9348,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return C(C(0))}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-16|0;fb=b;e=v[a+40>>2];f=v[a+36>>2];i=v[a+16>>2];g=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=g;g=v[a+32>>2];j=v[a+28>>2];k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){h=t[v[b+12>>2]+i|0]<<8;f=f+j|0;v[c>>2]=v[c>>2]+B(h,f>>12);e=e+g|0;v[c+4>>2]=v[c+4>>2]+B(e>>12,h);Ob(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=e;v[a+20>>2]=f>>12;v[a+36>>2]=f;v[a+24>>2]=e>>12;fb=b+16|0}function NL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{g=b-4e3&65535;if(g>>>0<61537){break a}d=B(b,104)+a|0;e=d+484380|0;if(!Md(v[e>>2],v[d+484400>>2])){break a}h=a+1074992|0;d=0;while(1){if((d|0)==256){am(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[c+24>>2]=0;v[c+8>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c>>2]=0;v[c+4>>2]=0;cl(e,0,c);break a}f=B(d,872)+h|0;if(v[f+104>>2]==(e|0)){v[f>>2]=0;v[f+4>>2]=0;v[f+16>>2]=0;v[f+76>>2]=0}d=d+1|0;continue}}fb=c+32|0;return g>>>0>61536}function Iea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;ec(c+8|0,b,26);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function k_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=fb-208|0;fb=a;u[a+204>>1]=w[82859]|w[82860]<<8;v[a+200>>2]=w[82855]|w[82856]<<8|(w[82857]<<16|w[82858]<<24);f=wd();v[a>>2]=e;g=a+176|0;i=Fg(g,20,f,a+200|0,a);e=i+g|0;g=Pi(g,e,c);f=a+8|0;Xc(f,c);v[23220]=0;f=T(1104,f|0)|0;h=v[23220];v[23220]=0;if((h|0)!=1){Wb(a+8|0);h=f;f=a+16|0;OF(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=qr(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);fb=a+208|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function Wca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=fb-48|0;fb=f;nq(f+8|0,c);v[23220]=0;c=f+20|0;R(537,c|0,d|0);d=v[23220];v[23220]=0;b:{c:{d:{if((d|0)==1){break d}v[23220]=0;c=f+32|0;R(537,c|0,e|0);d=v[23220];v[23220]=0;if((d|0)==1){break d}tv(f,f+8|0);v[23220]=0;X(285,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23220];v[23220]=0;if((a|0)==1){break c}zP(f+8|0);fb=f+48|0;break a}a=P()|0;O()|0;while(1){c=ub(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;zP(f+8|0)}S(a|0);L()}}function CQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;v[a>>2]=0;v[a+4>>2]=0;mj(a+8|0,0);d=v[b+4>>2];if(d){Hq(a,d);Xk(c+8|0,v[b>>2]);$l(c,v[b>>2],v[b+4>>2]);b=fb-16|0;fb=b;d=v[a+4>>2];h=v[c+8>>2];i=v[c+12>>2];j=v[c>>2];k=v[c+4>>2];e=AQ(h,i,j,k)+d|0;v[a+4>>2]=e;a:{b:{if(!d){f=e-1|0;break b}f=e-1|0;if((f^d-1)>>>0>31){break b}g=v[a>>2];break a}g=v[a>>2];v[g+((e>>>0<33?0:f>>>5|0)<<2)>>2]=0}uo(b+8|0,g,d);BQ(b,h,i,j,k,v[b+8>>2],v[b+12>>2]);fb=b+16|0}fb=c+16|0;return a|0}function EW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=fb-48|0;fb=f;Io(f+8|0,c);v[23220]=0;c=f+20|0;R(126,c|0,d|0);d=v[23220];v[23220]=0;b:{c:{d:{if((d|0)==1){break d}v[23220]=0;c=f+32|0;R(126,c|0,e|0);d=v[23220];v[23220]=0;if((d|0)==1){break d}tv(f,f+8|0);v[23220]=0;X(101,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23220];v[23220]=0;if((a|0)==1){break c}br(f+8|0);fb=f+48|0;break a}a=P()|0;O()|0;while(1){c=vb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;br(f+8|0)}S(a|0);L()}}function aea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;kd(b,0);UA(d,a+1|0);c=d+16|0;Ac(c,d);ue(b+43|0,c);ub(c);v[b+24>>2]=w[a+73|0]|w[a+74|0]<<8|(w[a+75|0]<<16|w[a+76|0]<<24);c=w[a+54|0]|w[a+55|0]<<8|(w[a+56|0]<<16|w[a+57|0]<<24);v[b>>2]=c;v[b+4>>2]=w[a+58|0]|w[a+59|0]<<8|(w[a+60|0]<<16|w[a+61|0]<<24);e=w[a+62|0]|w[a+63|0]<<8|(w[a+64|0]<<16|w[a+65|0]<<24);if(e){v[b+8>>2]=e+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;uc(b+8|0,c);uc(b+4|0,v[b+8>>2]);fb=d+32|0}function Iga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;e=c+8|0;f=Ib(e+8|0);v[23220]=0;d=T(189,b|0)|0;g=v[23220];v[23220]=0;a:{b:{if((g|0)==1){break b}v[23220]=0;U(234,e|0,b|0,d|0);d=v[23220];v[23220]=0;if((d|0)==1){break b}d=v[e>>2];v[23220]=0;Q(175,b|0,d|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;$b(f);S(a|0);L()}wu(c,e);v[23220]=0;U(418,a|0,v[c>>2],v[c+4>>2]);a=v[23220];v[23220]=0;if((a|0)!=1){Jc(c+8|0);fb=c+32|0;return}a=P()|0;O()|0;Jc(c+8|0);S(a|0);L()}function fk(a){var b=0,c=0;a:{b=v[a+4>>2];b=v[v[b>>2]-12>>2]+b|0;b:{if(!v[b+24>>2]){break b}if(!Ch(b)|!(v[b+4>>2]&8192)){break b}if((cb()|0)>0){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[23220]=0;b=T(21,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[23220]=0;R(15,a+b|0,1);a=v[23220];v[23220]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Tb();L()}function IO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;j=b?33:32;c=v[a+8>>2]-1|0;e=v[a+12>>2];f=v[a>>2]+B(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(j|0)){break b}while(1)if((b|0)>=(e|0)){b=B(e,g);i=v[a+8>>2]-1|0;c:{if(!((i|0)!=(c|0)|(d|0)<=0)){if(!w[a+16|0]){d=1;c=0;break c}d=-1;c=c-(w[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=w[a+16|0];d=c?1:-1;c=c?0:i;break c}c=c+d|0}f=b+f|0;h=h+1|0;continue a}else{t[b+f|0]=w[v[a+4>>2]+(B(c,e)+b|0)|0];b=b+1|0;e=v[a+12>>2];continue}}break}}function $x(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{if((c|0)<2){break a}k=c-2>>>1|0;f=d-a|0;if((k|0)<f>>1){break a}h=f+1|0;e=(h<<1)+a|0;g=x[e>>1];i=f+2|0;if((i|0)<(c|0)){j=x[e+2>>1];f=op(b,g&65535,j);e=f?e+2|0:e;h=f?i:h;g=f?j:g}i=x[d>>1];if(op(b,g&65535,i)){break a}while(1){b:{f=e;u[d>>1]=g;if((h|0)>(k|0)){break b}d=h<<1;h=d|1;e=(h<<1)+a|0;g=x[e>>1];j=d+2|0;if((j|0)<(c|0)){l=x[e+2>>1];d=op(b,g&65535,l);e=d?e+2|0:e;h=d?j:h;g=d?l:g}d=f;if(!op(b,g&65535,i)){continue}}break}u[f>>1]=i}}function qr(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>>2|0;if((nm(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=MF(i,b,f);h=pc(f);v[23220]=0;h=W(1123,a|0,h|0,b|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break a}Nc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>>2|0;if((nm(a,c,b)|0)!=(b|0)){break b}}mo(e);j=a}fb=i+16|0;return j|0}a=P()|0;O()|0;Nc(f);S(a|0);L()}function jaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-48|0;fb=d;f=dO(a,1<<b-1);v[f+12>>2]=b;b=1<<b;h=-6.283185307179586/+(b>>>0);a=1;g=b>>>2|0;b=g;while(1){if(b){e=v[10505];c=d+16|0;v[c+8>>2]=v[10504];v[c+12>>2]=e;e=v[10503];v[c>>2]=v[10502];v[c+4>>2]=e;_y(c,h*+(b>>>0));_N(d+32|0,c);c=_c(v[f>>2],a);e=v[d+44>>2];v[c+8>>2]=v[d+40>>2];v[c+12>>2]=e;e=v[d+36>>2];v[c>>2]=v[d+32>>2];v[c+4>>2]=e;b=b>>>1|0;a=a<<1;continue}break}a=Ul(d,1,0);Ux(f,0,g,A[a>>3],A[a+8>>3]);fb=d+48|0;return f|0}function u3(a,b){a=a|0;b=b|0;var c=0,d=0;v[23220]=0;Y(919,a|0);c=v[23220];v[23220]=0;if((c|0)!=1){a=v[a+24>>2];c=-1;a:{if((b|0)<0){break a}d=v[a+24>>2];if(hj(Vb(v[d+484360>>2],w[d+484376|0]))>>>0<=b>>>0){break a}a=v[a+24>>2];c=x[ac(v[Vb(v[a+484360>>2],w[a+484376|0])>>2],b)>>1]}return c|0}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,9762,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function qz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;f=a+14|0;c=v[a>>2];e=v[a+4>>2];if(rc(c,e)){b=c}else{u[c>>1]=0;hf(c+2|0,b);g=d,h=Yl(Ab(v[a>>2]),1),v[g+8>>2]=h;while(1){e=Ab(v[a+4>>2]);c=v[d+8>>2];if(Nb(c,e)){g=c,h=x[Re(c,Yl(c,-1))>>1],u[g>>1]=h;hf(c+2|0,b);KP(d+8|0);continue}else{e=v[a+4>>2];b=v[a>>2]}break}}hf(f,ne(b,e)-1&255);hf(a+13|0,w[a+14|0]);hf(a+16|0,ne(v[a>>2],v[a+4>>2])-1&255);hf(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){hf(a+17|0,ne(v[a>>2],v[a+4>>2])-1&255)}fb=d+16|0}function UC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;g=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=g;a:{if(!g){break a}e=b+80|0;c=v[b+84>>2];if(c>>>0<=15){d=v[e>>2]}else{v[f+12>>2]=c-16;d=v[Sc(e,f+12|0)>>2]}v[a+8>>2]=d;c=v[b+88>>2];if(!(c&2)|!w[b+794|0]){break a}d=c;c=v[b+104>>2];b:{if(!(!TC(d,c)|v[e>>2]!=v[c+12>>2])){e=1;d=v[b+84>>2];if((d|0)==v[c+16>>2]){break b}}e=0;d=v[b+84>>2];if((d|0)!=v[c+8>>2]){break a}}h=a,i=B((v[c>>2]-d|0)+(e?112:48)|0,ik(x[c+34>>1]))+g|0,v[h+4>>2]=i}fb=f+16|0}function rv(a){var b=0,c=0,d=0;if(y[a+4>>2]<y[Cb(a)>>2]){b=fb-16|0;fb=b;a=mD(b,a);c=v[a+4>>2];v[23220]=0;Y(157,c|0);c=v[23220];v[23220]=0;a:{if((c|0)!=1){v[a+4>>2]=v[a+4>>2]+36;hc(a);fb=b+16|0;break a}b=P()|0;O()|0;hc(a);S(b|0);L()}return}c=fb-32|0;fb=c;b=Cb(a);b=jD(c+8|0,lD(a,Sq(v[a>>2],v[a+4>>2])+1|0),Sq(v[a>>2],v[a+4>>2]),b);d=v[b+8>>2];v[23220]=0;Y(157,d|0);d=v[23220];v[23220]=0;b:{if((d|0)!=1){v[b+8>>2]=v[b+8>>2]+36;iD(a,b);hv(b);fb=c+32|0;break b}a=P()|0;O()|0;hv(b);S(a|0);L()}}function OI(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=v[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(y[a+12>>2]<=d>>>0)){while(1){e=my(v[a>>2]);c=ib;f=v[a+36>>2];if((c|0)==(f|0)&y[a+32>>2]<=e>>>0|c>>>0>f>>>0){continue}break}c=b;b=v[a+8>>2];b=(e&v[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){d=my(v[a>>2]);c=ib;f=v[a+28>>2];if((c|0)==(f|0)&y[a+24>>2]<=d>>>0|c>>>0>f>>>0){continue}break}c=b;b=v[a+8>>2];b=(d&v[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function u_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=fb-96|0;fb=a;u[a+92>>1]=w[82859]|w[82860]<<8;v[a+88>>2]=w[82855]|w[82856]<<8|(w[82857]<<16|w[82858]<<24);f=wd();v[a>>2]=e;g=a- -64|0;i=Fg(g,20,f,a+88|0,a);e=i+g|0;g=Pi(g,e,c);f=a+8|0;Xc(f,c);v[23220]=0;f=T(18,f|0)|0;h=v[23220];v[23220]=0;if((h|0)!=1){Wb(a+8|0);h=f;f=a+16|0;UF(h,a- -64|0,e,f);h=b;b=f+i|0;b=Bq(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);fb=a+96|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function Ufa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Cb(a)>>2]){c=fb-16|0;fb=c;a=kU(c,a);wA(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;hc(a);fb=c+16|0;return}e=fb-32|0;fb=e;c=Cb(a);c=iU(e+8|0,jU(a,oq(v[a>>2],v[a+4>>2])+1|0),oq(v[a>>2],v[a+4>>2]),c);wA(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;wA(v[b>>2]-28|0,d);v[b>>2]=v[b>>2]-28;continue}break}kc(a,b);kc(a+4|0,c+8|0);kc(Cb(a),vc(c));v[c>>2]=v[c+4>>2];hU(c);fb=e+32|0}function ck(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Cb(a)>>2]){c=fb-16|0;fb=c;a=kU(c,a);oB(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;hc(a);fb=c+16|0;return}e=fb-32|0;fb=e;c=Cb(a);c=iU(e+8|0,jU(a,oq(v[a>>2],v[a+4>>2])+1|0),oq(v[a>>2],v[a+4>>2]),c);oB(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;oB(v[b>>2]-28|0,d);v[b>>2]=v[b>>2]-28;continue}break}kc(a,b);kc(a+4|0,c+8|0);kc(Cb(a),vc(c));v[c>>2]=v[c+4>>2];hU(c);fb=e+32|0}function dJ(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)==10){zx(a,b,c,d);return}g=d;i=B(e,e);k=B(i,e);j=B(i,i);a:{while(1){h=f|1;if(e>>>0>g>>>0){break a}h=f|2;if(g>>>0<i>>>0){break a}h=f|3;if(g>>>0<k>>>0){break a}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){v[a+4>>2]=61;v[a>>2]=c;return}f=b+f|0;b=f;while(1){b=b-1|0;c=(d>>>0)/(e>>>0)|0;t[b|0]=w[(d-B(c,e)|0)+4856|0];g=d>>>0>=e>>>0;d=c;if(g){continue}break}v[a+4>>2]=0;v[a>>2]=f}function vf(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function iL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a|0)!=(b|0)){c=fb-16|0;fb=c;d=v[b>>2];f=v[b+4>>2];e=$j(d,f);a:{if(e>>>0<=bu(a)>>>0){g=f;h=v[a>>2];i=$j(h,v[a+4>>2]);j=i>>>0>=e>>>0;if(!j){v[c+12>>2]=d;v[c+12>>2]=v[c+12>>2]+B(i,6);g=v[c+12>>2]}d=kL(d,g,h);if(!j){Qx(a,g,f,e-$j(v[a>>2],v[a+4>>2])|0);break a}Jd(a,d);break a}jL(a);OS(a,DA(a,e));Qx(a,d,f,e)}fb=c+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];hL(a+24|0,b+24|0);tq(a+36|0,b+36|0);return a}function PE(a,b,c,d,e,f,g,h){var i=0,j=0;i=fb-16|0;fb=i;v[23220]=0;Y(919,a|0);j=v[23220];v[23220]=0;a:{b:{if((j|0)!=1){c:{j=v[a+24>>2];v[23220]=0;ja(h|0,i|0,j|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[23220];v[23220]=0;if((b|0)==1){break c}b=Uf(Ec(i));ub(i);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[23220]=0;X(906,g|0,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$()}fb=i+16|0;return b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function $P(a){var b=0,c=0;a:{if(Mb(a+60|0,13799,4)){break a}b=w[a+28|0]|w[a+29|0]<<8;b:{if(b>>>0<=63){if((b|0)==26){break b}break a}if(b>>>0>2112){break a}}b=w[a+42|0];if(b>>>0>64&(b|0)!=88|(w[a+48|0]|w[a+49|0]<<8)>>>0>64|(w[a+50|0]|w[a+51|0]<<8)>>>0>96){break a}b=w[a+52|0]|w[a+53|0]<<8;if(b>>>0>129&(b|0)!=257|(w[a+30|0]|w[a+31|0]<<8)|(w[a+38|0]|w[a+39|0]<<8|(w[a+40|0]<<16|w[a+41|0]<<24)|(w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1)){break a}c=cQ(a+20|0)}return c}function hia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Ib(a);a:{b:{if(b){v[23220]=0;R(307,a|0,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}d=fb-16|0;fb=d;c=gq(d,a,b);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){hc(c);fb=d+16|0}else{t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+4|0]=6;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=8;t[b+3|0]=4;b=b+6|0;v[c+4>>2]=b;continue}break}}break a}b=P()|0;O()|0;qh(a);S(b|0);L()}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function g1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;e=Bo(a);v[e>>2]=60380;a=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=a;a=c;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;b=vc(e);c=fb-16|0;fb=c;d=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=d;d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;d=rI(c);b=Em(b);t[b+8|0]=0;v[b+4>>2]=d;v[b>>2]=60780;Ib(b+12|0);v[b>>2]=60544;d=v[a+4>>2];v[b+24>>2]=v[a>>2];v[b+28>>2]=d;d=v[a+12>>2];v[b+32>>2]=v[a+8>>2];v[b+36>>2]=d;fb=c+16|0;fb=a+16|0;return e|0}function OE(a,b,c,d,e,f,g){var h=0,i=0;h=fb-16|0;fb=h;v[23220]=0;Y(919,a|0);i=v[23220];v[23220]=0;a:{b:{if((i|0)!=1){c:{i=v[v[a+24>>2]+24>>2];v[23220]=0;ka(g|0,h|0,i|0,b|0,c|0,d|0,e|0);b=v[23220];v[23220]=0;if((b|0)==1){break c}b=Uf(Ec(h));ub(h);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[23220]=0;X(906,f|0,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$()}fb=h+16|0;return b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function NW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;a:{b:{e=AT(qd(b),xd(v[b+4>>2],w[b+11|0]),qd(c),xd(v[c+4>>2],w[c+11|0]));if((e|0)!=-1){f=d,g=Fi(b),v[f+16>>2]=g;f=d,g=Ei(d+16|0,e),v[f+24>>2]=g;f=d,g=Ei(d+24|0,1),v[f+32>>2]=g;c=Ef(d+40|0,d+32|0);f=d,g=ev(b),v[f>>2]=g;e=Ef(d+8|0,d);dD(b,v[c>>2],v[e>>2]);break b}if(!nl(v[b+4>>2],w[b+11|0])){break b}if(sT(qd(b),xd(v[b+4>>2],w[b+11|0]),qd(c),xd(v[c+4>>2],w[c+11|0]))){break b}Gb(a);break a}Mc(a,b)}fb=d+48|0}function cM(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;ib=v[e+4>>2];return v[e>>2]}function R1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-16|0;fb=c;a:{d=Lh(C(z[a+24>>2]*C(65536)));if((d|0)==65536){break a}i=v[b+4>>2];j=v[b+8>>2];k=d>>31;b:while(1){if((f|0)==(j|0)){break a}l=v[b+4>>2];m=v[b>>2];e=0;while(1)if((e|0)==(i|0)){f=f+1|0;continue b}else{g=Ih(m,l,e,f);h=v[g>>2];n=g,o=Dc(Cia(Bia(h,h>>31,d,k),ib,65536,0),ib),v[n>>2]=o;e=e+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;KI(a,c);fb=c+16|0}function H1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-16|0;fb=c;a:{d=Lh(C(z[a+24>>2]*C(65536)));if((d|0)==65536){break a}i=v[b+4>>2];j=v[b+8>>2];k=d>>31;b:while(1){if((f|0)==(j|0)){break a}l=v[b+4>>2];m=v[b>>2];e=0;while(1)if((e|0)==(i|0)){f=f+1|0;continue b}else{g=Ih(m,l,e,f);h=v[g>>2];n=g,o=Dc(Cia(Bia(h,h>>31,d,k),ib,65536,0),ib),v[n>>2]=o;e=e+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;CI(a,c);fb=c+16|0}function B7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ji(a,b,c,d);v[a>>2]=44232;b=Ib(a+4208|0);v[a+4236>>2]=-1;v[a+4240>>2]=0;v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;t[a+4244|0]=0;Sb(a+4248|0,0,48);v[23220]=0;Z(782);c=v[23220];v[23220]=0;a:{if((c|0)==1){break a}e=a,f=lM(),v[e+4296>>2]=f;vs(a);us(a);v[23220]=0;R(870,a+44|0,2);c=v[23220];v[23220]=0;if((c|0)==1){break a}ii(a);return a|0}c=P()|0;O()|0;$b(b);sf(a);S(c|0);L()}function FR(a,b,c,d){var e=0,f=0,g=0;f=fb-16|0;fb=f;while(1){a:{e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!Ye(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){e=Ye(a,f+14|0);if(e){g=w[f+14|0];u[c>>1]=g<<1|1;t[b|0]=g>>>7;u[c>>1]=w[c|0]}if(!e){break a}if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}fb=f+16|0}function qga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Zj(b),v[i>>2]=j;g=x[b>>1];c=fb-16|0;fb=c;f=a;d=Od(a);a:{if(d){b=fc(f);while(1){a=d;d=x[a+16>>1];if(bo(g,d)){b=a;d=v[a>>2];if(d){continue}break a}if(!bo(d,g)){break a}b=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=fc(f);b=a}v[c+12>>2]=a;a=v[b>>2];if(!a){HS(c,f,e);Tg(f,v[c+12>>2],b,v[c>>2]);a=Ud(c);GS(c);h=1}Sg(e+8|0,v[dc(c,a)>>2],h);fb=c+16|0;a=pd(v[e+8>>2]);fb=e+16|0;return a+4|0}function YK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Zj(b),v[i>>2]=j;g=x[b>>1];c=fb-16|0;fb=c;f=a;d=Od(a);a:{if(d){b=fc(f);while(1){a=d;d=x[a+16>>1];if(zs(g,d)){b=a;d=v[a>>2];if(d){continue}break a}if(!zs(d,g)){break a}b=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=fc(f);b=a}v[c+12>>2]=a;a=v[b>>2];if(!a){HS(c,f,e);Tg(f,v[c+12>>2],b,v[c>>2]);a=Ud(c);GS(c);h=1}Sg(e+8|0,v[dc(c,a)>>2],h);fb=c+16|0;a=pd(v[e+8>>2]);fb=e+16|0;return a+4|0}function iV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;kd(b,0);Sh(d,1,a+33|0);c=d+16|0;Ac(c,d);ue(b+43|0,c);ub(c);e=w[a+50|0]|w[a+51|0]<<8;v[b>>2]=e;v[b+24>>2]=w[a+52|0]|w[a+53|0]<<8;t[d+16|0]=w[a+54|0];t[d|0]=64;g=b,h=w[Rb(c,d)|0]<<2,u[g+30>>1]=h;f=w[a+55|0]|w[a+56|0]<<8;v[b+4>>2]=f;c=w[a+57|0]|w[a+58|0]<<8;v[b+8>>2]=c;a:{if((c|0)==65535){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(!w[a|0]|c>>>0<=f+2>>>0|c>>>0>e>>>0){break a}u[b+34>>1]=x[b+34>>1]|2}fb=d+32|0}function K8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;$k(d,2,a+2|0);e=d+16|0;Ac(e,d);yc(b+492|0,e);f=b+236|0;g=c+1|0;ub(e);c=0;while(1){if((c|0)==120){v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;oL(w[a|0]&15,w[a+1|0]&15,w[a+2|0]&15,w[a+3|0]&15,w[a+4|0]&15,a+5|0,b+48|0);oL(w[a|0]>>>4|0,w[a+1|0]>>>4|0,w[a+2|0]>>>4|0,w[a+3|0]>>>4|0,w[a+4|0]>>>4|0,a+35|0,b+68|0);fb=d+32|0}else{h=ac(f,c),i=w[(a+c|0)+31|0]+g|0,u[h>>1]=i;c=c+1|0;continue}break}}function wW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;a:{b:{e=ND(qd(b),xd(v[b+4>>2],w[b+11|0]),qd(c),xd(v[c+4>>2],w[c+11|0]));if((e|0)!=-1){f=d,g=Fi(b),v[f+32>>2]=g;c=Ef(d+40|0,d+32|0);f=d,g=Fi(b),v[f+8>>2]=g;f=d,g=Ei(d+8|0,e),v[f+16>>2]=g;e=Ef(d+24|0,d+16|0);dD(b,v[c>>2],v[e>>2]);break b}e=nl(v[b+4>>2],w[b+11|0]);if(!e){break b}if((MD(qd(b),xd(v[b+4>>2],w[b+11|0]),qd(c),xd(v[c+4>>2],w[c+11|0]))|0)!=(e-1|0)){break b}Gb(a);break a}Mc(a,b)}fb=d+48|0}function ry(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=v[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=w[b+813|0];if(c){t[b+813|0]=e&240|c&15;break a}c=e&15;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}Pj(a,b,b+700|0,0-(c<<2)|0,0);if(v[b+700>>2]<65536){break b}xb(d+8|0,a+1074312|0,7);if(yb(v[v[d+8>>2]>>2],v[d+12>>2])|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}fb=d+16|0}function q1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;v[d+4>>2]=1;g=d,h=tc(56),v[g+8>>2]=h;c=fb-16|0;fb=c;e=Bo(v[d+8>>2]);v[e>>2]=60880;f=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=f;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;b=Em(vc(e));v[b>>2]=61244;Ib(b+4|0);t[b+20|0]=0;v[b+16>>2]=0;v[b>>2]=61044;e=v[c+4>>2];v[b+24>>2]=v[c>>2];v[b+28>>2]=e;e=v[c+12>>2];v[b+32>>2]=v[c+8>>2];v[b+36>>2]=e;t[b+40|0]=0;fb=c+16|0;b=a;a=Do(d);Co(b,vc(a),a);Fm(d);fb=d+16|0}function gf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=Bia(b,c,h,i);i=ib;j=h;h=Bia(d,e,f,g);e=j+h|0;d=ib+i|0;i=e;h=i>>>0<h>>>0?d+1|0:d;j=i;k=g;e=0;l=c;d=0;i=Bia(g,e,c,d);g=j+i|0;c=ib+h|0;j=g;g=g>>>0<i>>>0?c+1|0:c;h=f;i=b;f=Bia(h,0,i,0);b=ib;c=0;d=Bia(h,c,l,d);b=b+d|0;c=ib+c|0;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+j|0;d=g;d=c>>>0<h>>>0?d+1|0:d;h=c;c=d;d=Bia(i,m,k,e)+b|0;e=ib;e=b>>>0>d>>>0?e+1|0:e;g=a;i=e;h=i+h|0;v[g+8>>2]=h;v[g+12>>2]=h>>>0<i>>>0?c+1|0:c;v[g>>2]=f;v[g+4>>2]=d}function ZF(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[115696];v[115696]=0;wd();a=mw(a,e+12|0,d);d=ib;g=v[115696];e:{if(g){if(v[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}v[115696]=h;if((b|0)!=v[e+12>>2]){break c}if(!d&a>>>0<65536){break b}}v[c>>2]=4;a=65535;break a}}v[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}fb=e+16|0;return a&65535}function Bq(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>0){if((nm(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=Ge(i,b,f);g=pc(f);v[23220]=0;g=W(22,a|0,g|0,b|0)|0;h=v[23220];v[23220]=0;if((h|0)==1){break a}ub(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((nm(a,c,b)|0)!=(b|0)){break b}}mo(e);j=a}fb=i+16|0;return j|0}a=P()|0;O()|0;ub(f);S(a|0);L()}function iE(a,b,c,d,e,f){var g=0;a:{g=fb-48|0;fb=g;Mm(g+8|0,c);v[23220]=0;c=g+20|0;R(f|0,c|0,d|0);d=v[23220];v[23220]=0;b:{c:{d:{if((d|0)==1){break d}v[23220]=0;c=g+32|0;R(100,c|0,e|0);d=v[23220];v[23220]=0;if((d|0)==1){break d}tv(g,g+8|0);v[23220]=0;X(101,a|0,b|0,v[g>>2],v[g+4>>2]);a=v[23220];v[23220]=0;if((a|0)==1){break c}br(g+8|0);fb=g+48|0;break a}a=P()|0;O()|0;while(1){c=vb(c-12|0);if((c|0)!=(g+8|0)){continue}break}break b}a=P()|0;O()|0;br(g+8|0)}S(a|0);L()}}function Vt(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{d:{if(!(a&3)|!c){break d}e=b&255;while(1){if((e|0)==w[a|0]){break c}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break d}if(c){continue}break}}if(!d){break a}if(w[a|0]==(b&255)|c>>>0<4){break c}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}while(1){if(w[a|0]==(b&255)){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function wM(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=v[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=w[b+814|0];if(c){t[b+814|0]=e&240|c&15;break a}c=e&15;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}Pj(a,b,b+700|0,0-c|0,0);if(v[b+700>>2]<65536){break b}xb(d+8|0,a+1074312|0,7);if(yb(v[v[d+8>>2]>>2],v[d+12>>2])|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}fb=d+16|0}function zE(a,b,c,d,e){var f=0,g=0,h=0;f=fb-160|0;fb=f;u[f+156>>1]=w[82853]|w[82854]<<8;v[f+152>>2]=w[82849]|w[82850]<<8|(w[82851]<<16|w[82852]<<24);g=f+152|0;sr(g|1,10715,e,v[b+4>>2]);e=wd();v[f>>2]=d;d=f+139|0;e=Fg(d,13,e,g,f)+d|0;g=Pi(d,e,b);h=f+16|0;Xc(h,b);v[23220]=0;ja(1121,d|0,g|0,e|0,f+32|0,f+28|0,f+24|0,h|0);d=v[23220];v[23220]=0;if((d|0)!=1){Wb(f+16|0);a=qr(a,f+32|0,v[f+28>>2],v[f+24>>2],b,c);fb=f+160|0;return a}a=P()|0;O()|0;Wb(f+16|0);S(a|0);L()}function mX(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;v[23220]=0;m=a;a=b;b=0;a=Ma(1014,m|b,a|0,c|0,d|0,b|e,f|0)|0;b=v[23220];v[23220]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23220]=0;ja(902,8814,g|0,h|0,i|0,j|0,k|0,l|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}return a|0}function A4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[23220]=0;Y(944,a|0);f=v[23220];v[23220]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[23220]=0;b=Ra(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,11272,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function f8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);e=fb-16|0;fb=e;c=bf(a,c);Yd(e,v[a+28>>2]);a:{if(!c){if(cd(a,5)){break a}}d=fb-32|0;fb=d;h=v[a+28>>2];nk(h,d+24|0);i=d,j=Pc(v[d+24>>2],v[d+28>>2]),v[i+16>>2]=j;v[d+12>>2]=256;Oj(b,v[Eb(d+16|0,d+12|0)>>2]);f=v[b>>2];while(1){if(sc(f,v[b+4>>2])>>>0<=g>>>0){fb=d+32|0}else{v[d+16>>2]=0;jp(h,d+16|0);f=v[b>>2];i=zb(f,g),k=z[d+16>>2],z[i>>2]=k;g=g+1|0;continue}break}d=c}We(a,d);fb=e+16|0}function bL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=v[a>>2];c=sc(d,v[a+4>>2]);if(c>>>0<=127){f=fb-32|0;fb=f;c=128-c|0;e=v[Cb(a)>>2];d=v[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){Mx(a,c,b);break a}e=Cb(a);d=cg(f+8|0,Pg(a,sc(v[a>>2],d)+c|0),sc(v[a>>2],v[a+4>>2]),e);g=fb-16|0;fb=g;c=il(g,d+8|0,c);e=v[c>>2];while(1){if(v[c+4>>2]!=(e|0)){As(e,z[b>>2]);e=v[c>>2]+4|0;v[c>>2]=e;continue}break}Ed(c);fb=g+16|0;vd(a,d);bg(d)}fb=f+32|0;return}if((c|0)!=128){Jd(a,d+512|0)}}function dL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-32|0;fb=e;v[e+16>>2]=c;v[e+24>>2]=b;i=e,j=Td(a),v[i+8>>2]=j;c=e+24|0;b=bk(c,e+8|0);c=bk(e+16|0,c);a:{if(Bb(a)>>>0>=b>>>0){if((c|0)==-1){aL(a,b);break a}f=a;d=fb-16|0;fb=d;v[d+12>>2]=c;if(c){g=Bb(f);h=pc(f);c=g-b|0;v[d+8>>2]=c;a=v[Eb(d+12|0,d+8|0)>>2];v[d+12>>2]=a;b:{if((a|0)==(c|0)){a=c;break b}b=b+h|0;pj(b,a+b|0,c-a|0)}a=g-a|0;hh(f,a);t[d+7|0]=0;bd(a+h|0,d+7|0)}fb=d+16|0;break a}fm();L()}fb=e+32|0}function WF(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{if((a|0)!=(b|0)){b:{c:{f=w[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=v[115696];v[115696]=0;wd();a=mw(a,e+12|0,d);d=ib;d:{g=v[115696];if(g){if(v[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}v[c>>2]=4;b=-1;a=-1;break a}v[115696]=h;if(v[e+12>>2]==(b|0)){break d}break b}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d;break a}}v[c>>2]=4;b=0;a=0}fb=e+16|0;ib=a;return b}function RZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;d=Bb(a);e=Qc(a);g=oi(b,c);a:{if(!g){break a}b:{if(!Cs(a,b)){if(e-d>>>0<g>>>0){Ll(a,e,(d+g|0)-e|0,d,d,0,0)}e=pc(a)+d|0;while(1){if((b|0)==(c|0)){break b}bd(e,b);b=b+1|0;e=e+1|0;continue}}b=Xf(f,b,c);c=Ec(b);d=Bb(b);v[23220]=0;W(1035,a|0,c|0,d|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){ub(b);break a}a=P()|0;O()|0;ub(b);S(a|0);L()}t[f+15|0]=0;bd(e,f+15|0);hh(a,d+g|0)}fb=f+16|0;return a|0}function uda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;_l(c+48|0,b);ge(c+16|0,v[c+48>>2],v[c+52>>2]);b=Xd(c+8|0);d=v[b+4>>2];b=v[b>>2];v[23220]=0;b=ga(153,c+24|0,v[c+16>>2],v[c+20>>2],b|0,d|0)|0;d=v[23220];v[23220]=0;a:{if((d|0)!=1){d=Ib(a);a=v[c+52>>2];e=v[c+48>>2];v[23220]=0;U(668,b|0,d|0,Wc(e,a)>>>5|0);a=v[23220];v[23220]=0;if((a|0)==1){a=P()|0;O()|0;ti(d);wb(b);break a}wb(b);$b(c+48|0);fb=c- -64|0;return}a=P()|0;O()|0}$b(c+48|0);S(a|0);L()}
function BE(a,b,c,d,e){var f=0,g=0,h=0;f=fb-80|0;fb=f;u[f+76>>1]=w[82853]|w[82854]<<8;v[f+72>>2]=w[82849]|w[82850]<<8|(w[82851]<<16|w[82852]<<24);g=f+72|0;sr(g|1,10715,e,v[b+4>>2]);e=wd();v[f>>2]=d;d=f+59|0;e=Fg(d,13,e,g,f)+d|0;g=Pi(d,e,b);h=f+16|0;Xc(h,b);v[23220]=0;ja(1118,d|0,g|0,e|0,f+32|0,f+28|0,f+24|0,h|0);d=v[23220];v[23220]=0;if((d|0)!=1){Wb(f+16|0);a=Bq(a,f+32|0,v[f+28>>2],v[f+24>>2],b,c);fb=f+80|0;return a}a=P()|0;O()|0;Wb(f+16|0);S(a|0);L()}function rda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;_l(c+48|0,b);ge(c+16|0,v[c+48>>2],v[c+52>>2]);b=Xd(c+8|0);d=v[b+4>>2];b=v[b>>2];v[23220]=0;b=ga(153,c+24|0,v[c+16>>2],v[c+20>>2],b|0,d|0)|0;d=v[23220];v[23220]=0;a:{if((d|0)!=1){d=Ib(a);a=v[c+52>>2];e=v[c+48>>2];v[23220]=0;U(669,b|0,d|0,Wc(e,a)>>>2|0);a=v[23220];v[23220]=0;if((a|0)==1){a=P()|0;O()|0;lc(d);wb(b);break a}wb(b);$b(c+48|0);fb=c- -64|0;return}a=P()|0;O()|0}$b(c+48|0);S(a|0);L()}function qda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;_l(c+48|0,b);ge(c+16|0,v[c+48>>2],v[c+52>>2]);b=Xd(c+8|0);d=v[b+4>>2];b=v[b>>2];v[23220]=0;b=ga(153,c+24|0,v[c+16>>2],v[c+20>>2],b|0,d|0)|0;d=v[23220];v[23220]=0;a:{if((d|0)!=1){d=Ib(a);a=v[c+52>>2];e=v[c+48>>2];v[23220]=0;U(670,b|0,d|0,Wc(e,a)>>>8|0);a=v[23220];v[23220]=0;if((a|0)==1){a=P()|0;O()|0;qt(d);wb(b);break a}wb(b);$b(c+48|0);fb=c- -64|0;return}a=P()|0;O()|0}$b(c+48|0);S(a|0);L()}function pda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;_l(c+48|0,b);ge(c+16|0,v[c+48>>2],v[c+52>>2]);b=Xd(c+8|0);d=v[b+4>>2];b=v[b>>2];v[23220]=0;b=ga(153,c+24|0,v[c+16>>2],v[c+20>>2],b|0,d|0)|0;d=v[23220];v[23220]=0;a:{if((d|0)!=1){d=Ib(a);a=v[c+52>>2];e=v[c+48>>2];v[23220]=0;U(671,b|0,d|0,Wc(e,a)>>>4|0);a=v[23220];v[23220]=0;if((a|0)==1){a=P()|0;O()|0;Yj(d);wb(b);break a}wb(b);$b(c+48|0);fb=c- -64|0;return}a=P()|0;O()|0}$b(c+48|0);S(a|0);L()}function qN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-16|0;fb=d;j=d,k=Zj(b),v[j>>2]=k;c=fb-16|0;fb=c;g=xy(a,c+12|0,w[b|0],v[b+4>>2]);b=v[g>>2];if(!b){e=fb-16|0;fb=e;b=fc(a);h=oh(c,tc(28),ph(e+8|0,b));b=v[h>>2];f=v[d>>2];i=v[f+4>>2];f=v[f>>2];v[b+24>>2]=0;v[b+16>>2]=f;v[b+20>>2]=i;j=fc(h),k=1,t[j+4|0]=k;fb=e+16|0;Tg(a,v[c+12>>2],g,v[c>>2]);b=Ud(c);_k(c);e=1}Sg(d+8|0,v[dc(c,b)>>2],e);fb=c+16|0;a=pd(v[d+8>>2]);fb=d+16|0;return a+8|0}function hx(a,b,c){var d=0,e=0,f=0;e=Ib(a);a:{b:{if(c){v[23220]=0;R(1038,e|0,c|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}d=fb-16|0;fb=d;c=ri(d,e,c);a=v[c+4>>2];f=v[c+8>>2];while(1){if((a|0)==(f|0)){hc(c);fb=d+16|0}else{v[a>>2]=0;lh(a);a=a+4|0;v[c+4>>2]=a;continue}break}}break a}a=P()|0;O()|0;lc(e);S(a|0);L()}a=0;c=0;d=fb-16|0;fb=d;f=d+8|0;while(1){if(a>>>0<32){a=a+48|0;c=dM(b);continue}break}v[f>>2]=c;Cn(f);fb=d+16|0;v[e+12>>2]=v[f>>2];return e}function dE(a,b,c,d,e){var f=0,g=0,h=0;a:{f=fb-32|0;fb=f;h=Ib(a);b:{c:{d:{e:{while(1){a=v[b+8>>2];g=v[b>>2];v[23220]=0;a=W(143,g|0,a|0,8)|0;g=v[23220];v[23220]=0;if((g|0)==1){break c}if(!a){break d}v[23220]=0;U(e|0,f|0,b|0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){v[23220]=0;R(d|0,h|0,f|0);a=v[23220];v[23220]=0;if((a|0)==1){break e}Id(f);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Id(f);break b}fb=f+32|0;break a}a=P()|0;O()|0}Vd(h);S(a|0);L()}}function cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+12>>2]+i|0;e=t[f|0];e=((B(t[f+1|0]-e|0,v[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Ob(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;fb=b+16|0}function D4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23220]=0;Y(944,a|0);e=v[23220];v[23220]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[23220]=0;b=fa(f|0,e|0,b|0,c|0,d|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,11417,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function C4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23220]=0;Y(944,a|0);e=v[23220];v[23220]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[23220]=0;b=fa(f|0,e|0,b|0,c|0,d|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,11453,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Oo(a,b,c,d,e){var f=0,g=0,h=0;a:{f=fb-32|0;fb=f;h=Ib(a);b:{c:{d:{e:{while(1){a=v[b+8>>2];g=v[b>>2];v[23220]=0;a=W(143,g|0,a|0,e|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break c}if(!a){break d}v[23220]=0;R(d|0,f|0,b|0);a=v[23220];v[23220]=0;if((a|0)!=1){v[23220]=0;R(c|0,h|0,f|0);a=v[23220];v[23220]=0;if((a|0)==1){break e}Id(f);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Id(f);break b}fb=f+32|0;break a}a=P()|0;O()|0}Vd(h);S(a|0);L()}}function IW(a,b){a=a|0;b=b|0;var c=0;a=Gb(a);a:{if(w[b+16|0]){v[23220]=0;Q(120,a|0,4906)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[23220]=0;Q(120,a|0,12514)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}}if(ah(v[a+4>>2],w[a+11|0])){v[23220]=0;Q(120,a|0,10028)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[23220]=0;Q(120,a|0,11039)|0;b=v[23220];v[23220]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;vb(a);S(b|0);L()}function X$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;v[d+16>>2]=b;e=v[a+48>>2];v[d+20>>2]=c-((e|0)!=0);g=v[a+44>>2];v[d+28>>2]=e;v[d+24>>2]=g;a:{b:{if(Kw(bb(v[a+60>>2],d+16|0,2,d+12|0)|0)){b=32}else{e=v[d+12>>2];if((e|0)>0){break b}b=e?32:16}v[a>>2]=b|v[a>>2];break a}g=v[d+20>>2];if(g>>>0>=e>>>0){f=e;break a}f=v[a+44>>2];v[a+4>>2]=f;v[a+8>>2]=f+(e-g|0);if(v[a+48>>2]){v[a+4>>2]=f+1;t[(b+c|0)-1|0]=w[f|0]}f=c}fb=d+32|0;return f|0}function y4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[23220]=0;Y(944,a|0);d=v[23220];v[23220]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[23220]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,6621,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function w4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[23220]=0;Y(944,a|0);d=v[23220];v[23220]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[23220]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,6675,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function i9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=x[a+30>>1];if(d){b=xn(b<<16>>16,d<<16>>16)}u[e+14>>1]=b;a=a+52|0;a:{if(!ah(v[c+4>>2],w[c+11|0])){Ho(YK(a,e+14|0),c);break a}b=Lx(a,e+14|0);if(!vg(b,wf(a))){break a}c=fb-16|0;fb=c;b=v[dc(c,b)>>2];d=fb-16|0;fb=d;f=Rg(dc(d+8|0,b));if((b|0)==v[a>>2]){v[a>>2]=v[f>>2]}g=Cb(a);v[g>>2]=v[g>>2]-1;XK(v[fc(a)>>2],b);a=v[f>>2];fb=d+16|0;Rt(pd(b));Fb(b);dc(c+8|0,a);fb=c+16|0}fb=e+16|0}function bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=(v[b+12>>2]<<1)+i|0;e=u[f>>1];e=e+((B(u[f+2>>1]-e|0,v[b+8>>2]>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Ob(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;fb=b+16|0}function LE(a,b,c,d){var e=0,f=C(0);v[23220]=0;Y(919,a|0);e=v[23220];v[23220]=0;if((e|0)!=1){a=v[v[a+24>>2]+24>>2];a:{if((b|0)<0|x[a+480188>>1]<=b>>>0){break a}a=a+B(b,872)|0;if(!(t[a+1075081|0]&1)){break a}f=C(C(w[a+d|0])*C(.0078125))}return f}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,c|0,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return C(0)}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function $da(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-32|0;fb=d;kd(b,0);UA(d,a+1|0);c=d+16|0;Ac(c,d);ue(b+43|0,c);ub(c);v[b+24>>2]=w[a+78|0]|w[a+79|0]<<8;c=w[a+58|0]|w[a+59|0]<<8|(w[a+60|0]<<16|w[a+61|0]<<24);v[b>>2]=c;v[b+4>>2]=w[a+62|0]|w[a+63|0]<<8|(w[a+64|0]<<16|w[a+65|0]<<24);v[b+8>>2]=w[a+66|0]|w[a+67|0]<<8|(w[a+68|0]<<16|w[a+69|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;uc(b+8|0,c);uc(b+4|0,v[b+8>>2]);fb=d+32|0}function mC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=Ic(d,v[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=v[Cb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){fC(a,b);break a}c=Cb(a);c=vj(e+8|0,wj(a,Ic(v[a>>2],d)+b|0),Ic(v[a>>2],v[a+4>>2]),c);f=fb-16|0;fb=f;b=wo(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){eC(d);d=v[b>>2]+2|0;v[b>>2]=d;continue}break}Ed(b);fb=f+16|0;vd(a,c);Di(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Jd(a,d+(b<<1)|0)}}function Oj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=sc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=v[Cb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){it(a,b);break a}c=Cb(a);c=cg(e+8|0,Pg(a,sc(v[a>>2],d)+b|0),sc(v[a>>2],v[a+4>>2]),c);f=fb-16|0;fb=f;b=il(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){tz(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Ed(b);fb=f+16|0;vd(a,c);bg(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Jd(a,d+(b<<2)|0)}}function ME(a,b,c,d){var e=0,f=C(0);v[23220]=0;Y(919,a|0);e=v[23220];v[23220]=0;if((e|0)!=1){a=v[v[a+24>>2]+24>>2];a:{if((b|0)<0|x[a+480188>>1]<=b>>>0){break a}a=a+B(b,872)|0;if(t[a+1075081|0]&1){break a}f=C(C(w[a+d|0])*C(.0078125))}return f}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,c|0,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return C(0)}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function BL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;d=Qc(a);a:{b:{c:{f=oi(b,c);if(d>>>0<f>>>0){if(Cs(a,b)){break c}g=d;h=f-d|0;d=Bb(a);Ll(a,g,h,d,0,d,0)}d=pc(a);while(1){if((b|0)==(c|0)){break b}bd(d,b);d=d+1|0;b=b+1|0;continue}}b=Xf(e,b,c);c=Ec(b);d=Bb(b);v[23220]=0;W(54,a|0,c|0,d|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){ub(b);break a}a=P()|0;O()|0;ub(b);S(a|0);L()}t[e+15|0]=0;bd(d,e+15|0);hh(a,f)}fb=e+16|0;return a|0}function ps(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(v[23214]){b=ps(v[23214])}if(!v[23138]){break a}c=b|c;a=v[23138];continue}break}d=v[a+76>>2]>=0;b:{c:{if(v[a+20>>2]==v[a+28>>2]){break c}jb[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break c}b=-1;if(d){break b}break a}b=v[a+8>>2];e=v[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;jb[v[a+40>>2]](a,b,b>>31,1)|0}b=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;if(!d){break a}}}return b|c}function nk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;v[b>>2]=0;v[b+4>>2]=0;t[e+15|0]=0;Hh(a,e+15|0);c=w[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){v[b>>2]=f;v[b+4>>2]=d;if(!g&(h|0)==(i|0)){fb=e+16|0}else{t[e+15|0]=0;Hh(a,e+15|0);c=v[b>>2];j=v[b+4>>2];f=w[e+15|0];d=g;g=h+1|0;d=g?d:d+1|0;h=g;g=d;k=c;d=(h<<3)-2|0;c=d&31;if((d&63)>>>0>=32){d=f<<c;c=0}else{d=(1<<c)-1&f>>>32-c;c=f<<c}f=k|c;d=d|j;continue}break}}function mc(a,b){var c=0,d=0,e=0;c=v[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if((b|0)>24){return mc(a,24)+(mc(a,b-24|0)<<24)|0}if(!c){v[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=Ur(a);d=0;if((e|0)==-1){break a}d=v[a+1396>>2];c=d+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){ca(10038,13164,1632,6791);L()}d=v[a+1392>>2];v[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}v[a+1396>>2]=c}return d}function Uf(a){var b=0,c=0,d=0;d=ep(Cf(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){b=w[a|0];break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}t[c|0]=b;if(!(b&255)){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function O1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-32|0;fb=e;a:{if(!c){break a}g=nl(v[b+4>>2],w[b+11|0]);h=g-1|0;d=d<<24>>24;while(1){if((f|0)==(g|0)){break a}b:{if(!f|(f>>>0)%(c>>>0)){break b}if((f|0)==(h|0)){if(w[qd(b)|0]==(ef(43)&255)){break b}if(w[qd(b)|0]==(ef(45)&255)){break b}}i=e,j=Fi(b),v[i+8>>2]=j;i=e,j=Ei(e+8|0,g-f|0),v[i+16>>2]=j;GI(b,v[Ef(e+24|0,e+16|0)>>2],1,ef(d))}f=f+1|0;continue}}Mc(a,b);fb=e+32|0}function tL(a,b,c,d,e,f,g,h){var i=0,j=0;i=fb-16|0;fb=i;v[i+12>>2]=d;a:{if(!(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24))){break a}v[i+8>>2]=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);j=b;b=v[Eb(i+8|0,i+12|0)>>2];v[j>>2]=b;b=Pd(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),b,d);v[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=x[e>>1]|f;u[e>>1]=b;if((w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))!=1){break a}u[e>>1]=b|g}fb=i+16|0}function mt(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;e=d+16|0;yP(e,a,a+1|0,a+2|0,a+3|0);yP(d,b,b+1|0,b+2|0,b+3|0);fb=d+32|0;a=w[v[e>>2]];b=w[v[d>>2]];c=1;a:{if(a>>>0<b>>>0){break a}c=0;if(a>>>0>b>>>0){break a}a=t[v[e+4>>2]];b=t[v[d+4>>2]];c=1;b:{if((a|0)<(b|0)){break b}c=0;if((a|0)>(b|0)){break b}f=v[e+12>>2];g=v[d+12>>2];a=w[v[d+8>>2]];b=w[v[e+8>>2]];c=1;c:{if(a>>>0>b>>>0){break c}c=0;if(a>>>0<b>>>0){break c}c=w[f|0]<w[g|0]}}}return c}function QU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a:{b:{if(!Sf(a,7)){break b}c=0;if(!bC(a,17771)){break a}if(!Sf(a,1)){break b}c=-1;if(!Zc(a,uq(a))){break a}c=fb-16|0;fb=c;f=d+8|0;no(c+8|0,f);e=v[c+12>>2];hd(c,a,v[c+8>>2],e);g=v[c+4>>2];if((g|0)==(e|0)){Zc(a,v[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){uu(f)}c=-1;if(!e){break a}c=0;if(!QB(w[d+8|0],w[d+9|0])){break a}c=Ce(a,b,PB(d+8|0),ib);break a}c=-1}fb=d+16|0;return c|0}function Iw(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[115701]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[115696]=25;a=-1}else{a=1}return a}t[a|0]=b;return 1}function yda(a,b){a=a|0;b=b|0;var c=0,d=0;c=Ib(a);a:{if(b){v[23220]=0;R(646,c|0,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break a}a=fb-16|0;fb=a;v[a>>2]=c;d=v[c+4>>2];v[a+4>>2]=d;v[a+8>>2]=d+B(b,9);b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=a+16|0}else{t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;b=b+9|0;v[a+4>>2]=b;continue}break}}return c|0}a=P()|0;O()|0;Jp(c);S(a|0);L()}function u4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[23220]=0;Y(944,a|0);d=v[23220];v[23220]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[23220]=0;ta(f|0,d|0,b|0,+c);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,11652,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function sda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-4096|0;fb=c;_l(a,b);a:while(1){if(Wc(v[a>>2],v[a+4>>2])>>>12>>>0>e>>>0){f=e<<12;b=0;d=0;while(1)if((b|0)==2048){g=f|2048;b=0;while(1){if((b|0)!=2048){h=Hb(v[a>>2],b+g|0);i=Hb(c,b<<1);d=w[h|0]+d|0;t[i|0]=d;b=b+1|0;continue}break}Yg(c,JP(c),Vg(Ab(v[a>>2]),f));e=e+1|0;continue a}else{g=Hb(v[a>>2],b+f|0);h=Hb(c,b<<1|1);d=w[g|0]+d|0;t[h|0]=d;b=b+1|0;continue}}break}fb=c+4096|0}function k4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[23220]=0;Y(944,a|0);d=v[23220];v[23220]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+96>>2];v[23220]=0;ta(f|0,d|0,b|0,+c);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,11590,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function i4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[23220]=0;Y(944,a|0);d=v[23220];v[23220]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+88>>2];v[23220]=0;ta(f|0,d|0,b|0,+c);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,10973,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function qaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=dg(e,v[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;a:{b:{d=b-d|0;b=v[Cb(a)>>2];f=v[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){kz(a,d,c);break c}b=Cb(a);b=kt(e+8|0,Hp(a,dg(v[a>>2],f)+d|0),dg(v[a>>2],v[a+4>>2]),b);v[23220]=0;U(727,b|0,d|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}vO(a,b);iz(b)}fb=e+32|0;break a}a=P()|0;O()|0;iz(b);S(a|0);L()}return}if(b>>>0<d>>>0){xO(a,e+(b<<5)|0)}}function Ji(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=Wc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=v[Cb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>>0){sE(a,b);break a}c=Cb(a);c=wl(e+8|0,tl(a,Wc(v[a>>2],d)+b|0),Wc(v[a>>2],v[a+4>>2]),c);f=fb-16|0;fb=f;b=Iv(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){rg(d);d=v[b>>2]+1|0;v[b>>2]=d;continue}break}Ed(b);fb=f+16|0;vd(a,c);vl(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Jd(a,b+d|0)}}function gfa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=fb-32|0;fb=g;a:{if(x[a+480192>>1]<b>>>0){break a}b=v[((b<<2)+a|0)+900380>>2];if(!b){break a}h=g+16|0;XR(h,b);i=g,j=Ab(v[g+16>>2]),v[i+8>>2]=j;h=Hf(h);while(1){b=v[g+8>>2];if(Nb(b,h)){b=x[Pp(b)>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}Rg(g+8|0);continue}else{rA(g+16|0)}break}}fb=g+32|0}function r3(a,b){a=a|0;b=b|0;var c=0,d=0;v[23220]=0;Y(919,a|0);c=v[23220];v[23220]=0;if((c|0)!=1){a=v[v[a+24>>2]+24>>2];c=0;a:{if(!Xr(b)){break a}d=v[a+484344>>2];if(!ke(d,v[a+484348>>2],b&65535)){break a}c=v[Xb(d,b)+12>>2]}return c|0}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,6585,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function N2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-16|0;fb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=aa(8)|0;v[23220]=0;b=Q(52,h|0,8187)|0;c=v[23220];v[23220]=0;if((c|0)==1){break c}a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}e=P()|0;O()|0;ub(b);break b}Ik(a,b,4);c=gx(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);fb=h+16|0;return c|0}e=P()|0;O()|0;ba(a|0)}S(e|0)}L()}function IN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;j=e,k=Zj(b),v[j>>2]=k;c=fb-16|0;fb=c;f=Xy(a,c+12|0,x[b>>1],v[b+4>>2]);b=v[f>>2];if(!b){b=fb-16|0;fb=b;d=fc(a);g=oh(c,tc(36),ph(b+8|0,d));d=v[g>>2]+16|0;h=v[e>>2];i=v[h+4>>2];v[d>>2]=v[h>>2];v[d+4>>2]=i;Ib(d+8|0);j=fc(g),k=1,t[j+4|0]=k;fb=b+16|0;Tg(a,v[c+12>>2],f,v[c>>2]);b=Ud(c);MN(c);d=1}Sg(e+8|0,v[dc(c,b)>>2],d);fb=c+16|0;a=pd(v[e+8>>2]);fb=e+16|0;return a+8|0}function $2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-16|0;fb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=aa(8)|0;v[23220]=0;b=Q(52,h|0,8187)|0;c=v[23220];v[23220]=0;if((c|0)==1){break c}a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}e=P()|0;O()|0;ub(b);break b}Ik(a,b,4);c=fx(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);fb=h+16|0;return c|0}e=P()|0;O()|0;ba(a|0)}S(e|0)}L()}function oS(a,b){var c=0,d=0,e=0,f=0;d=v[a>>2];c=sc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=v[Cb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){zA(a,b);break a}c=Cb(a);c=cg(e+8|0,Pg(a,sc(v[a>>2],d)+b|0),sc(v[a>>2],v[a+4>>2]),c);f=fb-16|0;fb=f;b=il(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){lm(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Ed(b);fb=f+16|0;vd(a,c);bg(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Jd(a,d+(b<<2)|0)}}function s2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-32|0;fb=e;a:{if(!c){break a}f=Bb(b);g=f-1|0;h=d<<24>>24;d=0;while(1){if((d|0)==(f|0)){break a}b:{if(!d|(d>>>0)%(c>>>0)){break b}if((d|0)==(g|0)){if(w[Fc(b,0)|0]==(ef(43)&255)){break b}if(w[Fc(b,0)|0]==(ef(45)&255)){break b}}i=e,j=Td(b),v[i+8>>2]=j;i=e,j=Ei(e+8|0,f-d|0),v[i+16>>2]=j;ix(b,v[Ef(e+24|0,e+16|0)>>2],1,ef(h))}d=d+1|0;continue}}Mc(a,b);fb=e+32|0}function cda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=Uc(c+8|0,16,1,1,0);v[c+4>>2]=0;kd(a,0);wc(b);a:{b:{if(zq(b,13736)){Vc(b,12);if(!km(b)){so(d,2)}Vc(b,24);break b}if(wh(b,13608)){wc(b);v[c+4>>2]=4;e=1;break a}Eh(d,8)}e=0}f=a,g=(Ze(b)>>>0)/(B(w[d|0],Up(w[d+1|0]))>>>3>>>0)|0,v[f>>2]=g;b=hg(d,a,b);if(!(!b|!e)){d=v[a+20>>2];f=c,g=sj(v[a>>2],x[a+34>>1]),v[f>>2]=g;Sb(d,0,v[Eb(c+4|0,c)>>2])}fb=c+16|0;return(b|0)!=0|0}function XF(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[115696];v[115696]=0;wd();a=mw(a,e+12|0,d);d=ib;g=v[115696];e:{if(g){if(v[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}v[115696]=h;if((b|0)!=v[e+12>>2]){break c}if(!d){break b}}v[c>>2]=4;a=-1;break a}}v[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}fb=e+16|0;return a}function cga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=v[a>>2];c=Bf(d,v[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;a:{b:{c=b-c|0;b=v[Cb(a)>>2];e=v[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){jC(a,c);break c}b=Cb(a);b=XA(d+8|0,YA(a,Bf(v[a>>2],e)+c|0),Bf(v[a>>2],v[a+4>>2]),b);v[23220]=0;R(463,b|0,c|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}WA(a,b);Xt(b)}fb=d+32|0;break a}a=P()|0;O()|0;Xt(b);S(a|0);L()}return}if(b>>>0<c>>>0){hC(a,d+B(b,20)|0)}}function cW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;v[e+4>>2]=1;k=e,l=tc(32),v[k+8>>2]=l;h=fb-16|0;fb=h;f=Bo(v[e+8>>2]);v[f>>2]=43128;i=vc(f);g=pl(h+8|0,v[b>>2],v[b+4>>2]);f=v[g>>2];j=v[c>>2];d=v[d>>2];b=fb-16|0;fb=b;g=v[g+4>>2];v[b+12>>2]=g;v[b+8>>2]=f;c=Em(i);v[c>>2]=43264;pl(c+4|0,f,g);v[c+16>>2]=d;v[c+12>>2]=j;be(b+8|0);fb=b+16|0;fb=h+16|0;b=a;a=Do(e);Co(b,vc(a),a);Fm(e);fb=e+16|0}function IT(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a+1064>>2];a:{while(1){if((b|0)>255){break a}f=(B(b,6)+a|0)+1072|0,g=jk(a,7),t[f|0]=g;d=jk(a,1);e=jk(a,1);c=v[a+1060>>2];if((c|0)>255){break a}b=v[a+1064>>2]+1|0;v[a+1060>>2]=b;v[a+1064>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1068>>1]=b;IT(a);b=v[a+1064>>2];break b}u[(B(c,6)+a|0)+1068>>1]=65535}v[a+1060>>2]=b;if(e){u[(B(c,6)+a|0)+1070>>1]=b;continue}break}u[(B(c,6)+a|0)+1070>>1]=65535}}function m4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23220]=0;Y(944,a|0);c=v[23220];v[23220]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[23220]=0;R(e|0,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,12753,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function h4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23220]=0;Y(944,a|0);c=v[23220];v[23220]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+84>>2];v[23220]=0;R(e|0,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,12236,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function g4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23220]=0;Y(944,a|0);c=v[23220];v[23220]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+80>>2];v[23220]=0;R(e|0,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,11063,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function B4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23220]=0;Y(944,a|0);c=v[23220];v[23220]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[23220]=0;R(e|0,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,11282,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function s4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23220]=0;Y(944,a|0);c=v[23220];v[23220]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[23220]=0;qa(e|0,c|0,+b);c=v[23220];v[23220]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23220]=0;X(906,11690,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23220]=0;Z(17);d=v[23220];v[23220]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function n4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23220]=0;Y(944,a|0);c=v[23220];v[23220]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[23220]=0;R(e|0,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,9283,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function l4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23220]=0;Y(944,a|0);c=v[23220];v[23220]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+100>>2];v[23220]=0;d=+sa(e|0,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,11608,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function cF(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=fb-16|0;fb=i;if(1073741806-b>>>0>=c>>>0){j=pc(a);k=1073741807;if(b>>>0<=536870886){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=xl(v[Sc(i+12|0,i+8|0)>>2])+1|0}c=pi(k);if(e){bi(c,j,e)}if(g){bi(c+(e<<2)|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){d=e<<2;bi((d+c|0)+(g<<2)|0,(d+j|0)+(f<<2)|0,h)}if((b|0)!=1){Fb(j)}td(a,c);yf(a,k);b=a;a=h+(e+g|0)|0;Bd(b,a);td(c+(a<<2)|0,0);fb=i+16|0;return}kf();L()}function W$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=v[a+16>>2];d=v[a+12>>2];b:{if(g>>>0>d>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=g-d;v[e+4>>2]=c-f;g=d;d=v[nd(e+12|0,nd(e+8|0,e+4|0))>>2];b=Fe(b,g,d);v[a+12>>2]=v[a+12>>2]+d;b=b+d|0;break b}d=jb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=rn(d),t[h|0]=i;d=1;b=b+1|0}f=d+f|0;continue}break}fb=e+16|0;return f|0}function zq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!w[b+7|0]){while(1){if((d|0)==7){d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=cc(c+8|0,c+24|0,7);jc(c+16|0,v[a>>2],v[a+8>>2],v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=7){break b}if(Mb(c+24|0,b,7)){break b}Yb(a,7);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17409,9050,413,13128);L()}ca(17388,9050,411,13128);L()}return d|0}function v4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23220]=0;Y(944,a|0);c=v[23220];v[23220]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[23220]=0;d=+sa(e|0,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,11671,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function q4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23220]=0;Y(944,a|0);c=v[23220];v[23220]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[23220]=0;qa(e|0,c|0,+b);c=v[23220];v[23220]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23220]=0;X(906,7695,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23220]=0;Z(17);d=v[23220];v[23220]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function o4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23220]=0;Y(944,a|0);c=v[23220];v[23220]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[23220]=0;qa(e|0,c|0,+b);c=v[23220];v[23220]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23220]=0;X(906,7643,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23220]=0;Z(17);d=v[23220];v[23220]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function j4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23220]=0;Y(944,a|0);c=v[23220];v[23220]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+92>>2];v[23220]=0;d=+sa(e|0,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,10993,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function TW(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;b=Qb(c,16715);v[23220]=0;U(107,c+16|0,a|0,b|0);a=v[23220];v[23220]=0;a:{if((a|0)!=1){vb(b);a=0;b=0;while(1){d=v[c+16>>2];if(!(b>>>0<=3&rd(d,v[c+20>>2])>>>0>b>>>0)){rl(c+16|0);fb=c+32|0;return a|0}v[23220]=0;d=T(108,Dd(d,b)|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=P()|0;O()|0;rl(c+16|0);break a}a=P()|0;O()|0;vb(b)}S(a|0);L()}function os(a,b){var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=Od(a);d=fc(a);f=fb-16|0;fb=f;while(1){if(c){g=Ws(c+16|0,b);d=g?d:c;c=v[(g?c+4|0:c)>>2];continue}break}c=v[dc(f+8|0,d)>>2];fb=f+16|0;a:{if(Nb(c,Hf(a))){if(!Ws(b,pd(c))){break a}}c=Hf(a)}if(!rc(c,Hf(a))){b=v[dc(e+8|0,c)>>2];c=fb-16|0;fb=c;d=Rg(dc(c+8|0,b));if((b|0)==v[a>>2]){v[a>>2]=v[d>>2]}d=Cb(a);v[d>>2]=v[d>>2]-1;XK(v[fc(a)>>2],b);fb=c+16|0;Rl(pd(b));Fb(b)}fb=e+16|0}function _P(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;v[b+4>>2]=((w[a+48|0]|w[a+49|0]<<8)<<1)+((w[a+32|0]|w[a+33|0]<<8)<<4);v[b+8>>2]=((w[a+50|0]|w[a+51|0]<<8)<<1)+((w[a+34|0]|w[a+35|0]<<8)<<4);v[b+12>>2]=(B(w[a+52|0]|w[a+53|0]<<8,5)+((w[a+36|0]|w[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=zb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=Yo(v[a>>2],v[c>>2])?c:a;continue}}fb=b+16|0;a=v[a>>2];ib=a>>31;return a}function z4(a,b){a=a|0;b=b|0;var c=0,d=0;v[23220]=0;Y(944,a|0);c=v[23220];v[23220]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[23220]=0;b=Q(d|0,c|0,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,6648,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function x4(a,b){a=a|0;b=b|0;var c=0,d=0;v[23220]=0;Y(944,a|0);c=v[23220];v[23220]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[23220]=0;b=Q(d|0,c|0,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,6699,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function ix(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;v[g+8>>2]=b;j=g,k=Td(a),v[j>>2]=k;b=bk(g+8|0,g);h=fb-16|0;fb=h;a:{f=Bb(a);if(b>>>0<=f>>>0){if(c){e=Qc(a);b:{if(e-f>>>0>=c>>>0){e=pc(a);if((b|0)==(f|0)){break b}i=b+e|0;pj(i+c|0,i,f-b|0);break b}Ll(a,e,(c+f|0)-e|0,f,b,0,c);e=v[a>>2]}lq(b+e|0,c,d);b=c+f|0;hh(a,b);t[h+15|0]=0;bd(b+e|0,h+15|0)}fb=h+16|0;break a}fm();L()}Td(a);fb=g+16|0}function g5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;if(a){b=oc(d+8|0,a);f=v[b>>2];c=fb-16|0;fb=c;e=v[b+4>>2];a=0;a:{if(!e){break a}a=32208;while(1){if((a|0)==32784){b=32784;while(1){a=b;if((a|0)!=32832){b=a+12|0;if(!AL(f,e,v[oc(c,v[a+8>>2])>>2],v[c+4>>2])){continue}}break}a=(a|0)!=32832;break a}b=v[a+8>>2];a=a+12|0;if(!AL(f,e,v[oc(c+8|0,b)>>2],v[c+12>>2])){continue}break}a=1}fb=c+16|0}else{a=0}fb=d+16|0;return a|0}function DG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;v[e+44>>2]=c;v[e+40>>2]=b;b=Qb(e+8|0,d);v[23220]=0;U(1079,e+24|0,e+40|0,b|0);c=v[23220];v[23220]=0;a:{b:{if((c|0)!=1){v[23220]=0;a=Q(1080,a|0,e+24|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break b}ub(e+24|0);ub(b);v[a>>2]=90796;b=v[e+44>>2];v[a+8>>2]=v[e+40>>2];v[a+12>>2]=b;fb=e+48|0;return a|0}d=P()|0;O()|0;break a}d=P()|0;O()|0;ub(e+24|0)}ub(b);S(d|0);L()}function Aaa(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:jh(a,0,c);return;case 1:jh(a,1,c);return;case 2:jh(a,2,c);return;case 3:jh(a,3,c);return;case 4:jh(a,4,c);return;case 5:jh(a,5,c);return;case 6:oO(a,23712,c);return;case 7:oO(a,24736,c);return;case 8:jh(a,6,c);return;case 9:jh(a,7,c);return;case 10:jh(a,8,c);return;case 11:jh(a,9,c);return;case 12:jh(a,10,c);return;case 13:jh(a,11,c);return;default:break a}}Gb(a)}function gg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[Tc(43116,d+14|0)>>1];e=v[a>>2];c=Ic(e,v[a+4>>2]);a:{if(b>>>0>c>>>0){e=fb-32|0;fb=e;b=b-c|0;c=v[Cb(a)>>2];g=v[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){po(a,b,f);break b}c=Cb(a);c=vj(e+8|0,wj(a,Ic(v[a>>2],g)+b|0),Ic(v[a>>2],v[a+4>>2]),c);wC(c,b,f);vd(a,c);Di(c)}fb=e+32|0;break a}if(b>>>0<c>>>0){Jd(a,e+(b<<1)|0)}}fb=d+16|0}function NS(a,b,c,d,e){var f=0,g=0,h=0,i=0;h=-1;f=d&2147483647;i=f;g=(f|0)==2147418112;a:{if(g&!c?a|b:g&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;g=(f|0)==2147418112;if(g?0:g&0|f>>>0>2147418112){break a}if(!(a|c|(f|i|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function G6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ji(a,b,c,d);v[a>>2]=45296;c=Ib(a+4256|0);b=a+4208|0;e=zb(b,0),f=1056964608,v[e>>2]=f;e=zb(b,1),f=1017370378,v[e>>2]=f;e=zb(b,2),f=1028670828,v[e>>2]=f;e=zb(b,3),f=1059760811,v[e>>2]=f;e=zb(b,4),f=1017370378,v[e>>2]=f;e=zb(b,5),f=1065353216,v[e>>2]=f;v[23220]=0;R(870,a+44|0,2);b=v[23220];v[23220]=0;if((b|0)!=1){ii(a);return a|0}b=P()|0;O()|0;lc(c);sf(a);S(b|0);L()}function UY(a){a=a|0;if(w[466816]){return v[116703]}if(!w[467336]){a=467168;while(1){a=Gb(a)+12|0;if((a|0)!=467336){continue}break}t[467336]=1}id(467168,87476);id(467180,87504);id(467192,87532);id(467204,87564);id(467216,87604);id(467228,87640);id(467240,87668);id(467252,87704);id(467264,87720);id(467276,87736);id(467288,87752);id(467300,87768);id(467312,87784);id(467324,87800);t[466816]=1;v[116703]=467168;return 467168}function eea(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;t[b+15|0]=128;a=eu(a,127,b+15|0);v[23220]=0;t[b+14|0]=64;d=W(539,a+12|0,127,b+14|0)|0;c=v[23220];v[23220]=0;a:{b:{if((c|0)!=1){v[23220]=0;t[b+13|0]=0;Q(616,a+24|0,b+13|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break b}v[a+44>>2]=0;v[a+48>>2]=0;v[a+36>>2]=-1;v[a+40>>2]=108855296;u[a+52>>1]=0;fb=b+16|0;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;$b(d)}$b(a);S(b|0);L()}function JE(a,b,c,d,e,f,g,h,i){var j=0;v[23220]=0;Y(919,a|0);j=v[23220];v[23220]=0;a:{b:{if((j|0)!=1){j=v[a+24>>2];v[23220]=0;b=ua(i|0,j|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,h|0,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function B2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=fb-32|0;fb=b;v[b+24>>2]=e;v[b+28>>2]=f;a:{e=a;a=cc(b+16|0,c,d);a=Fs(e,v[a>>2],v[a+4>>2],b+24|0);if(a+1>>>0>=3){a=aa(8)|0;v[23220]=0;b=Q(52,b|0,8044)|0;c=v[23220];v[23220]=0;b:{if((c|0)!=1){a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}d=P()|0;O()|0;ub(b);break b}d=P()|0;O()|0;ba(a|0)}S(d|0);L()}fb=b+32|0;return a|0}L()}function zH(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;c=z[a>>2];i=a-16|0;d=z[i>>2];e=C(c+d);b=a-8|0;f=z[b>>2];j=a-24|0;g=z[j>>2];h=C(f+g);z[a>>2]=e+h;z[b>>2]=e-h;b=a-12|0;h=z[b>>2];k=a-28|0;l=z[k>>2];e=C(h+l);p=b;b=a-4|0;m=z[b>>2];a=a-20|0;n=z[a>>2];o=C(m+n);z[p>>2]=o-e;f=C(f-g);g=C(m-n);z[k>>2]=f+g;c=C(c-d);d=C(h-l);z[i>>2]=c+d;z[j>>2]=c-d;z[b>>2]=e+o;z[a>>2]=g-f}function px(a,b,c,d,e){var f=0,g=0;a:{if(!Xr(b)){break a}f=v[a+484344>>2];if(!ke(f,v[a+484348>>2],b&65535)){break a}b=Xb(f,b);if(v[b+12>>2]<=(c|0)|e>>>0>5|x[a+480188>>1]<=d>>>0|(c|d)<0){break a}b=$c(v[b>>2],v[v[b+48>>2]+12>>2],c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}g=w[b|0]}return g}function D2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[23220]=0;Y(919,a|0);d=v[23220];v[23220]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[23220]=0;U(1013,d|0,b|0,c|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,10282,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Ce(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;g=$g(a);a:{b:{if(!b){i=e,j=$g(a),v[i+8>>2]=j;v[e+12>>2]=0;break b}f=v[b+4>>2];h=v[b>>2];v[e+8>>2]=h;v[e+12>>2]=f;a=v[a+12>>2];v[e>>2]=2048;v[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=Gq(e+8|0,e);c=v[a>>2];a=v[a+4>>2];if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break b}break a}a=0;if((d|0)==(f|0)&b>>>0>h>>>0|d>>>0>f>>>0){break a}}a=1}fb=e+16|0;return a}function lX(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[23220]=0;a=Ka(1016,a|0,b|0,c|0,d|0)|0;b=v[23220];v[23220]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23220]=0;ja(902,11086,e|0,f|0,g|0,h|0,i|0,j|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}return a|0}function T$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=v[a+12>>2];f=v[a+16>>2];b:{if(d>>>0<f>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=f-d>>2;v[e+4>>2]=c-g;f=d;d=v[nd(e+12|0,nd(e+8|0,e+4|0))>>2];bi(b,f,d);f=d<<2;v[a+12>>2]=f+v[a+12>>2];b=b+f|0;break b}d=jb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}fb=e+16|0;return g|0}function ZU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;v[d+12>>2]=-1;if(kg(a,d+8|0)){v[d+4>>2]=w[d+8|0];f=v[Eb(d+4|0,d+12|0)>>2];c=fb+-64|0;fb=c;e=c+40|0;Af(e,a,f);g=v[c+40>>2];a=c+8|0;Pf(a,3,te(e),g);v[23220]=0;R(209,c+24|0,a|0);a=v[23220];v[23220]=0;a:{if((a|0)!=1){cc(c,b,11);a=c+24|0;gl(c,a);ub(a);Jc(c+40|0);fb=c- -64|0;e=!f|(g|0)!=0;break a}a=P()|0;O()|0;Jc(c+40|0);S(a|0);L()}}fb=d+16|0;return e|0}function TN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;v[a+4>>2]=0;a:{if(b){b:{if(jt(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}e=Sn(d+16|0);v[23220]=0;f=Q(696,a|0,b|0)|0;g=v[23220];v[23220]=0;if((g|0)==1){break a}v[23220]=0;R(697,e|0,f|0);f=v[23220];v[23220]=0;if((f|0)==1){break a}v[e+4>>2]=b;pt(a,e);Ie(e)}Xk(d+8|0,v[a>>2]);Vu(v[d+8>>2],v[d+12>>2],b,w[c|0])}fb=d+32|0;return}a=P()|0;O()|0;Ie(e);S(a|0);L()}function Qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=$j(e,v[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;d=b-d|0;b=v[Cb(a)>>2];f=v[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){HA(a,d,c);break a}b=Cb(a);b=CS(e+8|0,DA(a,$j(v[a>>2],f)+d|0),$j(v[a>>2],v[a+4>>2]),b);BS(b,d,c);c=b+4|0;zS(v[a>>2],v[a+4>>2],c);kc(a,c);kc(a+4|0,b+8|0);kc(Cb(a),vc(b));v[b>>2]=v[b+4>>2];AS(b)}fb=e+32|0;return}if(b>>>0<d>>>0){Jd(a,e+B(b,6)|0)}}function H2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[23220]=0;Y(919,a|0);d=v[23220];v[23220]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[23220]=0;e=+ya(1009,d|0,b|0,c|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,5311,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function GI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;v[g+8>>2]=b;j=g,k=Fi(a),v[j>>2]=k;b=bk(g+8|0,g);h=fb-16|0;fb=h;a:{f=xd(v[a+4>>2],w[a+11|0]);if(b>>>0<=f>>>0){if(c){e=co(a);b:{if(e-f>>>0>=c>>>0){e=qd(a);if((b|0)==(f|0)){break b}i=b+e|0;pj(i+c|0,i,f-b|0);break b}Ay(a,e,(c+f|0)-e|0,f,b,c);e=v[a>>2]}lq(b+e|0,c,d);b=c+f|0;Yp(a,b);t[h+15|0]=0;bd(b+e|0,h+15|0)}fb=h+16|0;break a}fm();L()}Fi(a);fb=g+16|0}function t4(a){a=a|0;var b=0,c=0,d=0;v[23220]=0;Y(944,a|0);b=v[23220];v[23220]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[23220]=0;c=+na(d|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,11708,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function yH(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){Zb(a,21);return-1}if(v[a+1396>>2]<=9){Dk(a)}d=v[a+1392>>2];c=u[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=w[d+v[b+8>>2]|0];v[a+1392>>2]=e>>>c;c=v[a+1396>>2]-c|0;v[a+1396>>2]=(c|0)>0?c:0;c=(c|0)>=0?d:-1;break a}c=Dl(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!(!(v[a+1384>>2]?w[a+1376|0]:1)|(c|0)>=0)){Zb(a,21)}return c}ca(7484,13164,1793,5711);L()}function r4(a){a=a|0;var b=0,c=0,d=0;v[23220]=0;Y(944,a|0);b=v[23220];v[23220]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[23220]=0;c=+na(d|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,7712,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function p4(a){a=a|0;var b=0,c=0,d=0;v[23220]=0;Y(944,a|0);b=v[23220];v[23220]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[23220]=0;c=+na(d|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,7660,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Z2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!(e?d:0)){a=aa(8)|0;v[23220]=0;b=Q(52,f|0,8187)|0;c=v[23220];v[23220]=0;if((c|0)==1){break c}a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}e=P()|0;O()|0;ub(b);break b}Ik(a,b,2);c=fx(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c|0}e=P()|0;O()|0;ba(a|0)}S(e|0)}L()}function L2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!(e?d:0)){a=aa(8)|0;v[23220]=0;b=Q(52,f|0,8187)|0;c=v[23220];v[23220]=0;if((c|0)==1){break c}a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}e=P()|0;O()|0;ub(b);break b}Ik(a,b,2);c=gx(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c|0}e=P()|0;O()|0;ba(a|0)}S(e|0)}L()}function I4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;v[e+24>>2]=c;c=v[Rf(e+16|0,e+24|0)>>2];v[23220]=0;f=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;fa(913,a+8|0,e|0,c|0,d|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){a=lI(a);b=kI(a+88|0);c=jI(a+92|0);v[a>>2]=61608;v[b>>2]=61720;v[c>>2]=61800;pe(e+24|0);fb=e+32|0;return a|0}a=P()|0;O()|0;pe(e+24|0);S(a|0);L()}function d8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;c=bf(a,c);Yd(f,v[a+28>>2]);a:{b:{if(!c){d=-1;if(!cd(a,5)){break b}break a}d=v[c+8>>2]}g=v[a+28>>2];c:{if(!((d|0)!=4&(d|0)!=-1)){d=fb-16|0;fb=d;v[d+8>>2]=0;jp(g,d+8|0);z[b>>2]=z[d+8>>2];fb=d+16|0;break c}e=fb-32|0;fb=e;v[e+28>>2]=0;v[e+24>>2]=d;v[e+20>>2]=4;xr(e+8|0,g,e+28|0,v[Eb(e+24|0,e+20|0)>>2]);v[b>>2]=0;fb=e+32|0}e=c}We(a,e);fb=f+16|0}function Rw(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!Tr(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}Zb(a,32);return 0}ca(15700,13164,1564,5997);L()}function MY(a){a=a|0;if(w[466808]){return v[116701]}if(!w[467160]){a=466992;while(1){a=Gb(a)+12|0;if((a|0)!=467160){continue}break}t[467160]=1}ed(466992,5201);ed(467004,5208);ed(467016,5174);ed(467028,5182);ed(467040,5165);ed(467052,5215);ed(467064,5192);ed(467076,9719);ed(467088,9925);ed(467100,11268);ed(467112,12836);ed(467124,5464);ed(467136,10725);ed(467148,6548);t[466808]=1;v[116701]=466992;return 466992}function A1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;yI(a,c);a:{if(z[a+24>>2]==C(1)){break a}d=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;j=v[a+16>>2];k=v[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=Ih(k,j,b,i);z[f>>2]=z[a+24>>2]*z[f>>2];b=b+1|0;continue}}}fb=c+16|0}function wca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{c=v[b+4>>2];if(!c){break a}f=a+480190|0;u[d>>1]=x[f>>1];u[d+14>>1]=c-1;c=x[Tc(d,d+14|0)>>1];while(1){if(!c){break a}xb(d,v[b>>2],c);b:{if(yb(v[v[d>>2]>>2],v[d+4>>2])){break b}if(NL(a,c&65535)){e=Qb(d,21598);yc(((c<<5)+a|0)+946304|0,e);ub(e)}if(c>>>0<2){break b}e=x[f>>1];if((e|0)!=(c|0)){break b}u[a+480190>>1]=e-1}c=c-1|0;continue}}fb=d+16|0}function t1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-32|0;fb=e;v[e+24>>2]=c;v[e+28>>2]=d;a:{a=cc(e+16|0,a,b);a=Fs(3,v[a>>2],v[a+4>>2],e+24|0);if(a+1>>>0>=3){a=aa(8)|0;v[23220]=0;c=Q(52,e|0,8044)|0;b=v[23220];v[23220]=0;b:{if((b|0)!=1){a=qc(a,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}b=P()|0;O()|0;ub(c);break b}b=P()|0;O()|0;ba(a|0)}S(b|0);L()}fb=e+32|0;return a|0}L()}function ZH(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{d:{if((b|0)>=0){a=v[a+32>>2];if((zg(a)|0)>(b|0)){break d}}b=aa(8)|0;v[23220]=0;c=Q(52,c|0,10667)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}a=qc(b,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ub(c);break b}fb=c+16|0;return(v[(a+B(b,872)|0)+1075080>>2]&134218752)!=0|0}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function IE(a,b,c,d,e,f,g){var h=0;v[23220]=0;Y(919,a|0);h=v[23220];v[23220]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[23220]=0;b=ga(g|0,h|0,b|0,c|0,d|0,e|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,f|0,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Yt(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=Hb(a,0);e=(w[f|0]&15)<<8|w[Hb(a,1)|0];c=0;a:{if(!e|(e|0)==4095){break a}while(1){c=108;if((d|0)==84){break a}b:{c=x[(d<<1)+32832>>1];if(c>>>0<=e>>>0){if(!d|(e|0)==(c|0)|(x[(d<<1)+32830>>1]-e|0)>=(e-c|0)){break b}c=d+24|0;break a}d=d+1|0;continue}break}c=d+25|0}t[b|0]=c;e=w[f|0]&16;d=Hb(a,2);t[b+1|0]=e|w[d|0]>>>4;t[b+3|0]=w[d|0]&15;g=b,h=w[Hb(a,3)|0],t[g+5|0]=h}function yW(a){a=a|0;var b=0;a=Gb(a);v[23220]=0;R(70,a|0,4);b=v[23220];v[23220]=0;a:{b:{if((b|0)==1){break b}v[23220]=0;R(48,a|0,32);b=v[23220];v[23220]=0;if((b|0)==1){break b}v[23220]=0;R(48,a|0,10);b=v[23220];v[23220]=0;if((b|0)==1){break b}v[23220]=0;R(48,a|0,13);b=v[23220];v[23220]=0;if((b|0)==1){break b}v[23220]=0;R(48,a|0,9);b=v[23220];v[23220]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}}function tB(a){a=a|0;var b=0,c=0,d=0;b=v[a>>2];if(b){jb[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;Bc(a);b=fb-32|0;fb=b;a:{b:{d=Uo(a);c=Wc(v[a>>2],v[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}v[23220]=0;c=fa(879,b+8|0,c|0,c|0,Cb(a)|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){vd(a,c);vl(c);break c}a=V(0)|0;O()|0;_(a|0)|0;v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)==1){break b}}fb=b+32|0;break a}V(0)|0;O()|0;Tb();L()}}function M9(a){a=a|0;var b=0;a=Gb(a);v[23220]=0;R(43,a|0,4);b=v[23220];v[23220]=0;a:{b:{if((b|0)==1){break b}v[23220]=0;R(44,a|0,32);b=v[23220];v[23220]=0;if((b|0)==1){break b}v[23220]=0;R(44,a|0,10);b=v[23220];v[23220]=0;if((b|0)==1){break b}v[23220]=0;R(44,a|0,13);b=v[23220];v[23220]=0;if((b|0)==1){break b}v[23220]=0;R(44,a|0,9);b=v[23220];v[23220]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;ub(a);S(b|0);L()}}function K2(a,b){a=a|0;b=b|0;var c=0,d=0;v[23220]=0;Y(919,a|0);c=v[23220];v[23220]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23220]=0;R(1008,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,10807,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function yE(a,b,c,d,e,f){var g=0,h=0;g=fb-256|0;fb=g;v[g+248>>2]=37;v[g+252>>2]=0;h=g+248|0;sr(h|1,10548,f,v[b+4>>2]);f=wd();v[g>>2]=d;v[g+4>>2]=e;d=g+224|0;e=Fg(d,24,f,h,g)+d|0;f=Pi(d,e,b);h=g+16|0;Xc(h,b);v[23220]=0;ja(1121,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=v[23220];v[23220]=0;if((d|0)!=1){Wb(g+16|0);a=qr(a,g+32|0,v[g+28>>2],v[g+24>>2],b,c);fb=g+256|0;return a}a=P()|0;O()|0;Wb(g+16|0);S(a|0);L()}function MO(a,b,c){a:{switch(b|0){case 0:kh(a,0,c);return;case 1:kh(a,1,c);return;case 2:kh(a,2,c);return;case 3:kh(a,3,c);return;case 4:kh(a,4,c);return;case 5:kh(a,5,c);return;case 6:uO(a,23712,c);return;case 7:uO(a,24736,c);return;case 8:kh(a,6,c);return;case 9:kh(a,7,c);return;case 10:kh(a,8,c);return;case 11:kh(a,9,c);return;case 12:kh(a,10,c);return;case 13:kh(a,11,c);return;default:break a}}Gb(a)}function Tt(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=fb-16|0;fb=i;if(-18-b>>>0>=c>>>0){j=qd(a);k=-17;if(b>>>0<=2147483622){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=Qh(v[Sc(i+12|0,i+8|0)>>2])+1|0}c=tc(k);if(e){Fe(c,j,e)}if(g){Fe(c+e|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){Fe((c+e|0)+g|0,(e+j|0)+f|0,h)}if((b|0)!=10){Fb(j)}td(a,c);yf(a,k);b=a;a=h+(e+g|0)|0;Bd(b,a);t[i+7|0]=0;bd(a+c|0,i+7|0);fb=i+16|0;return}kf();L()}function Ro(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=fb-16|0;fb=i;if(-18-b>>>0>=c>>>0){j=pc(a);k=-17;if(b>>>0<=2147483622){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=Qh(v[Sc(i+12|0,i+8|0)>>2])+1|0}c=tc(k);if(e){Fe(c,j,e)}if(g){Fe(c+e|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){Fe((c+e|0)+g|0,(e+j|0)+f|0,h)}if((b|0)!=10){Fb(j)}td(a,c);yf(a,k);b=a;a=h+(e+g|0)|0;Bd(b,a);t[i+7|0]=0;bd(a+c|0,i+7|0);fb=i+16|0;return}kf();L()}function AE(a,b,c,d,e,f){var g=0,h=0;g=fb-112|0;fb=g;v[g+104>>2]=37;v[g+108>>2]=0;h=g+104|0;sr(h|1,10548,f,v[b+4>>2]);f=wd();v[g>>2]=d;v[g+4>>2]=e;d=g+80|0;e=Fg(d,24,f,h,g)+d|0;f=Pi(d,e,b);h=g+16|0;Xc(h,b);v[23220]=0;ja(1118,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=v[23220];v[23220]=0;if((d|0)!=1){Wb(g+16|0);a=Bq(a,g+32|0,v[g+28>>2],v[g+24>>2],b,c);fb=g+112|0;return a}a=P()|0;O()|0;Wb(g+16|0);S(a|0);L()}function $H(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{d:{if((b|0)>=0){a=v[a+32>>2];if((zg(a)|0)>(b|0)){break d}}b=aa(8)|0;v[23220]=0;c=Q(52,c|0,10667)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}a=qc(b,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ub(c);break b}fb=c+16|0;return+(+v[(a+B(b,872)|0)+1075740>>2]*.015625)}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function Pm(a,b,c,d,e,f){var g=0;v[23220]=0;Y(919,a|0);g=v[23220];v[23220]=0;a:{b:{if((g|0)!=1){g=v[a+24>>2];v[23220]=0;b=fa(f|0,g|0,b|0,c|0,d|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,e|0,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function F4(a){a=a|0;var b=0;v[23220]=0;Y(944,a|0);b=v[23220];v[23220]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){jb[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){Fb(b);v[a+20>>2]=0}Fb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,5012,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function c1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;a:{if(w[b+8|0]){f=v[b+12>>2];h=e,i=Wc(f,v[b+16>>2])-c|0,v[h+28>>2]=i;v[e+24>>2]=v[d+4>>2];g=v[Eb(e+28|0,e+24|0)>>2];f=Vg(Ab(f),c);c=Vg(Vg(Ab(v[b+12>>2]),c),g);b=v[d>>2];Yg(f,c,b);ec(a,b,g);break a}g=v[d+4>>2];d=v[d>>2];v[e+16>>2]=d;v[e+20>>2]=g;f=v[v[b>>2]+40>>2];v[e+8>>2]=d;v[e+12>>2]=g;jb[f|0](a,b,c,e+8|0)}fb=e+32|0}function U$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=v[a+28>>2];d=v[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=Jf(t[b|0]),h=v[v[a>>2]+52>>2],jb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{v[e+12>>2]=g-d;v[e+8>>2]=c-f;g=d;d=v[nd(e+12|0,e+8|0)>>2];Fe(g,b,d);v[a+24>>2]=d+v[a+24>>2];f=f+d|0;b=b+d|0}continue}break}fb=e+16|0;return f|0}function Me(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=Po(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(YE(a,b)&3){case 0:c=Po(A[b>>3],A[b+8>>3]);break a;case 1:c=-Qo(A[b>>3],A[b+8>>3],1);break a;case 2:c=-Po(A[b>>3],A[b+8>>3]);break a;default:break b}}c=Qo(A[b>>3],A[b+8>>3],1)}a=c;fb=b+16|0;return a}function ly(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;t[a+1074368|0]=b;ZL(a+1074332|0,b);f=a+906300|0;a=0;while(1){if((a|0)!=250){b=v[B(a,160)+f>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;if(jb[v[v[b>>2]+136>>2]](b)|0){d=v[b+16>>2];e=d+1074332|0;c=C(C(c/z[e+8>>2])*C(C(y[d+480232>>2])/z[e+20>>2]))}z[b+4196>>2]=c}a=a+1|0;continue}break}}function b3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[23220]=0;c=Q(52,e|0,8187)|0;b=v[23220];v[23220]=0;if((b|0)==1){break c}a=qc(a,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}b=P()|0;O()|0;ub(c);break b}Ik(a,b,1);c=fx(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);fb=e+16|0;return c|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function P2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[23220]=0;c=Q(52,e|0,8187)|0;b=v[23220];v[23220]=0;if((b|0)==1){break c}a=qc(a,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}b=P()|0;O()|0;ub(c);break b}Ik(a,b,1);c=gx(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);fb=e+16|0;return c|0}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function ws(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);v[a+4228>>2]=(B(v[a+4232>>2],w[a+4264|0])+250>>>0)/500;z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16)}function F2(a,b){a=a|0;b=+b;var c=0;v[23220]=0;Y(919,a|0);c=v[23220];v[23220]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23220]=0;b=+Ua(1010,c|0,+b);c=v[23220];v[23220]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;_(c|0)|0;v[23220]=0;X(906,7524,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;O()|0;v[23220]=0;Z(17);c=v[23220];v[23220]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function bt(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;v[b+40>>2]=0;v[b+44>>2]=0;f=b- -64|0;v[f>>2]=0;v[f+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=Ab(v[c>>2]);v[e+8>>2]=d;f=Ab(v[c+4>>2]);while(1){if(!Nb(d,f)){break a}g=d,h=XN(b,A[d>>3]),A[g>>3]=h;d=v[_s(e+8|0)>>2];continue}}}else{XN(b,A[Ne(v[c>>2],0)>>3]);d=d+1|0;continue}break}Wj(a,c);fb=e+16|0}function bC(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!w[b+7|0]){while(1){if((d|0)==7){d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=cc(c+8|0,c+24|0,7);hd(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=7){break b}if(Mb(c+24|0,b,7)){break b}Zc(a,7);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17409,9050,413,13128);L()}ca(17388,9050,411,13128);L()}return d}function tea(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;b=-1;a:{if(!Sf(a,8)){break a}b=fb-32|0;fb=b;v[b+24>>2]=0;v[b+28>>2]=0;d=cc(b+8|0,b+24|0,8);hd(b+16|0,a,v[d>>2],v[d+4>>2]);d=0;b:{if(v[b+20>>2]!=8){break b}if(Mb(b+24|0,14111,8)){break b}Zc(a,8);d=1}fb=b+32|0;b=0;if(!d){break a}b=-1;if(!yj(a,c+8|0)){break a}b=0;if(!_b(v[c+12>>2])){break a}b=!(_b(v[c+8>>2])&-2139062144)}fb=c+16|0;return b|0}function QH(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[23220]=0;d=Q(52,d|0,10667)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}a=qc(b,d);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ub(d);break b}e=(v[a+32>>2]+B(b,872)|0)+1075766|0,f=Gz(c*32768),u[e>>1]=f;fb=d+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function fo(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-16|0;fb=f;v[f+12>>2]=c;a:{if(!Lb(v[b>>2],v[b+8>>2],c)){break a}uc(f+12|0,65535);gg(a,x[f+12>>1]);c=Ab(v[a>>2]);v[f>>2]=c;h=Ab(v[a+4>>2]);while(1){if(!Nb(c,h)){break a}a=f+11|0;if(!kg(b,a)){rg(a)}a=w[f+11|0];u[c>>1]=a;g=65535;b:{if((a|0)!=(d|0)){g=65534;if((a|0)!=(e|0)){break b}}u[c>>1]=g}c=v[Oe(f)>>2];continue}}fb=f+16|0}function dr(a){var b=0,c=0;Im(a,1,15004);v[23220]=0;b=ha(113)|0;c=v[23220];v[23220]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[23220]=0;b=ha(114)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}t[a+16|0]=b;v[23220]=0;b=ha(115)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[23220]=0;Y(116,a+20|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;vb(a);S(b|0);L()}function H8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;Ue(d,2,a+6|0);e=d+16|0;Ac(e,d);yc(b+492|0,e);f=b+236|0;g=c+1|0;ub(e);c=0;while(1){if((c|0)==128){v[b>>2]=(w[a+226|0]|w[a+227|0]<<8)<<5;Rx(a+180|0,b+48|0,0);Rx(a+228|0,b+88|0,2);Rx(a+276|0,b+68|0,1);if(!(w[a+324|0]|w[a+325|0]<<8)){zz(f)}fb=d+32|0}else{h=ac(f,c),i=w[(a+c|0)+38|0]+g|0,u[h>>1]=i;c=c+1|0;continue}break}}function Cca(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Cb(a)>>2]){c=fb-16|0;fb=c;a=vz(c,a);fP(v[a+4>>2],w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));v[a+4>>2]=v[a+4>>2]+4;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Cb(a);c=cg(d+8|0,Pg(a,sc(v[a>>2],v[a+4>>2])+1|0),sc(v[a>>2],v[a+4>>2]),c);fP(v[c+8>>2],w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));v[c+8>>2]=v[c+8>>2]+4;vd(a,c);bg(c);fb=d+32|0}function hM(a,b){var c=0,d=0,e=0,f=0;c=v[a>>2];v[a>>2]=b;if(c){d=fb-16|0;fb=d;b=Ab(v[c>>2]);v[d+8>>2]=b;f=Ab(v[c+4>>2]);while(1){a:{b:{if(Nb(b,f)){while(1){a=v[b>>2];e=v[a>>2];if(!e){break b}a=v[v[e>>2]+8>>2];v[23220]=0;Y(a|0,e|0);a=v[23220];v[23220]=0;if((a|0)!=1){continue}break}V(0)|0;O()|0;Tb();L()}a=lc(c);fb=d+16|0;break a}Pb(a+20|0);Pb(a+8|0);Fb(a);b=v[ye(d+8|0)>>2];continue}break}Fb(a)}}function gE(a,b,c,d,e){var f=0,g=0;a:{f=fb-80|0;fb=f;eA(b);g=f+56|0;Af(g,a,c);a=v[f+56>>2];c=f+8|0;Pf(c,e,te(g),a);v[23220]=0;R(209,f+24|0,c|0);a=v[23220];v[23220]=0;b:{c:{if((a|0)!=1){v[23220]=0;U(11,f+40|0,d|0,f+24|0);a=v[23220];v[23220]=0;if((a|0)==1){break c}a=f+40|0;Db(b,a);vb(a);ub(f+24|0);Jc(f+56|0);fb=f+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;ub(f+24|0)}Jc(f+56|0);S(a|0);L()}}function y3(a){a=a|0;var b=0,c=0;v[23220]=0;Y(919,a|0);b=v[23220];v[23220]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23220]=0;b=T(986,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,7196,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function _da(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=Mz(a,b);v[23220]=0;c=Q(621,a+12|0,b+12|0)|0;d=v[23220];v[23220]=0;b:{c:{if((d|0)!=1){v[23220]=0;Q(622,a+24|0,b+24|0)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}c=v[b+40>>2];v[a+36>>2]=v[b+36>>2];v[a+40>>2]=c;u[a+52>>1]=x[b+52>>1];c=v[b+48>>2];v[a+44>>2]=v[b+44>>2];v[a+48>>2]=c;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;$b(c)}$b(a);S(b|0);L()}}function z1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;a:{if(z[a+24>>2]==C(1)){break a}g=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=v[b+4>>2];j=v[b>>2];k=+z[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Jg(j,i,d,e);A[f>>3]=A[f>>3]*k;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;xI(a,c);fb=c+16|0}function id(a,b){var c=0,d=0,e=0,f=0,g=0;a:{e=iG(b);c=To(a);if(e>>>0<=c>>>0){f=pc(a);d=f;c=e;if(c){b:{if((b|0)==(d|0)){break b}if(d-b>>>0>=c<<2>>>0){if(!c){break b}while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}break b}if(!c){break b}while(1){c=c-1|0;g=c<<2;v[g+d>>2]=v[b+g>>2];if(c){continue}break}}}td((e<<2)+f|0,0);hh(a,e);break a}d=a;a=Bb(a);cF(d,c,e-c|0,a,0,a,e,b)}}function bS(a){var b=0;a:{if(Mb(a,14252,3)|(w[a+3|0]-52&255)>>>0<252){break a}if(_b(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788>>>0<840){break a}if(_b(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))>>>0<52){break a}if(_b(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))-1>>>0<51){break a}b=_b(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))>>>0<4294967216}return b}function QQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!w[b+8|0]){while(1){if((d|0)==8){v[c+24>>2]=0;v[c+28>>2]=0;d=cc(c+8|0,c+24|0,8);jc(c+16|0,v[a>>2],v[a+8>>2],v[d>>2],v[d+4>>2]);d=0;b:{if(v[c+20>>2]!=8){break b}if(Mb(c+24|0,b,8)){break b}Yb(a,8);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17409,9050,413,13128);L()}ca(17388,9050,411,13128);L()}return d|0}function Q1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;a:{if(z[a+24>>2]==C(1)){break a}g=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=v[b+4>>2];j=v[b>>2];k=+z[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Jg(j,i,d,e);A[f>>3]=A[f>>3]*k;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;JI(a,c);fb=c+16|0}function Kca(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;u[b+12>>1]=0;u[b+14>>1]=1;qg(b+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);e=b+12|0;d=fb-16|0;fb=d;c=x[b+14>>1];v[d+12>>2]=c;a:{if(wm(a)>>>0>=c>>>0){g=v[a>>2];f=Ic(g,v[a+4>>2]);v[d+8>>2]=f;Et(g,v[Eb(d+12|0,d+8|0)>>2],e);if(c>>>0>f>>>0){po(a,c-f|0,e);break a}Jd(a,v[a>>2]+(c<<1)|0);break a}FO(a);Tz(a,wj(a,c));po(a,c,e)}fb=d+16|0;fb=b+16|0}function K1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;FI(a,c);a:{if(z[a+24>>2]==C(1)){break a}d=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;j=v[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=Np(j,b,i);z[f>>2]=z[a+24>>2]*z[f>>2];b=b+1|0;continue}}}fb=c+16|0}function J1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;a:{if(z[a+24>>2]==C(1)){break a}g=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=v[b+4>>2];j=v[b>>2];k=+z[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Jg(j,i,d,e);A[f>>3]=A[f>>3]*k;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;EI(a,c);fb=c+16|0}function G1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;a:{if(z[a+24>>2]==C(1)){break a}g=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=v[b+4>>2];j=v[b>>2];k=+z[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Jg(j,i,d,e);A[f>>3]=A[f>>3]*k;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;BI(a,c);fb=c+16|0}function qi(a){var b=0,c=0;b=fb-16|0;fb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=Qo(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(YE(a,b)&3){case 0:a=Qo(A[b>>3],A[b+8>>3],1);break a;case 1:a=Po(A[b>>3],A[b+8>>3]);break a;case 2:a=-Qo(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-Po(A[b>>3],A[b+8>>3])}fb=b+16|0;return a}function L3(a){a=a|0;var b=0,c=0;v[23220]=0;Y(919,a|0);b=v[23220];v[23220]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23220]=0;c=+na(977,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,7596,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function q6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ji(a,b,c,d);v[a>>2]=45904;b=Ib(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=v[c+24620>>2];v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;d=a+4228|0;v[d>>2]=1048576e3;v[d+4>>2]=1048576e3;v[a+4236>>2]=0;v[a+4260>>2]=0;v[a+4256>>2]=c;v[23220]=0;R(870,a+44|0,2);c=v[23220];v[23220]=0;if((c|0)!=1){ii(a);return a|0}c=P()|0;O()|0;lc(b);sf(a);S(c|0);L()}function RU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;v[a>>2]=0;v[a+4>>2]=0;if(!Lb(v[b>>2],v[b+8>>2],c)){c=Ze(b)}v[a>>2]=c;c=v[b>>2];a:{if(jb[v[v[c>>2]+16>>2]](c)|0){c=a;a=v[b>>2];e=c,f=(jb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[e+4>>2]=f;break a}Ji(a+8|0,v[a>>2]);c=v[a+8>>2];a=v[a+12>>2];if(rc(c,a)){break a}ge(d+8|0,c,a);jc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2])}fb=d+16|0}function ax(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;a:{if(w[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=v[a+16>>2];if(b>>>0<=c>>>0){break a}b=tI(b,4096);sI(a,b-c|0);c=v[a+16>>2];b=cc(d+16|0,Hb(v[a+4>>2],c),b-c|0);c=v[v[a>>2]+44>>2];e=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=e;jb[c|0](d+24|0,a,d+8|0);v[a+16>>2]=v[a+16>>2]+v[d+28>>2];if(!(jb[v[v[a>>2]+40>>2]](a)|0)){break a}t[a+20|0]=1}fb=d+32|0}function VF(a,b,c){var d=0,e=0,f=C(0),g=0,h=C(0);e=fb-16|0;fb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[115696];v[115696]=0;wd();d=fb-16|0;fb=d;lw(d,a,e+12|0,0);f=yF(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);fb=d+16|0;a=v[115696];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[115696]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}fb=e+16|0;return f}function xu(a,b,c){var d=0,e=0,f=0;d=v[c+16>>2];a:{if(!d){if(xC(c)){break a}d=v[c+16>>2]}f=v[c+20>>2];if(d-f>>>0<b>>>0){return jb[v[c+36>>2]](c,a,b)|0}b:{if(v[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(w[e+a|0]!=10){continue}break}e=jb[v[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=v[c+20>>2]}nc(f,a,b);v[c+20>>2]=v[c+20>>2]+b;e=b+d|0}return e}function b9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;a:{b:{e=AT(Ec(b),Bb(b),Ec(c),Bb(c));if((e|0)!=-1){f=d,g=Td(b),v[f+16>>2]=g;f=d,g=Ei(d+16|0,e),v[f+24>>2]=g;f=d,g=Ei(d+24|0,1),v[f+32>>2]=g;c=Ef(d+40|0,d+32|0);f=d,g=ih(b),v[f>>2]=g;e=Ef(d+8|0,d);dL(b,v[c>>2],v[e>>2]);break b}if(!Bb(b)){break b}if(sT(Ec(b),Bb(b),Ec(c),Bb(c))){break b}Gb(a);break a}Mc(a,b)}fb=d+48|0}function JA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Lb(v[a>>2],v[a+8>>2],b)){break a}if(b>>>0<=3){d=fb-16|0;fb=d;if(Lb(v[a>>2],v[a+8>>2],b)){while(1){if((c|0)==4){c=v[d+12>>2]}else{t[d+11|0]=0;b:{if(b>>>0>c>>>0){kg(a,d+11|0);e=t[d+11|0];g=e>>>31|0;break b}e=0-g|0}t[(d+12|0)+c|0]=e;c=c+1|0;continue}break}}fb=d+16|0;break a}c=mg(a);Yb(a,b-4|0)}t[f|0]=c}function wR(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Rz(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+30|0]=0;t[a+31|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function x2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=fb-32|0;fb=b;a:{e=a;a=cc(b+24|0,c,d);a=Fs(e,v[a>>2],v[a+4>>2],0);if(a+1>>>0>=3){a=aa(8)|0;v[23220]=0;b=Q(52,b+8|0,8044)|0;c=v[23220];v[23220]=0;b:{if((c|0)!=1){a=qc(a,b);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}d=P()|0;O()|0;ub(b);break b}d=P()|0;O()|0;ba(a|0)}S(d|0);L()}fb=b+32|0;return a|0}L()}function Ni(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(Ij(a,f+8|0)){break b}h=Ak(v[a>>2]);g=4;if(!eh(v[d+8>>2],2048,h)){break b}b=Um(d,h);while(1){c:{b=b-48|0;h=Al(a);if(!Zo(h,f+8|0)|(e|0)<2){break c}g=Ak(v[h>>2]);if(!eh(v[d+8>>2],2048,g)){break a}e=e-1|0;b=Um(d,g)+B(b,10)|0;continue}break}g=2;if(!Ij(h,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}fb=f+16|0;return b}function sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=fb-16|0;fb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;e=v[a+8>>2];j=v[a+12>>2];while(1){if(d){f=u[(v[b+12>>2]<<1)+i>>1];v[c>>2]=v[c>>2]+B(f,h);v[c+4>>2]=v[c+4>>2]+B(g,f);Ob(b+8|0,e,j);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;fb=b+16|0}function gI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<=0|b>4){a=aa(8)|0;v[23220]=0;c=Q(52,c|0,7772)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}a=qc(a,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}d=P()|0;O()|0;ub(c);break b}a=v[a+32>>2];e=a,f=Ee(65536/b),v[e+480244>>2]=f;qp(a);fb=c+16|0;return}d=P()|0;O()|0;ba(a|0)}S(d|0)}L()}function eI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<=0|b>4){a=aa(8)|0;v[23220]=0;c=Q(52,c|0,7793)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}a=qc(a,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}d=P()|0;O()|0;ub(c);break b}a=v[a+32>>2];e=a,f=Ee(b*65536),v[e+480240>>2]=f;qp(a);fb=c+16|0;return}d=P()|0;O()|0;ba(a|0)}S(d|0)}L()}function TF(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[115696];v[115696]=0;wd();d=fb-16|0;fb=d;lw(d,a,e+12|0,1);f=Ww(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);fb=d+16|0;a=v[115696];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[115696]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}fb=e+16|0;return f}function HE(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!d){a=aa(8)|0;v[23220]=0;c=Q(52,f|0,8187)|0;b=v[23220];v[23220]=0;if((b|0)==1){break c}a=qc(a,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}b=P()|0;O()|0;ub(c);break b}Ik(a,b,e);c=DE(a,c,e,d,59552,60324);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function GE(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!d){a=aa(8)|0;v[23220]=0;c=Q(52,f|0,8187)|0;b=v[23220];v[23220]=0;if((b|0)==1){break c}a=qc(a,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}b=P()|0;O()|0;ub(c);break b}Ik(a,b,e);c=DE(a,c,e,d,58724,59496);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c}b=P()|0;O()|0;ba(a|0)}S(b|0)}L()}function N7(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[23220]=0;R(275,b+4|0,8);b=v[23220];v[23220]=0;if((b|0)!=1){b=v[a+4264>>2];c=v[v[a+20>>2]+4>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(91480)|0;if((O()|0)==(ea(91480)|0)){_(b|0)|0;Bc(v[a+20>>2]+4|0);$();return}S(b|0);L()}function VH(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[23220]=0;c=Q(52,c|0,10667)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}a=qc(b,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ub(c);break b}a=v[a+32>>2]+B(b,872)|0;v[a+1075008>>2]=0;v[a+1075068>>2]=0;fb=c+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=fb-16|0;fb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;e=v[a+8>>2];j=v[a+12>>2];while(1){if(d){f=t[v[b+12>>2]+i|0]<<8;v[c>>2]=v[c>>2]+B(f,h);v[c+4>>2]=v[c+4>>2]+B(g,f);Ob(b+8|0,e,j);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;fb=b+16|0}function Vha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{e=Ae(a);b:{if(e>>>0>1){break b}c:{if(e){v[23220]=0;U(320,d|0,a|0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){hm(b,d);$b(d);break c}a=V(30480)|0;if((O()|0)!=(ea(30480)|0)){break a}_(a|0)|0;$();break b}if(!Lb(v[a>>2],v[a+8>>2],c)){break b}Cu(a,b,c)}f=Wc(v[b>>2],v[b+4>>2])>>>0>=c>>>0}fb=d+16|0;return f|0}S(a|0);L()}function wh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!w[b+4|0]){while(1){if((d|0)==4){d=0;v[c+28>>2]=0;e=cc(c+8|0,c+28|0,4);jc(c+16|0,v[a>>2],v[a+8>>2],v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=4){break b}if(Mb(c+28|0,b,4)){break b}Yb(a,4);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17409,9050,413,13128);L()}ca(17388,9050,411,13128);L()}return d|0}function RH(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[23220]=0;c=Q(52,c|0,10667)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}a=qc(b,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ub(c);break b}fb=c+16|0;return+(+(v[(v[a+32>>2]+B(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function Q0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+32|0;tq(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){b=pc(c)+Bb(c)|0;v[a+44>>2]=b;d=pc(c);an(a,d,d,b);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=Bb(c);e=a,f=b+pc(c)|0,v[e+44>>2]=f;Bx(c,Qc(c));d=pc(c);ww(a,d,Bb(c)+d|0);if(!(w[a+48|0]&3)){break a}while(1){if((b|0)<0){Gr(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}Gr(a,b)}}function PH(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[23220]=0;c=Q(52,c|0,10667)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}a=qc(b,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ub(c);break b}fb=c+16|0;return+(+u[(v[a+32>>2]+B(b,872)|0)+1075766>>1]*30517578125e-15)}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function O9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;a:{b:{e=ND(Ec(b),Bb(b),Ec(c),Bb(c));if((e|0)!=-1){f=d,g=Td(b),v[f+32>>2]=g;c=Ef(d+40|0,d+32|0);f=d,g=Td(b),v[f+8>>2]=g;f=d,g=Ei(d+8|0,e),v[f+16>>2]=g;e=Ef(d+24|0,d+16|0);dL(b,v[c>>2],v[e>>2]);break b}e=Bb(b);if(!e){break b}if((MD(Ec(b),Bb(b),Ec(c),Bb(c))|0)!=(e-1|0)){break b}Gb(a);break a}Mc(a,b)}fb=d+48|0}function sR(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!w[b+5|0]){while(1){if((d|0)==5){d=0;t[c+28|0]=0;v[c+24>>2]=0;e=cc(c+8|0,c+24|0,5);jc(c+16|0,v[a>>2],v[a+8>>2],v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=5){break b}if(Mb(c+24|0,b,5)){break b}Yb(a,5);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17409,9050,413,13128);L()}ca(17388,9050,411,13128);L()}return d}function qfa(a){a=a|0;var b=0,c=0,d=0,e=0;e=fb-16|0;fb=e;b=tc(2500);c=fb-2496|0;fb=c;JQ(a,c,c+2496|0);a=0;while(1){if((a|0)==624){v[b+2496>>2]=0;a:{if(v[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!v[b+d>>2]){continue}break a}break}v[b>>2]=-2147483648}fb=c+2496|0}else{d=a<<2;v[d+b>>2]=v[c+d>>2];a=a+1|0;continue}break}a=v[uf(e+8|0,b)>>2];fb=e+16|0;return a|0}function R$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;while(1){a:{if((c|0)<=(g|0)){break a}d=v[a+24>>2];e=v[a+28>>2];if(d>>>0>=e>>>0){if((jb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{v[f+12>>2]=e-d>>2;v[f+8>>2]=c-g;e=d;d=v[nd(f+12|0,f+8|0)>>2];bi(e,b,d);e=d<<2;v[a+24>>2]=e+v[a+24>>2];g=g+d|0;b=b+e|0}continue}break}fb=f+16|0;return g|0}function O4(a){a=a|0;var b=0;v[23220]=0;Y(919,a|0);b=v[23220];v[23220]=0;if((b|0)!=1){b=v[a+24>>2];if(b){Fb(ns(b))}v[a+24>>2]=0;b=v[a+20>>2];if(b){Fb(b);v[a+20>>2]=0}Fb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,5039,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Gha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;ec(c+8|0,b,15);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0}}function ega(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;ec(c+8|0,b,14);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0}}function cI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<0|b>1){a=aa(8)|0;v[23220]=0;c=Q(52,c|0,11726)|0;d=v[23220];v[23220]=0;if((d|0)==1){break c}a=qc(a,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}d=P()|0;O()|0;ub(c);break b}e=v[a+32>>2]+1074456|0,f=Ee(b*256),v[e>>2]=f;fb=c+16|0;return}d=P()|0;O()|0;ba(a|0)}S(d|0)}L()}function V7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=tc(64);v[23220]=0;e=T(807,c|0)|0;f=v[23220];v[23220]=0;a:{if((f|0)!=1){c=uf(d,e);e=v[c>>2];v[23220]=0;a=W(868,e|0,a|0,b|0)|0;b=v[23220];v[23220]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}mf(d+8|0);break b}a=P()|0;O()|0;fg(c);break a}Rf(d+8|0,c)}fg(c);fb=d+16|0;return v[d+8>>2]}a=P()|0;O()|0;Fb(c)}S(a|0);L()}function K4(a,b){a=a|0;b=b|0;var c=0;v[23220]=0;Y(919,a|0);c=v[23220];v[23220]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}Fb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,5621,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function y7(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function aP(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a=Gb(a);d=Bb(b);v[23220]=0;R(43,a|0,d|0);d=v[23220];v[23220]=0;a:{if((d|0)!=1){e=c,f=Vs(b),v[e+8>>2]=f;e=c,f=Ts(b),v[e>>2]=f;while(1){if(!Kh(c+8|0,c)){break a}b=w[v[c+8>>2]];v[23220]=0;R(44,a|0,((b|0)==13?10:b)<<24>>24);b=v[23220];v[23220]=0;if((b|0)!=1){xe(c+8|0);continue}break}}b=P()|0;O()|0;ub(a);S(b|0);L()}fb=c+16|0}function y6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ji(a,b,c,d);v[a>>2]=45532;b=a+4208|0;e=zb(b,0),f=1060320051,v[e>>2]=f;e=zb(b,1),f=1041865114,v[e>>2]=f;e=zb(b,2),f=1065353216,v[e>>2]=f;e=zb(b,3),f=1049951732,v[e>>2]=f;e=zb(b,4),f=1049951732,v[e>>2]=f;v[23220]=0;R(870,a+44|0,2);b=v[23220];v[23220]=0;if((b|0)!=1){ii(a);return a|0}b=P()|0;O()|0;sf(a);S(b|0);L()}function vx(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(y[v[a+16>>2]+24620>>2]);c=C(C(C(jb[v[v[a>>2]+204>>2]](a))*b)/C(1e3));d=a,e=C(C(c*C(jb[v[v[a>>2]+196>>2]](a)))*C(2048)),z[d+4248>>2]=e;d=a,f=Lh(C(C(c+C(2))*C(4096))),v[d+4256>>2]=f;c=C(jb[v[v[a>>2]+208>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(jb[v[v[a>>2]+192>>2]](a)|0)){b=mK(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function Mi(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(xk(a,f+8|0)){break b}g=4;h=zk(v[a>>2]);if(!yk(d,2048,h)){break b}b=Tm(d,h);while(1){c:{b=b-48|0;h=bn(a);if(!Ir(h,f+8|0)|(e|0)<2){break c}g=zk(v[h>>2]);if(!yk(d,2048,g)){break a}e=e-1|0;b=Tm(d,g)+B(b,10)|0;continue}break}g=2;if(!xk(h,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}fb=f+16|0;return b}function HL(a,b){var c=0,d=0,e=0,f=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,872)+a|0;e=w[c+1075783|0];switch(e-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}d=a+901404|0;f=a+1074376|0;e=(e|0)==32;c=t[c+1075785|0];d:{if((c|0)>=0){d=le(d+288|0,w[(B(b,872)+a|0)+1075836|0]);break d}d=le(d+800|0,c&127)}bN(a,f,b,e,d,c&255)}}function vy(a,b,c,d){a:{if(v[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=B(b,872)+a|0;v[c+1075688>>2]=0;d=c+1075e3|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075080|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,872)+a|0;v[c+1075680>>2]=0;c=v[c+1075080>>2]}d=B(b,872)+a|0;v[d+1075080>>2]=c|2097152;Nl(a,b,255,0);if(!(w[d+1075081|0]&2)){break a}a=v[a+1298300>>2];if(!sd(a)){break a}fj(a,b,0)}}function El(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return t[a+71760|0]}if(a>>>0<=511){return t[(a>>>5|0)+71760|0]+5|0}return t[(a>>>10|0)+71760|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return t[(a>>>15|0)+71760|0]+15|0}return t[(a>>>20|0)+71760|0]+20|0}if(a>>>0<=536870911){return t[(a>>>25|0)+71760|0]+25|0}a=t[(a>>>30|0)+71760|0]+30|0}else{a=0}return a}function hI(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=aa(8)|0;v[23220]=0;c=Q(52,c|0,9334)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}a=qc(b,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ub(c);break b}v[v[a+32>>2]+1074420>>2]=B(b,1e4);fb=c+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function X1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a:{b:{if((Lj(w[a+140|0])|0)!=1){break b}if((ZI(a)|0)!=(b|0)){break b}d=a+120|0;ds(w[d+20|0]);b=fb-16|0;fb=b;v[b+8>>2]=c+8;a=fb-16|0;fb=a;e=v[14235];v[a+8>>2]=v[14234];v[a+12>>2]=e;e=v[14233];v[a>>2]=v[14232];v[a+4>>2]=e;jb[v[cp(a,Lj(w[d+20|0]))>>2]](b+8|0,d);fb=a+16|0;fb=b+16|0;break a}YI(a,1,b)}fb=c+16|0}function N4(a){a=a|0;var b=0;v[23220]=0;Y(919,a|0);b=v[23220];v[23220]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}Fb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,8887,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function KB(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){a=fb-16|0;fb=a;c=aa(16)|0;b=fb-16|0;fb=b;if(!w[463304]){t[463304]=1}cc(b+8|0,1,92560);d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;fb=b+16|0;b=v[a+12>>2];a=v[a+8>>2];v[23220]=0;a=TE(1081,c,8914,a,b);b=v[23220];v[23220]=0;if((b|0)!=1){ia(a|0,77444,1082);L()}a=P()|0;O()|0;ba(c|0);S(a|0);L()}}function CE(a,b,c){var d=0;d=fb-16|0;fb=d;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[23220]=0;c=Q(52,d|0,10667)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}a=qc(b,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ub(c);break b}a=(v[a+32>>2]+B(b,872)|0)+1075080|0;v[a>>2]=v[a>>2]|c;fb=d+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function rr(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}t[a|0]=b;return(d|0)!=260}function DC(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if(Mb(a,11060,2)){if(Mb(a,13753,2)){break a}if(w[a+110|0]<=64){break b}break a}if(w[a+110|0]>64){break a}}if(t[a+112|0]<0|w[a+111|0]>128){break a}while(1){d=(b|0)==128;if(d){break a}c=a+b|0;e=t[c+113|0];if((e|0)<-2){break a}f=w[c+241|0];if(!f&(e|0)>=0|f>>>0>15){break a}b=b+1|0;if(w[c+369|0]<64){continue}break}}return d}function L4(a){a=a|0;var b=0;v[23220]=0;Y(919,a|0);b=v[23220];v[23220]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return Uf(a)|0}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,12149,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();return 0}return Uf(21598)|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function x3(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;a:{b:{if(Nb(v[a+36>>2],v[a+40>>2])){mf(b+24|0);break b}c=b+8|0;qn(c,a);v[23220]=0;d=T(978,c|0)|0;c=v[23220];v[23220]=0;if((c|0)==1){break a}v[b+24>>2]=d;Tf(b+8|0)}d=a+36|0;c=v[d>>2];if(!Nb(c,v[a+40>>2])){d=v[b+24>>2];c=v[d>>2]}a=pn(c,v[d+4>>2]);Fk(b+24|0);fb=b+32|0;return a|0}a=P()|0;O()|0;Tf(b+8|0);S(a|0);L()}function Fga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=fb-16|0;fb=f;c=bf(a,c);Yd(f,v[a+28>>2]);a:{b:{if(!c){d=-1;if(!cd(a,5)){break b}break a}d=v[c+8>>2]}e=v[a+28>>2];c:{d:{switch(d+1|0){case 0:case 2:d=fb-32|0;fb=d;t[d+24|0]=0;Ui(d+8|0,d+24|0);cn(d+16|0,e,v[d+8>>2],v[d+12>>2]);t[b|0]=w[d+24|0];fb=d+32|0;break c;default:break d}}FS(e,b,d)}e=c}We(a,e);fb=f+16|0}function q3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[23220]=0;Y(919,a|0);f=v[23220];v[23220]=0;if((f|0)!=1){return px(v[v[a+24>>2]+24>>2],b,c,d,e)|0}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,12392,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function iI(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=aa(8)|0;v[23220]=0;c=Q(52,c|0,5809)|0;a=v[23220];v[23220]=0;if((a|0)==1){break c}a=qc(b,c);v[23220]=0;U(106,a|0,61832,923);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ub(c);break b}v[v[a+32>>2]+1074416>>2]=b;fb=c+16|0;return}a=P()|0;O()|0;ba(b|0)}S(a|0)}L()}function Eha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;e=Ib(a);a=Ab(v[b>>2]);v[d+24>>2]=a;b=Ab(v[b+4>>2]);a:{while(1){if(Nb(a,b)){wi(d,v[a>>2],v[a+4>>2]);if((_b(v[d>>2])|0)==(c|0)){ko(d,a);v[23220]=0;R(345,e|0,d|0);a=v[23220];v[23220]=0;if((a|0)==1){break a}wb(d)}a=v[jm(d+24|0)>>2];continue}break}fb=d+32|0;return}a=P()|0;O()|0;wb(d);fd(e);S(a|0);L()}function In(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+810|0]=w[b+810|0]&15|c<<4;break a}c=w[b+810|0]>>>4|0;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(t[a+480180|0]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function I9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=b;c=fb-16|0;fb=c;d=tc(223888);v[23220]=0;b=Q(774,d|0,b+1074376|0)|0;e=v[23220];v[23220]=0;a:{if((e|0)!=1){b=v[uf(c+8|0,b)>>2];fb=c+16|0;break a}a=P()|0;O()|0;Fb(d);S(a|0);L()}v[a+4>>2]=b;b=Ib(a+8|0);v[23220]=0;Y(547,a|0);c=v[23220];v[23220]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;Wd(b);SM(a+4|0);S(c|0);L()}function _F(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{if((a|0)!=(b|0)){g=v[115696];v[115696]=0;wd();d=eG(a,e+12|0,d);a=ib;f=v[115696];b:{if(f){if(v[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}v[c>>2]=4;a=!!d&(a|0)>=0|(a|0)>0;d=a?-1:0;a=a?2147483647:-2147483648;break a}v[115696]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0}fb=e+16|0;ib=a;return d}function $U(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;Eu(e+8|0,c);c=w[d|0];v[23220]=0;R(233,e+20|0,c|0);c=v[23220];v[23220]=0;b:{c:{if((c|0)!=1){lk(e,e+8|0);v[23220]=0;X(101,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23220];v[23220]=0;if((a|0)==1){break c}yh(e+8|0);fb=e+32|0;break a}a=P()|0;O()|0;vb(e+8|0);break b}a=P()|0;O()|0;yh(e+8|0)}S(a|0);L()}}
function cV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=-1;a:{if(!Sf(a,7)){break a}c=0;if(!bC(a,11748)){break a}c=fb-16|0;fb=c;_B(c+8|0,d);e=v[c+12>>2];hd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Zc(a,v[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){ZB(d)}c=-1;if(!e){break a}c=0;if(!aC(w[d+1|0])){break a}c=Ce(a,b,$B(d),ib)}fb=d+16|0;return c|0}function D9(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;t[d+15|0]=b;a:{b:{b=w[a+11|0];c:{d:{if(nf(b)){b=v[a+4>>2];c=eB(v[a+8>>2])-1|0;if((b|0)==(c|0)){break d}break b}c=10;b=Jf(b);if((b|0)!=10){break c}}Ay(a,c,1,c,c,0);b=c;if(nf(w[a+11|0])){break b}}ae(a,b+1|0);break a}c=v[a>>2];Bd(a,b+1|0);a=c}a=a+b|0;bd(a,d+15|0);t[d+14|0]=0;bd(a+1|0,d+14|0);fb=d+16|0}function B3(a){a=a|0;var b=0;v[23220]=0;Y(919,a|0);b=v[23220];v[23220]=0;if((b|0)!=1){a=v[v[a+24>>2]+24>>2];return hj(Vb(v[a+484360>>2],w[a+484376|0]))|0}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,6846,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function nt(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;Bia(b,0,a,0);a=ib?0:B(a,b)}else{a=0}a:{if(!a){break a}v[23220]=0;b=T(720,a|0)|0;c=v[23220];v[23220]=0;b:{c:{if((c|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;Z(17);c=v[23220];v[23220]=0;b=0;if((c|0)==1){break c}}break b}V(0)|0;O()|0;Tb();L()}if(!b){break a}d=Sb(b,0,a)- -64|0}return d}function Qz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;e=Ib(a);a=Ab(v[b>>2]);v[d+24>>2]=a;b=Ab(v[b+4>>2]);a:{while(1){if(Nb(a,b)){wi(d,v[a>>2],v[a+4>>2]);if(v[d>>2]==(c|0)){ko(d,a);v[23220]=0;R(345,e|0,d|0);a=v[23220];v[23220]=0;if((a|0)==1){break a}wb(d)}a=v[jm(d+24|0)>>2];continue}break}fb=d+32|0;return}a=P()|0;O()|0;wb(d);fd(e);S(a|0);L()}function A3(a){a=a|0;var b=0;v[23220]=0;Y(919,a|0);b=v[23220];v[23220]=0;if((b|0)!=1){a=v[v[a+24>>2]+24>>2];return Zs(v[a+484344>>2],v[a+484348>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,6914,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function lQ(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!w[b+4|0]){while(1){if((d|0)==4){d=0;v[c+28>>2]=0;e=cc(c+8|0,c+28|0,4);hd(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=4){break b}if(Mb(c+28|0,b,4)){break b}Zc(a,4);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}ca(17409,9050,413,13128);L()}ca(17388,9050,411,13128);L()}return d}function c$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=v[a+84>>2];f=v[e>>2];d=v[e+4>>2];h=v[a+28>>2];g=v[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){nc(f,h,g);f=g+v[e>>2]|0;v[e>>2]=f;d=v[e+4>>2]-g|0;v[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){nc(f,b,d);f=d+v[e>>2]|0;v[e>>2]=f;v[e+4>>2]=v[e+4>>2]-d}t[f|0]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;return c|0}function Vo(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+8|0;Xc(d,b);v[23220]=0;b=T(1105,d|0)|0;d=v[23220];v[23220]=0;a:{if((d|0)==1){break a}v[23220]=0;d=T(1114,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break a}v[c>>2]=d;v[23220]=0;R(1115,a|0,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break a}Wb(e+8|0);fb=e+16|0;return}a=P()|0;O()|0;Wb(e+8|0);S(a|0);L()}function i6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;b=vK(a,b,c,d,e^1);v[b>>2]=46132;a=b+4208|0;f=zb(a,0),g=1056964608,v[f>>2]=g;f=zb(a,1),g=1065353216,v[f>>2]=g;f=zb(a,2),g=1020054733,v[f>>2]=g;f=zb(a,3),g=1065353216,v[f>>2]=g;f=zb(a,4),g=1056964608,v[f>>2]=g;f=zb(a,5),g=1048406533,v[f>>2]=g;f=zb(a,6),g=1056964608,v[f>>2]=g;return b|0}function bT(a){var b=0,c=0,d=0;a:{if(Mb(a+60|0,15486,4)|(w[a+32|0]|w[a+33|0]<<8)>>>0>256|(w[a+49|0]<32|(w[a+36|0]|w[a+37|0]<<8)>>>0>255)){break a}if(t[a+51|0]<4|w[a+50|0]>64){break a}b=a- -64|0;a=0;while(1){if((a|0)==32){d=c;break a}b:{switch(w[((a<<4)+b|0)+15|0]){case 0:case 1:c=1;break;case 2:break b;default:break a}}a=a+1|0;continue}}return d&1}function Xo(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+8|0;Xc(d,b);v[23220]=0;b=T(1087,d|0)|0;d=v[23220];v[23220]=0;a:{if((d|0)==1){break a}v[23220]=0;d=T(1100,b|0)|0;f=v[23220];v[23220]=0;if((f|0)==1){break a}t[c|0]=d;v[23220]=0;R(1101,a|0,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break a}Wb(e+8|0);fb=e+16|0;return}a=P()|0;O()|0;Wb(e+8|0);S(a|0);L()}function SK(a,b){var c=0,d=0,e=0,f=0,g=0,h=C(0);c=fb-16|0;fb=c;d=0;a:{if(!Ch(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;_j(a,c+12|0);e=v[c+12>>2];d=0;if(e>>>0>65535){break a}Oj(b,e);while(1){if((f|0)==(e|0)){d=Ch(v[v[a>>2]-12>>2]+a|0)}else{v[c+8>>2]=0;jp(a,c+8|0);g=zb(v[b>>2],f),h=z[c+8>>2],z[g>>2]=h;f=f+1|0;continue}break}}a=d;fb=c+16|0;return a}function zfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;nq(e+8|0,c);v[23220]=0;R(537,e+20|0,d|0);c=v[23220];v[23220]=0;b:{c:{if((c|0)!=1){lk(e,e+8|0);v[23220]=0;X(285,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23220];v[23220]=0;if((a|0)==1){break c}CR(e+8|0);fb=e+32|0;break a}a=P()|0;O()|0;ub(e+8|0);break b}a=P()|0;O()|0;CR(e+8|0)}S(a|0);L()}}function h9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;u[a>>1]=0;c=Ib(a+4|0);d=Ib(a+16|0);v[a+36>>2]=0;e=Gb(a+40|0);f=eg(a+52|0);Bc(c);u[a+28>>1]=65472;v[23220]=0;v[b+12>>2]=1065353216;R(811,c|0,b+12|0);g=v[23220];v[23220]=0;if((g|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;Bc(d);fb=b+16|0;return a|0}a=P()|0;O()|0;IS(f);vb(e);lc(d);lc(c);S(a|0);L()}function h5(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;a=Ib(a);v[23220]=0;Y(909,b+16|0);c=v[23220];v[23220]=0;a:{b:{if((c|0)!=1){c=Ab(v[b+16>>2]);d=Ab(v[b+20>>2]);e=v[dc(b+8|0,a)>>2];v[23220]=0;U(910,c|0,d|0,e|0);c=v[23220];v[23220]=0;if((c|0)==1){break b}lc(b+16|0);fb=b+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;lc(b+16|0)}De(a);S(c|0);L()}function tu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;HB(e+8|0,c);v[23220]=0;R(100,e+20|0,d|0);c=v[23220];v[23220]=0;b:{c:{if((c|0)!=1){lk(e,e+8|0);v[23220]=0;X(101,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23220];v[23220]=0;if((a|0)==1){break c}yh(e+8|0);fb=e+32|0;break a}a=P()|0;O()|0;vb(e+8|0);break b}a=P()|0;O()|0;yh(e+8|0)}S(a|0);L()}}function ZW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;Mm(e+8|0,c);v[23220]=0;R(100,e+20|0,d|0);c=v[23220];v[23220]=0;b:{c:{if((c|0)!=1){lk(e,e+8|0);v[23220]=0;X(101,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23220];v[23220]=0;if((a|0)==1){break c}yh(e+8|0);fb=e+32|0;break a}a=P()|0;O()|0;vb(e+8|0);break b}a=P()|0;O()|0;yh(e+8|0)}S(a|0);L()}}function J2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[23220]=0;Y(919,a|0);d=v[23220];v[23220]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,13013,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function H9(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Cb(a)>>2]){c=fb-16|0;fb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+32;FM(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;hc(c);fb=c+16|0;return}d=fb-32|0;fb=d;c=Cb(a);c=kt(d+8|0,Hp(a,dg(v[a>>2],v[a+4>>2])+1|0),dg(v[a>>2],v[a+4>>2]),c);FM(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;vd(a,c);uP(c);fb=d+32|0}function Ks(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;a:{if(!b){break a}xb(e+8|0,a+1074312|0,73);j=yb(v[v[e+8>>2]>>2],v[e+12>>2])?c- -64|0:c;c=120;h=cj(a);k=h^-1;f=1;while(1){if(!c){break a}l=c;c=c>>>1|0;i=f+c|0;g=Lg(a,i,j,d);if(!(g>>>0>b>>>0&k)&(!(!g|h)|b>>>0<=g>>>0)){continue}f=i+1|0;c=(c^-1)+l|0;continue}}fb=e+16|0;return f}function Hn(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+810|0];if(c){t[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(t[a+480180|0]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function yu(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if(!(w[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=42;break b}if(w[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}t[a|0]=42;t[b|0]=w[d|0]}t[c|0]=0}}function Wv(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];b:{if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if((d|0)!=1){break a}if(v[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=v[a+24>>2];if((c|0)==2){v[a+24>>2]=d;c=d}if(v[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}v[a+36>>2]=v[a+36>>2]+1}t[a+54|0]=1}}function rI(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=jb[a|0](b)|0;d=ib;if((d|0)<0){break b}if((jb[c|0](b,0,0,0)|0)<0){break a}if((jb[c|0](b,0,0,2)|0)<0){break a}f=jb[a|0](b)|0;a=ib;jb[c|0](b,e,d,0)|0;if((a|0)<0){break b}g=Py(f,a)}return g}jb[c|0](b,e,d,0)|0;return 0}function xaa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=Ib(a);b:{c:{c=Ic(v[b>>2],v[b+4>>2]);if(c){v[23220]=0;R(580,a|0,c|0);d=v[23220];v[23220]=0;if((d|0)==1){break b}wO(a,v[b>>2],v[b+4>>2],c)}break c}v[23220]=0;Q(3,a+12|0,b+12|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){v[a+24>>2]=v[b+24>>2];u[a+28>>1]=x[b+28>>1];break a}}b=P()|0;O()|0;ld(a);S(b|0);L()}}function bea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;c=d+11|0;GQ(a,c);if(Mb(c,13553,4)){a=1}else{GQ(a,d+11|0);t[b|0]=1;a=0}c=fb-16|0;fb=c;a:{b:{a=(d+11|0)+a|0;c:{if(!a){a=0;break c}b=Qb(c,a);v[23220]=0;a=T(619,b|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break b}ub(b)}fb=c+16|0;break a}a=P()|0;O()|0;ub(b);S(a|0);L()}fb=d+16|0;return a|0}function vaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=fb-32|0;fb=d;CA(d+8|0,c);v[23220]=0;R(417,d+20|0,43372);c=v[23220];v[23220]=0;b:{c:{if((c|0)!=1){lk(d,d+8|0);v[23220]=0;X(101,a|0,b|0,v[d>>2],v[d+4>>2]);a=v[23220];v[23220]=0;if((a|0)==1){break c}yh(d+8|0);fb=d+32|0;break a}a=P()|0;O()|0;vb(d+8|0);break b}a=P()|0;O()|0;yh(d+8|0)}S(a|0);L()}}function mk(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;v[f+8>>2]=a;v[f+12>>2]=b;h=v[a+8>>2]+120|0;ds(w[h+20|0]);g=fb-16|0;fb=g;v[g+8>>2]=f+8;e=fb-16|0;fb=e;i=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=i;d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;jb[v[cp(e,Lj(w[h+20|0]))>>2]](g+8|0,h);fb=e+16|0;fb=g+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];fb=f+16|0}function Cj(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e307;if(b>>>0<2047){b=b-1023|0;break a}a=a*8.98846567431158e307;b=((b|0)<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2.004168360008973e-292;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2.004168360008973e-292;b=((b|0)>-2960?b:-2960)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function a7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ji(a,b,c,d);v[a>>2]=45040;c=Ib(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=1056964608;b=a+4228|0;t[b+4|0]=0;t[b+5|0]=4;t[b|0]=69;t[b+1|0]=99;t[b+2|0]=104;t[b+3|0]=111;t[b+6|0]=1;v[23220]=0;R(870,a+44|0,2);b=v[23220];v[23220]=0;if((b|0)!=1){ii(a);ts(a);return a|0}b=P()|0;O()|0;lc(c);sf(a);S(b|0);L()}function sN(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;i=v[d+20>>2];h=v[d+52>>2];g=!h|e;t[f+15|0]=g;a:{if(!g|(b|0)!=2){break a}g=c&65535;c=0;while(1){if((c|0)==(g|0)){break a}v[(B(c,872)+d|0)+1380>>2]=0;c=c+1|0;continue}}v[d+24>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d+48>>2]=h;u[d+72>>1]=x[d+74>>1];et(a,i>>>0>1&e&(b|0)==1,f+15|0);fb=f+16|0}function Pha(a){a=a|0;var b=0,c=0,d=0;c=Ib(a);v[23220]=0;Y(329,c|0);a=v[23220];v[23220]=0;if((a|0)==1){a=P()|0;O()|0;lc(c);S(a|0);L()}a=fb-16|0;fb=a;v[a>>2]=c;b=v[c+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+32768;b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=a+16|0}else{u[b>>1]=0;u[b+2>>1]=0;b=b+4|0;v[a+4>>2]=b;continue}break}return c|0}function C2(a,b){a=a|0;b=b|0;var c=0;v[23220]=0;Y(919,a|0);c=v[23220];v[23220]=0;if((c|0)!=1){v[v[v[a+24>>2]+24>>2]+480272>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,5745,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function BX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=fb+-64|0;fb=e;d=1;a:{if(Eg(a,b,0)){break a}d=0;if(!b){break a}b=zy(b,91132,91180);d=0;if(!b){break a}d=e+8|0;Sb(d|4,0,52);v[e+56>>2]=1;v[e+20>>2]=-1;v[e+16>>2]=a;v[e+8>>2]=b;jb[v[v[b>>2]+28>>2]](b,d,v[c>>2],1);a=v[e+32>>2];if((a|0)==1){v[c>>2]=v[e+24>>2]}d=(a|0)==1}fb=e- -64|0;return d|0}function iy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;e=oi(b,c);a:{if(e>>>0<=Uo(a)>>>0){f=c;g=v[a>>2];h=Wc(g,v[a+4>>2]);i=h>>>0>=e>>>0;if(!i){v[d+12>>2]=b;v[d+12>>2]=v[d+12>>2]+h;f=v[d+12>>2]}b=Gi(b,f,g);if(!i){Qt(a,f,c,e-Wc(v[a>>2],v[a+4>>2])|0);break a}Jd(a,b);break a}aB(a);jl(a,tl(a,e));Qt(a,b,c,e)}fb=d+16|0}function Zd(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;Cm(b);e=a+8|0;f=uf(d+8|0,b);a:{b=v[a+8>>2];if(sc(b,v[a+12>>2])>>>0<=c>>>0){v[23220]=0;R(1177,e|0,c+1|0);a=v[23220];v[23220]=0;if((a|0)==1){break a}b=v[e>>2]}a=zb(b,c);b=v[a>>2];if(b){Gm(b);a=zb(v[e>>2],c)}g=a,h=Ud(f),v[g>>2]=h;pF(f);fb=d+16|0;return}a=P()|0;O()|0;pF(f);S(a|0);L()}function $y(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function wG(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;e=b+16|0;a:{while(1){d=v[a+36>>2];c=b+8|0;f=jb[v[v[d>>2]+20>>2]](d,v[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=v[b+4>>2]-c|0;if((dk(g,1,c,v[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=ps(v[a+32>>2])?-1:0}fb=b+16|0;return d|0}function jY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=fb-16|0;fb=g;k=$h(g+8|0,v[a+8>>2]);i=yr(0,c,d-c|0,b?b:466540);_h(k);fb=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function XV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;f=v[b+16>>2];a:{if(f>>>0<=c>>>0){ec(a,v[d>>2],0);break a}g=v[b+12>>2];b=v[b+4>>2];v[e+20>>2]=v[d+4>>2];v[e+16>>2]=f-c;ec(e+24|0,v[d>>2],v[Eb(e+20|0,e+16|0)>>2]);d=v[v[b>>2]+28>>2];f=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=f;jb[d|0](a,b,c+g|0,e+8|0)}fb=e+32|0}function I2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[23220]=0;Y(919,a|0);d=v[23220];v[23220]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:900;return}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,13043,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Ap(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;t[d+15|0]=b;a:{b:{c:{d:{if(ve(a)){c=hl(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=10;b=w[a+11|0];if((b|0)!=10){break c}}Ll(a,c,1,c,c,0,0);b=c;if(ve(a)){break b}}ae(a,b+1|0);break a}c=v[a>>2];Bd(a,b+1|0);a=c}a=a+b|0;bd(a,d+15|0);t[d+14|0]=0;bd(a+1|0,d+14|0);fb=d+16|0}function m1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=v[d+4>>2];ax(b,c,g);f=v[b+16>>2];a:{if(f>>>0<=c>>>0){ec(a,v[d>>2],0);break a}v[e+12>>2]=f-c;v[e+8>>2]=g;d=v[d>>2];f=v[Eb(e+12|0,e+8|0)>>2];dq(e,d,g,0,f);h=v[e>>2];i=v[e+4>>2];Yg(Vg(Ab(v[b+4>>2]),c),Vg(Vg(Ab(v[b+4>>2]),c),i),h);dq(a,d,g,0,f)}fb=e+16|0}function lo(a,b,c,d,e){var f=0,g=0,h=0;g=fb-16|0;fb=g;a:{b:{while(1){f=h&255;if(f>>>0>3){break b}if(!vq(b,c,f>>>0>1)){Wg(b,d);Wg(c,e);h=h+1|0;continue}break}t[g+15|0]=0;et(a,0,g+15|0);break a}h=g+8|0;f=w[b|0];if(yi(f)>>>0>yi(w[d|0])>>>0){Wg(b,d);Wg(c,e);f=w[b|0]}d=et(h,f,c);t[b|0]=0;t[c|0]=0;b=x[d>>1];t[a|0]=b;t[a+1|0]=b>>>8}fb=g+16|0}function _ea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb+-64|0;fb=c;b=-1;a:{if(!(jb[v[v[a>>2]+32>>2]](a,0,1084)|0)){break a}Yk(a,1080);d=c+60|0;BR(a,d);e=d;d=zR(c+40|0);b=0;if(!yR(e,d)){break a}Yk(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=y[d+4>>2]>=f>>>0}else{e=c+8|0;xR(a,e);b=b+1|0;f=dA(e)+f|0;continue}break}}fb=c- -64|0;return b|0}function PK(a){var b=0,c=0,d=0;c=fb-32|0;fb=c;a:{d=Gx(a);b=xj(v[a>>2],v[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}v[23220]=0;b=fa(874,c+8|0,b|0,b|0,Cb(a)|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){vd(a,b);MK(b);break b}a=V(0)|0;O()|0;_(a|0)|0;v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)==1){break a}}fb=c+32|0;return}V(0)|0;O()|0;Tb();L()}function OK(a){var b=0,c=0,d=0;c=fb-32|0;fb=c;a:{d=si(a);b=sc(v[a>>2],v[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}v[23220]=0;b=fa(875,c+8|0,b|0,b|0,Cb(a)|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){vd(a,b);bg(b);break b}a=V(0)|0;O()|0;_(a|0)|0;v[23220]=0;Z(17);a=v[23220];v[23220]=0;if((a|0)==1){break a}}fb=c+32|0;return}V(0)|0;O()|0;Tb();L()}function M3(a){a=a|0;var b=0;v[23220]=0;Y(919,a|0);b=v[23220];v[23220]=0;if((b|0)!=1){return y[v[v[a+24>>2]+24>>2]+1074420>>2]/1e4|0}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,9301,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function $B(a){var b=0,c=0,d=0,e=0,f=0;d=w[a+9|0]|w[a+10|0]<<8;c=Bia(w[a+3|0],0,18,0);d=d+c|0;b=ib;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;c=w[a+6|0]|w[a+7|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=w[a+4|0]|w[a+5|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;a=b>>>0<3?a+1|0:a;ib=a;return b}function xha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-112|0;fb=d;c=fb-16|0;fb=c;f=d+8|0;pT(c+8|0,f);e=v[c+12>>2];hd(c,a,v[c+8>>2],e);g=v[c+4>>2];if((g|0)==(e|0)){Zc(a,v[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){oT(f)}c=-1;a:{if(!e){break a}c=0;if(!rT(d+8|0)){break a}c=Ce(a,b,qT(w[d+55|0]|w[d+56|0]<<8),ib)}fb=d+112|0;return c|0}function Uy(a,b,c){var d=0,e=0,f=0;d=Gb(a);a=Bb(b);v[23220]=0;R(45,d|0,a|0);a=v[23220];v[23220]=0;if((a|0)!=1){a:{while(1){if(Bb(b)>>>0>e>>>0){a=65533;f=t[Vf(b,e)|0];if((f|0)>=-96){a=v[((f&255)<<2)+c>>2]}v[23220]=0;R(46,d|0,a|0);a=v[23220];v[23220]=0;if((a|0)==1){break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;Nc(d);S(a|0);L()}function T1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{if(!(c&1024)){break a}f=e,g=Fi(b),v[f+8>>2]=g;c=nl(v[b+4>>2],w[b+11|0]);b:{if(!c){break b}if(w[qd(b)|0]!=(ef(43)&255)){if(w[qd(b)|0]!=(ef(45)&255)){break b}}d=d+1|0;kJ(e+8|0)}if(c>>>0>=d>>>0){break a}GI(b,v[Ef(e,e+8|0)>>2],d-c|0,ef(48))}Mc(a,b);fb=e+16|0}function rq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Ab(v[b>>2]);g=Ab(v[b+4>>2]);e=fb-16|0;fb=e;v[e+8>>2]=d;while(1){a:{if(!Nb(d,g)){break a}f=fb-16|0;fb=f;wi(f+8|0,v[d>>2],v[d+4>>2]);h=_b(v[f+8>>2]);fb=f+16|0;if((c|0)==(h|0)){break a}d=v[jm(e+8|0)>>2];continue}break}fb=e+16|0;if(rc(d,Ab(v[b+4>>2]))){xh(a);return}ko(a,d)}function U8(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;t[b+23|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+27|0]=0;t[b+28|0]=0;t[b+29|0]=0;t[b+30|0]=0;v[b+16>>2]=0;v[b+20>>2]=0;c=cc(b,b+16|0,15);jc(b+8|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);c=0;a:{if(v[b+12>>2]!=15){break a}if(Mb(b+16|0,8512,15)){break a}Yb(a,15);c=1}fb=b+32|0;return c|0}function vV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-512|0;fb=d;c=fb-16|0;fb=c;f=d+8|0;BC(c+8|0,f);e=v[c+12>>2];hd(c,a,v[c+8>>2],e);g=v[c+4>>2];if((g|0)==(e|0)){Zc(a,v[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){AC(f)}c=-1;a:{if(!e){break a}c=0;if(!DC(d+8|0)){break a}c=Ce(a,b,CC(w[d+118|0],w[d+119|0]),ib)}fb=d+512|0;return c|0}function WQ(a){var b=0,c=0,d=0,e=0,f=0;e=w[a+28|0]|w[a+29|0]<<8;b=Bia(w[a+30|0],0,37,0);c=ib;d=b;b=Bia(w[a+24|0]|w[a+25|0]<<8,0,192,0);d=d+b|0;c=ib+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;a=w[a+26|0];c=a>>>26|0;e=d;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;a=b>>>0<192?a+1|0:a;ib=a;return b}function b1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=0;a:{if(!v[b+28>>2]){break a}e=0;if((jb[v[b+32>>2]](v[b+24>>2],c,0,0)|0)<0){break a}f=v[d+4>>2];c=v[d>>2];while(1){b:{if(!f){break b}e=jb[v[b+28>>2]](v[b+24>>2],c,f)|0;if(!e){break b}f=f-e|0;c=c+e|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;continue}break}e=g}ec(a,v[d>>2],e)}function Ega(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;c=bf(a,c);Yd(f,v[a+28>>2]);a:{if(!c){e=0;if(cd(a,5)){break a}}h=v[a+28>>2];g=fb-16|0;fb=g;e=Gb(g);v[23220]=0;fa(412,b|0,h|0,e|0,d|0)|0;b=v[23220];v[23220]=0;b:{if((b|0)!=1){vb(e);fb=g+16|0;break b}a=P()|0;O()|0;vb(e);S(a|0);L()}e=c}We(a,e);fb=f+16|0}function gK(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=v[v[a+16>>2]+24620>>2]/5|0;b=Dc(b,b>>31);v[a+4272>>2]=b;v[23220]=0;v[c+12>>2]=0;U(876,a+4256|0,b<<1,c+12|0);b=v[23220];v[23220]=0;a:{if((b|0)==1){b=V(91480)|0;if((O()|0)!=(ea(91480)|0)){break a}_(b|0)|0;v[a+4272>>2]=0;$()}v[a+4276>>2]=0;v[a+4268>>2]=0;fb=c+16|0;return}S(b|0);L()}function Cp(a){var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;d=Ab(v[a>>2]);e=a;f=Ab(v[a+4>>2]);a=fb-16|0;fb=a;v[a+8>>2]=d;while(1){if(Nb(d,f)){b=b+A[d>>3];d=v[_s(a+8|0)>>2];continue}break}fb=a+16|0;a=Ab(v[e>>2]);v[c+8>>2]=a;b=-b;e=Ab(v[e+4>>2]);while(1){if(Nb(a,e)){b=b+A[a>>3];A[a>>3]=b;a=v[_s(c+8|0)>>2];continue}else{fb=c+16|0}break}}function kd(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;am(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;d=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?d|32:d;b=Qb(c,21598);ue(a+43|0,b);ub(b);CP(a);fb=c+16|0}function I5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ji(a,b,c,d);v[a+4272>>2]=1065353216;v[a>>2]=47152;b=a+4208|0;e=zb(b,0),f=1056880300,v[e>>2]=f;e=zb(b,1),f=1050733080,v[e>>2]=f;e=zb(b,2),f=1056964608,v[e>>2]=f;v[23220]=0;R(870,a+44|0,2);b=v[23220];v[23220]=0;if((b|0)!=1){ii(a);return a|0}b=P()|0;O()|0;sf(a);S(b|0);L()}function A5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ji(a,b,c,d);v[a>>2]=47384;b=a+4208|0;e=zb(b,0),f=1065353216,v[e>>2]=f;e=zb(b,1),f=1065353216,v[e>>2]=f;e=zb(b,2),f=1051372203,v[e>>2]=f;e=zb(b,3),f=0,v[e>>2]=f;v[23220]=0;R(870,a+44|0,2);b=v[23220];v[23220]=0;if((b|0)!=1){ii(a);return a|0}b=P()|0;O()|0;sf(a);S(b|0);L()}function wI(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a>>2];a:{if(!b){break a}c=v[a+8>>2];if(!c){break a}d=v[a+12>>2];if(!d){break a}e=jb[d|0](b)|0;a=ib;f=a;if((a|0)<0){break a}a=0;b:{if((jb[c|0](b,0,0,0)|0)<0){break b}a=0;if((jb[c|0](b,0,0,2)|0)<0){break b}jb[d|0](b)|0;a=ib;a=(a|0)>0|(a|0)>=0}g=a;jb[c|0](b,e,f,0)|0}return g|0}function iM(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{while(1){v[e+12>>2]=b;v[e+8>>2]=d;if(y[Eb(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=sp(t[Hb(a,f)|0]);h=sp(t[Hb(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}fb=e+16|0;return a}function G4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;v[f+8>>2]=d;d=v[Rf(f,f+8|0)>>2];v[23220]=0;ga(917,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){a=lI(a);b=kI(a+88|0);c=jI(a+92|0);v[a>>2]=61608;v[b>>2]=61720;v[c>>2]=61800;pe(f+8|0);fb=f+16|0;return a|0}a=P()|0;O()|0;pe(f+8|0);S(a|0);L()}function n8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,52)+e;a=v[d>>2];a:{while(1){if(v[d+4>>2]==(a|0)){break a}v[23220]=0;R(849,a|0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){a=v[d>>2]+52|0;v[d>>2]=a;continue}break}a=P()|0;O()|0;Ed(d);S(a|0);L()}Ed(d);fb=d+16|0}function Mw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-240|0;fb=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((jb[b|0](a,f)|0)>=0){if((jb[b|0](a,e)|0)>=0){break a}}j=f;f=(jb[b|0](f,e)|0)>=0;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}oH(g,h);fb=g+240|0}function Ll(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=fb-16|0;fb=h;i=-17;if(-17-b>>>0>=c>>>0){j=pc(a);if(b>>>0<=2147483622){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;i=Qh(v[Sc(h+12|0,h+8|0)>>2])+1|0}c=tc(i);if(e){Fe(c,j,e)}k=e+f|0;if((k|0)!=(d|0)){Fe((c+e|0)+g|0,(e+j|0)+f|0,d-k|0)}if((b|0)!=10){Fb(j)}td(a,c);yf(a,i);fb=h+16|0;return}kf();L()}function nE(a,b,c,d,e){var f=0;a:{f=fb-32|0;fb=f;Io(f+8|0,c);v[23220]=0;R(e|0,f+20|0,d|0);c=v[23220];v[23220]=0;b:{c:{if((c|0)!=1){lk(f,f+8|0);v[23220]=0;X(101,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23220];v[23220]=0;if((a|0)==1){break c}yh(f+8|0);fb=f+32|0;break a}a=P()|0;O()|0;vb(f+8|0);break b}a=P()|0;O()|0;yh(f+8|0)}S(a|0);L()}}function jE(a,b,c,d,e){var f=0;a:{f=fb-32|0;fb=f;tT(f+8|0,c);v[23220]=0;R(e|0,f+20|0,d|0);c=v[23220];v[23220]=0;b:{c:{if((c|0)!=1){lk(f,f+8|0);v[23220]=0;X(101,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23220];v[23220]=0;if((a|0)==1){break c}yh(f+8|0);fb=f+32|0;break a}a=P()|0;O()|0;vb(f+8|0);break b}a=P()|0;O()|0;yh(f+8|0)}S(a|0);L()}}function RR(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;e=ne(b,c);a:{if(e>>>0<=si(a)>>>0){f=c;g=v[a>>2];h=sc(g,v[a+4>>2]);i=h>>>0>=e>>>0;if(!i){v[d+12>>2]=b;v[d+12>>2]=v[d+12>>2]+(h<<2);f=v[d+12>>2]}b=Gi(b,f,g);if(!i){nA(a,f,c,e-sc(v[a>>2],v[a+4>>2])|0);break a}Jd(a,b);break a}lA(a);oo(a,Pg(a,e));nA(a,b,c,e)}fb=d+16|0}function CF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;i=v[b>>2];h=v[a>>2];e=v[fc(a)>>2]==1126;f=v[c>>2]-h|0;g=f<<1;f=f>>>0<2147483647?g?g:4:-1;g=Pr(e?0:h,f);if(g){if(!e){Ud(a)}v[d+4>>2]=1091;e=he(d+8|0,g,d+4|0);a=zF(a,e);Kc(e);v[b>>2]=v[a>>2]+(i-h|0);v[c>>2]=v[a>>2]+(f&-4);fb=d+16|0;return}jw();L()}function j9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(!sd(v[a+1298300>>2])){d=v[a+24620>>2];e=fb-16|0;fb=e;b=tc(536);v[23220]=0;d=Q(806,b|0,d|0)|0;f=v[23220];v[23220]=0;a:{if((f|0)!=1){b=v[uf(e+8|0,d)>>2];fb=e+16|0;break a}a=P()|0;O()|0;Fb(b);S(a|0);L()}v[c+8>>2]=b;b=a+1298300|0;a=c+8|0;gM(b,Ud(a));oy(a)}fb=c+16|0}function Rga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=Wc(e,v[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;b=b-d|0;d=v[Cb(a)>>2];f=v[a+4>>2];a:{if(b>>>0<=d-f>>>0){vo(a,b,c);break a}d=Cb(a);d=wl(e+8|0,tl(a,Wc(v[a>>2],f)+b|0),Wc(v[a>>2],v[a+4>>2]),d);wS(d,b,c);vd(a,d);vl(d)}fb=e+32|0;return}if(b>>>0<d>>>0){Jd(a,b+e|0)}}function yL(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;cc(d+8|0,qd(b),xd(v[b+4>>2],w[b+11|0]));b=v[d+8>>2];e=v[d+12>>2];c=fb-16|0;fb=c;f=xd(v[a+4>>2],w[a+11|0]);v[c+12>>2]=f;v[c+8>>2]=e;g=Eb(c+12|0,c+8|0);a=Ml(qd(a),b,v[g>>2]);a:{if(a){break a}a=-1;if(e>>>0>f>>>0){break a}a=e>>>0<f>>>0}fb=c+16|0;fb=d+16|0;return a>>>31|0}function y2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{if(!(c&1024)){break a}f=e,g=Td(b),v[f+8>>2]=g;b:{if(!Bb(b)){break b}if(w[Fc(b,0)|0]!=(ef(43)&255)){if(w[Fc(b,0)|0]!=(ef(45)&255)){break b}}d=d+1|0;kJ(e+8|0)}c=Bb(b);if(c>>>0>=d>>>0){break a}ix(b,v[Ef(e,e+8|0)>>2],d-c|0,ef(48))}Mc(a,b);fb=e+16|0}function F$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=v[a+44>>2];c=v[a+24>>2];if(e>>>0<c>>>0){v[a+44>>2]=c;e=c}f=v[a+8>>2];c=v[a+12>>2];d=-1;a:{if(f>>>0>=c>>>0){break a}if(rc(b,-1)){an(a,f,c-1|0,e);return vw(b)|0}g=rn(b);if(!(v[a+48>>2]&16)){d=-1;if(!rc(g,t[c-1|0])){break a}}an(a,f,c-1|0,e);t[v[a+12>>2]]=g;d=b}return d|0}function EC(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(b>>>0<3){if(!b){break a}if(!Lb(v[a>>2],v[a+8>>2],b)){break a}while(1)if((d|0)==2){d=x[c+14>>1];break a}else{t[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){kg(a,c+13|0);e=w[c+13|0]}else{e=0}t[f|0]=e;d=d+1|0;continue}}ca(11197,9050,136,14177);L()}fb=c+16|0;return d&65535}function eha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+12>>2]=c;a:{e=Lb(v[b>>2],v[b+8>>2],c<<2);if(!e){break a}uc(d+12|0,65535);gg(a,x[d+12>>1]);c=Ab(v[a>>2]);v[d>>2]=c;a=Ab(v[a+4>>2]);while(1){if(!Nb(c,a)){break a}f=d+8|0;if(!zo(b,f)){lm(f)}u[c>>1]=v[d+8>>2];c=v[Oe(d)>>2];continue}}fb=d+16|0;return e|0}function Xf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=a;f=fb-16|0;fb=f;a:{e=oi(b,c);if(e>>>0<4294967280){b:{if(e>>>0<=10){ae(d,e);break b}g=Qh(e)+1|0;h=tc(g);td(d,h);yf(d,g);Bd(d,e);d=h}while(1){if((b|0)!=(c|0)){bd(d,b);d=d+1|0;b=b+1|0;continue}break}t[f+15|0]=0;bd(d,f+15|0);fb=f+16|0;break a}kf();L()}return a|0}function uF(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;g=1073741807;if(1073741807-b>>>0>=c>>>0){h=pc(a);if(b>>>0<=536870886){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;g=xl(v[Sc(f+12|0,f+8|0)>>2])+1|0}c=pi(g);if(e){bi(c,h,e)}if((d|0)!=(e|0)){i=e<<2;bi(c+i|0,h+i|0,d-e|0)}if((b|0)!=1){Fb(h)}td(a,c);yf(a,g);fb=f+16|0;return}kf();L()}function dW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-32|0;fb=f;v[f+28>>2]=c;v[f+24>>2]=b;v[f+20>>2]=d;v[f+16>>2]=e;v[23220]=0;X(160,f|0,f+24|0,f+20|0,f+16|0);b=v[23220];v[23220]=0;if((b|0)!=1){b=f+8|0;iv(b,v[f>>2],v[f+4>>2]);ng(a,b);be(b);be(f);be(f+24|0);fb=f+32|0;return}a=P()|0;O()|0;be(f+24|0);S(a|0);L()}function z3(a){a=a|0;var b=0;v[23220]=0;Y(919,a|0);b=v[23220];v[23220]=0;if((b|0)!=1){return js(v[v[a+24>>2]+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,7398,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function cK(a){var b=C(0),c=0,d=C(0);b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);d=C(v[a+4256>>2]<<1>>>0);b=C(z[a+4228>>2]*d);a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}v[a+4248>>2]=c;c=a+4252|0;b=C(z[a+4232>>2]*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function b8(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Cb(a)>>2]){c=fb-16|0;fb=c;a=ri(c,a,1);As(v[a+4>>2],z[b>>2]);v[a+4>>2]=v[a+4>>2]+4;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Cb(a);c=cg(d+8|0,Pg(a,sc(v[a>>2],v[a+4>>2])+1|0),sc(v[a>>2],v[a+4>>2]),c);As(v[c+8>>2],z[b>>2]);v[c+8>>2]=v[c+8>>2]+4;vd(a,c);bg(c);fb=d+32|0}function Z6(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;v[v[a+20>>2]+148>>2]=-1;no(c+8|0,a+4228|0);d=v[a+20>>2];e=v[c+12>>2];b=v[c+8>>2];v[23220]=0;U(888,d+4|0,b|0,Hb(b,e)|0);b=v[23220];v[23220]=0;a:{if((b|0)==1){b=V(91480)|0;if((O()|0)!=(ea(91480)|0)){break a}_(b|0)|0;Bc(v[a+20>>2]+4|0);$()}fb=c+16|0;return}S(b|0);L()}function TZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;i=v[b>>2];h=v[a>>2];e=v[fc(a)>>2]==1126;f=v[c>>2]-h|0;g=f<<1;f=f>>>0<2147483647?g?g:1:-1;g=Pr(e?0:h,f);if(g){if(!e){Ud(a)}v[d+4>>2]=1091;e=he(d+8|0,g,d+4|0);a=zF(a,e);Kc(e);v[b>>2]=v[a>>2]+(i-h|0);v[c>>2]=f+v[a>>2];fb=d+16|0;return}jw();L()}function P9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;b=Oh(d,b);v[23220]=0;U(771,d+16|0,b|0,c|0);e=v[23220];v[23220]=0;a:{b:{if((e|0)!=1){v[23220]=0;U(53,a|0,d+16|0,c|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}ub(d+16|0);ub(b);fb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;ub(d+16|0)}ub(b);S(c|0);L()}function LB(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Cb(a)>>2]){c=fb-16|0;fb=c;a=Ci(c,a,1);Ai(v[a+4>>2],x[b>>1]);v[a+4>>2]=v[a+4>>2]+2;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Cb(a);c=vj(d+8|0,wj(a,Ic(v[a>>2],v[a+4>>2])+1|0),Ic(v[a>>2],v[a+4>>2]),c);Ai(v[c+8>>2],x[b>>1]);v[c+8>>2]=v[c+8>>2]+2;vd(a,c);Di(c);fb=d+32|0}function D3(a){a=a|0;var b=0;v[23220]=0;Y(919,a|0);b=v[23220];v[23220]=0;if((b|0)!=1){return zg(v[v[a+24>>2]+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,7039,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function CU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;ec(c+8|0,b,10);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0}return a|0}function C3(a){a=a|0;var b=0;v[23220]=0;Y(919,a|0);b=v[23220];v[23220]=0;if((b|0)!=1){return ks(v[v[a+24>>2]+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,6748,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function xW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;b=Km(d,b);v[23220]=0;U(141,d+16|0,b|0,c|0);e=v[23220];v[23220]=0;a:{b:{if((e|0)!=1){v[23220]=0;U(4,a|0,d+16|0,c|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}vb(d+16|0);vb(b);fb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+16|0)}vb(b);S(c|0);L()}function l7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;v[d+28>>2]=c;v[d+8>>2]=33;e=v[a>>2];f=v[a+8>>2];c=v[Eb(d+28|0,d+8|0)>>2];if(!Lb(e,f,c)){c=Ze(a)}e=d+8|0;xA(e,b);f=cc(d+16|0,v[d+8>>2],c);jc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);xA(e,b);Sb(v[d+8>>2]+c|0,0,33-c|0);Yb(a,v[d+28>>2]);fb=d+32|0;return c|0}function hj(a){var b=0,c=0,d=0,e=0,f=0;b=v[a+4>>2];if(rc(v[a>>2],b)){a=0}else{b=oj(b);e=oj(v[a>>2]);c=fb-16|0;fb=c;v[c+8>>2]=b;while(1){a:{if(!vg(b,e)){break a}d=fb-16|0;fb=d;v[d+8>>2]=b;f=DO(d+8|0);fb=d+16|0;if(x[v[f>>2]>>1]!=65535){break a}b=v[DO(c+8|0)>>2];continue}break}fb=c+16|0;a=pB(Ab(v[a>>2]),b)}return a&65535}function S3(a){a=a|0;var b=0;v[23220]=0;Y(919,a|0);b=v[23220];v[23220]=0;if((b|0)!=1){return+TL(v[v[a+24>>2]+24>>2])}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,10110,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Pv(a,b,c){var d=0;v[23220]=0;Y(919,a|0);d=v[23220];v[23220]=0;if((d|0)!=1){return v[v[v[a+24>>2]+24>>2]+c>>2]}c=V(0)|0;O()|0;_(c|0)|0;v[23220]=0;X(906,b|0,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function KE(a,b,c){var d=0;v[23220]=0;Y(919,a|0);d=v[23220];v[23220]=0;if((d|0)!=1){return x[v[v[a+24>>2]+24>>2]+c>>1]}c=V(0)|0;O()|0;_(c|0)|0;v[23220]=0;X(906,b|0,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function uX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Eg(a,v[b+8>>2],e)){Vv(b,c,d);return}a:{if(!Eg(a,v[b>>2],e)){break a}if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function uI(a){var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;if(!w[a+20|0]){while(1){if(!(jb[v[v[a>>2]+40>>2]](a)|0)){sI(a,65536);c=cc(b+16|0,Hb(v[a+4>>2],v[a+16>>2]),65536);d=v[v[a>>2]+44>>2];e=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=e;jb[d|0](b+24|0,a,b+8|0);v[a+16>>2]=v[a+16>>2]+v[b+28>>2];continue}break}t[a+20|0]=1}fb=b+32|0}function mO(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;if(w[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){t[a+534|0]=0}else{fj(a,d,1);c=c+1|0;continue}break}}t[b+15|0]=0;Wh(a+8|0,18,b+15|0);Et(a+26|0,18,29194);t[b+14|0]=255;Wh(a+62|0,256,b+14|0);Ng(v[a>>2],v[a+4>>2],65535,261,1);Ng(v[a>>2],v[a+4>>2],65535,260,0);fb=b+16|0}function sV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-48|0;fb=e;c=fb-16|0;fb=c;f=e+8|0;tC(c+8|0,f);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){sC(f)}c=-1;a:{if(!d){break a}c=0;if(!vC(e+8|0)){break a}c=Ce(a,b,uC(w[e+43|0]),ib)}fb=e+48|0;return c|0}function is(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;a:{if(!(c&32)){break a}g=d,h=Td(b),v[g+8>>2]=h;g=d,h=ih(b),v[g>>2]=h;while(1){if(!Kh(d+8|0,d)){break a}c=v[d+8>>2];f=ef(97);e=t[c|0];b:{if((f|0)>(e|0)){break b}if((ef(122)|0)<(e|0)){break b}g=c,h=(ef(65)-f|0)+e|0,t[g|0]=h}xe(d+8|0);continue}}Mc(a,b);fb=d+16|0}function bs(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;a:{if(!(c&32)){break a}g=d,h=Fi(b),v[g+8>>2]=h;g=d,h=ev(b),v[g>>2]=h;while(1){if(!Kh(d+8|0,d)){break a}c=v[d+8>>2];f=ef(97);e=t[c|0];b:{if((f|0)>(e|0)){break b}if((ef(122)|0)<(e|0)){break b}g=c,h=(ef(65)-f|0)+e|0,t[g|0]=h}xe(d+8|0);continue}}Mc(a,b);fb=d+16|0}function Tfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb+-64|0;fb=e;c=fb-16|0;fb=c;f=e+8|0;$R(c+8|0,f);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){_R(f)}c=-1;a:{if(!d){break a}c=0;if(!bS(e+8|0)){break a}c=Ce(a,b,aS(e+8|0),ib)}fb=e- -64|0;return c|0}function FC(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(b>>>0<5){if(!b){break a}if(!Lb(v[a>>2],v[a+8>>2],b)){break a}while(1)if((d|0)==4){d=v[c+12>>2];break a}else{t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){kg(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;continue}}ca(11197,9050,136,14177);L()}fb=c+16|0;return d}function pha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-576|0;fb=d;c=fb-16|0;fb=c;$S(c+8|0,d);e=v[c+12>>2];hd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Zc(a,v[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){_S(d)}c=-1;a:{if(!e){break a}c=0;if(!bT(d)){break a}c=Ce(a,b,aT(x[d+34>>1],x[d+36>>1]),ib)}fb=d+576|0;return c|0}function XM(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;f=-2147483648;f=!c|!(t[c+15|0]&1)?f:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){f=x[d+28>>1];break b}if((f|0)==-2147483648){break a}}Fp(b,f,a);xb(e+8|0,a+1074312|0,10);if(!yb(v[v[e+8>>2]>>2],v[e+12>>2])|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}fb=e+16|0}function Wfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;v[c>>2]=v[a+8>>2];d=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,20)+d;a=v[c>>2];a:{while(1){if(v[c+4>>2]==(a|0)){break a}v[23220]=0;Y(218,a|0);a=v[23220];v[23220]=0;if((a|0)!=1){a=v[c>>2]+20|0;v[c>>2]=a;continue}break}a=P()|0;O()|0;Ed(c);S(a|0);L()}Ed(c);fb=c+16|0}function yQ(a){var b=0,c=0;a:{if(Mb(a,3868,4)|w[a+63|0]!=26){break a}b=w[a+65|0];if(w[a+66|0]|(b|0)!=16&(b|0)!=1|(w[a+64|0]&3|(w[a+78|0]|w[a+79|0]<<8)>>>0>127)){break a}if((w[a+80|0]|w[a+81|0]<<8)>>>0>127){break a}b=a+80|0;a=a+78|0;a=ll(w[a|0]|w[a+1|0]<<8,w[b|0]|w[b+1|0]<<8)?b:a;c=(w[a|0]|w[a+1|0]<<8)!=0}return c}function p3(a){a=a|0;var b=0;v[23220]=0;Y(919,a|0);b=v[23220];v[23220]=0;if((b|0)!=1){return+A[v[a+24>>2]+16>>3]}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,7560,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function j3(a){a=a|0;var b=0;v[23220]=0;Y(919,a|0);b=v[23220];v[23220]=0;if((b|0)!=1){return v[v[a+24>>2]+8>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,10837,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Vx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=F(c,.999);h=c*3.141592653589793;i=at(b);while(1){if((e|0)!=32768){f=((e<<12^-1)&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=qi(g)*at(K(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=Gz(c*d*32768),u[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function vQ(a){var b=0;a:{if(Mb(a+44|0,14134,4)|w[a+28|0]!=26|(w[a+40|0]|w[a+41|0]<<8|w[a+30|0]>2)){break a}if(((w[a+38|0]|w[a+39|0]<<8)-33&65535)>>>0<65504|((w[a+32|0]|w[a+33|0]<<8)-257&65535)>>>0<65280|((w[a+34|0]|w[a+35|0]<<8)-256&65535)>>>0<65281){break a}b=((w[a+36|0]|w[a+37|0]<<8)-1&65535)>>>0<128}return b}function Dda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=fb-32|0;fb=d;e=fb-16|0;fb=e;f=e,g=Jb(c&65535),u[f+14>>1]=g;c=d+16|0;sJ(c,e+14|0);fb=e+16|0;Ui(d+8|0,c);v[23220]=0;X(101,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23220];v[23220]=0;if((a|0)!=1){bc(d+16|0);fb=d+32|0;break a}a=P()|0;O()|0;bc(d+16|0);S(a|0);L()}}function Cr(a){var b=0,c=0;b=v[a+76>>2];a:{if(!((b|0)>=0&(!b|(b&-1073741825)!=((w[462800]?42:0)|0)))){b=v[a+4>>2];if((b|0)!=v[a+8>>2]){v[a+4>>2]=b+1;a=w[b|0];break a}a=sw(a);break a}b=a+76|0;c=v[b>>2];v[b>>2]=c?c:1073741823;c=v[a+4>>2];b:{if((c|0)!=v[a+8>>2]){v[a+4>>2]=c+1;a=w[c|0];break b}a=sw(a)}Ud(b)}return a}function Aca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;v[d+28>>2]=c;v[d+8>>2]=4896;e=v[a>>2];f=v[a+8>>2];c=v[Eb(d+28|0,d+8|0)>>2];if(!Lb(e,f,c)){c=Ze(a)}e=d+8|0;AA(e,b);f=cc(d+16|0,v[d+8>>2],c);jc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);AA(e,b);Sb(v[d+8>>2]+c|0,0,4896-c|0);Yb(a,v[d+28>>2]);fb=d+32|0}function AZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a:{if(!ve(f)){b=v[f+4>>2];v[a>>2]=v[f>>2];v[a+4>>2]=b;v[a+8>>2]=v[f+8>>2];break a}d=v[f>>2];b:{c:{c=v[f+4>>2];d:{if(c>>>0<=1){ae(a,c);break d}if(c>>>0>=1073741808){break c}e=xl(c)+1|0;b=pi(e);td(a,b);yf(a,e);Bd(a,c);a=b}bi(a,d,c+1|0);break b}kf();L()}}}function pea(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Cb(a)>>2]){c=fb-16|0;fb=c;a=Hu(c,a,1);PQ(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+20;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Cb(a);c=XA(d+8|0,YA(a,Bf(v[a>>2],v[a+4>>2])+1|0),Bf(v[a>>2],v[a+4>>2]),c);PQ(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;WA(a,c);Xt(c);fb=d+32|0}function afa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,24);a=v[c+4>>2];b=v[c+8>>2];a:{while(1){if((a|0)==(b|0)){break a}v[23220]=0;Y(538,a|0);d=v[23220];v[23220]=0;if((d|0)!=1){a=a+24|0;v[c+4>>2]=a;continue}break}a=P()|0;O()|0;hc(c);S(a|0);L()}hc(c);fb=c+16|0}function _0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-32|0;fb=f;v[f+28>>2]=e;v[f+24>>2]=d;Hg(f+16|0,b,c);b=ng(f+8|0,f+24|0);c=v[b+4>>2];b=v[b>>2];v[23220]=0;ga(156,a|0,v[f+16>>2],v[f+20>>2],b|0,c|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){be(f+24|0);fb=f+32|0;return}a=P()|0;O()|0;be(f+24|0);S(a|0);L()}function Lx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;h=x[b>>1];c=Od(a);e=fc(a);f=fb-16|0;fb=f;while(1){if(c){g=zs(x[c+16>>1],h);e=g?e:c;c=v[(g?c+4|0:c)>>2];continue}break}c=v[dc(f+8|0,e)>>2];fb=f+16|0;a:{if(Nb(c,Hf(a))){if(!zs(x[b>>1],x[pd(c)>>1])){break a}}c=Hf(a)}a=v[dc(d+8|0,c)>>2];fb=d+16|0;return a}function Ica(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;v[d+28>>2]=c;v[d+8>>2]=263;e=v[a>>2];f=v[a+8>>2];c=v[Eb(d+28|0,d+8|0)>>2];if(!Lb(e,f,c)){c=Ze(a)}e=d+8|0;dP(e,b);f=cc(d+16|0,v[d+8>>2],c);jc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);dP(e,b);Sb(v[d+8>>2]+c|0,0,263-c|0);Yb(a,v[d+28>>2]);fb=d+32|0}function HU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-1968|0;fb=e;c=fb-16|0;fb=c;f=e+8|0;EB(c+8|0,f);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){DB(f)}c=-1;a:{if(!d){break a}c=0;if(!FB(e+8|0)){break a}c=Ce(a,b,1024,0)}fb=e+1968|0;return c|0}function waa(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Cb(a)>>2]){c=fb-16|0;fb=c;a=yz(c,a,1);jz(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+32;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Cb(a);c=kt(d+8|0,Hp(a,dg(v[a>>2],v[a+4>>2])+1|0),dg(v[a>>2],v[a+4>>2]),c);jz(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;vO(a,c);iz(c);fb=d+32|0}function by(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;f=v[b+656>>2];e=0;a:{if(!f){break a}f=Nu(f,c);e=a+1074312|0;xb(d+8|0,e,31);a=0;if(!yb(v[v[d+8>>2]>>2],v[d+12>>2])){xb(d,e,93);a=yb(v[v[d>>2]>>2],v[d+4>>2])^1}if(!(t[DL(b,c)+6|0]&1)){e=0;if(!(t[f+12|0]&1)|a){break a}}e=rc(v[f>>2],v[f+4>>2])^1}fb=d+16|0;return e}function _T(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Cb(a)>>2]){c=fb-16|0;fb=c;a=QT(c,a,1);PT(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+48;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Cb(a);c=NT(d+8|0,OT(a,fq(v[a>>2],v[a+4>>2])+1|0),fq(v[a>>2],v[a+4>>2]),c);PT(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+48;MT(a,c);LT(c);fb=d+32|0}function Aha(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Cb(a)>>2]){c=fb-16|0;fb=c;a=Hu(c,a,1);ZA(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+20;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Cb(a);c=XA(d+8|0,YA(a,Bf(v[a>>2],v[a+4>>2])+1|0),Bf(v[a>>2],v[a+4>>2]),c);ZA(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;WA(a,c);Xt(c);fb=d+32|0}function zda(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Cb(a)>>2]){c=fb-16|0;fb=c;a=xv(c,a);Jz(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Cb(a);c=kk(d+8|0,Jm(a,rd(v[a>>2],v[a+4>>2])+1|0),rd(v[a>>2],v[a+4>>2]),c);Jz(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;UP(a,c);TP(c);fb=d+32|0}function yN(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Cb(a)>>2]){c=fb-16|0;fb=c;a=st(c,a,1);Ko(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Cb(a);c=kk(d+8|0,Jm(a,rd(v[a>>2],v[a+4>>2])+1|0),rd(v[a>>2],v[a+4>>2]),c);Ko(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;er(a,c);xN(c);fb=d+32|0}function d_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=v[20763];v[g+24>>2]=v[20762];v[g+28>>2]=h;h=v[20761];v[g+16>>2]=v[20760];v[g+20>>2]=h;h=v[20759];v[g+8>>2]=v[20758];v[g+12>>2]=h;h=v[20757];v[g>>2]=v[20756];v[g+4>>2]=h;h=a;a=g+32|0;b=Fj(h,b,c,d,e,f,g,a);fb=a;return b|0}function U3(a,b){a=a|0;b=b|0;var c=0,d=0;a=Gb(a);c=Bb(b);v[23220]=0;R(70,a|0,c|0);c=v[23220];v[23220]=0;if((c|0)!=1){a:{b:{while(1){if(Bb(b)>>>0<=d>>>0){break b}c=t[Vf(b,d)|0];v[23220]=0;R(48,a|0,ef(c)|0);c=v[23220];v[23220]=0;if((c|0)!=1){d=d+1|0;continue}break}break a}return}}b=P()|0;O()|0;vb(a);S(b|0);L()}function Ofa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;v[d+28>>2]=c;v[d+8>>2]=22;e=v[a>>2];f=v[a+8>>2];c=v[Eb(d+28|0,d+8|0)>>2];if(!Lb(e,f,c)){c=Ze(a)}e=d+8|0;Zt(e,b);f=cc(d+16|0,v[d+8>>2],c);jc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);Zt(e,b);Sb(v[d+8>>2]+c|0,0,22-c|0);Yb(a,v[d+28>>2]);fb=d+32|0}function Mfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;v[d+28>>2]=c;v[d+8>>2]=40;e=v[a>>2];f=v[a+8>>2];c=v[Eb(d+28|0,d+8|0)>>2];if(!Lb(e,f,c)){c=Ze(a)}e=d+8|0;oA(e,b);f=cc(d+16|0,v[d+8>>2],c);jc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);oA(e,b);Sb(v[d+8>>2]+c|0,0,40-c|0);Yb(a,v[d+28>>2]);fb=d+32|0}function pf(a,b,c,d){var e=0,f=0,g=0;a:{if(!Bb(a)|(c-b|0)<5){break a}ur(b,c);e=c-4|0;c=Ec(a);g=c+Bb(a)|0;b:{while(1){c:{a=t[c|0];f=a-127|0;if(b>>>0>=e>>>0){break c}if((a|0)!=v[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;c=((g-c|0)>1)+c|0;continue}break}if((f&255)>>>0<130|a>>>0>v[e>>2]-1>>>0){break a}}v[d>>2]=4}}function hV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;v[d+28>>2]=c;v[d+8>>2]=65;e=v[a>>2];f=v[a+8>>2];c=v[Eb(d+28|0,d+8|0)>>2];if(!Lb(e,f,c)){c=Ze(a)}e=d+8|0;Gu(e,b);f=cc(d+16|0,v[d+8>>2],c);jc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);Gu(e,b);Sb(v[d+8>>2]+c|0,0,65-c|0);Yb(a,v[d+28>>2]);fb=d+32|0}function PW(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Cb(a)>>2]){c=fb-16|0;fb=c;a=xv(c,a);Ko(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Cb(a);c=kk(d+8|0,Jm(a,rd(v[a>>2],v[a+4>>2])+1|0),rd(v[a>>2],v[a+4>>2]),c);Ko(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;er(a,c);wv(c);fb=d+32|0}function JV(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Cb(a)>>2]){c=fb-16|0;fb=c;a=mD(c,a);gv(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+36;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Cb(a);c=jD(d+8|0,lD(a,Sq(v[a>>2],v[a+4>>2])+1|0),Sq(v[a>>2],v[a+4>>2]),c);gv(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+36;iD(a,c);hv(c);fb=d+32|0}function Gv(a,b,c,d,e){var f=0,g=0;g=c-b|0;a:{if((e|0)>=(g|0)){e=B(32-E(d|1)|0,1233)>>>12|0;f=61;if((g|0)<((e-(y[(e<<2)+25760>>2]>d>>>0)|0)+1|0)){break a}}b:{if(d>>>0<=99999999){c=Gw(b,d);break b}c=d;d=(d>>>0)/1e8|0;e=c+B(d,-1e8)|0;c=(e>>>0)/1e4|0;c=Vi(Vi(aH(b,d),c),e+B(c,-1e4)|0)}f=0}v[a+4>>2]=f;v[a>>2]=c}function i1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{if(w[b+40|0]){break a}if(!v[b+28>>2]){t[b+40|0]=1;break a}d=v[c+4>>2];f=v[c>>2];while(1){b:{if(d){e=jb[v[b+28>>2]](v[b+24>>2],f,d)|0;if(e){break b}t[b+40|0]=1}d=g;break a}d=d-e|0;f=e+f|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;continue}}ec(a,v[c>>2],d)}function Xha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;c=fb-16|0;fb=c;f=e+8|0;SB(c+8|0,f);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){vu(f)}c=-1;a:{if(!d){break a}c=0;if(!CT(e+8|0)){break a}c=Ce(a,b,72,0)}fb=e+32|0;return c|0}function IK(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[23220]=0;v[c+12>>2]=0;U(876,a+4208|0,b<<1,c+12|0);b=v[23220];v[23220]=0;a:{if((b|0)==1){b=V(91480)|0;if((O()|0)!=(ea(91480)|0)){break a}_(b|0)|0;v[a+4220>>2]=0;$()}v[a+4224>>2]=0;fb=c+16|0;return}S(b|0);L()}function Ay(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;h=-17;if(-17-b>>>0>=c>>>0){i=qd(a);if(b>>>0<=2147483622){v[g+8>>2]=b<<1;v[g+12>>2]=b+c;h=Qh(v[Sc(g+12|0,g+8|0)>>2])+1|0}c=tc(h);if(e){Fe(c,i,e)}if((d|0)!=(e|0)){Fe((c+e|0)+f|0,e+i|0,d-e|0)}if((b|0)!=10){Fb(i)}td(a,c);yf(a,h);fb=g+16|0;return}kf();L()}function vs(a){var b=0,c=0,d=0;b=Kj(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){if(b>45e-5){c=ip(b)/.6931471805599453;b=c-H(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=Kj(d+c)*.5}else{b=0}A[a+4248>>3]=b}us(a)}function ml(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}b:{switch(d-2|0){case 0:d=B(c,872)+b|0;f=KM(v[d+720>>2],v[d+1272>>2],e);if((f+5&255)>>>0>5){break a}return JM(a,b,c,e);case 1:break b;default:break a}}f=JM(a,b,c,e);if((f+5&255)>>>0>5){break a}a=B(c,872)+b|0;f=KM(v[a+720>>2],v[a+1272>>2],e)}return f}function lB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;v[f+8>>2]=c;g=f,h=Ze(b),v[g+28>>2]=h;c=f+8|0;Af(c,b,v[Eb(c,f+28|0)>>2]);b=te(c);v[23220]=0;da(226,a|0,b|0,v[f+8>>2],d|0,e|0);a=v[23220];v[23220]=0;if((a|0)!=1){Jc(f+8|0);fb=f+32|0;return}a=P()|0;O()|0;Jc(f+8|0);S(a|0);L()}function f4(a){a=a|0;var b=0;v[23220]=0;Y(944,a|0);b=v[23220];v[23220]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,11948,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function Uda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-608|0;fb=d;c=fb-16|0;fb=c;tQ(c+8|0,d);e=v[c+12>>2];hd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Zc(a,v[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){sQ(d)}c=-1;a:{if(!e){break a}c=0;if(!vQ(d)){break a}c=Ce(a,b,uQ(x[d+34>>1]),ib)}fb=d+608|0;return c|0}function M4(a){a=a|0;var b=0;v[23220]=0;Y(919,a|0);b=v[23220];v[23220]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[23220]=0;X(906,5651,a|0,0,0);a=v[23220];v[23220]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Tb();L()}function zm(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{if(v[c>>2]|v[d>>2]){while(1){if((b|0)==(f|0)){break a}e=v[d>>2];g=v[c>>2];h=c,i=g-dd((dd(0-g|0,31)&255)+g|0,8)|0,v[h>>2]=i;h=d,i=v[d>>2]-dd(e+(dd(0-e|0,31)&255)|0,8)|0,v[h>>2]=i;e=(f<<3)+a|0;v[e>>2]=v[c>>2];v[e+4>>2]=v[d>>2];f=f+1|0;continue}}Sb(a,0,b<<3)}}function zU(a){a=a|0;var b=0,c=0,d=0;c=fb-32|0;fb=c;b=255;a:{if(gj(v[a>>2],v[a+4>>2])>>>0<=49){b=mz(c,v[a+12>>2]);v[23220]=0;R(279,a|0,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break a}Uk(b);xi(a,gj(v[a>>2],v[a+4>>2])-1&255);b=gj(v[a>>2],v[a+4>>2])-1|0}fb=c+32|0;return b&255}a=P()|0;O()|0;Uk(b);S(a|0);L()}function d0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Gb(a);d=xd(v[b+4>>2],w[b+11|0]);e=xd(v[c+4>>2],w[c+11|0]);b=qd(b);v[23220]=0;X(88,a|0,b|0,d|0,d+e|0);b=v[23220];v[23220]=0;a:{if((b|0)!=1){b=qd(c);v[23220]=0;W(89,a|0,b|0,e|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}}function Ox(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;v[d>>2]=a;a=v[a+4>>2];v[d+4>>2]=a;v[d+8>>2]=a+B(b,52);a=v[d+4>>2];b=v[d+8>>2];a:{while(1){if((a|0)==(b|0)){break a}v[23220]=0;R(849,a|0,c|0);e=v[23220];v[23220]=0;if((e|0)!=1){a=a+52|0;v[d+4>>2]=a;continue}break}a=P()|0;O()|0;hc(d);S(a|0);L()}hc(d);fb=d+16|0}function xU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+12>>2]=c;a:{if(!Lb(v[b>>2],v[b+8>>2],c<<1)){break a}uc(d+12|0,65535);gg(a,x[d+12>>1]);c=Ab(v[a>>2]);v[d>>2]=c;a=Ab(v[a+4>>2]);while(1){if(!Nb(c,a)){break a}Au(b,d+8|0);e=c,f=Jb(x[d+8>>1]),u[e>>1]=f;c=v[Oe(d)>>2];continue}}fb=d+16|0}function v6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;Xc(a,b);v[23220]=0;U(63,d+8|0,b|0,c|0);e=v[23220];v[23220]=0;a:{if((e|0)==1){break a}Wb(d+8|0);b=v[b+24>>2];if(b){v[23220]=0;U(64,d|0,b|0,c|0);b=v[23220];v[23220]=0;if((b|0)==1){break a}Wb(d)}fb=d+16|0;return}b=P()|0;O()|0;Wb(a);S(b|0);L()}function sr(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}t[a|0]=b}function mia(a,b){a=a|0;b=b|0;var c=0;iu(a,b);Mf(b);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}t[b+3|0]=45;t[b+5|0]=a&15;return}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;return}t[b+3|0]=20;t[b+5|0]=a&15|160;return}t[b+3|0]=0}}function lY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;b=fb-16|0;fb=b;v[e>>2]=c;a=Zv(b+12|0,0,v[a+8>>2]);c=2;a:{if(a+1>>>0<2){break a}a=a-1|0;c=1;if(a>>>0>d-v[e>>2]>>>0){break a}c=b+12|0;while(1){if(a){d=w[c|0];f=v[e>>2];v[e>>2]=f+1;t[f|0]=d;a=a-1|0;c=c+1|0;continue}break}c=0}fb=b+16|0;return c|0}function dO(a,b){var c=0,d=0,e=0;a=Ib(a);a:{if(b){v[23220]=0;R(736,a|0,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break a}d=fb-16|0;fb=d;c=Lo(d,a,b);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){hc(c);fb=d+16|0}else{Ul(b,0,0);b=b+16|0;v[c+4>>2]=b;continue}break}}return a}b=P()|0;O()|0;Yj(a);S(b|0);L()}function _N(a,b){var c=0,d=0,e=0,f=0;c=A[b+8>>3];a:{d=A[b>>3];if(Xe(d)){if(d<0){c=VN(c)?c:1;break a}if(c!=0){if(VN(c)){break a}}Ul(a,d,Xe(c)?M:c);return}if(!Mh(d)|c!=0){break a}e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;return}d=tx(d);f=qi(c);Ul(a,d*Me(c),f*d)}function Jk(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;qx(c,b);v[23220]=0;R(1023,c+16|0,c|0);b=v[23220];v[23220]=0;a:{b:{if((b|0)!=1){v[23220]=0;U(1024,a|0,0,c+16|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}Nc(c+16|0);vb(c);fb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Nc(c+16|0)}vb(c);S(b|0);L()}function S7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ji(a,b,c,d);v[a>>2]=43996;b=Ib(a+4208|0);v[a+4228>>2]=0;v[a+4220>>2]=0;v[a+4224>>2]=0;v[a+4232>>2]=v[c+24620>>2];rU(a+4260|0,80,150,80,255);v[23220]=0;R(870,a+44|0,2);c=v[23220];v[23220]=0;if((c|0)!=1){ii(a);return a|0}c=P()|0;O()|0;lc(b);sf(a);S(c|0);L()}function hga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Ab(v[b>>2]);g=Ab(v[b+4>>2]);e=fb-16|0;fb=e;v[e+8>>2]=d;while(1){a:{if(!Nb(d,g)){break a}f=fb-16|0;fb=f;yS(f+8|0,d);fb=f+16|0;if(x[f+8>>1]==(c|0)){break a}d=v[jm(e+8|0)>>2];continue}break}fb=e+16|0;if(rc(d,Ab(v[b+4>>2]))){xh(a);return}ko(a,d)}function C9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=nc(a,b,614);e=c+616|0;a=0;while(1){d=B(a,872);up(d+e|0,(b+d|0)+616|0);a=a+1|0;if((a|0)!=256){continue}break}a=Mz(c+223848|0,b+223848|0);v[23220]=0;Q(775,c+223860|0,b+223860|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){return c|0}b=P()|0;O()|0;$b(a);S(b|0);L()}function nL(a){var b=0,c=0;a:{if(Mb(a,14168,4)){break a}b=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);if(!b){break a}c=(b+24|0)==(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))}return c}function zea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-1120|0;fb=d;c=fb-16|0;fb=c;TQ(c+8|0,d+8|0);e=v[c+12>>2];hd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Zc(a,v[c+12>>2])}fb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!VQ(d+8|0)){break a}c=Ce(a,b,UQ(v[d+1112>>2]),ib)}fb=d+1120|0;return c|0}function Vp(a){var b=0,c=0;b=fb-32|0;fb=b;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b>>2]=0;v[b+4>>2]=0;c=a+288|0;rz(c,c+512|0,b);v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b>>2]=0;v[b+4>>2]=0;a=a+800|0;rz(a,JP(a),b);fb=b+32|0}function vha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-224|0;fb=d;c=fb-16|0;fb=c;hT(c+8|0,d);e=v[c+12>>2];hd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Zc(a,v[c+12>>2])}fb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!jT(d)){break a}c=Ce(a,b,iT(w[d+216|0],w[d+217|0]),ib)}fb=d+224|0;return c|0}function g6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=6){c=Ld(c,C(0));a:{b:{switch(b-1|0){case 0:c=Nh(c);if(c==z[zb(a+4208|0,1)>>2]){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 3:break b;default:break a}}c=C(Nh(C(c*C(4)))*C(.25))}d=zb(a+4208|0,b),e=c,z[d>>2]=e;vx(a)}}function R6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=6){c=Ld(c,C(0));a:{b:{switch(b-3|0){case 0:c=Nh(c);if(c==z[zb(a+4208|0,3)>>2]){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 1:break b;default:break a}}c=C(Nh(C(c*C(4)))*C(.25))}d=zb(a+4208|0,b),e=c,z[d>>2]=e;vx(a)}}function sf(a){a=a|0;var b=0,c=0;v[a>>2]=44464;b=v[a+12>>2];if(v[b>>2]==(a|0)){v[b>>2]=v[a+4>>2]}b=v[a+20>>2];if(b){v[b>>2]=0;v[a+20>>2]=0}b=v[a+4>>2];if(b){v[b+8>>2]=v[a+8>>2]}c=v[a+8>>2];if(c){v[c+4>>2]=b}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+16>>2];v[b+946300>>2]=v[b+946300>>2]-1;AK(a+44|0);return a|0}function rN(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=v[b+48>>2]+1|0;v[b+52>>2]=e;a:{if(y[Xb(v[a+484344>>2],x[b+70>>1])+12>>2]>e>>>0){break a}if(!c){u[b+74>>1]=x[b+72>>1]+1}v[b+52>>2]=0;xb(d+8|0,a+1074312|0,63);if(!yb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}a=v[b+56>>2];v[b+56>>2]=0;v[b+52>>2]=a}fb=d+16|0}function Hda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb+-64|0;fb=d;c=fb-16|0;fb=c;hu(c+8|0,d);e=v[c+12>>2];hd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Zc(a,v[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){$t(d)}c=-1;a:{if(!e){break a}c=0;if(!$P(d)){break a}c=Ce(a,b,_P(d),ib)}fb=d- -64|0;return c|0}function jha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-192|0;fb=d;c=fb-16|0;fb=c;sq(c+8|0,d);e=v[c+12>>2];hd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Zc(a,v[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){VS(d)}c=-1;a:{if(!e){break a}c=0;if(!XS(d)){break a}c=Ce(a,b,WS(d),ib)}fb=d+192|0;return c|0}function Sl(a,b,c){var d=0,e=0;a=Gb(a);d=Bb(b);v[23220]=0;R(45,a|0,d|0);d=v[23220];v[23220]=0;if((d|0)!=1){a:{while(1){if(Bb(b)>>>0>e>>>0){d=v[(w[Vf(b,e)|0]<<2)+c>>2];v[23220]=0;R(46,a|0,d|0);d=v[23220];v[23220]=0;if((d|0)==1){break a}e=e+1|0;continue}break}return}}b=P()|0;O()|0;Nc(a);S(b|0);L()}function BK(a){a=a|0;var b=0,c=0,d=0;b=A[a+4264>>3]*+y[v[a+16>>2]+1074376>>2];a:{if(D(b)<0x8000000000000000){d=~~b>>>0;c=D(b)>=1?~~(b>0?F(H(b*2.3283064365386963e-10),4294967295):I((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}c=-2147483648}A[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function Mca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;c=fb-16|0;fb=c;tS(c+8|0,d);e=v[c+12>>2];hd(c,a,v[c+8>>2],e);f=v[c+4>>2];if((f|0)==(e|0)){Zc(a,v[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){BA(d)}c=-1;a:{if(!e){break a}c=0;if(!iP(d)){break a}c=Ce(a,b,hP(d),ib)}fb=d+80|0;return c|0}function qha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;v[d+8>>2]=c;v[d+12>>2]=-1;if((c|0)!=-1){f=d,g=Bb(a),v[f>>2]=g;e=v[Eb(d+12|0,d)>>2];v[d+4>>2]=e;a=Ml(Ec(a),b,v[Eb(d+4|0,d+8|0)>>2]);a:{if(a){break a}a=-1;if(c>>>0>e>>>0){break a}a=c>>>0<e>>>0}fb=d+16|0;return a|0}fm();L()}function Pea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-128|0;fb=e;c=fb-16|0;fb=c;eR(c+8|0,e);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);f=v[c+4>>2];if((f|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;d=(d|0)==(f|0);if(!d){dR(e)}c=-1;a:{if(!d){break a}c=0;if(!fR(e)){break a}c=Ce(a,b,256,0)}fb=e+128|0;return c|0}function Ig(a,b){var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=E(e);vf(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;fb=d+16|0}function cB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;v[e+8>>2]=c;f=e,g=Ze(b),v[f+28>>2]=g;c=e+8|0;Af(c,b,v[Eb(c,e+28|0)>>2]);b=te(c);v[23220]=0;X(328,a|0,b|0,v[e+8>>2],d|0);a=v[23220];v[23220]=0;if((a|0)!=1){Jc(e+8|0);fb=e+32|0;return}a=P()|0;O()|0;Jc(e+8|0);S(a|0);L()}function JB(a,b,c){var d=0,e=0,f=0;d=fb-32|0;fb=d;v[d+28>>2]=c;v[d+8>>2]=192;e=v[a>>2];f=v[a+8>>2];c=v[Eb(d+28|0,d+8|0)>>2];if(!Lb(e,f,c)){c=Ze(a)}e=d+8|0;sq(e,b);f=cc(d+16|0,v[d+8>>2],c);jc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);sq(e,b);Sb(v[d+8>>2]+c|0,0,192-c|0);Yb(a,v[d+28>>2]);fb=d+32|0}function EX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;a:{e=v[b>>2];if(sd(e)){if(!ze(c)){GJ(c,17713);e=v[b>>2]}b=v[b+4>>2];jb[v[v[b>>2]+24>>2]](d,b,e);v[23220]=0;Q(772,c|0,d|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break a}ub(d)}Mc(a,c);fb=d+16|0;return}a=P()|0;O()|0;ub(d);S(a|0);L()}function lJ(a,b){var c=0;c=fb-32|0;fb=c;ei(c,b);v[23220]=0;U(1029,c+16|0,0,c|0);b=v[23220];v[23220]=0;a:{b:{if((b|0)!=1){v[23220]=0;R(1030,a|0,c+16|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}Nc(c+16|0);ub(c);fb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Nc(c+16|0)}ub(c);S(b|0);L()}function XR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;e=eg(a);a=b+236|0;b=$p(a);a:{while(1){if((a|0)!=(b|0)){d=x[a>>1];u[c+14>>1]=d;if(d){v[23220]=0;U(496,c|0,e|0,c+14|0);d=v[23220];v[23220]=0;if((d|0)==1){break a}}a=a+2|0;continue}break}fb=c+16|0;return}a=P()|0;O()|0;rA(e);S(a|0);L()}function RK(a,b){var c=0,d=0,e=0,f=0,g=C(0);c=fb-16|0;fb=c;if(Ch(v[v[a>>2]-12>>2]+a|0)){u[c+14>>1]=0;If(a,c+14|0);e=x[c+14>>1];Oj(b,e);while(1){if((d|0)!=(e|0)){v[c+8>>2]=0;jp(a,c+8|0);f=zb(v[b>>2],d),g=z[c+8>>2],z[f>>2]=g;d=d+1|0;continue}break}d=Ch(v[v[a>>2]-12>>2]+a|0)}fb=c+16|0;return d}function FP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;v[e+12>>2]=6553600;i=e,j=_b(b),v[i+8>>2]=j;f=+(d>>>0)/6553600;g=e+12|0;b=e+8|0;h=bq(f*+y[Eb(g,b)>>2]);v[e+8>>2]=6553600;i=e,j=_b(c),v[i+4>>2]=j;i=e,j=bq(f*+y[Eb(b,e+4|0)>>2]),v[i+12>>2]=j;v[e+8>>2]=d-h;Tn(a,h,Eb(b,g));fb=e+16|0}function Dp(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{e=Tk(a,b);if((e|0)==255){break a}g=v[a>>2];if(Tj(g)){break a}f=Dd(a+318|0,e);e=lO(e);if(h=1,i=t[Hb(f,10)|0]&1,j=d,j?h:i){Ng(g,v[a+4>>2],b,e- -64&65535,kO(c,w[Hb(f,2)|0]))}if(d){break a}Ng(v[a>>2],v[a+4>>2],b,e+67&65535,kO(c,w[Hb(f,3)|0]))}}function uT(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function sv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function lw(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-160|0;fb=e;v[e+60>>2]=b;v[e+20>>2]=b;v[e+24>>2]=-1;f=e+16|0;ai(f,0,0);qG(e,f,d,1);d=v[e+8>>2];f=v[e+12>>2];g=v[e>>2];h=v[e+4>>2];if(c){v[c>>2]=((v[e+20>>2]+v[e+136>>2]|0)-v[e+60>>2]|0)+b}v[a+8>>2]=d;v[a+12>>2]=f;v[a>>2]=g;v[a+4>>2]=h;fb=e+160|0}function wX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(Eg(a,v[b+8>>2],0)){Uv(b,c,d);return}e=v[a+12>>2];_E(v[a+16>>2],v[a+20>>2],b,c,d);a:{if((e|0)<2){break a}a=a+16|0;e=a+(e<<3)|0;a=a+8|0;while(1){_E(v[a>>2],v[a+4>>2],b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function sy(a,b,c){var d=0;d=v[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=w[b+813|0];if(c){t[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}Pj(a,b,b+700|0,c<<2,0)}}function n2(a,b){a=a|0;b=b|0;var c=0,d=0;a=Ib(a);a:{c=bh(v[b+4>>2],v[b+8>>2]);if(!c){break a}v[23220]=0;R(1025,a|0,c|0);d=v[23220];v[23220]=0;if((d|0)!=1){d=v[b+8>>2];b=v[b+4>>2];v[23220]=0;X(1026,a|0,b|0,d|0,c|0);b=v[23220];v[23220]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;hs(a);S(b|0);L()}}function bK(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[23220]=0;v[c+12>>2]=0;U(876,a+4208|0,b<<2,c+12|0);b=v[23220];v[23220]=0;a:{if((b|0)==1){b=V(91480)|0;if((O()|0)!=(ea(91480)|0)){break a}_(b|0)|0;v[a+4240>>2]=0;$()}v[a+4244>>2]=0;fb=c+16|0;return}S(b|0);L()}function Wo(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;Xc(d,a);v[23220]=0;a=T(1104,d|0)|0;d=v[23220];v[23220]=0;a:{b:{if((d|0)==1){break b}v[23220]=0;X(1116,a|0,82816,82842,b|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}Wb(c+8|0);fb=c+16|0;break a}a=P()|0;O()|0;Wb(c+8|0);S(a|0);L()}return b}function WC(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=v[a+92>>2];e=v[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){v[a+96>>2]=e;v[a+92>>2]=d}else{f=(g<<3)+b|0;h=v[f>>2];d=d-dd((dd(0-d|0,31)&255)+d|0,8)|0;v[f>>2]=h+d;h=v[f+4>>2];e=e-dd((dd(0-e|0,31)&255)+e|0,8)|0;v[f+4>>2]=h+e;g=g+1|0;continue}break}}}function A9(a,b){a=a|0;b=b|0;var c=0,d=0;if(Nd(w[b+24|0])){a=eg(a);c=oj(v[b>>2]);d=wf(b);v[23220]=0;U(778,a|0,c|0,d|0);c=v[23220];v[23220]=0;a:{b:{if((c|0)==1){break b}v[23220]=0;Q(777,a+12|0,b+12|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;PM(a);S(b|0);L()}t[a+24|0]=1}}function rga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;Lf(b);v[d+12>>2]=0;a:{if(!_j(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}t[d+11|0]=0;if(Hh(a,d+11|0)){Ap(b,t[d+11|0]);e=e+1|0;continue}break}e=0}fb=d+16|0;return e|0}function ZZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=fb-128|0;fb=c;v[c+12>>2]=c+116;d=v[a+8>>2];a=c+16|0;FF(d,a,c+12|0,e,f,g);e=v[c+12>>2];d=fb-16|0;fb=d;v[d+8>>2]=b;while(1){if((a|0)!=(e|0)){JG(d+8|0,t[a|0]);a=a+1|0;continue}break}fb=d+16|0;fb=c+128|0;return v[d+8>>2]}function Iy(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;g=v[b+480180>>2];a:{if(g&64671904){b=w[(d&15)+43904|0];t[a+2|0]=0;u[a>>1]=b;break a}xb(f+8|0,b+1074312|0,66);h=a;a=(c&255)==4&(g|0)==4;b=(d&255)<<a<<4;_n(h,(i=yb(v[v[f+8>>2]>>2],v[f+12>>2])?0:b,j=b,k=e,k?i:j),a)}fb=f+16|0}function vM(a,b,c){var d=0;d=v[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=w[b+814|0];if(c){t[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}Pj(a,b,b+700|0,c,0)}}function PR(a,b,c){var d=0,e=0,f=0;f=fb-16|0;fb=f;e=Bb(a);d=Qc(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=pc(a);if(e){pj(c+d|0,d,e);b=(b>>>0>=d>>>0?d+e>>>0>b>>>0?c:0:0)+b|0}b=pj(d,b,c);c=c+e|0;hh(a,c);t[f+15|0]=0;bd(b+c|0,f+15|0);break a}Ro(a,d,(c+e|0)-d|0,e,0,0,c,b)}fb=f+16|0;return a}function Nl(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,872)+a|0)+1075648>>2];if(!f){break a}if(!jj(w[f+31|0])){break a}e=w[f+34|0];if((e-1&255)>>>0>249){break a}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break a}jb[v[v[e>>2]+92>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,872)+a|0)+1075834>>1]=65535}}function Kz(a,b,c,d,e){var f=0;a:{f=v[a>>2];if(!Md(f,v[a+20>>2])|c>>>0>=f>>>0|f-c>>>0<d>>>0){break a}am(b);b=Wn(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!wg(b)){break a}if(v[a>>2]!=(d|0)){Pq(b+68|0)}nc(v[b+20>>2],v[a+20>>2]+c|0,d);v[b+8>>2]=e?d:0;v[b+4>>2]=0;u[b+34>>1]=x[b+34>>1]&65533|(e?2:0)}}function saa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;v[e+24>>2]=d;c=bf(a,c);Yd(e+8|0,v[a+28>>2]);f=a;a:{if(!c){d=0;if(cd(a,5)){break a}}d=v[a+28>>2];a=0;mC(b,v[e+24>>2]);while(1){if(y[e+24>>2]>a>>>0){tO(d,ac(v[b>>2],a));a=a+1|0;continue}break}d=c}We(f,d);fb=e+32|0}function _I(a,b,c,d,e){var f=0;a:{if((e|0)==10){tJ(a,b,c,d);break a}f=d>>>0<e>>>0?1:B(e,e)>>>0>d>>>0?2:3;if((f|0)>(c-b|0)){v[a+4>>2]=61;v[a>>2]=c;break a}c=b+f|0;b=c;while(1){f=d&255;d=(f|0)/(e|0)|0;b=b-1|0;t[b|0]=w[(f-B(d,e)|0)+4856|0];if(d&255){continue}break}v[a+4>>2]=0;v[a>>2]=c}}function WK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+12>>2]=b;a:{if(si(a)>>>0>=b>>>0){f=v[a>>2];e=sc(f,v[a+4>>2]);v[d+8>>2]=e;VK(f,v[Eb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Mx(a,b-e|0,c);break a}Jd(a,v[a>>2]+(b<<2)|0);break a}lA(a);oo(a,Pg(a,b));Mx(a,b,c)}fb=d+16|0}function V8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb+-64|0;fb=d;Lf(b);e=d+40|0;Af(e,a,c);a=v[d+40>>2];c=d+8|0;Pf(c,1,te(e),a);v[23220]=0;R(209,d+24|0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){a=d+24|0;xc(b,a);ub(a);Jc(d+40|0);fb=d- -64|0;break a}a=P()|0;O()|0;Jc(d+40|0);S(a|0);L()}}function PC(a,b,c,d){var e=0,f=0,g=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;e=d;d=v[a+1068>>2];u[e+(d<<1)>>1]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;f=a,g=Cd(x[v[a+1060>>2]+34>>1])+d|0,v[f+1068>>2]=g;v[a+1072>>2]=v[a+1072>>2]-1}function BG(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a=ms(a);v[a+32>>2]=b;v[a>>2]=77932;b=d+8|0;Fr(b,a);v[23220]=0;b=T(1083,b|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){Wb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;f=a,g=$m(b),t[f+44|0]=g;fb=d+16|0;return}b=P()|0;O()|0;Wb(d+8|0);un(a);S(b|0);L()}function B1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=ss(c);v[a>>2]=77192;v[d>>2]=77212;v[a+60>>2]=77252;v[a>>2]=77232;v[a+4>>2]=0;e=c;c=a+8|0;sn(e,c);v[a>>2]=77192;v[d>>2]=77212;v[23220]=0;Q(78,c|0,b|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Ck(d);S(a|0);L()}function AG(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a=VG(a);v[a+32>>2]=b;v[a>>2]=78100;b=d+8|0;Fr(b,a);v[23220]=0;b=T(1084,b|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){Wb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;f=a,g=$m(b),t[f+44|0]=g;fb=d+16|0;return}b=P()|0;O()|0;Wb(d+8|0);Kr(a);S(b|0);L()}function XU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;v[d+12>>2]=c;a:{if(!Lb(v[b>>2],v[b+8>>2],c<<1)){break a}uc(d+12|0,65535);gg(a,x[d+12>>1]);c=Ab(v[a>>2]);v[d>>2]=c;a=Ab(v[a+4>>2]);while(1){if(!Nb(c,a)){break a}Au(b,d+8|0);u[c>>1]=x[d+8>>1];c=v[Oe(d)>>2];continue}}fb=d+16|0}function QS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb+-64|0;fb=c;d=c+40|0;Af(d,a,32);a=v[c+40>>2];e=c+8|0;Pf(e,2,te(d),a);v[23220]=0;R(209,c+24|0,e|0);a=v[23220];v[23220]=0;if((a|0)!=1){vm(c,b);a=c+24|0;gl(c,a);ub(a);Jc(c+40|0);fb=c- -64|0;break a}a=P()|0;O()|0;Jc(c+40|0);S(a|0);L()}}function wr(a,b,c,d){var e=0,f=0;e=fb-160|0;fb=e;f=-1;v[e+148>>2]=b?b-1|0:0;a=b?a:e+158|0;v[e+144>>2]=a;e=Sb(e,0,144);v[e+76>>2]=-1;v[e+36>>2]=1086;v[e+80>>2]=-1;v[e+44>>2]=e+159;v[e+84>>2]=e+144;a:{if((b|0)<0){v[115696]=61;break a}t[a|0]=0;f=hH(e,c,d,1066,1067)}fb=e+160|0;return f}function ZI(a){var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;b=a+120|0;ds(w[b+20|0]);c=fb-16|0;fb=c;v[c+8>>2]=d+8;a=fb-16|0;fb=a;e=v[14231];v[a+8>>2]=v[14230];v[a+12>>2]=e;e=v[14229];v[a>>2]=v[14228];v[a+4>>2]=e;b=jb[v[cp(a,Lj(w[b+20|0]))>>2]](c+8|0,b)|0;fb=a+16|0;fb=c+16|0;fb=d+16|0;return b}function Lc(a,b,c){var d=0,e=0;d=b^-2147483648;e=a;b=c&31;if((c&63)>>>0>=32){a=0;b=d>>>b|0}else{a=d>>>b|0;b=((1<<b)-1&d)<<32-b|e>>>b}d=c&31;if((c&63)>>>0>=32){c=0;d=-2147483648>>>d|0}else{c=-2147483648>>>d|0;d=((1<<d)-1&-2147483648)<<32-d}e=b-d|0;ib=a-(c+(b>>>0<d>>>0)|0)|0;return e}function Cf(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=w[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function yl(a,b){v[a>>2]=0;v[a+4>>2]=0;v[a+20>>2]=0;u[a+16>>1]=65535;v[a+8>>2]=0;v[a+12>>2]=0;v[a+24>>2]=11;v[a+28>>2]=b;Ib(a+32|0);Ib(a+44|0);v[a+72>>2]=0;v[a+76>>2]=0;v[a+64>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;v[a+80>>2]=0;v[a+84>>2]=0;v[a+88>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;return a}function QJ(a,b,c){t[a+12|0]=0;v[c>>2]=0;v[b>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;u[a+24>>1]=0;v[a+36>>2]=0;v[a+40>>2]=0;v[a+44>>2]=0;v[a+48>>2]=0;PJ(a+60|0);PJ(a+52|0);rp(a+49956|0);rp(a+58148|0);rp(a+66340|0);rp(a+74532|0);Sb(a+228|0,0,32768);Sb(a+32996|0,0,512);Sb(a+33508|0,0,16384)}function lv(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;v[f+12>>2]=e;v[f+8>>2]=d;Hg(f,b,c);v[23220]=0;U(158,a|0,v[f>>2],v[f+4>>2]);b=v[23220];v[23220]=0;if((b|0)!=1){v[a+8>>2]=0;b=f+8|0;ng(a+12|0,b);be(b);fb=f+16|0;return a|0}a=P()|0;O()|0;be(f+8|0);S(a|0);L()}function haa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=Ib(a);a:{d=Dg(v[b>>2],v[b+4>>2]);if(d){v[23220]=0;R(735,a|0,d|0);c=v[23220];v[23220]=0;if((c|0)==1){break a}c=fb-16|0;fb=c;e=v[b>>2];f=v[b+4>>2];b=Tq(c,a,d);Pt(e,f,b+4|0);hc(b);fb=c+16|0}return a|0}b=P()|0;O()|0;Wd(a);S(b|0);L()}function caa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+12>>2]=b;a:{if(Uo(a)>>>0>=b>>>0){f=v[a>>2];e=Wc(f,v[a+4>>2]);v[d+8>>2]=e;Wh(f,v[Eb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){vo(a,b-e|0,c);break a}Jd(a,v[a>>2]+b|0);break a}aB(a);jl(a,tl(a,b));vo(a,b,c)}fb=d+16|0}function RB(a,b,c){var d=0,e=0,f=0;d=fb+-64|0;fb=d;Lf(b);e=d+40|0;Af(e,a,c);a=v[d+40>>2];f=d+8|0;Pf(f,3,te(e),a);v[23220]=0;R(209,d+24|0,f|0);e=v[23220];v[23220]=0;if((e|0)!=1){e=b;b=d+24|0;xc(e,b);ub(b);Jc(d+40|0);fb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Jc(d+40|0);S(a|0);L()}function Oi(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;v[e+12>>2]=d;g=$h(e+8|0,b);b=fb-16|0;fb=b;d=v[e+12>>2];v[b+12>>2]=d;v[b+8>>2]=d;f=-1;d=wr(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=Fd(d);v[h>>2]=a;if(!a){break a}f=wr(a,d,c,v[b+12>>2])}fb=b+16|0;_h(g);fb=e+16|0;return f}function aha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb+-64|0;fb=d;e=d+40|0;Af(e,a,c);a=v[d+40>>2];c=d+8|0;Pf(c,2,te(e),a);v[23220]=0;R(209,d+24|0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){a=d+24|0;mm(b,a);ub(a);Jc(d+40|0);fb=d- -64|0;break a}a=P()|0;O()|0;Jc(d+40|0);S(a|0);L()}}function Nh(a){var b=C(0),c=0,d=0;c=(p(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return C(a*C(0))}a=(c|0)>=0?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){a=C(C(a+b)+C(-1));break a}a=C(a+b);if(!(b<=C(-.5))){break a}a=C(a+C(1))}a=(c|0)>=0?a:C(-a)}return a}function M7(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{d=v[a+20>>2];c=v[d+4>>2];if((Wc(c,v[d+8>>2])|0)!=8){break b}if(Mb(c,9527,4)){break b}b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);v[a+4260>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[a+4264>>2]=b;break a}Ex(a,b)}ws(a)}function dU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb+-64|0;fb=d;e=d+40|0;Af(e,a,c);a=v[d+40>>2];c=d+8|0;Pf(c,2,te(e),a);v[23220]=0;R(209,d+24|0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){a=d+24|0;yc(b,a);ub(a);Jc(d+40|0);fb=d- -64|0;break a}a=P()|0;O()|0;Jc(d+40|0);S(a|0);L()}}function XO(a,b){var c=0,d=0,e=0,f=0;c=fb-96|0;fb=c;JQ(b,c,c+96|0);b=0;while(1){if((b|0)==12){v[a+104>>2]=0;v[a+96>>2]=!(v[a+88>>2]|v[a+92>>2]);v[a+100>>2]=0;fb=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d&65535;b=b+1|0;continue}break}v[a+112>>2]=0}function S8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb+-64|0;fb=d;e=d+40|0;Af(e,a,c);a=v[d+40>>2];c=d+8|0;Pf(c,1,te(e),a);v[23220]=0;R(209,d+24|0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){a=d+24|0;ue(b,a);ub(a);Jc(d+40|0);fb=d- -64|0;break a}a=P()|0;O()|0;Jc(d+40|0);S(a|0);L()}}function Cq(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=fb-16|0;fb=f;v[f+12>>2]=c;c=f+12|0;uc(c,256);uc(c,65535);h=x[f+12>>1];gg(a,h);c=0;while(1){if((c|0)==(h|0)){fb=f+16|0}else{g=w[b+c|0];i=el(v[a>>2],v[a+4>>2],c),j=(d|0)==(g|0)?-1:(e|0)==(g|0)?-2:g,u[i>>1]=j;c=c+1|0;continue}break}}function bJ(a,b,c){var d=0,e=0;while(1){a:{if((a|0)!=(b|0)){e=v[a>>2];d=Cf(e);b:{c:{if((Bb(c)|0)==(d|0)){v[23220]=0;d=W(354,c|0,e|0,d|0)|0;e=v[23220];v[23220]=0;if((e|0)==1){break c}d=!d}else{d=0}break b}V(0)|0;O()|0;Tb();L()}if(!d){break a}}else{a=b}return a}a=a+8|0;continue}}function Ws(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;re(d+8|0,b);b=v[d+8>>2];e=v[d+12>>2];c=fb-16|0;fb=c;f=Bb(a);v[c+12>>2]=f;v[c+8>>2]=e;g=Eb(c+12|0,c+8|0);a=Ml(Ec(a),b,v[g>>2]);a:{if(a){break a}a=-1;if(e>>>0>f>>>0){break a}a=e>>>0<f>>>0}fb=c+16|0;fb=d+16|0;return a>>>31|0}function TR(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;v[e+12>>2]=a;a:{if(!(!c|b)){a=Ee(+(B(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){uc(e+12|0,10);a=B(w[v[e+12>>2]+26800|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=Ee(733.8401379310345/f*1e4);break a}a=Ee(f/.264*1e4)}fb=e+16|0;return a}function OC(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;t[v[a+1068>>2]+d|0]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=v[a+1068>>2]+Cd(x[v[a+1060>>2]+34>>1])|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function gl(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;d=Ec(b);e=c,f=Bb(b),v[e+12>>2]=f;v[c+8>>2]=v[a+4>>2]-1;Yg(d,d+v[Eb(c+12|0,c+8|0)>>2]|0,v[a>>2]);d=v[a>>2];e=c,f=Bb(b),v[e+12>>2]=f;a=v[a+4>>2];v[c+8>>2]=a-1;b=v[Eb(c+12|0,c+8|0)>>2];t[c+7|0]=0;Jl(b+d|0,a+d|0,c+7|0);fb=c+16|0}function Pe(a){var b=0,c=0;b=fb-32|0;fb=b;t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;yC(b+9|0);v[a>>2]=v[b>>2];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;c=v[b+24>>2];v[a+20>>2]=v[b+20>>2];v[a+24>>2]=c;t[a+28|0]=w[b+28|0];fb=b+32|0}function naa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;b=tP(d,a+8|0,b);a=v[b>>2];a:{while(1){if(v[b+4>>2]==(a|0)){break a}v[23220]=0;R(723,a|0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){a=v[b>>2]+32|0;v[b>>2]=a;continue}break}a=P()|0;O()|0;Ed(b);S(a|0);L()}Ed(b);fb=d+16|0}function Q9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb+-64|0;fb=c;d=c+40|0;Af(d,a,32);a=v[c+40>>2];e=c+8|0;Pf(e,1,te(d),a);v[23220]=0;R(209,c+24|0,e|0);a=v[23220];v[23220]=0;if((a|0)!=1){a=c+24|0;yc(b,a);ub(a);Jc(c+40|0);fb=c- -64|0;break a}a=P()|0;O()|0;Jc(c+40|0);S(a|0);L()}}function wK(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=v[v[a+16>>2]+1074404>>2];v[23220]=0;v[c+12>>2]=0;U(876,a+4208|0,B(b,254)|0,c+12|0);b=v[23220];v[23220]=0;a:{if((b|0)==1){b=V(91480)|0;if((O()|0)!=(ea(91480)|0)){break a}_(b|0)|0;$()}v[a+4220>>2]=0;fb=c+16|0;return}S(b|0);L()}function fR(a){var b=0;a:{if(Mb(a,15456,4)|((w[a+8|0]|w[a+9|0]<<8)-768&65535)>>>0<65280|(((w[a+112|0]|w[a+113|0]<<8)-65&65535)>>>0<65472|(w[a+106|0]|w[a+107|0]<<8)>>>0>256)){break a}if((w[a+122|0]|w[a+123|0]<<8)>>>0>255){break a}b=(w[a+124|0]|w[a+125|0]<<8)>>>0<4e3}return b}function UB(a,b,c){var d=0,e=0,f=0;d=fb+-64|0;fb=d;e=d+40|0;Af(e,a,c);a=v[d+40>>2];f=d+8|0;Pf(f,3,te(e),a);v[23220]=0;R(209,d+24|0,f|0);e=v[23220];v[23220]=0;if((e|0)!=1){e=b;b=d+24|0;yc(e,b);ub(b);Jc(d+40|0);fb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Jc(d+40|0);S(a|0);L()}function Jv(a,b,c,d,e){var f=0,g=0;a:{f=fb+-64|0;fb=f;g=f+40|0;Af(g,a,e);a=v[f+40>>2];e=f+8|0;Pf(e,d,te(g),a);v[23220]=0;R(209,f+24|0,e|0);a=v[23220];v[23220]=0;if((a|0)!=1){cc(f,b,c);a=f+24|0;gl(f,a);ub(a);Jc(f+40|0);fb=f- -64|0;break a}a=P()|0;O()|0;Jc(f+40|0);S(a|0);L()}}function tga(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;v[c+8>>2]=b;a:{if(sc(v[a>>2],v[a+4>>2])>>>0>511){break a}if(!sd(b)){break a}v[23220]=0;R(442,a|0,c+8|0);a=v[23220];v[23220]=0;d=b;if((a|0)!=1){break a}a=P()|0;O()|0;fg(c+8|0);S(a|0);L()}fg(c+8|0);fb=c+16|0;return d|0}function sT(a,b,c,d){var e=0,f=0,g=0;if(!b|!d){a=-1}else{e=a;f=e+b|0;d=c+d|0;while(1){a:{b=c;b:{if((e|0)!=(f|0)){while(1){if((b|0)==(d|0)){break b}g=t[b|0];b=b+1|0;if(!rc(t[e|0],g)){continue}break}b=e}else{b=f}break a}e=e+1|0;continue}break}a=(b|0)==(f|0)?-1:b-a|0}return a}function jU(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;v[d+12>>2]=b;c=fb-16|0;fb=c;v[c+12>>2]=153391689;v[c+8>>2]=2147483647;e=Eb(c+12|0,c+8|0);fb=c+16|0;c=b;b=v[e>>2];if(c>>>0<=b>>>0){a=qB(a);if(a>>>0<b>>>1>>>0){v[d+8>>2]=a<<1;b=v[Sc(d+8|0,d+12|0)>>2]}fb=d+16|0;return b}od();L()}function N9(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{d:{if(ve(a)){c=hl(a)-1|0;d=v[a+4>>2];if((c|0)==(d|0)){break d}break b}c=1;d=w[a+11|0];if((d|0)!=1){break c}}uF(a,c,1,c,c);d=c;if(ve(a)){break b}}ae(a,d+1|0);break a}c=v[a>>2];Bd(a,d+1|0);a=c}a=(d<<2)+a|0;td(a,b);td(a+4|0,0)}function vB(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function jC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;b=Hu(c,a,b);a=v[b+4>>2];d=v[b+8>>2];a:{while(1){if((a|0)==(d|0)){break a}v[23220]=0;Y(218,a|0);e=v[23220];v[23220]=0;if((e|0)!=1){a=a+20|0;v[b+4>>2]=a;continue}break}a=P()|0;O()|0;hc(b);S(a|0);L()}hc(b);fb=c+16|0}function OT(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;v[d+12>>2]=b;c=fb-16|0;fb=c;v[c+12>>2]=89478485;v[c+8>>2]=2147483647;e=Eb(c+12|0,c+8|0);fb=c+16|0;c=b;b=v[e>>2];if(c>>>0<=b>>>0){a=KT(a);if(a>>>0<b>>>1>>>0){v[d+8>>2]=a<<1;b=v[Sc(d+8|0,d+12|0)>>2]}fb=d+16|0;return b}od();L()}function NR(a,b){var c=0,d=0;a:{c=v[b>>2];d=v[b+20>>2];if(!Md(c,d)){break a}if(v[a+20>>2]==(d|0)){v[a+20>>2]=0;c=v[b>>2]}uc(a,c);c=x[a+34>>1]&-2|u[b+34>>1]&1;u[a+34>>1]=c;u[a+34>>1]=c&65471|x[b+34>>1]&64;if(!wg(a)){break a}nc(v[a+20>>2],v[b+20>>2],sj(v[a>>2],x[a+34>>1]))}}function GD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;g=v[b+8>>2];f=v[b>>2];Hg(e+16|0,c,d);c=v[v[f>>2]+28>>2];d=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=d;jb[c|0](e+24|0,f,g,e+8|0);Hg(a,v[e+24>>2],v[e+28>>2]);v[b+8>>2]=v[b+8>>2]+v[a+4>>2];fb=e+32|0}function xh(a){var b=0,c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;b=fb-16|0;fb=b;v[b+4>>2]=1;f=b,g=tc(16),v[f+8>>2]=g;c=Bo(v[b+8>>2]);v[c>>2]=42888;f=Em(vc(c)),g=43020,v[f>>2]=g;c=d+8|0;e=Do(b);Co(c,vc(e),e);Fm(b);fb=b+16|0;ng(a,c);be(c);fb=d+16|0;v[a+8>>2]=0;Xd(a+12|0);return a}function gn(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=Eia(a,b,10,0);f=ib;e=Bia(d,f,246,0)+a|0;c=c-1|0;t[c|0]=e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=B(a,246)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function e2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;qn(c,a);if(v[b>>2]){Bc(b);a=v[b>>2];Ct(b);Fb(a);d=Cb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=Cb(c);d=Cb(b),e=v[a>>2],v[d>>2]=e;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Tf(c);fb=c+16|0}function b$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=t[b|0];g=t[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function x1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;v[d+24>>2]=c;a:{while(1){if((a|0)==(b|0)){break a}c=Qb(d+8|0,v[a>>2]);v[23220]=0;Q(1048,d+24|0,c|0)|0;e=v[23220];v[23220]=0;if((e|0)!=1){ub(c);a=a+4|0;continue}break}a=P()|0;O()|0;ub(c);S(a|0);L()}fb=d+32|0}function de(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function k7(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;v[b+12>>2]=a;v[b+8>>2]=4104;a=0;d=v[b+8>>2];a:{if(d>>>0<4096){break a}c=v[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}v[b+12>>2]=e;v[b+8>>2]=d-c;a=e}if(!a){ca(6014,8985,88,7318);L()}fb=b+16|0;return a|0}function Wm(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(!b){b=0;break a}d=b;b=E(b);vf(c,d,0,0,0,b+81|0);e=16414-b<<16;b=0;d=b+v[c+8>>2]|0;e=e+(v[c+12>>2]^65536)|0;e=b>>>0>d>>>0?e+1|0:e;f=d;d=v[c>>2];b=v[c+4>>2]}v[a>>2]=d;v[a+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=e;fb=c+16|0}function TO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-16|0;fb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Ec(d);Xf(b,a,Bb(d)+a|0);break c}MO(e,c,d);v[23220]=0;U(41,a|0,b|0,e|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}Nc(e)}fb=e+16|0;break a}a=P()|0;O()|0;Nc(e);S(a|0);L()}}function pU(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;f=Hb(a,31),g=0,t[f|0]=g;t[b+15|0]=0;c=mi(a,Rn(a),b+15|0);t[b+14|0]=0;c=oi(a,c);Jl(c+a|0,Rn(a),b+14|0);while(1){if((c|0)!=(d|0)){e=Hb(a,d);if((w[e|0]-127&255)>>>0<=160){t[e|0]=32}d=d+1|0;continue}break}fb=b+16|0}function ts(a){var b=0,c=0,d=C(0);c=w[a+4232|0];if(c>>>0>=5){t[a+4232|0]=0;c=0}if(t[a+4233|0]<0){t[a+4233|0]=127}b=t[a+4234|0];if((b|0)<0){t[a+4234|0]=127;b=127}a:{if((c|0)==3){d=C(C(1)-ie(C(2),C(-C((b&255)+1|0))));break a}d=ie(C(2),C(-C((b&255)>>>0)))}z[a+4224>>2]=d}function lW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+12>>2]=c;v[d+8>>2]=b;b=fb-16|0;fb=b;v[b+4>>2]=1;e=b,f=tc(24),v[e+8>>2]=f;c=Bo(v[b+8>>2]);v[c>>2]=61300;CD(vc(c),v[d+8>>2],v[d+12>>2]);c=Do(b);Co(d,vc(c),c);Fm(b);fb=b+16|0;ng(a,d);be(d);fb=d+16|0}function bQ(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=Ab(v[a>>2]);v[c+8>>2]=b;e=Ab(v[a+4>>2]);while(1){a:{d=Nb(b,e);if(!d){break a}a=x[b>>1];b:{if(!((a|0)!=255&(a|0)!=99)){u[b>>1]=65535;break b}if(a>>>0>63){break a}}b=v[Oe(c+8|0)>>2];continue}break}fb=c+16|0;return d^1}function ID(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=fb-16|0;fb=d;b:{c:{if(!b){b=a;a=qd(c);Xf(b,a,xd(v[c+4>>2],w[c+11|0])+a|0);break c}IM(d,c);v[23220]=0;U(41,a|0,b|0,d|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}Nc(d)}fb=d+16|0;break a}a=P()|0;O()|0;Nc(d);S(a|0);L()}}function th(a,b){var c=0,d=0,e=0;a:{if(!(b?1:t[a+480180|0]&1)){break a}e=v[a+24616>>2]&524288;b=0;while(1){if((b|0)==127){break a}c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;continue}}}function tE(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;v[e+12>>2]=c;c=e+12|0;uc(c,d);uc(c,65535);f=x[e+12>>1];gg(a,f);c=0;while(1){if((c|0)==(f|0)){fb=e+16|0}else{d=w[b+c|0];g=el(v[a>>2],v[a+4>>2],c),h=(d|0)==255?-1:(d|0)==254?-2:d,u[g>>1]=h;c=c+1|0;continue}break}}function raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;f=bf(a,c);Yd(e,v[a+28>>2]);a:{b:{if(!f){c=-1;if(!cd(a,5)){break b}break a}c=v[f+8>>2]}d=v[a+28>>2];c:{d:{switch(c+1|0){case 0:case 2:ci(d,b);break c;default:break d}}FS(d,b,c)}d=f}We(a,d);fb=e+16|0}function qj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Ab(v[b>>2]);f=Ab(v[b+4>>2]);e=fb-16|0;fb=e;v[e+8>>2]=d;while(1){a:{if(!Nb(d,f)){break a}if(RT(c,v[d>>2],v[d+4>>2])){break a}d=v[jm(e+8|0)>>2];continue}break}fb=e+16|0;if(rc(d,Ab(v[b+4>>2]))){xh(a);return}ko(a,d)}function qia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-624|0;fb=b;e=-1;c=fb-16|0;fb=c;f=b+8|0;fU(c+8|0,f);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(g|0);if(!a){eU(f)}if(a){e=gU(b+8|0)}fb=b+624|0;return e|0}function n$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=Jf(t[b|0]),e=v[v[a>>2]+52>>2],jb[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=dk(b,1,c,v[a+32>>2])}return c|0}function kz(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;b=yz(d,a,b);a=v[b+4>>2];e=v[b+8>>2];a:{while(1){if((a|0)==(e|0)){break a}v[23220]=0;R(723,a|0,c|0);f=v[23220];v[23220]=0;if((f|0)!=1){a=a+32|0;v[b+4>>2]=a;continue}break}a=P()|0;O()|0;hc(b);S(a|0);L()}hc(b);fb=d+16|0}function Xda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-160|0;fb=b;e=-1;c=fb-16|0;fb=c;f=b+8|0;xQ(c+8|0,f);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(g|0);if(!a){wQ(f)}if(a){e=yQ(b+8|0)}fb=b+160|0;return e|0}function VT(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[$e(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){t[d+13|0]=1;t[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=w[$e(d+13|0,d+12|0)|0]}fb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function RC(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;Xc(d,a);v[23220]=0;a=T(18,d|0)|0;d=v[23220];v[23220]=0;a:{if((d|0)==1){break a}v[23220]=0;a=Q(19,a|0,b|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break a}Wb(c+8|0);fb=c+16|0;return a}a=P()|0;O()|0;Wb(c+8|0);S(a|0);L()}function Qo(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function LC(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=v[a+4>>2];f=e+b|0;v[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=v[a>>2];break a}a=v[a>>2];v[a+((f>>>0<33?0:g>>>5|0)<<2)>>2]=0}uo(d+8|0,a,e);Vu(v[d+8>>2],v[d+12>>2],b,c);fb=d+16|0}function c7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;v[a+4>>2]=b;v[a>>2]=0;b=dt(a+8|0,d);v[23220]=0;Q(886,a+20|0,c|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&224|25;return a|0}a=P()|0;O()|0;Pb(b);S(a|0);L()}function lga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;e=-1;c=fb-16|0;fb=c;f=b+8|0;qu(c+8|0,f);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(g|0);if(!a){kS(f)}if(a){e=lS(b+8|0)}fb=b+16|0;return e|0}function aJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Gb(a);d=Cf(b);e=Bb(c);v[23220]=0;X(1034,a|0,b|0,d|0,d+e|0);b=v[23220];v[23220]=0;a:{if((b|0)!=1){b=Ec(c);v[23220]=0;W(1035,a|0,b|0,e|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;ub(a);S(b|0);L()}}function Mha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-32|0;fb=b;e=-1;c=fb-16|0;fb=c;f=b+8|0;Zt(c+8|0,f);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);g=v[c+4>>2];if((g|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(g|0);if(!a){uT(f)}if(a){e=vT(b+8|0)}fb=b+32|0;return e|0}function MA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=fb-16|0;fb=f;d=co(a);e=xd(v[a+4>>2],w[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=qd(a);Fe(d+e|0,b,c);b=c+e|0;Yp(a,b);t[f+15|0]=0;bd(b+d|0,f+15|0);break a}Tt(a,d,(c+e|0)-d|0,e,e,0,c,b)}fb=f+16|0;return a|0}function G$(a){a=a|0;var b=0,c=0,d=0;c=v[a+44>>2];b=v[a+24>>2];if(c>>>0<b>>>0){v[a+44>>2]=b;c=b}d=-1;a:{if(!(w[a+48|0]&8)){break a}b=v[a+16>>2];if(b>>>0<c>>>0){an(a,v[a+8>>2],v[a+12>>2],c);b=v[a+16>>2]}a=v[a+12>>2];if(a>>>0>=b>>>0){break a}d=Jf(t[a|0])}return d|0}function Br(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=v[b+76>>2]>=0;b:{c=v[b+4>>2];c:{if(!c){Ew(b);c=v[b+4>>2];if(!c){break c}}if(v[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;d=a&255}return d}function lE(a,b,c,d){var e=0,f=0;a:{e=fb+-64|0;fb=e;f=e+40|0;Af(f,a,d);a=v[e+40>>2];d=e+8|0;Pf(d,c,te(f),a);v[23220]=0;R(209,e+24|0,d|0);a=v[23220];v[23220]=0;if((a|0)!=1){a=e+24|0;ue(b,a);ub(a);Jc(e+40|0);fb=e- -64|0;break a}a=P()|0;O()|0;Jc(e+40|0);S(a|0);L()}}function $5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=ji(a,b,c,d);v[a>>2]=46628;b=a+4208|0;e=zb(b,0),f=1017370378,v[e>>2]=f;e=zb(b,1),f=0,v[e>>2]=f;v[23220]=0;R(870,a+44|0,2);b=v[23220];v[23220]=0;if((b|0)!=1){ii(a);return a|0}b=P()|0;O()|0;sf(a);S(b|0);L()}function r1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=fb-16|0;fb=c;v[c+4>>2]=1;e=c,f=tc(52),v[e+8>>2]=f;d=v[c+8>>2];v[23220]=0;Q(1055,d|0,b|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){b=a;a=Do(c);Co(b,vc(a),a);Fm(c);fb=c+16|0;break a}a=P()|0;O()|0;Fm(c);S(a|0);L()}}function qU(a,b,c){var d=0,e=0;d=fb+-64|0;fb=d;Lf(b);e=d+40|0;Af(e,a,c);a=v[d+40>>2];c=d+8|0;Pf(c,2,te(e),a);v[23220]=0;R(209,d+24|0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){a=d+24|0;xc(b,a);ub(a);Jc(d+40|0);fb=d- -64|0;return}a=P()|0;O()|0;Jc(d+40|0);S(a|0);L()}function paa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;t[c+40|0]=b;b=c+40|0;Fq(c+16|0,b);d=v[c+16>>2];Fq(c+8|0,b);b=Xf(c+24|0,d,v[c+8>>2]+1|0);v[23220]=0;Q(726,a|0,b|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){ub(b);fb=c+48|0;return}a=P()|0;O()|0;ub(b);S(a|0);L()}function l8(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;u[c+40>>1]=b;b=c+40|0;kl(c+16|0,b);d=v[c+16>>2];kl(c+8|0,b);b=Xf(c+24|0,d,v[c+8>>2]+2|0);v[23220]=0;Q(726,a|0,b|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){ub(b);fb=c+48|0;return}a=P()|0;O()|0;ub(b);S(a|0);L()}function dG(a,b,c){var d=0,e=0,f=0,g=0;d=a;a:{e=ne(b,c);if(e>>>0<1073741808){b:{if(e>>>0<=1){ae(d,e);break b}f=xl(e)+1|0;g=pi(f);td(d,g);yf(d,f);Bd(d,e);d=g}while(1){if((b|0)!=(c|0)){td(d,v[b>>2]);d=d+4|0;b=b+4|0;continue}break}td(d,0);break a}kf();L()}return a}function WS(a){var b=0,c=0,d=0,e=0;d=w[a+32|0]|w[a+33|0]<<8;e=w[a+38|0]|w[a+39|0]<<8;c=w[a+34|0]|w[a+35|0]<<8;b=c+(w[a+36|0]|w[a+37|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;ib=a;return b}function zj(a,b){var c=0,d=0,e=0,f=0,g=0;g=v[a+8>>2];while(1){if((b|0)!=(e|0)){d=v[a>>2];if(d){c=v[a+4>>2]}else{v[a>>2]=8;c=g;d=v[a+12>>2];if((c|0)!=(d|0)){c=d-1|0;v[a+12>>2]=c}d=8;c=w[c|0]}v[a>>2]=d-1;v[a+4>>2]=c>>>1;f=c&1|f<<1;e=e+1|0;continue}break}return f}function Vca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;v[c+12>>2]=4925421;v[c+8>>2]=2147483647;d=Eb(c+12|0,c+8|0);fb=c+16|0;if(y[d>>2]<b>>>0){od();L()}if(b>>>0>=4925422){xf(11129);L()}c=B(b,872);b=tc(c);v[a>>2]=b;v[a+4>>2]=b;e=Cb(a),f=b+c|0,v[e>>2]=f}function Dk(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=Ur(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function Z0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Ib(a);a:{if(!c){break a}v[23220]=0;R(1056,a|0,c|0);d=v[23220];v[23220]=0;if((d|0)!=1){v[23220]=0;X(1057,a|0,b|0,Dd(b,c)|0,c|0);b=v[23220];v[23220]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;De(a);S(b|0);L()}return a|0}function Tb(){var a=0;a=v[23217];v[23220]=0;Z(a|0);a=v[23220];v[23220]=0;a:{if((a|0)!=1){v[23220]=0;Z(1179);a=v[23220];v[23220]=0;if((a|0)!=1){break a}}a=V(0)|0;O()|0;_(a|0)|0;v[23220]=0;Z(1179);a=v[23220];v[23220]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Tb()}L()}function Ge(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=fb-16|0;fb=e;a:{if(b>>>0<4294967280){b:{if(b>>>0<=10){ae(d,b);break b}f=Qh(b)+1|0;g=tc(f);td(d,g);yf(d,f);Bd(d,b);d=g}c=lq(d,b,c);t[e+15|0]=0;bd(b+c|0,e+15|0);fb=e+16|0;break a}kf();L()}return a|0}function tM(a,b,c,d){var e=0,f=0,g=0;t[c+851|0]=w[c+851|0]|64;e=a?w[c+813|0]:0;g=(d|0)<0?e:0-e|0;f=(+(a>>>0)+1)*+(d|0)/+(b>>>0);a:{if(D(f)<2147483648){e=~~f;break a}e=-2147483648}v[c+852>>2]=g+(e+v[c+852>>2]|0);b=(a+1|0)==(b|0)?d:e;a=b>>31;t[c+813|0]=(a^b)-a}function Xy(a,b,c,d){var e=0,f=0,g=0;e=Od(a);a:{if(e){f=fc(a);while(1){a=e;e=x[a+16>>1];g=v[a+20>>2];if(Sk(c,d,e,g)){f=a;e=v[a>>2];if(e){continue}break a}if(!Sk(e,g,c,d)){break a}f=a+4|0;e=v[a+4>>2];if(e){continue}break}break a}a=fc(a);f=a}v[b>>2]=a;return f}function VO(a,b){var c=0,d=0;v[a+4>>2]=b;v[a>>2]=92888;v[a+20>>2]=0;v[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;v[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;v[a+8>>2]=d;v[a+32>>2]=d>>>0<31?-1>>>31-d|0:-1;v[a+28>>2]=b>>>0<c>>>0?0:-1>>>32-d|0;v[a+16>>2]=(B(c,d)-b|0)+c;return a}function J7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0),f=0,g=C(0);d=fb-16|0;fb=d;f=d,g=C(C(jb[v[v[a>>2]+48>>2]](a,b))+c),z[f+12>>2]=g;c=C(0);e=z[d+12>>2];a:{if(!(e<C(0))){c=C(1);if(!(e>C(1))){break a}}z[d+12>>2]=c}jb[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);fb=d+16|0}function xy(a,b,c,d){var e=0,f=0,g=0;e=Od(a);a:{if(e){f=fc(a);while(1){a=e;e=w[a+16|0];g=v[a+20>>2];if(An(c,d,e,g)){f=a;e=v[a>>2];if(e){continue}break a}if(!An(e,g,c,d)){break a}f=a+4|0;e=v[a+4>>2];if(e){continue}break}break a}a=fc(a);f=a}v[b>>2]=a;return f}function jW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;f=v[b+8>>2];a:{if(f>>>0<=c>>>0){c=v[d>>2];b=0;break a}v[e+12>>2]=f-c;v[e+8>>2]=v[d+4>>2];c=v[b+4>>2]+c|0;f=c;b=v[Eb(e+12|0,e+8|0)>>2];g=c+b|0;c=v[d>>2];Gi(f,g,c)}ec(a,c,b);fb=e+16|0}function Gk(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;v[e+8>>2]=c;while(1){a:{if((a|0)!=(b|0)){c=fb-16|0;fb=c;d=oc(c+8|0,v[a>>2]);f=v[d>>2];g=v[d+4>>2];d=v[e+8>>2];d=Hc(f,g,v[d>>2],v[d+4>>2]);fb=c+16|0;if(!d){break a}b=a}fb=e+16|0;return b}a=a+8|0;continue}}function pga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;Lf(b);t[c+15|0]=0;a:{if(!Hh(a,c+15|0)){break a}f=w[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}t[c+14|0]=0;if(Hh(a,c+14|0)){Ap(b,t[c+14|0]);e=e+1|0;continue}break}d=0}fb=c+16|0;return d|0}function __(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function WB(a,b,c){var d=0,e=0;d=fb+-64|0;fb=d;e=d+40|0;Af(e,a,c);a=v[d+40>>2];c=d+8|0;Pf(c,3,te(e),a);v[23220]=0;R(209,d+24|0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){a=d+24|0;mm(b,a);ub(a);Jc(d+40|0);fb=d- -64|0;return}a=P()|0;O()|0;Jc(d+40|0);S(a|0);L()}function b_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;v[g+8>>2]=b;Xc(g,d);v[23220]=0;b=T(1104,g|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){Wb(g);IF(a,f+24|0,g+8|0,c,e,b);fb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function a_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;v[g+8>>2]=b;Xc(g,d);v[23220]=0;b=T(1104,g|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){Wb(g);HF(a,f+16|0,g+8|0,c,e,b);fb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function Ew(a){var b=0,c=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;if(v[a+20>>2]!=v[a+28>>2]){jb[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function rea(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;a:{if(!Lb(v[b>>2],v[b+8>>2],8)){u[c>>1]=0;b=4;while(1){if(b){d=w[c|0]|w[c+1|0]<<8;t[a|0]=d;t[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}break a}Bm(c+8|0,a);md(c,b,v[c+8>>2],v[c+12>>2])}fb=c+16|0}function h_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;v[g+8>>2]=b;Xc(g,d);v[23220]=0;b=T(18,g|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){Wb(g);LF(a,f+24|0,g+8|0,c,e,b);fb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function g_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;v[g+8>>2]=b;Xc(g,d);v[23220]=0;b=T(18,g|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){Wb(g);KF(a,f+16|0,g+8|0,c,e,b);fb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function Y6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b:{e=v[a+20>>2];c=v[e+4>>2];if((Wc(c,v[e+8>>2])|0)!=7){break b}if(Mb(c,9527,4)){break b}b=Ab(c);c=Ab(v[v[a+20>>2]+8>>2]);no(d+8|0,a+4228|0);Yg(b,c,v[d+8>>2]);break a}Ex(a,b)}ts(a);fb=d+16|0}function XT(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}t[d+15|0]=1;t[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=w[$e(d+15|0,d+14|0)|0]}a=e;fb=d+16|0;return a&255}function tA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ZR(a,b);Vc(a,_b(w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))+504|0);YR(a,d);a:{b=_b(w[b+32|0]|w[b+33|0]<<8|(w[b+34|0]<<16|w[b+35|0]<<24));if(!b){break a}if(!Vc(a,b)){break a}vA(a,c);return}Sb(c,0,80)}function S1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[b+8>>2];e=v[b+4>>2];f=v[b>>2];a=0;a:while(1){b:{b=0;if((a|0)==(e|0)){break b}while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{c=v[(a<<2)+f>>2]+(b<<3)|0;v[c>>2]=0;v[c+4>>2]=0;b=b+1|0;continue}}break}}function w9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{b:{if((b|0)!=437){if((b|0)==1252){break b}d=0;if((b|0)==65001){break a}c:{if((b|0)!=28591){if((b|0)==28605){break c}if((b|0)!=20127){break b}d=1;break a}d=2;break a}d=3;break a}d=5;break a}d=8}_C(a,d,c)}function sha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=fb-160|0;fb=b;e=-1;c=fb-16|0;fb=c;eT(c+8|0,b);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);f=v[c+4>>2];if((f|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(f|0);if(!a){dT(b)}if(a){e=fT(b)}fb=b+160|0;return e|0}function d1(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;if(!w[a+8|0]){Ji(a+12|0,v[a+4>>2]);ge(b+24|0,v[a+12>>2],v[a+16>>2]);c=v[v[a>>2]+40>>2];d=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=d;jb[c|0](b+16|0,a,0,b+8|0);t[a+8|0]=1}fb=b+32|0;return v[a+12>>2]}function aA(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-1024|0;fb=e;d=fb-16|0;fb=d;Yz(d+8|0,e);f=v[d+12>>2];jc(d,v[a>>2],v[a+8>>2],v[d+8>>2],f);g=v[d+4>>2];if((g|0)==(f|0)){Yb(a,v[d+12>>2])}fb=d+16|0;if((f|0)==(g|0)){h=Zz(e,c)>>>0<=b>>>0}fb=e+1024|0;return h}function Ov(a,b,c,d,e,f){var g=0;g=fb-16|0;fb=g;v[g+12>>2]=e;v[g+8>>2]=d;d=ng(g,g+8|0);e=v[d+4>>2];d=v[d>>2];v[23220]=0;a=ga(f|0,a|0,b|0,c|0,d|0,e|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){be(g+8|0);fb=g+16|0;return a}a=P()|0;O()|0;be(g+8|0);S(a|0);L()}function Fda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=fb-208|0;fb=b;e=-1;c=fb-16|0;fb=c;YP(c+8|0,b);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);f=v[c+4>>2];if((f|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(f|0);if(!a){XP(b)}if(a){e=ZP(b)}fb=b+208|0;return e|0}function MF(a,b,c){var d=0,e=0,f=0;d=a;a:{if(b>>>0<1073741808){b:{if(b>>>0<=1){ae(d,1);break b}e=xl(b)+1|0;f=pi(e);td(d,f);yf(d,e);Bd(d,b);d=f}e=b;f=d;while(1){v[f>>2]=c;f=f+4|0;e=e-1|0;if(e){continue}break}td((b<<2)+d|0,0);break a}kf();L()}return a}function bF(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;v[b>>2]=0;t[c+15|0]=0;Hh(a,c+15|0);d=w[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){v[b>>2]=e;if((d|0)==(f|0)){fb=c+16|0}else{t[c+15|0]=0;Hh(a,c+15|0);d=d+1|0;e=v[b>>2]|w[c+15|0]<<(d<<3)-2;continue}break}}function pV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=fb-48|0;fb=b;e=-1;c=fb-16|0;fb=c;pC(c+8|0,b);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);f=v[c+4>>2];if((f|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(f|0);if(!a){oC(b)}if(a){e=qC(b)}fb=b+48|0;return e|0}function _C(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=fb-16|0;fb=d;b:{c:{if(!b){b=a;a=Ec(c);Xf(b,a,Bb(c)+a|0);break c}MO(d,b,c);v[23220]=0;R(47,a|0,d|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}Nc(d)}fb=d+16|0;break a}a=P()|0;O()|0;Nc(d);S(a|0);L()}}function ZP(a){var b=0;a:{if(Mb(a,14972,4)){break a}if(Jb(w[a+4|0]|w[a+5|0]<<8)>>>0>2|w[a+6|0]>128){break a}if(Jb(w[a+200|0]|w[a+201|0]<<8)>>>0>3999){break a}if(!Jb(w[a+140|0]|w[a+141|0]<<8)){break a}b=(Jb(w[a+148|0]|w[a+149|0]<<8)|0)==50}return b}function mr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=fb-16|0;fb=f;d=Qc(a);e=Bb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=pc(a);Fe(d+e|0,b,c);b=c+e|0;hh(a,b);t[f+15|0]=0;bd(b+d|0,f+15|0);break a}Ro(a,d,(c+e|0)-d|0,e,e,0,c,b)}fb=f+16|0;return a|0}function iH(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=iH(a*0x10000000000000000,b);c=v[b>>2]+-64|0}v[b>>2]=c;return a}v[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function xia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+16|0;nq(e,c);Ui(d+8|0,e);v[23220]=0;X(285,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23220];v[23220]=0;if((a|0)!=1){Pb(d+16|0);fb=d+32|0;break a}a=P()|0;O()|0;Pb(d+16|0);S(a|0);L()}}function Tga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+16|0;CA(e,c);Ui(d+8|0,e);v[23220]=0;X(101,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23220];v[23220]=0;if((a|0)!=1){bc(d+16|0);fb=d+32|0;break a}a=P()|0;O()|0;bc(d+16|0);S(a|0);L()}}function TD(a,b,c,d){var e=0,f=0,g=0;a:{if((c|0)==(d|0)){break a}b:{d=d-c|0;if((d|0)>(b-a|0)){break b}f=1-d|0;g=w[c|0];while(1){e=b-a|0;if((d|0)>(e|0)){break b}a=Wp(a,f+e|0,g);if(!a){break b}if(!Ml(a,c,d)){break a}a=a+1|0;continue}}a=b}return a}function Pga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+16|0;Io(e,c);Ui(d+8|0,e);v[23220]=0;X(101,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23220];v[23220]=0;if((a|0)!=1){bc(d+16|0);fb=d+32|0;break a}a=P()|0;O()|0;bc(d+16|0);S(a|0);L()}}function Nr(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=aa(16)|0;aF();a=cc(c+8|0,a,92864);c=v[a+4>>2];a=v[a>>2];v[23220]=0;a=fa(1068,d|0,a|0,c|0,b|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){ia(a|0,90832,1069);L()}a=P()|0;O()|0;ba(d|0);S(a|0);L()}function Kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+16|0;hp(e,c);Ui(d+8|0,e);v[23220]=0;X(285,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23220];v[23220]=0;if((a|0)!=1){Pb(d+16|0);fb=d+32|0;break a}a=P()|0;O()|0;Pb(d+16|0);S(a|0);L()}}function GA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Ib(a+8|0);v[23220]=0;d=T(189,b|0)|0;e=v[23220];v[23220]=0;b:{if((e|0)==1){break b}v[23220]=0;U(234,a|0,b|0,d|0);a=v[23220];v[23220]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;$b(c);S(a|0);L()}}function CO(a,b,c){var d=0,e=0,f=0,g=0;f=v[b+4>>2];e=b+4|0;Ip(v[a>>2],c,e);g=v[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){Ai(v[d>>2],x[c>>1]);v[d>>2]=v[d>>2]+2;c=c+2|0;continue}break}kc(a,e);kc(a+4|0,d);kc(Cb(a),vc(b));v[b>>2]=v[b+4>>2];return f}function $Z(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=fb-16|0;fb=a;v[a+8>>2]=b;Xc(a,d);v[23220]=0;b=T(1104,a|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){Wb(a);GF(f+20|0,a+8|0,c,e,b);fb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Wb(a);S(b|0);L()}function xT(a,b,c){var d=0,e=0,f=0,g=0;f=v[b+4>>2];e=b+4|0;Ip(v[a>>2],c,e);g=v[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){Hj(v[d>>2],w[c|0]);v[d>>2]=v[d>>2]+1;c=c+1|0;continue}break}kc(a,e);kc(a+4|0,d);kc(Cb(a),vc(b));v[b>>2]=v[b+4>>2];return f}function v8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;f=bf(a,c);Yd(e,v[a+28>>2]);a:{b:{if(!f){c=-1;if(!cd(a,5)){break b}break a}c=v[f+8>>2]}d=v[a+28>>2];c:{if(!((c|0)!=4&(c|0)!=-1)){_j(d,b);break c}cH(d,b,c)}d=f}We(a,d);fb=e+16|0}function ql(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Cf(b);e=fb-16|0;fb=e;d=co(a);a:{if(d>>>0>=c>>>0){b=pj(qd(a),b,c);t[e+15|0]=0;bd(b+c|0,e+15|0);Yp(a,c);break a}f=d;g=c-d|0;d=xd(v[a+4>>2],w[a+11|0]);Tt(a,f,g,d,0,d,c,b)}fb=e+16|0;return a|0}function nV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+16|0;Eu(e,c);Ui(d+8|0,e);v[23220]=0;X(101,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23220];v[23220]=0;if((a|0)!=1){bc(d+16|0);fb=d+32|0;break a}a=P()|0;O()|0;bc(d+16|0);S(a|0);L()}}function OD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+16|0;Mm(e,c);Ui(d+8|0,e);v[23220]=0;X(101,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23220];v[23220]=0;if((a|0)!=1){bc(d+16|0);fb=d+32|0;break a}a=P()|0;O()|0;bc(d+16|0);S(a|0);L()}}function $T(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+16|0;HB(e,c);Ui(d+8|0,e);v[23220]=0;X(101,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23220];v[23220]=0;if((a|0)!=1){bc(d+16|0);fb=d+32|0;break a}a=P()|0;O()|0;bc(d+16|0);S(a|0);L()}}function nD(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function f_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=fb-16|0;fb=a;v[a+8>>2]=b;Xc(a,d);v[23220]=0;b=T(18,a|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){Wb(a);JF(f+20|0,a+8|0,c,e,b);fb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Wb(a);S(b|0);L()}function Po(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function PB(a){var b=0,c=0,d=0,e=0;b=w[a+2|0];c=b+(w[a+5|0]|w[a+6|0]<<8)|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;a=w[a+3|0]|w[a+4|0]<<8;d=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;a=b>>>0<47?a+1|0:a;ib=a;return b}function $N(a){var b=0,c=0,d=0,e=0,f=0;b=fb-16|0;fb=b;c=a;d=v[a>>2];f=bh(d,v[a+4>>2]);a=Ab(d);v[b+8>>2]=a;e=+(f>>>0);c=Ab(v[c+4>>2]);while(1){if(Nb(a,c)){A[a>>3]=A[a>>3]/e;A[a+8>>3]=A[a+8>>3]/e;a=v[Un(b+8|0)>>2];continue}else{fb=b+16|0}break}}function md(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;g=v[b+8>>2];f=v[b>>2];v[e+12>>2]=d;v[e+8>>2]=c;c=v[v[f>>2]+28>>2];d=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=d;jb[c|0](a,f,g,e);v[b+8>>2]=v[b+8>>2]+v[a+4>>2];fb=e+16|0}function $z(a,b,c){var d=0;d=fb-16|0;fb=d;u[d+12>>1]=c;u[d+14>>1]=b;b=Ab(v[a>>2]);c=Ab(v[a+4>>2]);a=fb-16|0;fb=a;v[a+8>>2]=b;while(1){if(Nb(b,c)){if(x[b>>1]==x[d+14>>1]){u[b>>1]=x[d+12>>1]}b=v[Oe(a+8|0)>>2];continue}break}fb=a+16|0;fb=d+16|0}function kN(a,b){var c=0,d=0;d=fb-16|0;fb=d;c=v[a+104>>2];a:{if(!c){break a}c=v[c>>2];if(!c){break a}v[a+76>>2]=c;v[a+88>>2]=v[a+88>>2]&-131|128;v[d+12>>2]=b<<8;v[d+8>>2]=c-1;b=c+(v[Eb(d+12|0,d+8|0)>>2]^-1)|0;v[a>>2]=0;v[a+4>>2]=b}fb=d+16|0}function jH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;if(d>>>0<4294967280){a:{if(d>>>0<=10){ae(a,c);break a}f=Qh(d)+1|0;d=tc(f);td(a,d);yf(a,f);Bd(a,c);a=d}a=Fe(a,b,c);t[e+15|0]=0;bd(a+c|0,e+15|0);fb=e+16|0;return}kf();L()}function iK(a,b,c){var d=0,e=0;if(C(D(a))<C(0x8000000000000000)){d=~~a>>>0}else{d=0}e=d&-2147483648;d=e?0-d|0:d;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return C((e?b^-1|e:b)|0)}function XC(a){var b=0,c=0;a:{if(Mb(a,14153,4)){break a}if(Mb(a+8|0,14074,4)){break a}b=_b(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24));if(!b){break a}c=(_b(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24))|0)!=0&b>>>0>27}return c}function qM(a,b){a=nM(a);nM(a+368680|0);if(b){mM(a,1);return}if(!w[461752]){qM(93048,1);t[461752]=1}Ln(224160,289696,a+131112|0);Ln(289696,355232,a+196648|0);Ln(355232,420768,a+262184|0);Ln(93072,224160,a+24|0);nc(a+327720|0,420768,40960)}function mE(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;v[e+12>>2]=c;c=e+12|0;uc(c,d);uc(c,65535);d=x[e+12>>1];gg(a,d);c=0;while(1){if((c|0)==(d|0)){fb=e+16|0}else{f=w[b+c|0];g=el(v[a>>2],v[a+4>>2],c),h=f,u[g>>1]=h;c=c+1|0;continue}break}}function k2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-32|0;fb=d;Jk(d,c);c=d+16|0;v[c>>2]=b;Mc(c+4|0,d);v[23220]=0;R(1028,a+4|0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){gs(d+16|0);ub(d);fb=d+32|0;return}a=P()|0;O()|0;gs(d+16|0);ub(d);S(a|0);L()}function gha(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;t[b+30|0]=0;u[b+28>>1]=0;c=cc(b+8|0,b+28|0,3);jc(b+16|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=3){break a}if(Mb(b+28|0,14725,3)){break a}Yb(a,3);d=1}fb=b+32|0;return d|0}function eQ(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if((b|0)!=26&(b|0)!=2|w[a+30|0]!=2){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=cQ(a+20|0)}return c}function _ca(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;u[b+28>>1]=0;v[b+24>>2]=0;c=cc(b+8|0,b+24|0,6);jc(b+16|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=6){break a}if(Mb(b+24|0,3856,6)){break a}Yb(a,6);d=1}fb=b+32|0;return d|0}function Af(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ib(a+8|0);v[23220]=0;U(234,a|0,b|0,c|0);c=v[23220];v[23220]=0;a:{if((c|0)!=1){a=v[a>>2];v[23220]=0;Q(175,b|0,a|0)|0;a=v[23220];v[23220]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;$b(d);S(a|0);L()}}function AN(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+3|0]|w[b+4|0]<<8|(w[b+5|0]<<16|w[b+6|0]<<24);t[a+3|0]=b;t[a+4|0]=b>>>8;t[a+5|0]=b>>>16;t[a+6|0]=b>>>24}function $d(a,b){var c=0,d=0;c=v[a+4>>2];d=c+b|0;v[a+4>>2]=d;if(v[a+8>>2]>=(d|0)){d=v[a>>2]+(c>>3)|0;a=c&7;c=w[d|0]&255>>>a;a=a+b|0;b=0;while(1){if((a|0)>=9){a=a-8|0;b=c<<a|b;c=w[d+1|0];d=d+1|0;continue}break}a=c>>>8-a|b}else{a=0}return a}function _ha(a,b){a=a|0;b=b|0;var c=0;b=fb-32|0;fb=b;c=-1;a:{if(!gB(a,b+16|0)){break a}c=0;if(!HT(b+16|0)){break a}if(!Mb(b+16|0,14139,4)){c=-1;if(!Zc(a,4)){break a}}c=-1;if(!yj(a,b+8|0)){break a}c=!Mb(b+8|0,14115,4)}fb=b+32|0;return c|0}function Sv(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;u[b>>1]=0;t[c+15|0]=0;Hh(a,c+15|0);d=w[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){u[b>>1]=e;if(d>>>0>=f>>>0){fb=c+16|0}else{t[c+15|0]=0;Hh(a,c+15|0);e=x[b>>1]|w[c+15|0]<<7;d=1;continue}break}}function tfa(a,b){a=a|0;b=b|0;var c=0;a=Ib(a);a:{if(!b){break a}v[23220]=0;R(534,a|0,b|0);c=v[23220];v[23220]=0;if((c|0)!=1){v[23220]=0;R(535,a|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;fA(a);S(b|0);L()}return a|0}function UM(a,b){var c=0,d=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}c=v[c>>2];b:{if(c){d=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[d+696>>2]=a;a=(B(a,v[b>>2])|0)/65536|0;break b}if(v[a+696>>2]){break a}a=0}v[b>>2]=a}}function kV(a,b){a=a|0;b=b|0;var c=0;a=Ib(a);a:{if(!b){break a}v[23220]=0;R(216,a|0,b|0);c=v[23220];v[23220]=0;if((c|0)!=1){v[23220]=0;R(217,a|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;fd(a);S(b|0);L()}return a|0}function jN(a,b){var c=0,d=0;a:{if(!(t[a+851|0]&1)){break a}c=v[a+104>>2];if(!c){break a}d=v[c>>2];if(!d){break a}v[a+76>>2]=d;v[a>>2]=0;v[a+4>>2]=d-1;c=v[a+88>>2];v[a+88>>2]=b?c|134:c&-135|128;if(!b){break a}v[a+84>>2]=d;v[a+80>>2]=0}}function ai(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;e=v[a+4>>2];d=v[a+44>>2]-e|0;v[a+120>>2]=d;v[a+124>>2]=d>>31;d=a;a=v[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}v[d+104>>2]=a}function vga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;while(1){a:{d=v[a>>2];if(sc(d,v[a+4>>2])>>>0>e>>>0){Km(c,v[zb(d,e)>>2]+40|0);d=Tp(c,b);vb(c);if(!d){break a}f=v[zb(v[a>>2],e)>>2]}fb=c+16|0;return f|0}e=e+1|0;continue}}function eN(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=c&15;if(e){t[b+824|0]=e}c=c&240;if(c){t[b+823|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;xb(d+8|0,a+1074312|0,80);if(!(!e|!yb(v[v[d+8>>2]>>2],v[d+12>>2]))){t[b+824|0]=w[b+824|0]<<2}fb=d+16|0}function U1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=v[b+8>>2];d=v[b+4>>2];e=v[b>>2];a=0;a:while(1){b:{b=0;if((a|0)==(d|0)){break b}while(1)if((b|0)==(c|0)){a=a+1|0;continue a}else{f=Np(e,a,b),g=0,v[f>>2]=g;b=b+1|0;continue}}break}}function U6(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(v[b+4>>2]!=8){break a}b=v[b>>2];if(Mb(b,9527,4)){break a}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4228>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4232>>2]=c;ts(a)}}function Pi(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function D7(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(v[b+4>>2]!=8){break a}b=v[b>>2];if(Mb(b,9527,4)){break a}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4264>>2]=c;ws(a)}}function wP(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,872);a=v[c+4>>2];b=v[c+8>>2];while(1){if((a|0)==(b|0)){hc(c);fb=c+16|0}else{vP(Sb(a,0,872));a=a+872|0;v[c+4>>2]=a;continue}break}}function q$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((jb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=dk(b,4,c,v[a+32>>2])}return c|0}function Rca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;e=lf(v[b>>2],v[b+4>>2]);c=oP(d+8|0,c);v[23220]=0;X(695,a|0,b|0,e-1&65535,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){Ie(c);fb=d+32|0;return}a=P()|0;O()|0;Ie(c);S(a|0);L()}function HG(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;f=dc(e+8|0,v[v[b>>2]-12>>2]+b|0),g=b,v[f+4>>2]=g;Bk(v[e+12>>2],c,d);b=fb-16|0;fb=b;v[b+12>>2]=v[v[e+12>>2]+4>>2];v[b+8>>2]=0;d=v[Ke(b+8|0,b+12|0)>>2];fb=b+16|0;ec(a,c,d);fb=e+16|0}function yy(a,b,c){var d=0,e=0;d=Od(a);a:{if(d){e=fc(a);while(1){a=d;d=w[a+16|0];if(Bn(c,d)){e=a;d=v[a>>2];if(d){continue}break a}if(!Bn(d,c)){break a}e=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=fc(a);e=a}v[b>>2]=a;return e}function Cz(a,b){var c=0,d=0,e=0,f=0;u[a+24>>1]=0;v[a+20>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(D(d)<2147483648){b=~~d;break a}b=-2147483648}v[a+16>>2]=b;v[a>>2]=0;v[a+4>>2]=0;e=a,f=GP(c-+(b<<2)),v[e+8>>2]=f;v[a+12>>2]=ib;return a}function q8(a,b){a=a|0;b=b|0;var c=0,d=0;a=Ib(a);a:{b:{c=sc(v[b>>2],v[b+4>>2]);if(c){v[23220]=0;R(215,a|0,c|0);d=v[23220];v[23220]=0;if((d|0)==1){break b}nA(a,v[b>>2],v[b+4>>2],c)}break a}b=P()|0;O()|0;lc(a);S(b|0);L()}return a|0}function iea(a,b){a=a|0;b=b|0;var c=0;b=fb-32|0;fb=b;c=-1;a:{if(!gB(a,b+16|0)){break a}c=0;if(!IQ(b+16|0)){break a}c=-1;if(!yj(a,b+8|0)){break a}c=0;if(!v[b+12>>2]){break a}a=v[b+8>>2];c=(a&2139062143)==(a|0)}fb=b+32|0;return c|0}function QD(){var a=0,b=0,c=0;b=fb-16|0;fb=b;a=Qb(b,14944);a:{if(!Bb(a)){break a}c=1;if((pg(a,14621)|0)!=-1){break a}if((pg(a,16743)|0)!=-1){break a}if((pg(a,13687)|0)!=-1){break a}c=(pg(a,13730)|0)!=-1}ub(a);fb=b+16|0;return c|0}function KD(a){var b=0;if(!(Mb(a,13324,8)|(w[a+8|0]|w[a+9|0]<<8)!=14|(!(w[a+12|0]|w[a+13|0]<<8)|(w[a+14|0]|w[a+15|0]<<8|(w[a+16|0]<<16|w[a+17|0]<<24))<=0))){b=(w[a+18|0]|w[a+19|0]<<8|(w[a+20|0]<<16|w[a+21|0]<<24))>>>0>23}return b}function Yf(a,b){var c=0,d=0,e=0,f=0;d=x[a+22>>1];e=d+x[a+20>>1]|0;c=x[a+24>>1]<<17;while(1){if((d|0)==(e|0)){a=(c|0)/32768|0}else{f=c;c=((d&127)<<2)+a|0;c=f-B(v[zb(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;continue}break}return a}function MU(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Lb(v[a>>2],v[a+8>>2],120);a:{if(!d){a=0;while(1){if((a|0)!=120){rg(a+b|0);a=a+1|0;continue}break}break a}ec(c+8|0,b,120);md(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0;return d|0}function Jha(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Lb(v[a>>2],v[a+8>>2],64);a:{if(!d){a=0;while(1){if((a|0)!=32){Aq((a<<1)+b|0);a=a+1|0;continue}break}break a}hu(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0;return d|0}function AR(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){e=v[a+4>>2];f=e>>>8|0;d=v[a>>2];e=(e&255)<<24|d>>>8;d=(((d^w[b|0])&255)<<3)+21664|0;g=v[d>>2];d=v[d+4>>2]^f;v[a>>2]=e^g;v[a+4>>2]=d;b=b+1|0;continue}break}return a}function xda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;v[c+12>>2]=477218588;v[c+8>>2]=2147483647;d=Eb(c+12|0,c+8|0);fb=c+16|0;if(y[d>>2]<b>>>0){od();L()}c=B(b,9);b=tc(c);v[a>>2]=b;v[a+4>>2]=b;e=Cb(a),f=b+c|0,v[e>>2]=f}function ki(a){var b=0,c=0,d=0,e=0;e=Ae(a);c=e&63;a:{if(!(e&64)){break a}b=6;while(1){d=Ae(a);c=(d&127)<<b|c;if(!(d&128)){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}a=e>>>7|0;b=a?-2147483648:c;return a?(c|0)>=0?0-c|0:b:b}function kB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=v[a>>2];f=ek(e,v[a+4>>2]);while(1){a:{c=d&65535;if(c>>>0>=f>>>0){break a}c=Nf(e,c);if(!Nb(v[c>>2],v[c+4>>2])){break a}d=d+1|0;continue}break}return(Xg(a,d&65535,b)?d:-1)&65535}function iia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;cv(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){t[b+2|0]=0;t[b|0]=0;t[b+1|0]=0}}function Rea(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;u[b+30>>1]=0;c=cc(b+8|0,b+30|0,2);jc(b+16|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=2){break a}if(Mb(b+30|0,13595,2)){break a}Yb(a,2);d=1}fb=b+32|0;return d|0}function CL(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Dc(Cia(Bia(d,d>>31,g,h),ib,256,0),ib);v[a+4>>2]=f-d;v[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function pN(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!c){break a}v[b+40>>2]=c;if(!c|v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[Sc(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=Lz(c&255),v[e+44>>2]=f}fb=d+16|0}function ju(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;if(b){e=Qc(a);d=Bb(a);g=d+b|0;if(e-d>>>0<b>>>0){Ll(a,e,g-e|0,d,d,0,0)}e=d;d=pc(a);lq(e+d|0,b,c);hh(a,g);t[f+15|0]=0;bd(d+g|0,f+15|0)}fb=f+16|0;return a|0}function OL(a){var b=0,c=0,d=0;b=fb-544|0;fb=b;a:{if(!(w[a+480210|0]&128)|!v[a+24668>>2]){break a}d=a+1074992|0;a=Cz(b,v[a+24620>>2]);while(1){if((c|0)==256){break a}nc((B(c,872)+d|0)+112|0,a,538);c=c+1|0;continue}}fb=b+544|0}function Cia(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=Eia(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;ib=(g^ib)-((a>>>0<f>>>0)+g|0)|0;return b}function gA(a,b){var c=0,d=0,e=0,f=0;c=a<<8;d=c&16711680;c=e;e=a<<24|d;f=c;d=b<<24|a>>>8;c=b<<8|a>>>24;a=f|(((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24));ib=e|(d&65280|c&255);return a}function bha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;AA(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Sb(b,0,4896)}return a|0}function Gs(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=43980;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=43832;break a;case 2:c=43828;break a;case 1:break b;case 0:break c}}c=43824;break a}c=43820}v[a>>2]=v[c>>2]}function Gd(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+22>>1];g=d+x[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(g|0)){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0<2048){break a}u[a+20>>1]=c-d}return}c=c+1|0;continue}}function hha(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;v[a+480180>>2]=b;Iz(c,Zp(a));d=v[c+12>>2];b=a+1074320|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074312>>2]=v[c>>2];v[a+1074316>>2]=b;Gs(a+8|0,Zp(a));fb=c+16|0}function VD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=co(a);e=xd(v[a+4>>2],w[a+11|0]);f=e+1|0;if((c|0)==(e|0)){Ay(a,c,f-c|0,c,c,0)}c=qd(a);lq(c+e|0,1,b);Yp(a,f);t[d+15|0]=0;bd(c+f|0,d+15|0);fb=d+16|0;return a|0}function Bp(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(A[b-8>>3]-A[a>>3]);b=0;while(1){if((b|0)!=2048){d=-de(f*A[Ne(a,b)>>3]);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=zb(c,b),h=e,v[g>>2]=h;b=b+1|0;continue}break}}function qE(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;v[f+24>>2]=a;v[f+28>>2]=b;v[f+16>>2]=d;v[f+20>>2]=e;v[f+8>>2]=c;v[f+12>>2]=0;a=IB(f+24|0,f+8|0);b=f+16|0;a=ZD(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?a:b;fb=f+32|0;return v[a>>2]}function iN(a,b,c,d){var e=0;a=Rc(Gn(a,x[c+70>>1],v[c+48>>2],b,0)-32768|0);a:{if(!d){break a}d=Ok(c)-v[c+16>>2]|0;if((d|0)<2){break a}e=a;a=u[(B(b,872)+c|0)+1390>>1];a=Rc(((e-a|0)/(d|0)|0)+a|0)}u[(B(b,872)+c|0)+1390>>1]=a}function Cea(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Lb(v[a>>2],v[a+8>>2],6);a:{if(!d){a=0;while(1){if((a|0)!=6){rg(a+b|0);a=a+1|0;continue}break}break a}_A(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0;return d|0}function wt(a,b){var c=0,d=0,e=0;if(v[a>>2]){oU(a);c=v[a>>2];qB(a);Fb(c);d=Cb(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Cb(b);d=Cb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0}function mV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Gu(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Sb(b,0,65)}return a|0}function NK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;Gf(a+12|0,d);if(b){if(b>>>0>=2097152){xf(11129);L()}d=tc(b<<11)}else{d=0}v[a>>2]=d;c=d+(c<<11)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=vc(a),f=d+(b<<11)|0,v[e>>2]=f;return a|0}function gQ(a,b,c){var d=0;d=fb-16|0;fb=d;t[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){t[d+14|0]=(x[(b<<1)+32782>>1]-x[(c<<1)+32782>>1]|0)/5;a=w[Rb(d+15|0,d+14|0)|0]}fb=d+16|0;return a&255}function fha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;a:{if(a){jb[v[v[a>>2]+8>>2]](a,b,c);break a}if(!LS(d+8|0,b)){break a}v[d+24>>2]=0;a=bM(d+24|0);e=d+8|0;aM(e,9124,10798,140,42);cE(a,e,b,13220,c)}fb=d+32|0}function Ur(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!Rw(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=Le(a)}return b}ca(15657,13164,1578,5390);L()}function RY(a){a=a|0;if(w[466848]){return v[116711]}if(!w[468008]){a=467984;while(1){a=Gb(a)+12|0;if((a|0)!=468008){continue}break}t[468008]=1}id(467984,88336);id(467996,88348);t[466848]=1;v[116711]=467984;return 467984}function NM(a,b){var c=0,d=0,e=0,f=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];d=Cb(a);c=fc(a);a:{if(!v[d>>2]){v[a>>2]=c;break a}v[v[c>>2]+8>>2]=c;c=fc(b);v[b>>2]=c;v[c>>2]=0;e=Cb(b),f=0,v[e>>2]=f}return a}function KY(a){a=a|0;if(w[466840]){return v[116709]}if(!w[467976]){a=467952;while(1){a=Gb(a)+12|0;if((a|0)!=467976){continue}break}t[467976]=1}ed(467952,13837);ed(467964,13816);t[466840]=1;v[116709]=467952;return 467952}function mga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;c=-1;a:{if(!yj(a,d+8|0)){break a}e=v[d+12>>2];c=0;if(!(v[d+8>>2]==(rm(8949)|0)&e>>>0>255&e>>>0<260)){break a}c=Ce(a,b,e>>>0<259?80:76,0)}fb=d+16|0;return c|0}function gS(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function cs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=v[b>>2];b=sc(d,v[b+4>>2]);a=0;while(1){if((a|0)==(b|0)){fb=c+16|0}else{v[c+8>>2]=0;e=lh(c+8|0);f=zb(d,a),g=v[e>>2],v[f>>2]=g;a=a+1|0;continue}break}}function O6(a){a=a|0;var b=0;jb[v[v[a>>2]+128>>2]](a);vx(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=jb[v[v[a>>2]+192>>2]](a)|0;v[a+4328>>2]=0;v[a+4312>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4324>>2]=b;v[a+4320>>2]=b}function Mz(a,b){a=a|0;b=b|0;var c=0,d=0;a=Ib(a);a:{c=Wc(v[b>>2],v[b+4>>2]);if(c){v[23220]=0;R(308,a|0,c|0);d=v[23220];v[23220]=0;if((d|0)==1){break a}Qt(a,v[b>>2],v[b+4>>2],c)}return a|0}b=P()|0;O()|0;$b(a);S(b|0);L()}function JM(a,b,c,d){var e=0,f=0;e=v[(B(c,872)+b|0)+704>>2];a:{if(!(!(e&134218752)|(d|0)!=1)|e&67108864){break a}b=x[(B(c,872)+b|0)+1402>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=w[((b<<5)+a|0)+480288|0]}return f}function Eo(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;if(c>>>0<4294967280){a:{if(c>>>0<=10){ae(a,c);break a}e=Qh(c)+1|0;f=tc(e);td(a,f);yf(a,e);Bd(a,c);a=f}a=Fe(a,b,c);t[d+15|0]=0;bd(a+c|0,d+15|0);fb=d+16|0;return}kf();L()}function uq(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=fb-16|0;fb=b;Fq(b+8|0,c+15|0);d=v[b+12>>2];hd(b,a,v[b+8>>2],d);e=v[b+4>>2];if((e|0)==(d|0)){Zc(a,v[b+12>>2])}fb=b+16|0;fb=c+16|0;return((d|0)==(e|0)?w[c+15|0]:0)&255}function pO(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function Ux(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;a:{if(!c){a=_c(v[a>>2],b);A[a+8>>3]=e;A[a>>3]=d;break a}g=c>>>1|0;Ux(a,b,g,d,e);h=_c(v[a>>2],c);li(f,d,e,A[h>>3],A[h+8>>3]);Ux(a,b|c,g,A[f>>3],A[f+8>>3])}fb=f+16|0}function Fp(a,b,c){var d=0;d=fb-16|0;fb=d;xb(d+8|0,c+1074312|0,102);a:{if(!yb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}c=x[a+692>>1]+1|0;u[a+784>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+784>>1]=c|32768}v[a+692>>2]=b;fb=d+16|0}function laa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;hO(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){$y(b)}return a|0}function hz(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:tO(a,b);return;default:break a}}d=fb-32|0;fb=d;v[d+28>>2]=c;u[d+24>>1]=0;v[d+12>>2]=2;xr(d+16|0,a,d+24|0,v[Eb(d+28|0,d+12|0)>>2]);u[b>>1]=x[d+24>>1];fb=d+32|0}function Xfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;xA(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){yA(b)}return a|0}function XS(a){var b=0;a:{b:{if(Mb(a,13814,4)){if(Mb(a,16224,4)){break a}if((w[a+34|0]|w[a+35|0]<<8)>>>0<=255){break b}break a}if((w[a+34|0]|w[a+35|0]<<8)>>>0>255){break a}}b=(w[a+36|0]|w[a+37|0]<<8)>>>0<4e3}return b}function Bia(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;ib=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function xt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;KQ(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){LQ(b)}return a|0}function oH(a,b){var c=0,d=0,e=0;c=fb-256|0;fb=c;if((b|0)>=2){v[(b<<2)+a>>2]=c;nc(c,v[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;nc(v[e>>2],v[(d<<2)+a>>2],4);v[e>>2]=v[e>>2]+4;if((b|0)!=(d|0)){continue}break}}fb=c+256|0}function nC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;pC(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){oC(b)}return a|0}function Pw(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!Tr(a)){break a}if(!(t[a+1375|0]&1)){continue}break}Zb(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function Jy(a,b,c){var d=0,e=0;e=x[a+480192>>1];a:{if(e){if(!Oc(b)|c>>>0>e>>>0){break a}c=v[((c<<2)+a|0)+900380>>2];if(!c){break a}d=x[ac(c+236|0,b-1|0)>>1];break a}d=c}return(x[a+480190>>1]<(d&65535)>>>0?0:d)&65535}function Du(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;_B(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){ZB(b)}return a|0}function XN(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=e*A[a+16>>3]+(A[a>>3]*b+c*A[a+8>>3])-d*A[a+24>>3]-f*A[a+32>>3];A[a+56>>3]=b;return b}function up(a,b){a=nc(a,b,88);v[a+88>>2]=v[b+88>>2];nc(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];nc(a+672|0,b+672|0,52);Cy(a+724|0,b+724|0);Cy(a+732|0,b+732|0);Cy(a+740|0,b+740|0);nc(a+748|0,b+748|0,123);return a}function hn(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return C(b?-1/a:a)}function QO(a){var b=0;b=u[a+784>>1];if(b){v[a+692>>2]=(b&32767)-1;if((b|0)<0){v[a+88>>2]=v[a+88>>2]|256}u[a+784>>1]=0}b=w[a+795|0];if(b){t[a+795|0]=0;t[a+838|0]=b-1}b=w[a+796|0];if(b){t[a+796|0]=0;t[a+837|0]=b-1}}function Kl(a,b){var c=C(0),d=0,e=0;c=C(1);d=u[a+28>>1];a:{if((d|0)>(b|0)){break a}e=v[a+4>>2];if((sc(e,v[a+8>>2])+d<<16)-65536>>16<(b|0)){break a}c=z[zb(e,b-d|0)>>2];c=c<=C(1.0000000036274937e-15)?C(1):c}return c}function KZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=To(a);e=Bb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=pc(a);bi(d+(e<<2)|0,b,c);b=c+e|0;hh(a,b);td(d+(b<<2)|0,0);return a|0}cF(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function faa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Ib(a);d=eg(a+12|0);t[a+32|0]=c;v[a+28>>2]=0;v[a+24>>2]=b;v[23220]=0;R(737,a|0,1);b=v[23220];v[23220]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;RN(d);QN(a);S(b|0);L()}function BS(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,6)+e;a=v[d>>2];while(1){if(v[d+4>>2]!=(a|0)){Ot(a,c);a=v[d>>2]+6|0;v[d>>2]=a;continue}break}Ed(d);fb=d+16|0}function hk(a){uc(a+16|0,v[a>>2]);uc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function GO(a,b,c,d){var e=0;e=fb-16|0;fb=e;a=Ci(e,a,d);d=fb-16|0;fb=d;v[d+8>>2]=b;while(1){if(Nb(b,c)){Ai(v[a+4>>2],x[b>>1]);b=Oe(d+8|0);v[a+4>>2]=v[a+4>>2]+2;b=v[b>>2];continue}break}fb=d+16|0;hc(a);fb=e+16|0}function GC(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Lb(v[a>>2],v[a+8>>2],1)){break b}t[c+15|0]=0;kg(a,c+15|0);d=t[c+15|0]}fb=c+16|0;a=d;break a}ca(11197,9050,136,14177);L()}return a}function ey(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;IL(a+24648|0);OL(a)}function IG(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=jb[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!dn(b)){break a}v[a>>2]=0}return a|0}function Dj(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;ec(d+8|0,b,c);e=v[d+12>>2];jc(d,v[a>>2],v[a+8>>2],v[d+8>>2],e);f=v[d+4>>2];if((f|0)==(e|0)){Yb(a,v[d+12>>2])}fb=d+16|0;a=(e|0)==(f|0);if(!a){Sb(b,0,c)}return a}function yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{a=Ib(a);b:{d=b+c|0;c=oi(b,d);if(c){v[23220]=0;R(330,a|0,c|0);e=v[23220];v[23220]=0;if((e|0)==1){break b}Qt(a,b,d,c)}break a}b=P()|0;O()|0;$b(a);S(b|0);L()}}function vO(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-32|0;jz(v[d>>2]-32|0,c);v[d>>2]=v[d>>2]-32;continue}break}kc(a,d);kc(a+4|0,b+8|0);kc(Cb(a),vc(b));v[b>>2]=v[b+4>>2]}function taa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;c=bf(a,c);Yd(e,v[a+28>>2]);a:{b:{if(!c){d=-1;if(!cd(a,5)){break b}break a}d=v[c+8>>2]}hz(v[a+28>>2],b,d);f=c}a=We(a,f);fb=e+16|0;return a|0}function t7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=Nj(a);if(a){d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;e=v[v[a>>2]+72>>2];v[c>>2]=b;v[c+4>>2]=d;a=jb[e|0](a,c)|0}else{a=1}fb=c+16|0;return a|0}function iD(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-36|0;gv(v[d>>2]-36|0,c);v[d>>2]=v[d>>2]-36;continue}break}kc(a,d);kc(a+4|0,b+8|0);kc(Cb(a),vc(b));v[b>>2]=v[b+4>>2]}function er(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;Ko(v[d>>2]-12|0,c);v[d>>2]=v[d>>2]-12;continue}break}kc(a,d);kc(a+4|0,b+8|0);kc(Cb(a),vc(b));v[b>>2]=v[b+4>>2]}function WA(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-20|0;ZA(v[d>>2]-20|0,c);v[d>>2]=v[d>>2]-20;continue}break}kc(a,d);kc(a+4|0,b+8|0);kc(Cb(a),vc(b));v[b>>2]=v[b+4>>2]}function Uv(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function R8(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;a:{if(!yj(a,b+8|0)){break a}c=0;if(!rL(v[b+8>>2],v[b+12>>2])){break a}a=iQ(a,b);if(!a){lm(b)}c=-1;if(!a){break a}c=qL(v[b>>2])}a=c;fb=b+16|0;return a|0}function Im(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a:{if(c){Qb(d,c);break a}Gb(d)}v[23220]=0;U(11,a|0,b|0,d|0);a=v[23220];v[23220]=0;if((a|0)!=1){ub(d);fb=d+16|0;return}a=P()|0;O()|0;ub(d);S(a|0);L()}function yv(a,b,c){var d=0,e=0;d=qd(a);a=xd(v[a+4>>2],w[a+11|0]);e=qd(b);b=xd(v[b+4>>2],w[b+11|0]);a:{if(a>>>0>=c>>>0){if(!b){break a}a=a+d|0;b=TD(c+d|0,a,e,b+e|0);c=(a|0)==(b|0)?-1:b-d|0}else{c=-1}}return c}function x8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=fb-16|0;fb=f;c=bf(a,c);Yd(f,v[a+28>>2]);a:{b:{if(!c){e=-1;if(!cd(a,5)){break b}break a}e=v[c+8>>2]}jb[d|0](v[a+28>>2],b,e);g=c}We(a,g);fb=f+16|0}function jT(a){var b=0,c=0,d=0;a:{if(Mb(a,21587,11)){break a}d=a+63|0;a=0;while(1){c=(a|0)==8;if(c){break a}b=B(a,19)+d|0;if(w[b+16|0]>3|w[b+17|0]>3){break a}a=a+1|0;if(w[b+18|0]<16){continue}break}}return c}function gy(a,b){var c=0;c=v[b+24>>2];v[a+24628>>2]=c?c>>>0<512?c:512:1;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}nc(a+24604|0,b,40);JL(a,c)}function Zz(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;e=yD(a);a:while(1){if((a|0)!=(e|0)){f=pd(a);b=a;while(1)if((b|0)==(f|0)){a=a+16|0;continue a}else{c=((w[Hb(b,0)|0]&d)!=0)+c|0;b=b+4|0;continue}}break}return c}function IV(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;d=-1;a:{if(!YC(a,c+8|0)){break a}d=0;if(!XC(c+8|0)){break a}if(b){a=v[b>>2];if(!v[b+4>>2]&a>>>0<_b(v[c+12>>2])-8>>>0){break a}}d=1}fb=c+48|0;return d|0}function GP(a){a=a*4294967296;if(D(a)<0x8000000000000000){ib=D(a)>=1?~~(a>0?F(H(a*2.3283064365386963e-10),4294967295):I((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0}ib=-2147483648;return 0}function vu(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function ud(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Lb(v[a>>2],v[a+8>>2],1)){break b}t[c+15|0]=0;kg(a,c+15|0);d=w[c+15|0]}fb=c+16|0;break a}ca(11197,9050,136,14177);L()}return d}function p9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;v[a>>2]=v[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){iy(d,v[c+4>>2],v[c+8>>2])}nc(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function cA(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;f=v[b+12>>2];v[e+12>>2]=d;v[e+8>>2]=c;c=v[v[b>>2]+28>>2];d=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=d;jb[c|0](a,b,f,e);v[b+12>>2]=v[b+12>>2]+v[a+4>>2];fb=e+16|0}function FM(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+28>>2];v[a+24>>2]=v[b+24>>2];v[a+28>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function Es(a){var b=0;v[23220]=0;a=T(784,a|0)|0;b=v[23220];v[23220]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23220]=0;Z(17);b=v[23220];v[23220]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Tb();L()}function $0(a,b){a=a|0;b=b|0;var c=0;a=ms(a);v[a>>2]=76512;c=Gb(a+32|0);v[a+44>>2]=0;v[a+48>>2]=8;v[23220]=0;R(79,a|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;ub(c);un(a);S(b|0);L()}function tda(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;_l(a,b);b=Ab(v[a>>2]);v[c+8>>2]=b;a=Ab(v[a+4>>2]);while(1){if(Nb(b,a)){d=w[b|0]+(d&255)|0;t[b|0]=d;b=v[xe(c+8|0)>>2];continue}else{fb=c+16|0}break}}function nia(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Lb(v[a>>2],v[a+8>>2],64)){a=0;while(1){if((a|0)!=64){rg(a+b|0);a=a+1|0;continue}break}break a}hu(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0}function mca(a){a=a|0;var b=0;b=fb-16|0;fb=b;a:{if(_p(a,10226)){aJ(b,17517,a);a=Ec(b);v[23220]=0;R(38,44,a|0);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;ub(b);S(a|0);L()}fb=b+16|0;return}L()}function kaa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Lb(v[a>>2],v[a+8>>2],27)){a=0;while(1){if((a|0)!=27){rg(a+b|0);a=a+1|0;continue}break}break a}hO(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0}function i2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;lJ(d,c);a=v[a+1298464>>2];v[23220]=0;U(360,a|0,b|0,d|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(d);fb=d+16|0;return}a=P()|0;O()|0;vb(d);S(a|0);L()}function gz(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=v[c>>2];if(d){Pn(d);qO(v[c>>2])}b=b+1|0;continue}break}}function Ck(a){a=a|0;var b=0;v[a>>2]=77708;v[23220]=0;R(67,a|0,0);b=v[23220];v[23220]=0;if((b|0)!=1){Wb(a+28|0);Fb(v[a+32>>2]);Fb(v[a+36>>2]);Fb(v[a+48>>2]);Fb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Tb();L()}function qf(a,b,c,d,e){var f=0;f=fb-256|0;fb=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;Sb(f,b&255,d?c:256);if(!d){while(1){cf(a,f,256);c=c-256|0;if(c>>>0>255){continue}break}}cf(a,f,c)}fb=f+256|0}function $Q(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Lb(v[a>>2],v[a+8>>2],32)){a=0;while(1){if((a|0)!=32){rg(a+b|0);a=a+1|0;continue}break}break a}YQ(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0}function xfa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Lb(v[a>>2],v[a+8>>2],2)){a=0;while(1){if((a|0)!=2){rg(a+b|0);a=a+1|0;continue}break}break a}kl(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0}function fT(a){var b=0;a:{if(Mb(a,3873,4)|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(Mb(a+71|0,13675,4)|w[a+75|0]!=1|w[a+76|0]){break a}b=((w[a+116|0]|w[a+117|0]<<8)-1&65535)>>>0<9}return b}function e6(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=v[b+52>>2];if(c&16){d=v[b+48>>2];c=v[b+28>>2];if(d>>>0<c>>>0){v[b+48>>2]=c;d=c}Xf(a,v[b+24>>2],d);break a}if(c&8){Xf(a,v[b+12>>2],v[b+20>>2]);break a}Gb(a)}}function _d(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Fd(b)}return c}function U5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;b=Dc(Cia(Bia(d,d>>31,b,0),ib,1e3,0),ib);v[a+16>>2]=0;v[a+12>>2]=b+c;$J(a,e);b=v[a+12>>2];v[f+12>>2]=0;WK(a,b,f+12|0);fb=f+16|0}function Oca(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if((b|0)>=0){d=2147483647;a=jt(a);if(a>>>0<=1073741822){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[Sc(c+12|0,c+8|0)>>2]}fb=c+16|0;return d|0}uz();L()}function uB(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Lb(v[a>>2],v[a+8>>2],8)){a=0;while(1){if((a|0)!=8){rg(a+b|0);a=a+1|0;continue}break}break a}Bm(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0}function m2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a=Lo(e,a,d);v[23220]=0;U(1027,b|0,c|0,a+4|0);b=v[23220];v[23220]=0;if((b|0)!=1){hc(a);fb=e+16|0;return}b=P()|0;O()|0;hc(a);S(b|0);L()}function ZR(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;$R(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){_R(b)}return a}function ZK(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=Qc(a);a:{if(d>>>0>=c>>>0){b=pj(pc(a),b,c);t[e+15|0]=0;bd(b+c|0,e+15|0);hh(a,c);break a}f=d;g=c-d|0;d=Bb(a);Ro(a,f,g,d,0,d,c,b)}fb=e+16|0;return a}function X0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a=st(e,a,d);v[23220]=0;U(1058,b|0,c|0,a+4|0);b=v[23220];v[23220]=0;if((b|0)!=1){hc(a);fb=e+16|0;return}b=P()|0;O()|0;hc(a);S(b|0);L()}function VA(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;kT(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){lT(b)}return a}function Ff(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;c=2;if(a>>>0>=2){v[b+12>>2]=a>>>1;v[b+8>>2]=a^-1;d=b,e=v[Eb(b+12|0,b+8|0)>>2]+a|0,v[d+12>>2]=e;v[b+8>>2]=-1;c=v[Eb(b+12|0,b+8|0)>>2]}fb=b+16|0;return c}function FF(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){Wg(g+13|0,g+14|0)}h=c,i=(_a(b|0,Wc(b,v[c>>2])|0,g+12|0,d|0,a|0)|0)+b|0,v[h>>2]=i;fb=g+16|0}function zt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;YQ(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){Rz(b)}}function bR(a,b){a=a|0;b=b|0;var c=0,d=0;d=v[a>>2];c=65535;a:{if(!ke(d,v[a+4>>2],b)){break a}d=kB(a,v[Nf(d,b)+12>>2]);c=65535;if((d|0)==65535){break a}c=v[a>>2];a=Nf(c,b);iL(Nf(c,d),a);c=d}return c|0}function aX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;f=v[v[b>>2]+20>>2];e=v[c+12>>2];v[d+8>>2]=v[c+8>>2];v[d+12>>2]=e;e=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=e;jb[f|0](a,b,d,8);fb=d+16|0}function Kg(a,b){var c=0,d=0,e=0;c=Bb(a);a:{if((c|0)!=(Bb(b)|0)){break a}d=Ec(a);b=Ec(b);if(!ve(a)){while(1){e=!c;if(!c|w[d|0]!=w[b|0]){break a}b=b+1|0;d=d+1|0;c=c-1|0;continue}}e=!Ml(d,b,c)}return e}function qQ(a){var b=0,c=0,d=0;d=w[a+32|0]|w[a+33|0]<<8;b=w[a+34|0]|w[a+35|0]<<8;a=b+(w[a+36|0]|w[a+37|0]<<8)|0;c=a>>>0<b>>>0?1:c;b=a;a=c<<1|a>>>31;b=b<<1;c=d+b|0;a=c>>>0<b>>>0?a+1|0:a;ib=a;return c}function hP(a){var b=0,c=0,d=0;d=w[a+64|0]|w[a+65|0]<<8;b=w[a+70|0]|w[a+71|0]<<8;a=b+(w[a+72|0]|w[a+73|0]<<8)|0;c=a>>>0<b>>>0?1:c;b=a;a=c<<2|a>>>30;b=b<<2;c=d+b|0;a=c>>>0<b>>>0?a+1|0:a;ib=a;return c}function QW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;v[e+12>>2]=d;d=xd(v[b+4>>2],w[b+11|0]);if(d>>>0<c>>>0){fm();L()}b=qd(b);v[e+8>>2]=d-c;Eo(a,b+c|0,v[Eb(e+12|0,e+8|0)>>2]);fb=e+16|0}function OJ(a){var b=0,c=0,d=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(D(c)<2147483648){a=~~c;break a}a=-2147483648}d=C(Kj(b-+(a|0)))}else{d=C(0)}return d}function CB(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Lb(v[a>>2],v[a+8>>2],512)){a=0;while(1){if((a|0)!=128){lm((a<<2)+b|0);a=a+1|0;continue}break}break a}ou(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0}function Ku(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Lb(v[a>>2],v[a+8>>2],256)){a=0;while(1){if((a|0)!=256){rg(a+b|0);a=a+1|0;continue}break}break a}ec(c+8|0,b,256);md(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0}function iJ(){var a=0,b=0,c=0,d=0;a=fb-16|0;fb=a;b=tc(1298472);v[23220]=0;c=T(1032,b|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){b=v[uf(a+8|0,c)>>2];fb=a+16|0;return b|0}a=P()|0;O()|0;Fb(b);S(a|0);L()}function ZN(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function Ii(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;ec(d+8|0,b,c);e=v[d+12>>2];jc(d,v[a>>2],v[a+8>>2],v[d+8>>2],e);f=v[d+4>>2];if((f|0)==(e|0)){Yb(a,v[d+12>>2])}fb=d+16|0;if((e|0)!=(f|0)){Sb(b,0,c)}}function Hd(a,b){var c=0,d=0,e=0;d=x[a+24>>1];if((d|0)!=(b&65535)){c=x[a+22>>1]-1&127;u[a+22>>1]=c;e=x[a+20>>1];if(e>>>0<=127){u[a+20>>1]=e+1}c=(c<<2)+a|0;u[c+26>>1]=b-d;u[c+28>>1]=0;u[a+24>>1]=b}}function jr(a,b,c,d,e,f){var g=0,h=0;Gf(a+12|0,d);if(b){if(b>>>0>=f>>>0){xf(11129);L()}d=tc(B(b,e))}else{d=0}v[a>>2]=d;c=d+B(c,e)|0;v[a+8>>2]=c;v[a+4>>2]=c;g=vc(a),h=d+B(b,e)|0,v[g>>2]=h;return a}function Yi(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function Hv(a,b,c,d){var e=0,f=0,g=0;e=b+4|0;g=c;f=v[a>>2];c=v[a+4>>2]-f|0;d=v[e>>2]+B(g,(c|0)/(d|0)|0)|0;v[e>>2]=d;if((c|0)>0){nc(d,f,c)}kc(a,e);kc(a+4|0,b+8|0);kc(Cb(a),vc(b));v[b>>2]=v[b+4>>2]}function v2(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;lJ(c,b);a=v[a+1298464>>2];v[23220]=0;U(360,a|0,1,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){vb(c);fb=c+16|0;return}a=P()|0;O()|0;vb(c);S(a|0);L()}function u8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;c=bf(a,c);Yd(e,v[a+28>>2]);a:{b:{if(!c){d=-1;if(!cd(a,5)){break b}break a}d=v[c+8>>2]}RS(v[a+28>>2],b,d);f=c}We(a,f);fb=e+16|0}function fH(a){var b=0,c=0,d=0;d=v[a>>2];while(1){c=t[d|0];if(Jj(c)){d=d+1|0;v[a>>2]=d;if(b>>>0<=214748364){c=c-48|0;b=B(b,10);b=(c|0)>(2147483647-b|0)?-1:c+b|0}else{b=-1}continue}break}return b}function e8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;c=bf(a,c);Yd(e,v[a+28>>2]);a:{b:{if(!c){d=-1;if(!cd(a,5)){break b}break a}d=v[c+8>>2]}hz(v[a+28>>2],b,d);f=c}We(a,f);fb=e+16|0}function cu(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function RL(a){var b=0,c=0;c=a+906300|0;a=0;while(1){if((a|0)!=250){b=v[B(a,160)+c>>2];a:{if(!b){break a}if(!(jb[v[v[b>>2]+116>>2]](b)|0)){break a}jb[v[v[b>>2]+96>>2]](b)}a=a+1|0;continue}break}}function su(a,b,c){var d=0;a=(a&65535)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-8;t[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function iB(a,b){var c=0;c=fb-16|0;fb=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=Ub(128/(B(v[Ke(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[$e(c+7|0,c+6|0)|0];fb=c+16|0;return a|b<<4&240}function dS(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;_A(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)|0}function Vh(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;Bm(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)|0}function BO(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;t[a+16|0]=0;c=mz(b,v[a+12>>2]);v[23220]=0;R(722,a|0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){Uk(c);fb=b+32|0;return}a=P()|0;O()|0;Uk(c);S(a|0);L()}function vh(a,b){var c=0;c=v[a>>2];a=Sd(b);b=v[c+8>>2];if(sc(b,v[c+12>>2])>>>0>a>>>0){c=v[zb(b,a)>>2]!=0}else{c=0}if(!c){a=Fl(aa(4)|0);v[a>>2]=91924;ia(a|0,92060,1078);L()}return v[zb(b,a)>>2]}function RS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;If(a,d+14|0);e=x[d+14>>1];YL(b,e);c=0;while(1){if((c|0)==(e|0)){jy(b);fb=d+16|0}else{_j(a,zb(v[b>>2],c));c=c+1|0;continue}break}}function NJ(a,b){var c=0,d=0,e=0,f=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);c=+a;e=32768/(1-c);f=c;c=Me(31415.926535897932/+b);d=Xl(e*(1-(f*c+K(+C(a+a)*(1-c)-+C(a*a)*(1-c*c)))))}return d}function MQ(a){var b=0,c=0,d=0,e=0;ib=0;d=w[a+4|0];e=w[a+92|0];c=w[a+94|0]|w[a+95|0]<<8;b=c+w[a+93|0]|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function KH(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;b=(b|0)>0?b:0;h=a+2304|0;while(1){if((b|0)!=(d|0)){c=d<<2;e=c+a|0;f=z[e>>2];c=c+h|0;g=z[c>>2];z[e>>2]=f+g;z[c>>2]=f-g;d=d+1|0;continue}break}}function ig(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb+-64|0;fb=c;d=Px(c+8|0,a);v[23220]=0;U(188,a|0,b|0,d|0);a=v[23220];v[23220]=0;if((a|0)!=1){Mk(d);fb=c- -64|0;return}a=P()|0;O()|0;Mk(d);S(a|0);L()}function hy(a,b){var c=0;a=MP(a,b);t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function wj(a,b){var c=0,d=0;c=fb-16|0;fb=c;v[c+12>>2]=b;d=b;b=Ah(2147483647);if(d>>>0<=b>>>0){a=wm(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Sc(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}od();L()}function fj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=Tk(a,b);if((d|0)==255){break a}Sj(a,b);Dp(a,b,0,0);if(!c){break a}e=ac(a+26|0,d),f=65535,u[e>>1]=f;a=Hb(a+62|0,b);t[a|0]=w[a|0]|128}}function RO(a,b){var c=0;c=w[a+800|0];a:{if(c){break a}c=vi(w[a+797|0]-u[a+770>>1]|0);if(!b|(c<<24)-16777216>>24<0){break a}a=v[a+656>>2];if(!a){break a}c=w[Hb(a+108|0,c-1|0)|0]}return c&255}function Pg(a,b){var c=0,d=0;c=fb-16|0;fb=c;v[c+12>>2]=b;d=b;b=Ah(1073741823);if(d>>>0<=b>>>0){a=si(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Sc(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}od();L()}function nn(a){var b=0,c=0;b=fb-16|0;fb=b;a:{if(!XI(w[a+20|0])){v[23220]=0;R(1037,b+8|0,a|0);c=v[23220];v[23220]=0;if((c|0)==1){break a}}t[a+20|0]=255;fb=b+16|0;return}V(0)|0;O()|0;Tb();L()}function lD(a,b){var c=0,d=0;c=fb-16|0;fb=c;v[c+12>>2]=b;d=b;b=Ah(119304647);if(d>>>0<=b>>>0){a=fv(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Sc(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}od();L()}function _Q(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=(ip(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),A[d+8>>3]=e;wN(c+8|0,127);a=Yn(A[c+8>>3]);fb=c+16|0;return a}function YA(a,b){var c=0,d=0;c=fb-16|0;fb=c;v[c+12>>2]=b;d=b;b=Ah(214748364);if(d>>>0<=b>>>0){a=iC(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Sc(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}od();L()}function Wq(a,b){var c=0,d=0;c=fb-16|0;fb=c;v[c+12>>2]=b;d=b;b=Ah(536870911);if(d>>>0<=b>>>0){a=Hm(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Sc(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}od();L()}function Sm(a,b){var c=0,d=0,e=0;a:{c=iG(b);if(c>>>0<1073741808){b:{if(c>>>0<=1){ae(a,c);break b}d=xl(c)+1|0;e=pi(d);td(a,e);yf(a,d);Bd(a,c);a=e}bi(a,b,c);td((c<<2)+a|0,0);break a}kf();L()}}function Jm(a,b){var c=0,d=0;c=fb-16|0;fb=c;v[c+12>>2]=b;d=b;b=Ah(357913941);if(d>>>0<=b>>>0){a=Bj(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Sc(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}od();L()}function Hp(a,b){var c=0,d=0;c=fb-16|0;fb=c;v[c+12>>2]=b;d=b;b=Ah(134217727);if(d>>>0<=b>>>0){a=Xn(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Sc(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}od();L()}function DA(a,b){var c=0,d=0;c=fb-16|0;fb=c;v[c+12>>2]=b;d=b;b=Ah(715827882);if(d>>>0<=b>>>0){a=bu(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Sc(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}od();L()}function Cv(a,b){var c=0,d=0;c=fb-16|0;fb=c;v[c+12>>2]=b;d=b;b=Ah(268435455);if(d>>>0<=b>>>0){a=fr(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Sc(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}od();L()}function xC(a){var b=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;b=v[a>>2];if(b&8){v[a>>2]=b|32;return-1}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];return 0}function pR(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;vR(c+8|0,b);d=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){wR(b)}}function ot(a){var b=0;a:{if(Mb(a,13568,4)|w[a+4|0]){break a}if(Jb(w[a+6|0]|w[a+7|0]<<8)>>>0>1){break a}if(Jb(w[a+12|0]|w[a+13|0]<<8)){break a}b=(Jb(w[a+16|0]|w[a+17|0]<<8)|0)==20}return b}function oG(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function fL(a,b){var c=0,d=0;c=fb-16|0;fb=c;v[c+12>>2]=b;d=b;b=Ah(82595524);if(d>>>0<=b>>>0){a=Hs(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Sc(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}od();L()}function f9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(sc(v[a+4>>2],v[a+8>>2])+e|0)-1|0,u[f+10>>1]=g;a=_K(a,b,c,d+8|0);fb=d+16|0;return a|0}function _g(a,b,c){a:{if(b>>>0<=c>>>0){a=aa(8)|0;v[23220]=0;b=T(180,a|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){break a}b=P()|0;O()|0;ba(a|0);S(b|0);L()}return w[a+c|0]}ia(b|0,26072,155);L()}function HM(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;b=Tq(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){hc(b);fb=d+16|0}else{GM(a,v[c>>2],v[c+4>>2]);a=a+8|0;v[b+4>>2]=a;continue}break}}function dF(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=83064;c=a+8|0;while(1){b=v[c>>2];if(sc(b,v[c+4>>2])>>>0>d>>>0){b=v[zb(b,d)>>2];if(b){Gm(b)}d=d+1|0;continue}break}ub(a+152|0);bw(c);return a|0}function _z(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=Cb(a);c=cg(d+8|0,Pg(a,sc(v[a>>2],v[a+4>>2])+1|0),sc(v[a>>2],v[a+4>>2]),c);Kp(v[c+8>>2],v[b>>2]);v[c+8>>2]=v[c+8>>2]+4;vd(a,c);bg(c);fb=d+32|0}function Vw(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function Nx(a,b,c,d,e,f,g,h,i){var j=0;j=fb-16|0;fb=j;tg(j,b,c,d,e,f,g,h,i^-2147483648);d=v[j>>2];c=v[j+4>>2];b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;v[a>>2]=d;v[a+4>>2]=c;fb=j+16|0}function cP(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function PF(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=Cb(a);c=wl(d+8|0,tl(a,Wc(v[a>>2],v[a+4>>2])+1|0),Wc(v[a>>2],v[a+4>>2]),c);Hj(v[c+8>>2],w[b|0]);v[c+8>>2]=v[c+8>>2]+1;vd(a,c);vl(c);fb=d+32|0}function yj(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Bm(c+8|0,b);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){ol(b)}return a}function xR(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;vR(c+8|0,b);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){wR(b)}return a}function gB(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;fB(c+8|0,b);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){GT(b)}return a}function fQ(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;kT(c+8|0,b);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){lT(b)}return a}function d$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=Vt(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;nc(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function cU(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;gu(c+8|0,b);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){nB(b)}return a}function bj(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function YC(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Oq(c+8|0,b);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Pq(b)}return a}function OQ(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;KQ(c+8|0,b);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){LQ(b)}return a}function LD(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;JD(c+8|0,b);d=v[c+12>>2];hd(c,a,v[c+8>>2],d);e=v[c+4>>2];if((e|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){sv(b)}return a}function Db(a,b){var c=0,d=0;c=fb-16|0;fb=c;if(nf(w[a+11|0])){Fb(v[a>>2])}d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;v[a+8>>2]=v[b+8>>2];ae(b,0);t[c+15|0]=0;bd(b,c+15|0);fb=c+16|0;return a}function DS(a,b,c,d){var e=0;e=fb-16|0;fb=e;v[e+12>>2]=b;v[e+8>>2]=d;a=Ml(a,c,v[Eb(e+12|0,e+8|0)>>2]);a:{if(a){break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}fb=e+16|0;return a}function j_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;h=a;a=g+16|0;b=Gj(h,b,c,d,e,f,g+8|0,a);fb=a;return b|0}function f5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=EJ(f,b,c,d,0,0,0,0,e);fb=f+16|0;return a|0}function Ax(a){var b=0,c=0,d=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=Cn(d)|b<<15;continue}break}A[c+4280>>3]=C(C(b|0)*C(-4.656612873077393e-10))}function _r(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=v[a+4>>2];d=((b<<2)+(Su(v[a>>2],1)^270549120)|0)+2019860093|0;v[a>>2]=d;b=b+B(Su(d,16),5)|0;v[a+4>>2]=b;continue}break}return b}function _ga(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Lb(v[a>>2],v[a+8>>2],12);a:{if(!d){t[c|0]=0;Wh(b,12,c);break a}fB(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0;return d|0}function Z1(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=v[14239];v[c+8>>2]=v[14238];v[c+12>>2]=d;d=v[14237];v[c>>2]=v[14236];v[c+4>>2]=d;jb[v[cp(c,Lj(w[b+20|0]))>>2]](a,b);fb=c+16|0}function Lea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Ib(a);a:{if(b){v[23220]=0;R(580,a|0,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break a}po(a,b,c)}return a|0}b=P()|0;O()|0;ld(a);S(b|0);L()}function tl(a,b){var c=0,d=0;c=fb-16|0;fb=c;v[c+12>>2]=b;d=b;b=Ah(-1);if(d>>>0<=b>>>0){a=Uo(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Sc(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}od();L()}function lV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Ib(a);a:{if(b){v[23220]=0;R(215,a|0,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break a}kC(a,b,c)}return a|0}b=P()|0;O()|0;lc(a);S(b|0);L()}function TS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Ib(a);a:{if(b){v[23220]=0;R(403,a|0,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break a}HA(a,b,c)}return a|0}b=P()|0;O()|0;qh(a);S(b|0);L()}function Lh(a){var b=0;a=Nh(a);b=2147483647;a:{if(a>=C(2147483648)){break a}b=-2147483648;if(a<=C(-2147483648)){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function ns(a){var b=0;b=v[a+24>>2];v[23220]=0;Y(785,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){De(a+68|0);Tf(a+36|0);es(a+32|0);$i(a+24|0);_i(a+4|0);return pe(a)}V(0)|0;O()|0;Tb();L()}function dha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;oS(b,c);c=Lb(v[a>>2],v[a+8>>2],c<<2);if(c){nS(d+8|0,v[b>>2],v[b+4>>2]);md(d,a,v[d+8>>2],v[d+12>>2])}fb=d+16|0;return c|0}function cg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;Gf(a+12|0,d);if(b){d=pi(b)}else{d=0}v[a>>2]=d;c=d+(c<<2)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=vc(a),f=d+(b<<2)|0,v[e>>2]=f;return a|0}function Zca(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Lb(v[a>>2],v[a+8>>2],4);a:{if(!d){t[c|0]=0;cD(b,4,c);break a}zh(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0;return d|0}function Z7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;f=1;g=v[c>>2];if(g>>>0<Wc(a,b)>>>0){a=Rm(e,Hb(a,g),x[c+12>>1]);b=Yv(d,a);Pb(a);f=b^1}fb=e+16|0;return f|0}function LJ(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=KJ(f,b,c,d,e,0,0,0,0);fb=f+16|0;return+c}function vv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;v[e+12>>2]=d;d=Bb(b);if(d>>>0<c>>>0){fm();L()}b=Ec(b);v[e+8>>2]=d-c;Eo(a,b+c|0,v[Eb(e+12|0,e+8|0)>>2]);fb=e+16|0}function qW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;rD(b,c);c=Lb(v[a>>2],v[a+8>>2],c<<3);if(c){qD(d+8|0,v[b>>2],v[b+4>>2]);md(d,a,v[d+8>>2],v[d+12>>2])}fb=d+16|0;return c|0}function fW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;v[d+12>>2]=c;c=0;a=jb[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Eb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function Yy(a){var b=0,c=0;b=v[a>>2];c=v[b>>2];a:{if(!c){while(1){c=nh(b);b=v[b+8>>2];if(c){continue}break}break a}while(1){b=c;c=v[b+4>>2];if(c){continue}break}}v[a>>2]=b;return a}function XL(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;UL(c,b+80|0);v[23220]=0;U(11,a|0,0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){ub(c);fb=c+16|0;return}a=P()|0;O()|0;ub(c);S(a|0);L()}function zo(a,b){var c=0,d=0;c=fb-16|0;fb=c;zh(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function uS(a,b){var c=0,d=0;c=fb-16|0;fb=c;tS(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function ru(a,b){var c=0,d=0;c=fb-16|0;fb=c;qu(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function pu(a,b){var c=0,d=0;c=fb-16|0;fb=c;no(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function pW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=!b|(b>>>0>d>>>0|a>>>0>=d>>>0|d-a>>>0<b>>>0);a:{if(d){break a}a=a+b|0;if(Wc(v[c>>2],v[c+4>>2])>>>0>=a>>>0){break a}Ji(c,a)}return!d|0}function oR(a,b){var c=0,d=0;c=fb-16|0;fb=c;nR(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function mN(a,b,c,d){a:{if((a|0)!=67108864){break a}a=B(d,872)+c|0;v[a+704>>2]=v[a+704>>2]&-129;a=d^1;if(a>>>0>=(b&65535)>>>0){break a}a=B(a,872)+c|0;v[a+704>>2]=v[a+704>>2]&-129}}function kg(a,b){var c=0,d=0;c=fb-16|0;fb=c;Fq(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function gD(a,b){var c=0,d=0;c=fb-16|0;fb=c;JD(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function ada(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;LP(b,c);if(Lb(v[a>>2],v[a+8>>2],c<<8)){c=v[b>>2];ec(d+8|0,c,mh(c,v[b+4>>2])<<8);md(d,a,v[d+8>>2],v[d+12>>2])}fb=d+16|0}function ZC(a,b){var c=0,d=0;c=fb-16|0;fb=c;Oq(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function TT(a,b){var c=0,d=0;c=fb-16|0;fb=c;Fu(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function TB(a,b){var c=0,d=0;c=fb-16|0;fb=c;SB(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function SQ(a,b){var c=0,d=0;c=fb-16|0;fb=c;oA(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function Nv(a,b,c){var d=0;d=fb-16|0;fb=d;ec(d+8|0,b,c);b=v[d+12>>2];jc(d,v[a>>2],v[a+8>>2],v[d+8>>2],b);c=v[d+4>>2];if((b|0)==(c|0)){Yb(a,v[d+12>>2])}fb=d+16|0;return(b|0)==(c|0)}function Lq(a,b){var c=0,d=0;c=fb-16|0;fb=c;kl(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function JT(a,b){var c=0,d=0;c=fb-16|0;fb=c;gu(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function ET(a,b){var c=0,d=0;c=fb-16|0;fb=c;hu(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function DT(a,b){var c=0,d=0;c=fb-16|0;fb=c;fB(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Yb(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function yS(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+4|0]|w[b+5|0]<<8;t[a+4|0]=b;t[a+5|0]=b>>>8}function po(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;b=Ci(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){hc(b);fb=d+16|0}else{Ai(a,x[c>>1]);a=a+2|0;v[b+4>>2]=a;continue}break}}function kC(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;b=ri(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){hc(b);fb=d+16|0}else{Kp(a,v[c>>2]);a=a+4|0;v[b+4>>2]=a;continue}break}}function je(a,b){var c=0;a:{c=Cf(b);if((c|0)==(Bb(a)|0)){v[23220]=0;a=W(354,a|0,b|0,c|0)|0;b=v[23220];v[23220]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Tb();L()}function Yb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Lb(v[a>>2],v[a+8>>2],b);if(c){v[a+8>>2]=v[a+8>>2]+b;return c|0}b=a;a=v[a>>2];d=b,e=jb[v[v[a>>2]+24>>2]](a)|0,v[d+8>>2]=e;return c|0}function Mx(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;b=ri(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){hc(b);fb=d+16|0}else{As(a,z[c>>2]);a=a+4|0;v[b+4>>2]=a;continue}break}}function xc(a,b){var c=0,d=0;c=fb-16|0;fb=c;if(ve(a)){Fb(v[a>>2])}d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;v[a+8>>2]=v[b+8>>2];ae(b,0);t[c+15|0]=0;bd(b,c+15|0);fb=c+16|0;return a}function vo(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;b=vk(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){hc(b);fb=d+16|0}else{Hj(a,w[c|0]);a=a+1|0;v[b+4>>2]=a;continue}break}}function qC(a){var b=0,c=0;a:{if(Mb(a,14149,3)){break a}b=w[a+3|0];b:{if(b>>>0<=7){if((b|0)==1){break b}break a}if(b>>>0>14){break a}}c=(w[a+40|0]-1&255)>>>0<32|b>>>0<9}return c}function oga(){var a=0,b=0,c=0;a=fb-16|0;fb=a;b=tc(1);v[23220]=0;Z(29);c=v[23220];v[23220]=0;if((c|0)!=1){b=v[uf(a+8|0,b)>>2];fb=a+16|0;return b|0}a=P()|0;O()|0;Fb(b);S(a|0);L()}function fY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];if(a>>>0<=127){a=x[(a<<1)+79024>>1]}else{a=0}u[d>>1]=a;d=d+2|0;b=b+4|0;continue}break}return c|0}function We(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!b){b=1;if(cd(a,5)){break a}Yd(c,v[a+28>>2])}v[a>>2]=v[a>>2]|134217728;v[a+20>>2]=v[a+20>>2]+1;b=0}fb=c+16|0;return b|0}function Sga(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;QS(b,c);PS(a,c);fb=c+32|0}function Dga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;c=bf(a,c);Yd(e,v[a+28>>2]);a:{if(!c){f=0;if(cd(a,5)){break a}}MS(v[a+28>>2],b,d,0);f=c}We(a,f);fb=e+16|0}function SD(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&-256)!=(a|0)}return b}function RW(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;ID(b,0,a);v[23220]=0;a=T(112,b|0)|0;c=v[23220];v[23220]=0;if((c|0)!=1){ub(b);fb=b+16|0;return a|0}a=P()|0;O()|0;ub(b);S(a|0);L()}function O5(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);if(b>>>0<=12){c=Ld(c,C(0));d=a+4208|0;if((b|0)==12){c=C(Nh(C(c*C(3)))/C(3));b=12}e=zb(d,b),f=c,z[e>>2]=f;t[a+5046|0]=1}}function KN(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;while(1){if(c){f=Sk(x[c+16>>1],v[c+20>>2],a,b);d=f?d:c;c=v[(f?c+4|0:c)>>2];continue}break}a=v[dc(e+8|0,d)>>2];fb=e+16|0;return a}function D8(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-32|0;fb=d;c=-1;a:{if(!LD(a,d+8|0)){break a}c=0;if(!nL(d+8|0)|(v[d+16>>2]!=v[b>>2]|v[b+4>>2]?b:0)){break a}c=1}fb=d+32|0;return c|0}function $r(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;v[b+12>>2]=12;while(1){v[b+8>>2]=32;if(y[Eb(b+12|0,b+8|0)>>2]<=c>>>0){fb=b+16|0}else{c=c+15|0;d=Cn(a)&4095;continue}break}return d}function k1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;v[d+12>>2]=c;ax(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Eb(d+8|0,d+12|0)>>2]}fb=d+16|0;return c|0}function QE(a,b,c){var d=0;a:{if(!a){a=aa(8)|0;v[23220]=0;c=T(c|0,a|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){break a}b=P()|0;O()|0;ba(a|0);S(b|0);L()}return}ia(c|0,b|0,923);L()}function Iha(a,b){a=a|0;b=b|0;if(!DT(a,b)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0}}function Dv(a,b,c,d,e){var f=0;a:{f=Es(4332);if(f){v[23220]=0;ga(e|0,f|0,a|0,b|0,c|0,d|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break a}}return f}a=P()|0;O()|0;Fb(f);S(a|0);L()}function wda(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;b=-1;a:{if(!yj(a,c+8|0)){break a}b=0;if(!NP(c+8|0)){break a}b=-1;if(!Sf(a,4)){break a}b=jQ(a)>>>31|0}fb=c+16|0;return b|0}function sD(a,b,c){var d=0,e=0;a:{b:{if(c>>>0<=10){ae(a,c);break b}if(c>>>0>=4294967280){break a}d=Qh(c)+1|0;e=tc(d);td(a,e);yf(a,d);Bd(a,c);a=e}Fe(a,b,c+1|0);return}kf();L()}function hd(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;f=v[b+12>>2];v[e+12>>2]=d;v[e+8>>2]=c;c=v[v[b>>2]+28>>2];d=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=d;jb[c|0](a,b,f,e);fb=e+16|0}function h8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;c=bf(a,c);Yd(e,v[a+28>>2]);a:{if(!c){f=0;if(cd(a,5)){break a}}TK(d,v[a+28>>2],b);f=c}We(a,f);fb=e+16|0}function LX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;jb[v[v[a>>2]+12>>2]](d+8|0,a,b);a=v[d+8>>2];b=v[c>>2];a=rc(v[d+12>>2],v[c+4>>2])&(a|0)==(b|0);fb=d+16|0;return a|0}function EL(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;while(1){v[b+12>>2]=7;v[b+8>>2]=32;if(y[Eb(b+12|0,b+8|0)>>2]<=c>>>0){fb=b+16|0}else{c=c+15|0;d=Cn(a)&127;continue}break}return d}function z9(a,b){a=a|0;b=b|0;var c=0;a=eg(a);c=oj(v[b>>2]);b=wf(b);v[23220]=0;U(779,a|0,c|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;QM(a);S(b|0);L()}function wfa(a,b){a=a|0;b=b|0;var c=0;a=Ib(a);a:{if(b){v[23220]=0;R(533,a|0,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break a}zA(a,b)}return a|0}b=P()|0;O()|0;lc(a);S(b|0);L()}function iq(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];d=v[a+4>>2];if(Ic(c,d)>>>0>b>>>0){a=v[a+24>>2];b=el(c,d,b);a=ke(v[a+484344>>2],v[a+484348>>2],x[b>>1])}else{a=0}return a|0}function _o(a){var b=0,c=0;b=v[23139];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(Hw()>>>0<a>>>0){if(!(xa(a|0)|0)){break a}}v[23139]=a;return b}v[115696]=48;return-1}function Fca(a,b){a=a|0;b=b|0;var c=0;a=Ib(a);a:{if(b){v[23220]=0;R(215,a|0,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break a}it(a,b)}return a|0}b=P()|0;O()|0;lc(a);S(b|0);L()}function vT(a){var b=0;a:{if(Mb(a,16661,4)){break a}if(_b(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))-257>>>0<4294967053){break a}b=!Jb(w[a+8|0]|w[a+9|0]<<8)}return b}function lg(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=_g(v[d>>2],v[d+4>>2],a);return((_g(v[d>>2],v[d+4>>2],a+1|0)<<8|e<<16|_g(v[d>>2],v[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function Tea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;v[d+8>>2]=b;while(1){if(Nb(b,c)){v[d+4>>2]=v[b>>2];mA(a,d+4|0);b=v[ye(d+8|0)>>2];continue}else{fb=d+16|0}break}}function HA(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;b=gq(d,a,b);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){hc(b);fb=d+16|0}else{Ot(a,c);a=a+6|0;v[b+4>>2]=a;continue}break}}function Cu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;Ji(b,c);if(Lb(v[a>>2],v[a+8>>2],c)){c=v[b>>2];ec(d+8|0,c,Wc(c,v[b+4>>2]));md(d,a,v[d+8>>2],v[d+12>>2])}fb=d+16|0}function wl(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;Gf(a+12|0,d);if(b){d=tc(b)}else{d=0}v[a>>2]=d;c=c+d|0;v[a+8>>2]=c;v[a+4>>2]=c;e=vc(a),f=b+d|0,v[e>>2]=f;return a|0}function Rp(a){var b=0,c=0;c=v[a+4>>2];b=v[c>>2];v[a+4>>2]=b;if(b){Gl(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(nh(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c>>2]=a;Gl(a,c)}function Qp(a){var b=0,c=0;c=v[a>>2];b=v[c+4>>2];v[a>>2]=b;if(b){Gl(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(nh(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c+4>>2]=a;Gl(a,c)}function Hh(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;t[c+24|0]=0;Ui(c+8|0,c+24|0);cn(c+16|0,a,v[c+8>>2],v[c+12>>2]);a=v[c+20>>2];t[b|0]=w[c+24|0];fb=c+32|0;return(a|0)==1|0}function rf(a,b,c,d,e){a:{if(d>>>0<e>>>0){v[23220]=0;X(1047,17326,9081,393,6342);a=v[23220];v[23220]=0;if((a|0)==1){break a}L()}$L(a,b,c,d,e);return}V(0)|0;O()|0;Tb();L()}function dY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=v[c>>2];if(!(a>>>0>127|!(x[(a<<1)+79024>>1]&b))){c=c+4|0;continue}break}d=c}return d|0}function Te(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+8>>2]=c;v[d+4>>2]=31;e=d,f=nU(b,c),v[e+12>>2]=f;c=b;b=rB(d+4|0);Yg(c,c+b|0,a);e=Hb(a,b),f=0,t[e|0]=f;pU(a);fb=d+16|0}function Rfa(){var a=0,b=0,c=0;a=fb-16|0;fb=a;b=Qb(a,10226);v[23220]=0;Y(33,b|0);c=v[23220];v[23220]=0;if((c|0)!=1){ub(b);fb=a+16|0;return}a=P()|0;O()|0;ub(b);S(a|0);L()}
function gW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=jb[v[v[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Cl(a){a=a<<8&16711680|a<<24|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function zA(a,b){var c=0,d=0;c=fb-16|0;fb=c;b=ri(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){hc(b);fb=c+16|0}else{lm(a);a=a+4|0;v[b+4>>2]=a;continue}break}}function sE(a,b){var c=0,d=0;c=fb-16|0;fb=c;b=vk(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){hc(b);fb=c+16|0}else{rg(a);a=a+1|0;v[b+4>>2]=a;continue}break}}function it(a,b){var c=0,d=0;c=fb-16|0;fb=c;b=ri(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){hc(b);fb=c+16|0}else{tz(a);a=a+4|0;v[b+4>>2]=a;continue}break}}function fC(a,b){var c=0,d=0;c=fb-16|0;fb=c;b=Ci(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){hc(b);fb=c+16|0}else{eC(a);a=a+2|0;v[b+4>>2]=a;continue}break}}function eY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=v[c>>2];if(a>>>0>127|!(x[(a<<1)+79024>>1]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function K9(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Lb(v[a>>2],v[a+8>>2],16);a:{if(!d){cC(b);break a}Fu(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0;return d|0}function yt(a){var b=0,c=0,d=0,e=0;while(1){a:{if((b|0)==32){e=c;break a}d=w[a+b|0];if((d-1&255)>>>0<31|((c^1)&1?0:d)){break a}b=b+1|0;c=!d|c;continue}break}return e&1}function eo(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Lb(v[a>>2],v[a+8>>2],4);a:{if(!d){rS(b);break a}zh(c+8|0,b);md(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0;return d|0}function LH(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function wC(a,b,c){var d=0;d=fb-16|0;fb=d;b=wo(d,a+8|0,b);a=v[b>>2];while(1){if((a|0)!=v[b+4>>2]){Ai(a,x[c>>1]);a=v[b>>2]+2|0;v[b>>2]=a;continue}break}Ed(b);fb=d+16|0}function Jda(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;d=-1;a:{if(!fQ(a,c)){break a}d=0;if(!eQ(c)){break a}d=Ce(a,b,dQ(w[c+31|0],w[c+33|0]),ib)}fb=c+48|0;return d|0}function Gea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;rD(b,c);if(Lb(v[a>>2],v[a+8>>2],c<<3)){qD(d+8|0,v[b>>2],v[b+4>>2]);md(d,a,v[d+8>>2],v[d+12>>2])}fb=d+16|0}function wS(a,b,c){var d=0;d=fb-16|0;fb=d;b=Iv(d,a+8|0,b);a=v[b>>2];while(1){if((a|0)!=v[b+4>>2]){Hj(a,w[c|0]);a=v[b>>2]+1|0;v[b>>2]=a;continue}break}Ed(b);fb=d+16|0}function uA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;oS(b,c);if(Lb(v[a>>2],v[a+8>>2],c<<2)){nS(d+8|0,v[b>>2],v[b+4>>2]);md(d,a,v[d+8>>2],v[d+12>>2])}fb=d+16|0}function maa(a,b){a=a|0;b=b|0;a=mf(a);t[a+534|0]=0;v[a+4>>2]=0;v[23220]=0;R(728,a|0,b|0);b=v[23220];v[23220]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;$n(a);S(b|0);L()}function jfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Ib(a+8|0);v[23220]=0;U(234,a|0,b|0,c|0);a=v[23220];v[23220]=0;if((a|0)!=1){break a}a=P()|0;O()|0;$b(d);S(a|0);L()}}function VV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Eb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function Sj(a,b){var c=0,d=0,e=0;a:{c=Tk(a,b);if((c|0)==255){break a}if(Tj(v[a>>2])){break a}d=Hb(a+8|0,c);e=w[d|0]&223;t[d|0]=e;Ng(v[a>>2],v[a+4>>2],b,ct(c)|176,e)}}function K5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=dp(d,a);AJ(a,c);v[23220]=0;R(67,b|0,1);a=v[23220];v[23220]=0;if((a|0)==1){a=P()|0;O()|0;Wb(d);S(a|0);L()}}function mA(a,b){a=a|0;b=b|0;var c=0;if(y[a+4>>2]<y[Cb(a)>>2]){c=fb-16|0;fb=c;a=ri(c,a,1);Kp(v[a+4>>2],v[b>>2]);v[a+4>>2]=v[a+4>>2]+4;hc(a);fb=c+16|0;return}_z(a,b)}function l1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;ax(a,b,c);a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function hW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Eb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function c_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=jb[v[v[a+8>>2]+20>>2]](a+8|0)|0;b=pc(a);return Fj(g,h,c,d,e,f,b,b+(Bb(a)<<2)|0)|0}function bP(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=w[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function a0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a=Kw(Pa(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);fb=e+16|0;ib=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function HS(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;b=fc(b);a=oh(a,tc(32),ph(d+8|0,b));b=v[a>>2]+16|0;u[b>>1]=x[v[c>>2]>>1];Gb(b+4|0);e=fc(a),f=1,t[e+4|0]=f;fb=d+16|0}function iQ(a,b){var c=0,d=0;c=fb-16|0;fb=c;zh(c+8|0,b);b=v[c+12>>2];hd(c,a,v[c+8>>2],b);d=v[c+4>>2];if((b|0)==(d|0)){Zc(a,v[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function PG(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=Jf(b),d=v[v[a>>2]+52>>2],jb[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return Jf(b)}function jea(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Lb(v[b>>2],v[b+8>>2],5)){t[c|0]=0;Wh(a,5,c);break a}qu(c+8|0,a);md(c,b,v[c+8>>2],v[c+12>>2])}fb=c+16|0}function TI(a,b){var c=0,d=0;c=fb-16|0;fb=c;b=vk(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){hc(b);fb=c+16|0}else{a=a+1|0;v[b+4>>2]=a;continue}break}}function Je(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(c){a=v[fc(a)>>2];v[23220]=0;Y(a|0,c|0);a=v[23220];v[23220]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Tb();L()}function Dha(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Lb(v[b>>2],v[b+8>>2],6)){t[c|0]=0;Wh(a,6,c);break a}_A(c+8|0,a);md(c,b,v[c+8>>2],v[c+12>>2])}fb=c+16|0}function zaa(a,b){a=a|0;b=b|0;a=Ib(a);t[a+16|0]=0;v[a+12>>2]=b;v[23220]=0;Y(721,a|0);b=v[23220];v[23220]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;AO(a);S(b|0);L()}function uD(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;v[f+12>>2]=e;v[f+8>>2]=d;v[f+4>>2]=c;v[f>>2]=b;a=ng(a,f);v[a+8>>2]=0;b=a+12|0;a=f+8|0;ng(b,a);be(a);be(f);fb=f+16|0}function sI(a,b){var c=0,d=0;c=Wc(v[a+4>>2],v[a+8>>2]);b=v[a+16>>2]+b|0;if(c>>>0<b>>>0){d=a+4|0;a:{if(c){a=Ff(c);if(b>>>0<=a>>>0){break a}}a=tI(b,65536)}Ji(d,a)}}function rX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;v[d+12>>2]=v[c>>2];a=jb[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}fb=d+16|0;return a|0}function rB(a){var b=0,c=0;a:{c=zb(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=Xp(v[b>>2],v[a>>2])?b:a;continue}}return v[a>>2]}function pm(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Lb(v[b>>2],v[b+8>>2],4)){t[c|0]=0;Wh(a,4,c);break a}zh(c+8|0,a);md(c,b,v[c+8>>2],v[c+12>>2])}fb=c+16|0}function jia(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;Bm(c+8|0,b);b=v[c+12>>2];jc(c,v[a>>2],v[a+8>>2],v[c+8>>2],b);if((b|0)==v[c+4>>2]){Yb(a,v[c+12>>2])}fb=c+16|0}function Km(a,b){a=a|0;b=b|0;var c=0;if(!nf(w[b+11|0])){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return a|0}sD(a,v[b>>2],v[b+4>>2]);return a|0}function Gp(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function eP(a,b){var c=0;c=v[a+4>>2];a:{if((b|0)>=0){b=b+c|0;c=v[a>>2]+(b>>>3&536870908)|0;break a}b=b+c|0;c=v[a>>2]+((b-31|0)/32<<2)|0}v[a>>2]=c;v[a+4>>2]=b&31}function e9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=ui(b),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[uj(c+12|0,c+8|0,43984)>>2],v[d+36>>2]=e;kp(a);fb=c+16|0}function dM(a){var b=0,c=0,d=0;b=v[a+112>>2];if((b|0)>=11){c=378;while(1){if(c|d){cM(a);b=c;c=b-1|0;d=d-!b|0;continue}break}b=0}v[a+112>>2]=b+1;a=cM(a);return a}function _j(a,b){var c=0;c=fb-32|0;fb=c;v[c+24>>2]=0;zv(c+8|0,c+24|0);cn(c+16|0,a,v[c+8>>2],v[c+12>>2]);a=v[c+20>>2];v[b>>2]=v[c+24>>2];fb=c+32|0;return(a|0)==4}function ND(a,b,c,d){var e=0,f=0;e=-1;a:{if(!b){break a}f=a+b|0;b=a;while(1){if((b|0)==(f|0)){break a}if(Wp(c,d,w[b|0])){b=b+1|0;continue}break}e=b-a|0}return e}function Hi(a,b,c,d,e){a:{e=Es(e);if(e){v[23220]=0;fa(d|0,e|0,a|0,b|0,c|0)|0;a=v[23220];v[23220]=0;if((a|0)==1){break a}}return e}a=P()|0;O()|0;Fb(e);S(a|0);L()}function Bea(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-80|0;fb=d;c=-1;a:{if(!cU(a,d+8|0)){break a}c=0;if(!XQ(d+8|0)){break a}c=Ce(a,b,WQ(d+8|0),ib)}fb=d+80|0;return c|0}function jc(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;v[f+12>>2]=e;v[f+8>>2]=d;d=v[v[b>>2]+28>>2];e=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=e;jb[d|0](a,b,c,f);fb=f+16|0}function i_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=jb[v[v[a+8>>2]+20>>2]](a+8|0)|0;b=Ec(a);return Gj(g,h,c,d,e,f,b,Bb(a)+b|0)|0}function Tr(a){var b=0;a:{if((Le(a)|0)!=79){break a}if((Le(a)|0)!=103){break a}if((Le(a)|0)!=103){break a}b=(Le(a)|0)==83}if(!b){Zb(a,30);return 0}return DH(a)}function Ju(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Lb(v[b>>2],v[b+8>>2],2)){t[c|0]=0;dC(a,c);break a}kl(c+8|0,a);md(c,b,v[c+8>>2],v[c+12>>2])}fb=c+16|0}function x7(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;EK(b+8|0,a,0);c=v[b+12>>2];if(c){a=v[a+20>>2];v[a+148>>2]=-1;d=a+4|0;a=v[b+8>>2];iy(d,a,Hb(a,c))}fb=b+16|0}function jJ(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function aT(a,b){var c=0;c=Bia(b&65535,0,384,0);b=a&65535;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+ib|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;a=b>>>0<256?a+1|0:a;ib=a;return b}function aL(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(ve(a)){d=v[a>>2];t[c+15|0]=0;bd(b+d|0,c+15|0);Bd(a,b);break a}t[c+14|0]=0;bd(a+b|0,c+14|0);ae(a,b)}fb=c+16|0}function YB(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;v[c+12>>2]=-1;if(kg(a,c+8|0)){v[c+4>>2]=w[c+8|0];d=RB(a,b,v[Eb(c+4|0,c+12|0)>>2])}fb=c+16|0;return d|0}function Wl(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(D(a)<2147483648){return~~a}b=-2147483648}return b}function VU(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;v[c+12>>2]=-1;if(kg(a,c+8|0)){v[c+4>>2]=w[c+8|0];d=UB(a,b,v[Eb(c+4|0,c+12|0)>>2])}fb=c+16|0;return d|0}function Ld(a,b){var c=0,d=0,e=C(0);c=fb-16|0;fb=c;v[c+8>>2]=1065353216;z[c+12>>2]=b;d=c,e=tf(a),z[d+4>>2]=e;a=z[Mt(c+4|0,c+12|0,c+8|0)>>2];fb=c+16|0;return a}function CT(a){var b=0;if(!(Mb(a,17792,8)|w[a+8|0]>1|((w[a+9|0]-1&255)>>>0>7|(w[a+10|0]|w[a+11|0]<<8)>>>0>4096))){b=(w[a+12|0]|w[a+13|0]<<8)>>>0<4097}return b}function kk(a,b,c,d){var e=0,f=0;Gf(a+12|0,d);if(b){d=UD(b)}else{d=0}v[a>>2]=d;c=d+B(c,12)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=vc(a),f=d+B(b,12)|0,v[e>>2]=f;return a}function fD(a){var b=0;if(!(Mb(a,15471,4)|(w[a+4|0]-16&255)>>>0<249|((w[a+5|0]-16&255)>>>0<249|(w[a+6|0]-16&255)>>>0<249))){b=(w[a+7|0]-9&255)>>>0<7}return b}function Y_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function XA(a,b,c,d){var e=0,f=0;Gf(a+12|0,d);if(b){d=gC(b)}else{d=0}v[a>>2]=d;c=d+B(c,20)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=vc(a),f=d+B(b,20)|0,v[e>>2]=f;return a}function UJ(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function Gz(a){var b=0;a=de(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(D(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function pE(a,b,c,d){a=Ib(a);a:{if(b){v[23220]=0;R(d|0,a|0,b|0);d=v[23220];v[23220]=0;if((d|0)==1){break a}vo(a,b,c)}return a}b=P()|0;O()|0;$b(a);S(b|0);L()}function l2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((a|0)!=(b|0)){d=v[c>>2];v[d>>2]=v[a>>2];Oh(d+4|0,a+4|0);v[c>>2]=v[c>>2]+16;a=a+16|0;continue}break}}function eA(a){var b=0,c=0;b=fb-16|0;fb=b;a:{if(nf(w[a+11|0])){c=v[a>>2];t[b+15|0]=0;bd(c,b+15|0);Bd(a,0);break a}t[b+14|0]=0;bd(a,b+14|0);ae(a,0)}fb=b+16|0}function aR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;while(1){if((b|0)==(c|0)){fb=d+16|0}else{v[d+12>>2]=v[b>>2];mA(a,d+12|0);b=b+4|0;continue}break}}function Uca(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-48|0;fb=d;c=-1;a:{if(!fQ(a,d)){break a}c=0;if(!rP(d)){break a}c=Ce(a,b,qP(w[d+47|0]),ib)}fb=d+48|0;return c|0}function Mv(a,b,c,d){var e=0;e=aa(8)|0;v[23220]=0;a=Q(d|0,e|0,a|0)|0;d=v[23220];v[23220]=0;if((d|0)!=1){ia(a|0,c|0,b|0);L()}a=P()|0;O()|0;ba(e|0);S(a|0);L()}function $_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=t[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function vj(a,b,c,d){var e=0,f=0;Gf(a+12|0,d);if(b){d=NC(b)}else{d=0}v[a>>2]=d;c=d+(c<<1)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=vc(a),f=d+(b<<1)|0,v[e>>2]=f;return a}function tc(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=Fd(a);if(b){break a}b=v[117125];if(b){jb[b|0]();continue}break}ia(tn(aa(4)|0)|0,91480,25);L()}return b|0}function lM(){var a=0,b=0,c=0,d=0;a=fb-16|0;fb=a;b=a+8|0;while(1){if(c>>>0<32){c=c+48|0;d=my(92920);continue}break}v[b>>2]=d;Cn(b);fb=a+16|0;return v[b>>2]}function kt(a,b,c,d){var e=0,f=0;Gf(a+12|0,d);if(b){d=sP(b)}else{d=0}v[a>>2]=d;c=d+(c<<5)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=vc(a),f=d+(b<<5)|0,v[e>>2]=f;return a}function Wz(a,b,c){var d=0;d=fb-16|0;fb=d;v[d+8>>2]=a;c=c&65535;while(1){if(!(!Nb(a,b)|(c|0)==x[a>>1])){a=v[Oe(d+8|0)>>2];continue}break}fb=d+16|0;return a}function Vq(a,b,c,d){var e=0,f=0;Gf(a+12|0,d);if(b){d=pD(b)}else{d=0}v[a>>2]=d;c=d+(c<<3)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=vc(a),f=d+(b<<3)|0,v[e>>2]=f;return a}function Ms(a,b){var c=0,d=0,e=C(0);c=fb-16|0;fb=c;z[c+12>>2]=b;v[c+8>>2]=0;v[c+4>>2]=1065353216;d=a,e=z[Mt(c+12|0,c+8|0,c+4|0)>>2],z[d+144>>2]=e;fb=c+16|0}function CS(a,b,c,d){var e=0,f=0;Gf(a+12|0,d);if(b){d=xS(b)}else{d=0}v[a>>2]=d;c=d+B(c,6)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=vc(a),f=d+B(b,6)|0,v[e>>2]=f;return a}function Bv(a,b,c,d){var e=0,f=0;Gf(a+12|0,d);if(b){d=_D(b)}else{d=0}v[a>>2]=d;c=d+(c<<4)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=vc(a),f=d+(b<<4)|0,v[e>>2]=f;return a}function sB(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function ep(a,b){var c=0,d=0;a:{if(!a){break a}c=Bia(a,0,b,0);d=ib;if((a|b)>>>0<65536){break a}c=d?-1:c}a=Fd(c);if(!(!a|!(w[a-4|0]&3))){Sb(a,0,c)}return a}function eaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;if(Hm(a)>>>0<b>>>0){d=Cb(a);e=a;a=Vq(c+8|0,b,Dg(v[a>>2],v[a+4>>2]),d);vd(e,a);Uq(a)}fb=c+32|0}function eD(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=v[b>>2];d=(jb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0;a=v[b>>2];cc(c,d,(jb[v[v[a>>2]+24>>2]](a)|0)-v[b+8>>2]|0)}function aj(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;A[a>>3]=A[a>>3]-c;A[a+8>>3]=A[a+8>>3]-d}function Zh(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function WV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function R0(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=Oh(a,b);v[23220]=0;Q(51,a+12|0,c|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ub(a);S(b|0);L()}}function MD(a,b,c,d){var e=0;if(!d){return-1}b=a+b|0;e=-1;a:{while(1){if((a|0)==(b|0)){break a}b=b-1|0;if(!Wp(c,d,w[b|0])){continue}break}e=b-a|0}return e}function Ada(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;if(Bj(a)>>>0<b>>>0){d=Cb(a);e=a;a=kk(c+8|0,b,rd(v[a>>2],v[a+4>>2]),d);UP(e,a);TP(a)}fb=c+32|0}function vP(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;Cz(a+112|0,48e3);v[a+668>>2]=0;Bz(a+724|0);Bz(a+732|0);Bz(a+740|0);Rh(a+788|0)}function iW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function cH(a,b,c){var d=0;d=fb-32|0;fb=d;v[d+28>>2]=c;v[d+24>>2]=0;v[d+12>>2]=4;xr(d+16|0,a,d+24|0,v[Eb(d+28|0,d+12|0)>>2]);v[b>>2]=v[d+24>>2];fb=d+32|0}function _8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;if(Bj(a)>>>0<b>>>0){d=Cb(a);e=a;a=kk(c+8|0,b,rd(v[a>>2],v[a+4>>2]),d);er(e,a);xN(a)}fb=c+32|0}function Zm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;if(Uo(a)>>>0<b>>>0){d=Cb(a);e=a;a=wl(c+8|0,b,Wc(v[a>>2],v[a+4>>2]),d);vd(e,a);vl(a)}fb=c+32|0}function Z9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;if(Ry(a)>>>0<b>>>0){d=Cb(a);e=a;a=EN(c+8|0,b,Sy(v[a>>2],v[a+4>>2]),d);DN(e,a);CN(a)}fb=c+32|0}function Y8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;if(si(a)>>>0<b>>>0){d=Cb(a);e=a;a=cg(c+8|0,b,sc(v[a>>2],v[a+4>>2]),d);vd(e,a);bg(a)}fb=c+32|0}function Wj(a,b){var c=0,d=0,e=0;a=Ib(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Cb(b);d=Cb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function Uw(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(a*C(z[((c&3)<<2)+64880>>2]*C(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function UR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;if(wm(a)>>>0<b>>>0){d=Cb(a);e=a;a=vj(c+8|0,b,Ic(v[a>>2],v[a+4>>2]),d);vd(e,a);Di(a)}fb=c+32|0}function Oh(a,b){a=a|0;b=b|0;var c=0;if(!ve(b)){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return a|0}sD(a,v[b>>2],v[b+4>>2]);return a|0}function kE(a,b,c){a=Ib(a);a:{if(b){v[23220]=0;R(c|0,a|0,b|0);c=v[23220];v[23220]=0;if((c|0)==1){break a}sE(a,b)}return a}b=P()|0;O()|0;$b(a);S(b|0);L()}function jn(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=Fd(b)}return c}function Rg(a){var b=0,c=0;b=v[a>>2];c=v[b+4>>2];a:{if(!c){while(1){if(!nh(b)){b=v[b+8>>2];continue}break}b=v[b+8>>2];break a}b=QR(c)}v[a>>2]=b;return a}function Mb(a,b,c){var d=0,e=0;a:{while(1){d=w[a|0];e=w[b|0];if((d|0)!=(e|0)){break a}b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break}return 0}return d-e|0}function D5(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=Ny(C(C(C(C(y[v[a+16>>2]+24620>>2])/C(3))+C(-80))/C(15920)),C(0),C(1)),z[b+4272>>2]=c;VJ(a);UJ(a)}function rl(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;bc(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Bj(a);Fb(b)}}function l$(a,b){a=a|0;b=b|0;var c=0,d=0;b=pw(b);v[a+36>>2]=b;c=a,d=$g(b),v[c+44>>2]=d;c=a,d=$m(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Ar(5524);L()}}function hs(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-16|0;gs(b);continue}break}v[a+4>>2]=c;b=v[a>>2];fr(a);Fb(b)}}function hm(a,b){var c=0,d=0,e=0;aB(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Cb(b);d=Cb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function hD(a){a=a|0;var b=0;a=Gb(a);v[23220]=0;T(161,a+12|0)|0;b=v[23220];v[23220]=0;if((b|0)!=1){mf(a+32|0);return a|0}b=P()|0;O()|0;vb(a);S(b|0);L()}function h$(a,b){a=a|0;b=b|0;var c=0,d=0;b=uw(b);v[a+36>>2]=b;c=a,d=$g(b),v[c+44>>2]=d;c=a,d=$m(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Ar(5524);L()}}function fA(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-24|0;wb(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Ct(a);Fb(b)}}function YX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function Vc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(jb[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function MP(a,b){var c=0,d=0,e=0;lA(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Cb(b);d=Cb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function Ls(a,b,c){var d=0;a:{if(b&134218752){break a}if(!Qj(c)){break a}b=w[c+34|0];if((b+5&255)>>>0<6){break a}d=v[(B(b,160)+a|0)+906140>>2]}return d}function FQ(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-56|0;vt(b);continue}break}v[a+4>>2]=c;b=v[a>>2];EQ(a);Fb(b)}}function De(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;Pb(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Bj(a);Fb(b)}}function sn(a,b){v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Sb(a+32|0,0,40);WG(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function iT(a,b){var c=0;c=Bia(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+ib|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;a=b>>>0<11?a+1|0:a;ib=a;return b}function f3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-32|0;fb=h;i=h+8|0;nI(i,b,c,d,e,f,g);Mc(a,h+20|0);Rl(i);fb=h+32|0}function FS(a,b,c){var d=0;d=fb-32|0;fb=d;v[d+28>>2]=c;t[d+24|0]=0;v[d+12>>2]=1;xr(d+16|0,a,d+24|0,v[Eb(d+28|0,d+12|0)>>2]);t[b|0]=w[d+24|0];fb=d+32|0}function gN(a,b,c){var d=0,e=0;v[b+56>>2]=0;d=b,e=Gn(a,x[b+70>>1],v[b+48>>2],c,0),u[d+68>>1]=e;if(!(!(w[a+480180|0]&5)|v[b+60>>2]==-1)){v[b+60>>2]=0}}function dv(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Lb(v[b>>2],v[b+8>>2],3)){t[c|0]=0;Wh(a,3,c);break a}cv(c+8|0,a);md(c,b,v[c+8>>2],v[c+12>>2])}fb=c+16|0}function nea(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-96|0;fb=d;c=-1;a:{if(!OQ(a,d)){break a}c=0;if(!NQ(d)){break a}c=Ce(a,b,MQ(d),ib)}fb=d+96|0;return c|0}function bfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Ah(178956970)>>>0<b>>>0){od();L()}c=B(b,24);b=tc(c);v[a>>2]=b;v[a+4>>2]=b;d=Cb(a),e=b+c|0,v[d>>2]=e}function _u(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function Xca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Ah(119304647)>>>0<b>>>0){od();L()}c=B(b,36);b=tc(c);v[a>>2]=b;v[a+4>>2]=b;d=Cb(a),e=b+c|0,v[d>>2]=e}function Qda(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-96|0;fb=d;c=-1;a:{if(!OQ(a,d)){break a}c=0;if(!rQ(d)){break a}c=Ce(a,b,qQ(d),ib)}fb=d+96|0;return c|0}function QX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=t[b|0];t[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function Lf(a){var b=0,c=0;b=fb-16|0;fb=b;a:{if(ve(a)){c=v[a>>2];t[b+15|0]=0;bd(c,b+15|0);Bd(a,0);break a}t[b+14|0]=0;bd(a,b+14|0);ae(a,0)}fb=b+16|0}function xN(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;Pb(b);continue}break}c=v[a>>2];if(c){Jo(a);Fb(c)}}function wv(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;bc(b);continue}break}c=v[a>>2];if(c){Jo(a);Fb(c)}}function iz(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;v[a+8>>2]=b;Uk(b);continue}break}c=v[a>>2];if(c){Jo(a);Fb(c)}}function hv(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;v[a+8>>2]=b;Rq(b);continue}break}c=v[a>>2];if(c){vc(a);Fb(c)}}function hU(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;v[a+8>>2]=b;Id(b);continue}break}c=v[a>>2];if(c){vc(a);Fb(c)}}function cL(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;v[a+8>>2]=b;Mk(b);continue}break}c=v[a>>2];if(c){vc(a);Fb(c)}}function aia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Ah(715827882)>>>0<b>>>0){od();L()}c=B(b,6);b=tc(c);v[a>>2]=b;v[a+4>>2]=b;d=Cb(a),e=b+c|0,v[d>>2]=e}function aK(a){var b=0;b=y[v[a+16>>2]+24620>>2]/(kj(C(z[a+4208>>2]*C(999)))+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;uc(a+4224|0,b)}function Xt(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;v[a+8>>2]=b;wb(b);continue}break}c=v[a>>2];if(c){vc(a);Fb(c)}}function TL(a){if(w[a+480224|0]==2){return+y[a+1074420>>2]/1e4}return+y[a+24620>>2]/(+y[a+1074404>>2]*+(B(v[a+1074408>>2],v[a+1074416>>2])>>>0))*60}function JJ(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=mJ(tc(12));v[c+8>>2]=b;v[c+4>>2]=a;v[c>>2]=49132;a=v[uf(d+8|0,c)>>2];fb=d+16|0;return a|0}function DQ(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;v[a+8>>2]=b;vt(b);continue}break}c=v[a>>2];if(c){vc(a);Fb(c)}}function AX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Eg(a,v[b+8>>2],f)){Wv(b,c,d,e);return}a=v[a+8>>2];jb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function t$(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;jb[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);continue}break}}function jO(a){var b=0,c=0,d=0;d=w[a+26|0];b=d+27|0;while(1){if((c|0)==(d|0)){a=b&65535}else{b=w[(a+c|0)+27|0]+b|0;c=c+1|0;continue}break}return a}function ez(a,b,c){var d=0,e=0,f=0;d=Tk(a,b);if((d|0)!=255){e=ac(a+26|0,d),f=c,u[e>>1]=f;a=a+62|0;e=Hb(a,b),f=255,t[e|0]=f;e=Hb(a,c),f=d,t[e|0]=f}}function WE(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function Qx(a,b,c,d){var e=0;e=fb-16|0;fb=e;a=gq(e,a,d);c=c-b|0;if((c|0)>0){nc(v[a+4>>2],b,c);v[a+4>>2]=v[a+4>>2]+B((c>>>0)/6|0,6)}hc(a);fb=e+16|0}function GT(a){t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function Dia(a,b,c){var d=0;d=b>>31;a=a^d;zia(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);ib=hb;a=d^gb;b=a-d|0;ib=(d^ib)-((a>>>0<d>>>0)+d|0)|0;return b}function d4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-32|0;fb=h;i=h+8|0;nI(i,b,c,d,e,f,g);Mc(a,i);Rl(i);fb=h+32|0}function ZB(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0}function Z5(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);if(b>>>0<=1){c=Ld(c,C(0));if((b|0)==1){d=1;c=Nh(c)}e=zb(a+4208|0,d),f=c,z[e>>2]=f;aK(a)}}function sw(a){var b=0,c=0;b=fb-16|0;fb=b;c=-1;a:{if(Ew(a)){break a}if((jb[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}fb=b+16|0;return c}function e7(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;if(si(a)>>>0<=12){c=Cb(a);d=a;a=cg(b+8|0,13,sc(v[a>>2],v[a+4>>2]),c);vd(d,a);bg(a)}fb=b+32|0}function cfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Ah(1073741823)>>>0<b>>>0){od();L()}c=KC(b);v[a>>2]=c;v[a+4>>2]=c;d=Cb(a),e=(b<<2)+c|0,v[d>>2]=e}function bp(a,b){var c=0;a:{if(!LH(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function WG(a){var b=0,c=0;v[23220]=0;c=ha(1070)|0;b=v[23220];v[23220]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;Cm(a);return}V(0)|0;O()|0;Tb();L()}function UK(a){var b=0;b=fb-16|0;fb=b;z[b+12>>2]=D(a);v[b+8>>2]=646978941;v[b+4>>2]=1259902592;a=z[Mt(b+12|0,b+8|0,b+4|0)>>2];fb=b+16|0;return a}function If(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;u[c+24>>1]=0;lk(c+8|0,c+24|0);cn(c+16|0,a,v[c+8>>2],v[c+12>>2]);u[b>>1]=x[c+24>>1];fb=c+32|0}function oo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Ah(1073741823)>>>0<b>>>0){od();L()}c=pi(b);v[a>>2]=c;v[a+4>>2]=c;d=Cb(a),e=(b<<2)+c|0,v[d>>2]=e}function eV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Ah(214748364)>>>0<b>>>0){od();L()}c=gC(b);v[a>>2]=c;v[a+4>>2]=c;d=Cb(a),e=B(b,20)+c|0,v[d>>2]=e}function dk(a,b,c,d){var e=0;e=B(b,c);a:{if(v[d+76>>2]<0){a=xu(a,e,d);break a}a=xu(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function Zi(a,b,c){if(a>>>0<b>>>0){nc(a,b,c);return}if(c){a=a+c|0;b=b+c|0;while(1){a=a-1|0;b=b-1|0;t[a|0]=w[b|0];c=c-1|0;if(c){continue}break}}}function Y0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Ah(357913941)>>>0<b>>>0){od();L()}c=UD(b);v[a>>2]=c;v[a+4>>2]=c;d=Cb(a),e=B(b,12)+c|0,v[d>>2]=e}function VP(a){a=a|0;var b=0,c=0;u[a+34>>1]=0;b=fb-16|0;fb=b;t[b+15|0]=0;c=a+43|0;Jl(c,c+22|0,b+15|0);fb=b+16|0;v[a+20>>2]=0;kd(a,0);return a|0}function Tz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Ah(2147483647)>>>0<b>>>0){od();L()}c=NC(b);v[a>>2]=c;v[a+4>>2]=c;d=Cb(a),e=(b<<1)+c|0,v[d>>2]=e}function $M(a,b){t[a+840|0]=b;t[a+812|0]=b;t[a+811|0]=b;t[a+809|0]=b;t[a+807|0]=b;t[a+806|0]=b;t[a+833|0]=b;t[a+826|0]=b>>>4;t[a+827|0]=b<<2&60}function tH(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];if(!w[a+23|0]){v[(c<<2)+g>>2]=b;return}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;v[f+g>>2]=c}function nQ(a,b,c,d){var e=0;e=c&4;a:{b:{if(!(e|(b&255)!=4)){if(c&2){break b}Uc(a,8,1,0,10);return}b=16;if(e){break a}}b=8}Uc(a,b,c&2|1,0,d^1)}function j5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){nx(a,0,0,0,0,0,0,c,d);return}nx(a,v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2],v[b+24>>2],b,c,d)}function cj(a){var b=0,c=0;b=fb-16|0;fb=b;xb(b+8|0,a+1074312|0,7);if(yb(v[v[b+8>>2]>>2],v[b+12>>2])){c=em(v[a+480180>>2])^1}fb=b+16|0;return c}function YN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Ah(536870911)>>>0<b>>>0){od();L()}c=pD(b);v[a>>2]=c;v[a+4>>2]=c;d=Cb(a),e=(b<<3)+c|0,v[d>>2]=e}function Wy(a){var b=0,c=0;b=fb-16|0;fb=b;v[b+8>>2]=a;c=b+8|0;a=1;while(1){if((a|0)>0){Rg(c);a=a-1|0;continue}break}fb=b+16|0;return v[b+8>>2]}function WN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Ah(268435455)>>>0<b>>>0){od();L()}c=_D(b);v[a>>2]=c;v[a+4>>2]=c;d=Cb(a),e=(b<<4)+c|0,v[d>>2]=e}function Om(a,b){var c=0,d=0;d=v[a+4>>2];c=v[a+8>>2];while(1){if((c|0)!=(d|0)){c=c-b|0;v[a+8>>2]=c;continue}break}b=v[a>>2];if(b){vc(a);Fb(b)}}function OS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Ah(715827882)>>>0<b>>>0){od();L()}c=xS(b);v[a>>2]=c;v[a+4>>2]=c;d=Cb(a),e=B(b,6)+c|0,v[d>>2]=e}function OR(a){var b=0;if(!(Mb(a,14991,3)|(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))-2147483647>>>0<2147484072)){b=w[a+3|0]<6}return b}function Jea(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=mg(b);mg(b);break a}a=Ag(b);Ag(b)}while(1){if(a){if(a&1){Yb(b,260)}a=a>>>1|0;continue}break}}function vU(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;v[c+12>>2]=-1;if(kg(a,c+8|0)){v[c+4>>2]=w[c+8|0];qU(a,b,v[Eb(c+4|0,c+12|0)>>2])}fb=c+16|0}function uP(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){Jo(a);Fb(b)}}function bE(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-16|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){Jo(a);Fb(b)}}function _U(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;v[c+12>>2]=-1;if(kg(a,c+8|0)){v[c+4>>2]=w[c+8|0];WB(a,b,v[Eb(c+4|0,c+12|0)>>2])}fb=c+16|0}function Zs(a,b){var c=0,d=0;d=lf(a,b);while(1){a:{c=d;if(!(c&65535)){c=0;break a}d=c-1|0;if(!ke(a,b,d&65535)){continue}}break}return c&65535}function Yh(a){var b=0;a=a*a;b=a*a;return C(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function TP(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){Jo(a);Fb(b)}}function Am(a,b){var c=0;a=Em(a);v[a>>2]=61436;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function mB(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;u[c+14>>1]=1;d=c,e=al(a,b),u[d+12>>1]=e;a=x[Re(c+14|0,c+12|0)>>1];fb=c+16|0;return a-1&65535}function d3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=g+8|0;oI(h,b,c,d,e,f);Mc(a,g+20|0);Rl(h);fb=g+32|0}function bz(a,b,c){var d=0;while(1){if((b|0)!=(c|0)){d=v[a>>2];v[a>>2]=d<<8^v[((w[b|0]^d>>>24)<<2)+29196>>2];b=b+1|0;continue}break}return a}function ro(a,b){var c=0;a:{if(!b){break a}if(!Lb(v[a>>2],v[a+8>>2],b)){break a}if(b>>>0<=3){c=FC(a,b);break a}c=mg(a);Yb(a,b-4|0)}return c}function Ou(a,b){var c=0;a:{if(!b){break a}if(!Lb(v[a>>2],v[a+8>>2],b)){break a}if(b>>>0<=1){c=EC(a,1);break a}c=Ag(a);Yb(a,b-2|0)}return c}function Nha(a){a=a|0;var b=0,c=0,d=0;if(Ah(1073741823)>>>0<=8191){od();L()}b=tc(32768);v[a>>2]=b;v[a+4>>2]=b;c=Cb(a),d=b+32768|0,v[c>>2]=d}function Kb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;if(b>>>0>=117){So(12116);L()}e=d+8|0;xb(e,a,b);sg(e,c);fb=d+16|0;return a|0}function Be(a,b,c){t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a}function B9(a,b){a=a|0;b=b|0;a=By(a);v[23220]=0;R(776,a|0,b|0);b=v[23220];v[23220]=0;if((b|0)==1){b=P()|0;O()|0;vp(a);S(b|0);L()}return a|0}function hY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=fb-16|0;fb=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=Eb(a+12|0,a+8|0);fb=a+16|0;return v[b>>2]}function _E(a,b,c,d,e){var f=0;f=c;c=0;a:{if(!d){break a}c=b>>8;if(!(b&1)){break a}c=Tv(v[d>>2],c)}jb[v[v[a>>2]+28>>2]](a,f,c+d|0,b&2?e:2)}function Ok(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;c=v[a+24>>2];d=v[a+40>>2];v[b+12>>2]=1;a=v[Sc(a+20|0,b+12|0)>>2];fb=b+16|0;return B(a,c+d|0)}function um(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[Rb(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;fb=d+16|0}function tm(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[Rb(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;fb=d+16|0}function pg(a,b){var c=0,d=0,e=0;c=Ec(a);a=Bb(a);e=Cf(b);d=0;a:{if(!e){break a}a=a+c|0;b=TD(c,a,b,b+e|0);d=(a|0)==(b|0)?-1:b-c|0}return d}function WY(a){a=a|0;var b=0,c=0,d=0;if(Ah(1073741823)>>>0<=29){od();L()}b=oF(aw(a),30);v[a>>2]=b;v[a+4>>2]=b;c=Cb(a),d=b+120|0,v[c>>2]=d}function Rc(a){var b=0;b=fb-16|0;fb=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[b+4>>2]=32767;a=u[Ke(b+8|0,nd(b+12|0,b+4|0))>>1];fb=b+16|0;return a}function Nz(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=Cb(b),d=0,v[c>>2]=d;return a}function Lz(a){a=50-(B(w[(a>>>4|0)+31536|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Dc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function AT(a,b,c,d){var e=0;b=a+b|0;e=-1;a:{while(1){if((a|0)==(b|0)){break a}b=b-1|0;if(Wp(c,d,w[b|0])){continue}break}e=b-a|0}return e}function zT(a){var b=0,c=0,d=0;c=fb-16|0;fb=c;b=c+8|0;dv(b,a);a=w[Hb(b,0)|0];d=w[Hb(b,1)|0];b=w[Hb(b,2)|0];fb=c+16|0;return a|d<<8|b<<16}function xE(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=v[a>>2];if(d>>>0<=127){d=v[(d<<2)+c>>2]}v[a>>2]=d;a=a+4|0;continue}break}return b}function w7(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=v[a+20>>2];ge(b,v[c+4>>2],v[c+8>>2]);DK(a,cc(b+8|0,v[b>>2],v[b+4>>2]),0);fb=b+16|0}function U9(a){a=a|0;var b=0;b=v[a>>2];if(jb[v[v[b>>2]+32>>2]](b,0,32)|0){a=v[a>>2];a=jb[v[v[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function Nj(a){var b=0,c=0;b=xm(v[v[a+20>>2]+28>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[(v[a+16>>2]+B(b,160)|0)+906300>>2]}return c}function Fw(a,b){var c=0;if(b>>>0<=99){return aH(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return Or($G(c,a),B(a,-100)+b|0)}return Vi(a,b)}function dA(a){var b=0;b=Jb(w[a+26|0]|w[a+27|0]<<8);return((w[a+24|0]>15)+(w[a+25|0]>64)|0)+(Jb(w[a+22|0]|w[a+23|0]<<8)<<1>>>0<b>>>0)|0}function b4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=g+8|0;oI(h,b,c,d,e,f);Mc(a,h);Rl(h);fb=g+32|0}function _$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+7&-8;v[c>>2]=b+16;d=a,e=Ww(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}function Zc(a,b){var c=0,d=0,e=0;c=Sf(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=jb[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function Hq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((b|0)<0){uz();L()}b=(b-1>>>5|0)+1|0;c=KC(b);v[a+4>>2]=0;v[a>>2]=c;d=Cb(a),e=b,v[d>>2]=e}function vl(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;v[a+8>>2]=b;continue}break}a=v[a>>2];if(a){Fb(a)}}function Sr(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function rE(a,b,c,d){a=Ib(a);v[23220]=0;U(d|0,a|0,b|0,c|0);b=v[23220];v[23220]=0;if((b|0)!=1){return a}b=P()|0;O()|0;lc(a);S(b|0);L()}function p7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Oc(c&255))){FK(a,8,C(0))}a=Nj(a);if(a){jb[v[v[a>>2]+92>>2]](a,b,c,d,e)}}function PD(a){a=a|0;var b=0;a=Gb(a);v[23220]=0;Q(123,a|0,13633)|0;b=v[23220];v[23220]=0;if((b|0)==1){b=P()|0;O()|0;vb(a);S(b|0);L()}}function P0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=px(v[a+32>>2],b,c,d,2);if(a>>>0<=15){a=w[a+43888|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function wi(a,b,c){t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24;t[a+4|0]=c;t[a+5|0]=c>>>8;t[a+6|0]=c>>>16;t[a+7|0]=c>>>24}function wE(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=t[a|0];if((d|0)>=0){d=v[(d<<2)+c>>2]}t[a|0]=d;a=a+1|0;continue}break}return b}function Yn(a){var b=0;a=de(a);b=255;a:{if(a>=255){break a}b=0;if(a<=0){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b}function Li(a,b){var c=0;if(ve(a)){c=v[a>>2];hl(a);Fb(c)}c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];ae(b,0);td(b,0)}function DR(a){var b=0;b=fb-16|0;fb=b;v[b+12>>2]=a;v[b+8>>2]=-128;v[b+4>>2]=127;a=t[Ke(b+8|0,nd(b+12|0,b+4|0))|0];fb=b+16|0;return a}function zw(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return jb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return Jf(t[b|0])|0}function zf(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if(b>>>0>=117){So(12081);L()}d=c+8|0;xb(d,a,b);sg(d,0);fb=c+16|0;return a|0}function o6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;if(b>>>0<=4){c=Ld(c,C(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=Nh(c)}z[d>>2]=c;cK(a)}}function Y9(a,b){a=a|0;b=b|0;a=pu(a,b);if(!a){t[b+6|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0}return a|0}function Qr(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function Jh(a,b){var c=0,d=0;c=v[a>>2];d=v[a+4>>2];b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[Gc(c,d,(b>>31&a)+b|0)>>2]}function sH(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}ca(14201,13164,1180,5695);L()}if((b|0)==255){return 0}a=b>>>0>10}return a}function jl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Ah(-1)>>>0<b>>>0){od();L()}c=tc(b);v[a>>2]=c;v[a+4>>2]=c;d=Cb(a),e=b+c|0,v[d>>2]=e}function V$(a){a=a|0;var b=0;if((jb[v[v[a>>2]+36>>2]](a)|0)!=-1){b=a;a=v[a+12>>2];v[b+12>>2]=a+1;a=Jf(t[a|0])}else{a=-1}return a|0}function vi(a){var b=0;b=fb-16|0;fb=b;v[b+12>>2]=a;v[b+8>>2]=0;v[b+4>>2]=255;a=w[Ke(b+8|0,nd(b+12|0,b+4|0))|0];fb=b+16|0;return a}function E9(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if(b>>>0>=250){So(12116);L()}d=c+8|0;xb(d,a,b);dm(d);fb=c+16|0;return a|0}function CC(a,b){var c=0;c=Bia(b&255,0,1536,0);b=ib;a=Bia(a&255,0,25,0);c=a+c|0;b=ib+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;ib=b;return a}function uE(a,b,c){var d=0;d=fb-16|0;fb=d;v[d+8>>2]=a;v[d+12>>2]=b;v[d>>2]=c;v[d+4>>2]=0;a=Gq(d+8|0,d);fb=d+16|0;return v[a>>2]}function tV(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;b=v[v[b>>2]-12>>2]+b|0;if(Ch(b)){b=v[b+72>>2];if(b){Yu(b)}t[a|0]=1}return a|0}function fN(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(w[a+480180|0]&2){break a}}v[b+56>>2]=0;d=Gn(a,x[b+70>>1],v[b+48>>2],c,0)}return d}function be(a){var b=0;a=v[a+4>>2];if(a){if(Gm(a)){a:{b=a+8|0;if(v[b>>2]){if((kv(b)|0)!=-1){break a}}jb[v[v[a>>2]+16>>2]](a)}}}}function _X(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function Zy(a,b){var c=0;c=v[a+484360>>2];b=b&255;if(gj(c,v[a+484364>>2])>>>0<=b>>>0){return Vb(c,w[a+484376|0])}return nj(c,b)}function Tp(a,b){var c=0;c=xd(v[a+4>>2],w[a+11|0]);if((c|0)==(xd(v[b+4>>2],w[b+11|0])|0)){a=Ml(qd(a),qd(b),c)}else{a=1}return!a}function S$(a){a=a|0;var b=0;if((jb[v[v[a>>2]+36>>2]](a)|0)!=-1){b=a;a=v[a+12>>2];v[b+12>>2]=a+4;a=v[a>>2]}else{a=-1}return a|0}function Qw(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}nc(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function KF(a,b,c,d,e,f){a=jb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=vr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function HF(a,b,c,d,e,f){a=jb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=tr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function us(a){var b=0;b=A[a+4248>>3]/+y[v[a+16>>2]+24620>>2];A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*(A[a+4288>>3]/60)}}function sO(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){Bd(b,a)}if(c){Bd(c,a)}if(d){Bd(d,a)}if(e){Bd(e,a)}}function kY(a){a=a|0;var b=0;b=fb-16|0;fb=b;_h($h(b+8|0,v[a+8>>2]));fb=b+16|0;a=v[a+8>>2];if(!a){return 1}return(hF(a)|0)==1|0}function hJ(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=QI(tc(8));v[c+4>>2]=a;v[c>>2]=56968;a=v[uf(b+8|0,c)>>2];fb=b+16|0;return a|0}function eE(a,b,c){a=Nh(a);a:{if(a>=b){break a}c=0;if(a<=C(0)){break a}if(a<C(4294967296)&a>=C(0)){c=~~a>>>0;break a}}return c}function bq(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function XB(a,b){var c=0;c=v[b+4>>2];if(c){ec(a,c,v[b>>2]);return}c=v[b+8>>2];b=v[b+12>>2];if(!rc(c,b)){ge(a,c,b);return}Xd(a)}function SX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function RD(){var a=0,b=0,c=0;a=fb-16|0;fb=a;b=Qb(a,14944);if(Bb(b)){c=(pg(b,13838)|0)!=-1}else{c=0}ub(b);fb=a+16|0;return c|0}function yq(a,b){return Xp(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24),w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))?b:a}function yX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Eg(a,v[b+8>>2],0)){Uv(b,c,d);return}a=v[a+8>>2];jb[v[v[a>>2]+28>>2]](a,b,c,d)}function fS(a,b){var c=0;c=fb-16|0;fb=c;a=ri(c,a,1);Zn(v[a+4>>2],x[b>>1]|x[b+2>>1]<<16);v[a+4>>2]=v[a+4>>2]+4;hc(a);fb=c+16|0}function Yk(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(jb[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function Xv(a,b){var c=0,d=0,e=0,f=0;c=Cf(b);d=tc(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=nc(vc(d),b,c+1|0),v[e>>2]=f}function tN(a){Gy(a);v[a>>2]=0;v[a+4>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;a=eg(a);eg(a+12|0);t[a+24|0]=1}function rT(a){var b=0;a:{if(Mb(a,3863,4)){break a}if(Mb(a+44|0,17784,3)){break a}b=(w[a+47|0]|w[a+48|0]<<8)>>>0>97}return b}function Zf(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return Nn(a,d)}function VR(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;u[c+14>>1]=b;if((al(v[a>>2],v[a+4>>2])|0)!=65535){LB(a,c+14|0)}fb=c+16|0}function Lk(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;Tx(a,c,d)}function LF(a,b,c,d,e,f){a=jb[v[v[a+8>>2]>>2]](a+8|0)|0;a=vr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function IF(a,b,c,d,e,f){a=jb[v[v[a+8>>2]>>2]](a+8|0)|0;a=tr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function qc(a,b){var c=0;a=Fl(a);v[a+4>>2]=0;v[a>>2]=49232;c=Fd(Bb(b)+1|0);v[a+4>>2]=c;if(c){nc(c,Ec(b),Bb(b)+1|0)}return a}function hQ(a,b){var c=0;c=fb-16|0;fb=c;RQ(c+8|0,a);re(c,b);a=Hc(v[c+8>>2],v[c+12>>2],v[c>>2],v[c+4>>2]);fb=c+16|0;return a}function _J(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=lc(b-24|0);if((c|0)!=(b|0)){continue}break}return sf(a)|0}function wL(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function fE(a,b){v[a>>2]=b;WG(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function cQ(a){var b=0,c=0;while(1){b=c;if((b|0)!=8){c=b+1|0;if((w[a+b|0]-127&255)>>>0>160){continue}}break}return(b|0)==8}function Sz(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function P7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if(b>>>0<=3){d=(a+b|0)+4264|0,e=Og(C(Ld(c,C(0))*C(255))),t[d|0]=e;ws(a)}}function $6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if(b>>>0<=2){d=(a+b|0)+4232|0,e=Og(C(Ld(c,C(0))*C(127))),t[d|0]=e;ts(a)}}function xo(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}v[a>>2]=b}}function ee(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}v[a>>2]=b}}function W0(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((a|0)!=(b|0)){Ix(v[c>>2],a);v[c>>2]=v[c>>2]+12;a=a+12|0;continue}break}}function MG(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return jb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function KO(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){HO(a,1);HO(a,0)}}function JO(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){IO(a,1);IO(a,0)}}function Fg(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;v[f+12>>2]=e;c=$h(f+8|0,c);a=wr(a,b,d,v[f+12>>2]);_h(c);fb=f+16|0;return a}function FX(a,b,c){a=a|0;b=b|0;c=c|0;a:{if((c|0)>=257){aF();b=92864;break a}if(!w[468496]){t[468496]=1}b=92860}cc(a,c,b)}function CP(a){var b=0;if(!(w[a+35|0]&2)){a=a+68|0;b=9;while(1){if(b){v[a>>2]=268435456;b=b-1|0;a=a+4|0;continue}break}}}function BR(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Sf(a,4)){rS(b);break a}zh(c+8|0,b);cA(c,a,v[c+8>>2],v[c+12>>2])}fb=c+16|0}function mi(a,b,c){c=w[c|0];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=w[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function eX(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return jb[a|0](h|b,c,d,e,b|f,g)|0}function at(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function XQ(a){var b=0;if(!(Mb(a,13790,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64))){b=(w[a+33|0]-1&255)>>>0<32}return b}function WM(a,b,c,d){var e=0,f=0;if(c&255){e=a,f=Ub(v[a>>2]+((B((d^-1|-256)+b|0,c<<24>>24)|0)/2|0)|0,0,256),v[e>>2]=f}}function Le(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function yi(a){var b=0;while(1){a:{if((b|0)!=46){if(w[b+43920|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function QF(a,b,c){var d=0;d=fb-16|0;fb=d;v[d+12>>2]=c;b=$h(d+8|0,b);a=nG(a,9233,v[d+12>>2]);_h(b);fb=d+16|0;return a}function y5(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=3){c=Ld(c,C(0));d=zb(a+4208|0,b),e=c,z[d>>2]=e;TJ(a)}}function wg(a){var b=0;am(a);b=nt(v[a>>2],ik(x[a+34>>1]));v[a+20>>2]=b;if(!b){return 0}return sj(v[a>>2],x[a+34>>1])}function w6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=4){c=Ld(c,C(0));d=zb(a+4208|0,b),e=c,z[d>>2]=e;eK(a)}}function oU(a){var b=0,c=0;c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;Id(b);continue}break}v[a+4>>2]=c}function a8(a){a=a|0;var b=0;b=fb-16|0;fb=b;if(!cd(a,4)){Qv(a)}a=v[dc(b+8|0,Ab(v[a+44>>2]))>>2];fb=b+16|0;return a|0}function _7(a){a=a|0;var b=0;b=fb-16|0;fb=b;if(!cd(a,4)){Qv(a)}a=v[dc(b+8|0,Ab(v[a+48>>2]))>>2];fb=b+16|0;return a|0}function V_(a){a=a|0;var b=0,c=0;c=v[a+4>>2];b=v[a>>2];a=v[a+8>>2];b=b+(a>>1)|0;if(a&1){c=v[c+v[b>>2]>>2]}jb[c|0](b)}function SO(a){v[a+700>>2]=0;u[a+842>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function G5(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=2){c=Ld(c,C(0));d=zb(a+4208|0,b),e=c,z[d>>2]=e;VJ(a)}}function Fo(a){var b=0,c=0;c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;Rq(b);continue}break}v[a+4>>2]=c}function D6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=5){c=Ld(c,C(0));d=zb(a+4208|0,b),e=c,z[d>>2]=e;jK(a)}}function ui(a){var b=0;b=fb-16|0;fb=b;v[b+12>>2]=a;v[b+8>>2]=2147483647;a=v[Eb(b+12|0,b+8|0)>>2];fb=b+16|0;return a}function sG(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function lA(a){var b=0,c=0,d=0;if(v[a>>2]){Bc(a);b=v[a>>2];si(a);Fb(b);c=Cb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function jL(a){var b=0,c=0,d=0;if(v[a>>2]){Bc(a);b=v[a>>2];bu(a);Fb(b);c=Cb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function LN(a){var b=0,c=0,d=0;if(v[a>>2]){Bc(a);b=v[a>>2];Hm(a);Fb(b);c=Cb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function FO(a){var b=0,c=0,d=0;if(v[a>>2]){Bc(a);b=v[a>>2];wm(a);Fb(b);c=Cb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function Ah(a){var b=0;b=fb-16|0;fb=b;v[b+12>>2]=a;v[b+8>>2]=2147483647;a=Eb(b+12|0,b+8|0);fb=b+16|0;return v[a>>2]}function vd(a,b){var c=0;c=b+4|0;Ip(v[a>>2],v[a+4>>2],c);kc(a,c);kc(a+4|0,b+8|0);kc(Cb(a),vc(b));v[b>>2]=v[b+4>>2]}function rU(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function rQ(a){var b=0;if(!(Mb(a+44|0,13799,4)|w[a+29|0]!=16)){b=((w[a+42|0]|w[a+43|0]<<8)-1&65535)>>>0<2}return b}function qH(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+((c+c)*d+(c*c-e))}function nc(a,b,c){var d=0;if(c){d=a;while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function ur(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}kc(a,b);a=a+4|0;continue}}}function ul(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}Wg(a,b);a=a+1|0;continue}}}function dN(a,b){var c=0;c=b&15;if(c){t[a+827|0]=c<<2}b=b&240;if(b){t[a+826|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function dK(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function Nk(a,b){var c=0;c=b&15;if(c){t[a+824|0]=c<<2}b=b&240;if(b){t[a+823|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function JG(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!rc(PG(c,b),-1)){break a}v[a>>2]=0}return a|0}function u2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=jb[v[v[b>>2]+8>>2]](b)|0;d=c,e=Uf(a?a:21598),v[d>>2]=e}}function pP(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;v[a+8>>2]=b;continue}break}}function NP(a){if(Mb(a,13772,4)){a=0}else{a=(_b(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))|0)==1}return a}function rm(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function r$(a,b){a=a|0;b=b|0;var c=0,d=0;jb[v[v[a>>2]+24>>2]](a)|0;b=pw(b);v[a+36>>2]=b;c=a,d=$m(b),t[c+44|0]=d}function o$(a,b){a=a|0;b=b|0;var c=0,d=0;jb[v[v[a>>2]+24>>2]](a)|0;b=uw(b);v[a+36>>2]=b;c=a,d=$m(b),t[c+44|0]=d}function ew(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(v[a>>2]!=(c|0)){break a}}else{a=b}return a}a=a+4|0;continue}}function Us(a,b){var c=0;c=1;a:{switch((b&255)-4|0){default:c=(a&255)==11;break;case 0:case 2:break a}}return c}function Si(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function vE(a,b){var c=0,d=0;c=a+68|0;a=0;while(1){if((a|0)!=9){d=zb(c,a);a=a+1|0;v[d>>2]=a<<b;continue}break}}function sg(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function fu(a){var b=0;b=fb-16|0;fb=b;v[b+12>>2]=a;v[b+8>>2]=65535;a=x[Eb(b+12|0,b+8|0)>>1];fb=b+16|0;return a}function du(a,b){var c=0;c=fb-16|0;fb=c;v[c+12>>2]=(B(a,b)>>>0)/255;ee(c+12|0,0,15);fb=c+16|0;return w[c+12|0]}function dQ(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;b=a>>>0>c>>>0?b+1|0:b;ib=b;return c}function cd(a,b){var c=0;c=fb-16|0;fb=c;sk(c+8|0,a+24|0,b);a=yb(v[v[c+8>>2]>>2],v[c+12>>2]);fb=c+16|0;return a}function RF(a,b){var c=0;c=fb-16|0;fb=c;a=vk(c,a,1);Hj(v[a+4>>2],w[b|0]);v[a+4>>2]=v[a+4>>2]+1;hc(a);fb=c+16|0}function Eg(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!bj(v[a+4>>2],v[b+4>>2])}function $K(a){var b=0;b=fb-16|0;fb=b;v[b+12>>2]=a;v[b+8>>2]=32767;a=u[Eb(b+12|0,b+8|0)>>1];fb=b+16|0;return a}function jp(a,b){var c=0;c=fb-32|0;fb=c;zh(c+16|0,b);cn(c+24|0,a,v[c+16>>2],v[c+20>>2]);zh(c+8|0,b);fb=c+32|0}function _t(a){var b=0;b=fb-16|0;fb=b;u[b+14>>1]=a;u[b+12>>1]=255;a=w[Tc(b+14|0,b+12|0)|0];fb=b+16|0;return a}function VL(a,b){var c=0;c=fb-16|0;fb=c;a=vz(c,a);Kp(v[a+4>>2],v[b>>2]);v[a+4>>2]=v[a+4>>2]+4;hc(a);fb=c+16|0}function Rv(a,b,c,d,e,f,g){var h=0;h=b>>8;if(b&1){h=Tv(v[e>>2],h)}jb[v[v[a>>2]+20>>2]](a,c,d,e+h|0,b&2?f:2,g)}function Qk(a,b,c,d){var e=0;e=fb-16|0;fb=e;v[e+12>>2]=d;v[e+8>>2]=c;cc(a,b,v[Eb(e+12|0,e+8|0)>>2]);fb=e+16|0}function DL(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function qO(a){var b=0;b=v[a+4>>2];u[a+70>>1]=w[((x[b+20>>1]>>>6|x[b+22>>1]<<4)&65535)+29056|0]>>>x[a+68>>1]}function ii(a){var b=0,c=0;v[v[a+20>>2]>>2]=a;c=v[a+12>>2];b=v[c>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[c>>2]=a}function Raa(){var a=0;a=fb-16|0;fb=a;if(Za(a+12|0,4)|0){Nr(v[115696],12616);L()}fb=a+16|0;return v[a+12>>2]}function RG(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return jb[v[v[a>>2]+36>>2]](a)|0}return Jf(t[b|0])}function Jq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;t[d+15|0]=0;Xf(a,b,mi(b,b+c|0,d+15|0));fb=d+16|0}function JF(a,b,c,d,e){b=Ni(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function Gw(a,b){var c=0;if(b>>>0<=9999){return Fw(a,b)}c=a;a=(b>>>0)/1e4|0;return Vi(Fw(c,a),B(a,-1e4)+b|0)}function GF(a,b,c,d,e){b=Mi(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function sm(a){var b=0;b=fb-16|0;fb=b;v[b+12>>2]=a;v[b+8>>2]=255;a=w[Eb(b+12|0,b+8|0)|0];fb=b+16|0;return a}function qR(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(b>=0){A[a+8>>3]=b;v[a+16>>2]=3}return a}function Yl(a,b){var c=0;c=fb-16|0;fb=c;v[c+8>>2]=a;a=c+8|0;v[a>>2]=v[a>>2]+(b<<2);fb=c+16|0;return v[a>>2]}function Px(a,b){a=Ib(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;Ib(a+24|0);Gb(a+36|0);v[a+48>>2]=b;return a}function Pfa(a,b){a=a|0;b=b|0;if(!dS(a,b)){t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0}}function HH(a,b,c,d){z[d+4>>2]=a+c;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=b+a}function lia(a,b){a=a|0;b=b|0;var c=0;b=fb-80|0;fb=b;c=-1;if(cU(a,b+8|0)){c=bU(b+8|0)}fb=b+80|0;return c|0}function ev(a){var b=0;b=fb-16|0;fb=b;a=v[dc(b+8|0,qd(a)+xd(v[a+4>>2],w[a+11|0])|0)>>2];fb=b+16|0;return a}function Qs(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=Cn(a);continue}break}return a}function O2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return JE(a,b,c,d,e,f,g,12951,1006)|0}function Nu(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function NQ(a){var b=0;if(!(Mb(a,17779,4)|w[a+5|0]!=16|(w[a+54|0]-33&255)>>>0<224)){b=w[a+4|0]>95}return b}function Gfa(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;if(yj(a,b+8|0)){c=OR(b+8|0)}fb=b+16|0;return c|0}function zk(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return jb[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function lr(a,b,c,d,e,f){var g=0;g=b>>8;if(b&1){g=Tv(v[d>>2],g)}jb[v[v[a>>2]+24>>2]](a,c,d+g|0,b&2?e:2,f)}function iu(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;pm(c+8|0,a);v[c+4>>2]=v[c+8>>2];Yt(c+4|0,b);fb=c+16|0}function gF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function a3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return JE(a,b,c,d,e,f,g,12883,999)|0}function UN(a,b){var c=0;c=v[a+484344>>2];if(ke(c,v[a+484348>>2],b)){a=v[Xb(c,b)+12>>2]}else{a=1}return a}function FU(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;if(yj(a,b+8|0)){c=AB(b+8|0)}fb=b+16|0;return c|0}function yO(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;Uk(c);continue}break}v[a+4>>2]=b}function hC(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;wb(c);continue}break}v[a+4>>2]=b}function fe(a,b){a=pl(a,v[b>>2],v[b+4>>2]);v[a+8>>2]=v[b+8>>2];pl(a+12|0,v[b+12>>2],v[b+16>>2]);return a}function eM(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;Mk(c);continue}break}v[a+4>>2]=b}function RP(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;QP(c);continue}break}v[a+4>>2]=b}function Ob(a,b,c){var d=0;c=v[a+4>>2]+c|0;d=b;b=v[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;v[a>>2]=b;v[a+4>>2]=c}function ON(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;Ie(c);continue}break}v[a+4>>2]=b}function wN(a,b){var c=0,d=0;a:{if(b<0){break a}c=A[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}A[a>>3]=d}}function OX(){if(w[466732]){return v[116682]}dp(466724,hK());t[466732]=1;v[116682]=466724;return 466724}function HT(a){a:{if(Mb(a,14158,4)){break a}if(Mb(a+8|0,14139,4)){break a}return 1}return!Mb(a,14139,4)}function hF(a){var b=0,c=0;b=fb-16|0;fb=b;a=$h(b+8|0,a);c=v[v[115701]>>2];_h(a);fb=b+16|0;return c?4:1}function Sk(a,b,c,d){a=a&65535;c=c&65535;if(a>>>0>=c>>>0){a=b>>>0<d>>>0&a>>>0<=c>>>0}else{a=1}return a}function xq(a,b,c){var d=0;d=fb-16|0;fb=d;if(b){t[d+15|0]=0;BL(a+36|0,b,mi(b,b+c|0,d+15|0))}fb=d+16|0}function uW(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;c=-1;if(LD(a,b+8|0)){c=KD(b+8|0)}fb=b+32|0;return c|0}function iP(a){if(((w[a+68|0]|w[a+69|0]<<8)-128&65535)>>>0>=65409){a=Mb(a,17627,17)}else{a=1}return!a}function bB(a,b){if(b>>>0<=126){Pe(((b<<5)+a|0)+480280|0);Qn((B(b,872)+a|0)+1074992|0,a,b,134217728)}}function aB(a){var b=0,c=0;if(v[a>>2]){Bc(a);Fb(v[a>>2]);b=Cb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function Sb(a,b,c){var d=0;if(c){d=a;while(1){t[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function PV(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=-1;if(yj(a,b+8|0)){c=fD(b+8|0)}fb=b+16|0;return c|0}function zR(a){u[a+10>>1]=0;u[a+12>>1]=0;u[a+8>>1]=1084;v[a>>2]=0;v[a+4>>2]=40;u[a+14>>1]=0;return a}function uu(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0}function qq(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;if(Lq(a,b+8|0)){c=Jb(x[b+8>>1])}fb=b+16|0;return c|0}function ol(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function nM(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3;return a}function km(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;if(zo(a,b+8|0)){c=_b(v[b+8>>2])}fb=b+16|0;return c|0}function kP(a){Vd(a+140|0);wb(a+120|0);wb(a+100|0);wb(a+80|0);wb(a+60|0);wb(a+40|0);wb(a+20|0);wb(a)}function S0(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;VB(c+8|0,b);Jq(a,v[c+8>>2],v[c+12>>2]);fb=c+16|0}function JS(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){IS(c+52|0);vb(c+40|0);lc(c+16|0);lc(c+4|0);Fb(c)}}function BV(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;vm(c+8|0,b);Jq(a,v[c+8>>2],v[c+12>>2]);fb=c+16|0}function AV(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;mj(a+8|0,0);Hq(a,127);LC(a,127,w[b|0]);return a|0}function zS(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]+B((b|0)/-6|0,6)|0;v[d>>2]=c;if((b|0)>0){nc(c,a,b)}}function PL(a,b){if(b>>>0<=255){a=v[((b<<2)+a|0)+900380>>2];a=a?a+492|0:21598}else{a=21598}return a}function O0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=xz(px(v[a+32>>2],b,c,d,3));return(a>>>0<5?a+1|0:0)|0}function Mc(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];VE(b);return a}function rfa(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=Lq(a,b+8|0);fb=b+16|0;return(a?x[b+8>>1]:0)<<16>>16}function q2(a,b){a=a|0;b=b|0;var c=0;b=Ec(b);c=v[a+4>>2];if(c){jb[c|0](b,v[a+8>>2]);return}rs(b,a)}function n7(a,b,c){a=a|0;b=b|0;c=c|0;a=Nj(a);if(!a){return 0}return jb[v[v[a>>2]+100>>2]](a,b,c)|0}function iF(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;e=$h(f+8|0,e);a=yr(a,b,c,d);_h(e);fb=f+16|0;return a}function Uea(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;if(gB(a,b)){c=gR(b)}fb=b+16|0;return c|0}function SN(a,b,c){var d=0;d=fb-16|0;fb=d;a=v[dc(d+8|0,KN(b,c,Od(a),fc(a)))>>2];fb=d+16|0;return a}function Pu(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=kg(a,b+15|0);fb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function An(a,b,c,d){a=a&255;c=c&255;if(a>>>0>=c>>>0){a=b>>>0<d>>>0&a>>>0<=c>>>0}else{a=1}return a}function Zw(a,b,c){b=(B(B(Xw(a),Yw(a,b)),125)>>>0)/(OH(a,b)>>>0)|0;a=(a&6)==6?b&-4:b;return a?a:c}function C5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;jb[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;dp(d,a);AJ(a,c)}function xr(a,b,c,d){var e=0;e=fb-16|0;fb=e;ec(e+8|0,c,d);HG(a,b,v[e+8>>2],v[e+12>>2]);fb=e+16|0}function cn(a,b,c,d){var e=0;e=fb-16|0;fb=e;Hg(e+8|0,c,d);HG(a,b,v[e+8>>2],v[e+12>>2]);fb=e+16|0}function bi(a,b,c){if(c){while(1){v[a>>2]=v[b>>2];a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}}function Pz(a,b,c){b=b-a>>2;while(1){if((b|0)>0){v[a>>2]=v[c>>2];b=b-1|0;a=a+4|0;continue}break}}function P$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;jb[v[v[a>>2]+12>>2]](a,b,c,d,e,f)|0}function O$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;jb[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function N$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;jb[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function M$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;jb[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function L$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;jb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function K$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;jb[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function FE(a,b,c){var d=0;d=fb-16|0;fb=d;c=Qb(d,c);a=qc(a,c);ub(c);v[a>>2]=b;fb=d+16|0;return a}function Ei(a,b){var c=0;c=fb-16|0;fb=c;v[c+8>>2]=v[a>>2];a=v[$A(c+8|0,b)>>2];fb=c+16|0;return a}function sX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Eg(a,v[b+8>>2],f)){Wv(b,c,d,e)}}function qV(a){a=a|0;var b=0;b=v[a+76>>2];if(rc(-1,b)){b=RC(a,32);v[a+76>>2]=b}return b<<24>>24}function nga(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=zo(a,b+8|0);fb=b+16|0;return C(a?z[b+8>>2]:C(0))}function gt(a,b){b=Bia(a,a>>31,b,b>>31)+5e5|0;a=ib;return Dc(Cia(b,b>>>0<5e5?a+1|0:a,1e6,0),ib)}function g3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return PE(a,b,c,d,e,f,10580,996)|0}function e4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return PE(a,b,c,d,e,f,10625,970)|0}function _1(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=v[uf(b+8|0,Wj(tc(12),a))>>2];fb=b+16|0;return a|0}function ZQ(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}v[a>>2]=b}}function KU(a,b){a=a|0;b=b|0;if(!ru(a,b)){t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b|0]=0}}function B$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jb[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function $u(a,b){a=$C(a,v[b>>2],v[b+4>>2]);v[a+8>>2]=v[b+8>>2];$C(a+12|0,v[b+12>>2],v[b+16>>2])}function uH(a){var b=0;b=+((a&2097151)>>>0);return C(Cj(+C((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function hG(a){var b=0;b=v[115701];if(a){v[115701]=(a|0)==-1?466516:a}return(b|0)==466516?-1:b}function gr(a,b,c,d){var e=0;v[a>>2]=v[b>>2];e=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<d)+e;return a}function gU(a){var b=0;if(!(Mb(a,26340,20)|(w[a+25|0]-9&255)>>>0<248)){b=t[a+47|0]>=0}return b}function Z8(a,b){a=a|0;b=b|0;ki(a);ki(a);a:{if(b>>>0>=60){Yb(a,4);break a}ki(a)}return ki(a)|0}function WT(a,b){return(Ub((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Ub((B(a&15,b)>>>0)/15|0,1,15))&255}function TA(a,b){var c=0;c=fb-16|0;fb=c;v[c+8>>2]=a;a=v[gT(c+8|0,0-b|0)>>2];fb=c+16|0;return a}function ES(a,b,c){var d=0;d=fb-16|0;fb=d;t[d+15|0]=0;cc(a,b,mi(b,b+c|0,d+15|0)-b|0);fb=d+16|0}function uk(a){var b=0;b=fb-16|0;fb=b;a=v[dc(b+8|0,pc(a)+(Bb(a)<<2)|0)>>2];fb=b+16|0;return a}function uC(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;a=b>>>0<2624?a+1|0:a;ib=a;return b}function og(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=a;a=Qb(c,b);Mc(d,a);vb(a);fb=c+16|0}function ku(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=a;a=Qb(c,b);Mc(d,a);ub(a);fb=c+16|0}function gX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb[a|0](b,c,d,e)|0;ra(ib|0);return a|0}function PP(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function Jl(a,b,c){b=b-a|0;while(1){if((b|0)>0){t[a|0]=w[c|0];b=b-1|0;a=a+1|0;continue}break}}function yV(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=kg(a,b+8|0);fb=b+16|0;return(a?w[b+8|0]:0)&255}function jQ(a){var b=0,c=0;b=fb-16|0;fb=b;if(iQ(a,b+8|0)){c=_b(v[b+8>>2])}fb=b+16|0;return c}function iG(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function eF(a){a=a|0;var b=0;v[a>>2]=83084;b=v[a+8>>2];if(!(!b|!w[a+12|0])){Fb(b)}return a|0}function H$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return jb[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function $ea(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;c=a;a=xh(b+8|0);MR(c,a,0,0);wb(a);fb=b+32|0}function yg(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){bB(a,c);b=b+1|0;continue}break}}function lx(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=CK(d);b=b+1|0}dJ(a,b,c,d,e)}function Yw(a,b){a=a&255;return w[(B(a>>>1&3,15)+B(a>>>3&1,45)+((b&240)>>>4)|0)+63777|0]<<1}function JC(a,b){if((a&4088)>>>0>=520){b=Su(0-Fia(b^1230262859,25)|0,4)^1247037516}return b}function IQ(a){a:{if(Mb(a,17572,4)){break a}if(Mb(a+8|0,14196,4)){break a}return 1}return 0}function Fy(a){var b=0;v[a+84>>2]=0;v[a+88>>2]=0;b=v[a+80>>2];v[a+92>>2]=b;v[a+96>>2]=b<<12}function Dea(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=Vh(a,b+8|0);fb=b+16|0;return+(a?A[b+8>>3]:0)}function xL(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[fc(a)+4|0]){bc(b+16|0)}if(b){Fb(b)}}}function t5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;nx(a,b,c,d,e,0,0,f,g)}function sl(a,b,c){var d=C(0);if(b>>>0<=c>>>0){d=z[zb(a+4208|0,b)>>2]}else{d=C(0)}return d}function qP(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;a=b>>>0<259?a+1|0:a;ib=a;return b}function Zv(a,b,c){var d=0;d=fb-16|0;fb=d;c=$h(d+8|0,c);a=Iw(a,b);_h(c);fb=d+16|0;return a}function Vg(a,b){var c=0;c=fb-16|0;fb=c;v[c+8>>2]=a;a=v[$A(c+8|0,b)>>2];fb=c+16|0;return a}function Qh(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function QG(a){var b=0;b=v[a>>2];if(b){if(!rc(RG(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function MN(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[fc(a)+4|0]){NN(b+16|0)}if(b){Fb(b)}}}function GS(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[fc(a)+4|0]){Rt(b+16|0)}if(b){Fb(b)}}}function Av(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=v[(b<<2)+21644>>2]}else{b=9703}Qb(a,b)}function $J(a,b){var c=0;c=v[a+12>>2];if((c|0)>0){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function $C(a,b,c){var d=0;d=fb-16|0;fb=d;b=pl(d+8|0,b,c);DD(b,a);be(b);fb=d+16|0;return a}function s7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Nj(a);if(a){jb[v[v[a>>2]+76>>2]](a,b,c,d)}}function r7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Nj(a);if(a){jb[v[v[a>>2]+84>>2]](a,b,c,d)}}function q7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Nj(a);if(a){jb[v[v[a>>2]+88>>2]](a,b,c,d)}}function ow(a,b,c,d){var e=0;e=fb-16|0;fb=e;v[e+12>>2]=d;a=wr(a,b,c,d);fb=e+16|0;return a}function op(a,b,c){a=a+1074992|0;return v[(a+B(b,872)|0)+680>>2]>v[(a+B(c,872)|0)+680>>2]}function oJ(a){a=a|0;var b=0;v[a>>2]=49232;b=v[a+4>>2];if(b){Fb(b);v[a+4>>2]=0}return a|0}function fX(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;jb[a|0](b,c,d,e,f,g)}function RT(a,b,c){var d=0;d=fb-16|0;fb=d;wi(d+8|0,b,c);fb=d+16|0;return v[d+8>>2]==(a|0)}function JK(a,b){a=a|0;b=b|0;var c=0;c=Bb(a);if(c>>>0<b>>>0){ju(a,b-c|0,0);return}aL(a,b)}function Fia(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function Ag(a){var b=0;b=fb-16|0;fb=b;a=Lq(a,b+8|0);fb=b+16|0;return(a?x[b+8>>1]:0)&65535}function v$(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){tw(a,c);return}Qb(a,7872)}function sM(a,b){var c=0;c=w[a+851|0];if(c&1){t[a+851|0]=c|64;v[a+852>>2]=v[a+852>>2]+b}}function qv(){var a=0,b=0;a=fb-16|0;fb=a;b=uf(a+8|0,Ib(tc(12)));fb=a+16|0;return v[b>>2]}function oM(a){a=Gb(a);Gb(a+12|0);Gb(a+24|0);Gb(a+36|0);Gb(a+48|0);v[a+60>>2]=0;return a}function jz(a,b){a=Wj(a,b);Mc(a+12|0,b+12|0);u[a+28>>1]=x[b+28>>1];v[a+24>>2]=v[b+24>>2]}function ih(a){var b=0;b=fb-16|0;fb=b;a=v[dc(b+8|0,pc(a)+Bb(a)|0)>>2];fb=b+16|0;return a}function ds(a){if(XI(a)){a=aa(4)|0;v[a>>2]=0;a=Fl(a);v[a>>2]=91048;ia(a|0,91084,25);L()}}function Ts(a){var b=0;b=fb-16|0;fb=b;a=v[dc(b+8|0,Ec(a)+Bb(a)|0)>>2];fb=b+16|0;return a}function RQ(a,b){var c=0;c=fb-16|0;fb=c;vm(c+8|0,b);ES(a,v[c+8>>2],v[c+12>>2]);fb=c+16|0}function Cs(a,b){var c=0;c=Ec(a);if(c>>>0<=b>>>0){a=Bb(a)+c>>>0>=b>>>0}else{a=0}return a}function Ae(a){var b=0;b=fb-16|0;fb=b;a=kg(a,b+15|0);fb=b+16|0;return(a?w[b+15|0]:0)&255}function u7(a,b){a=a|0;b=b|0;a=Nj(a);if(!a){return 1}return jb[v[v[a>>2]+68>>2]](a,b)|0}function tp(a,b,c){a=Ok(a)-v[a+16>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function mG(a,b){var c=0;c=fb-16|0;fb=c;v[c+12>>2]=b;a=nG(a,11082,b);fb=c+16|0;return a}function kL(a,b,c){var d=0;d=b-a|0;if((a|0)!=(b|0)){Zi(c,a,d)}return B((d|0)/6|0,6)+c|0}function ft(a){var b=0;b=fb-16|0;fb=b;t[b+15|0]=0;Jl(a,Rn(a),b+15|0);fb=b+16|0;return a}function ZV(a){a=a|0;var b=0;b=v[a+4>>2];return(jb[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function Rh(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function OA(a){var b=0;b=sz(a);while(1){if((a|0)!=(b|0)){pU(a);a=a+32|0;continue}break}}function NG(a){var b=0;b=v[a>>2];if(b){if(!dn(zk(b))){return!v[a>>2]}v[a>>2]=0}return 1}function Mt(a,b,c){var d=C(0);d=z[a>>2];if(!Lt(d,z[b>>2])){b=Lt(z[c>>2],d)?c:a}return b}function Iv(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function Hx(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=CK(d);b=b+1|0}zx(a,b,c,d)}function Gm(a){var b=0;b=kv(a+4|0);if((b|0)==-1){jb[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function zP(a){var b=0;b=a+36|0;while(1){b=ub(b-12|0);if((b|0)!=(a|0)){continue}break}}function yc(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;vm(d,a);gl(d,b);fb=c+16|0;return a}function uN(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;sk(d,a,b);dm(d);fb=c+16|0;return a}function ok(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=d+8|0;sk(e,a+24|0,b);sg(e,c);fb=d+16|0}function kO(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function Pk(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;xb(d,a,b);dm(d);fb=c+16|0;return a}function OH(a,b){a=a&255;return v[(b&12)+63780>>2]>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function FW(){var a=0;a:{if(SD(19923968)){break a}if(RD()){break a}a=QD()^1}return a|0}function Eu(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;t[c+15|0]=b;uJ(a,c+15|0);fb=c+16|0}function ED(a,b){var c=0;c=fb-16|0;fb=c;b=ng(c+8|0,b);DD(b,a);be(b);fb=c+16|0;return a}function CR(a){var b=0;b=a+24|0;while(1){b=ub(b-12|0);if((b|0)!=(a|0)){continue}break}}function BB(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+26288|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function zF(a,b){var c=0,d=0;Je(a,Ud(b));b=fc(b);c=fc(a),d=v[b>>2],v[c>>2]=d;return a}function y_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return AE(b,c,d,e,f,0)|0}function xl(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function wO(a,b,c,d){var e=0;e=fb-16|0;fb=e;a=Ci(e,a,d);Pt(b,c,a+4|0);hc(a);fb=e+16|0}function tt(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function rs(a,b){a=a|0;b=b|0;b=fb-16|0;fb=b;v[b>>2]=a;FJ(17801,b);ps(92408);fb=b+16|0}function q_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return yE(b,c,d,e,f,1)|0}function o_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return yE(b,c,d,e,f,0)|0}function nA(a,b,c,d){var e=0;e=fb-16|0;fb=e;a=ri(e,a,d);Pt(b,c,a+4|0);hc(a);fb=e+16|0}function f0(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function el(a,b,c){a=a|0;b=b|0;c=c|0;if(Ic(a,b)>>>0<=c>>>0){Lu();L()}return(c<<1)+a|0}function e3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return OE(a,b,c,d,e,12339,997)|0}function e0(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function c4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return OE(a,b,c,d,e,12439,971)|0}function WX(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[((b&255)<<2)+81584>>2]}return b<<24>>24}function VE(a){var b=0;while(1){if((b|0)!=3){v[(b<<2)+a>>2]=0;b=b+1|0;continue}break}}function UX(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[((b&255)<<2)+80048>>2]}return b<<24>>24}function Qt(a,b,c,d){var e=0;e=fb-16|0;fb=e;a=vk(e,a,d);Pt(b,c,a+4|0);hc(a);fb=e+16|0}function Ps(a,b){if(!(t[b+851|0]&1&v[a+480180>>2]==8)){cy(a,b,0);cy(a,b,1);cy(a,b,2)}}function M2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return IE(a,b,c,d,e,9659,1007)|0}function It(a,b){var c=0;c=fb-16|0;fb=c;u[c+14>>1]=b;Et(a+236|0,128,c+14|0);fb=c+16|0}function Ip(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]-b|0;v[d>>2]=c;if((b|0)>0){nc(c,a,b)}}function A_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return AE(b,c,d,e,f,1)|0}function xP(a,b,c,d,e,f){a=dc(a,b);dc(a+4|0,c);dc(a+8|0,d);dc(a+12|0,e);dc(a+16|0,f)}function uj(a,b,c){var d=0;d=v[a>>2];if(!Yo(d,v[b>>2])){b=Yo(v[c>>2],d)?c:a}return b}function ug(a,b,c){var d=0;d=A[a>>3];if(!jP(d,A[b>>3])){b=jP(A[c>>3],d)?c:a}return b}function sh(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;Rh(a)}function oF(a,b){a:{if(!(w[a+120|0]|b>>>0>30)){t[a+120|0]=1;break a}a=pi(b)}return a}function ke(a,b,c){if(om(a,b,c)){a=Nf(a,c);a=Nb(v[a>>2],v[a+4>>2])}else{a=0}return a}function _2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return IE(a,b,c,d,e,9587,1e3)|0}function Ze(a){a=a|0;var b=0;b=v[a>>2];return(jb[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function Lv(a,b){var c=0;while(1){if((b|0)!=(c|0)){rg(a+c|0);c=c+1|0;continue}break}}function Jz(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function Cn(a){var b=0;b=a;a=v[a>>2];v[b>>2]=B(a,214013)+2531011;return a>>>16&32767}function u$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=DG(a,c,d,b);v[a>>2]=77388;return a|0}function ng(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function kG(a){return(a|0)!=0&(a|0)!=88544&(a|0)!=88568&(a|0)!=466432&(a|0)!=466456}function jF(a){a=a|0;v[a>>2]=83136;if(v[a+8>>2]!=(wd()|0)){jG(v[a+8>>2])}return a|0}function fp(a){a=a|0;v[a+56>>2]=77048;v[a>>2]=77028;qs(a+4|0);Ck(a+56|0);return a|0}function df(a){a=a|0;v[a+60>>2]=77212;v[a>>2]=77192;qs(a+8|0);Ck(a+60|0);return a|0}function c5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return CJ(a,b,c,d,0,0,0,0,e)|0}function aq(a,b){var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=Ee(Kj(b)*+(c>>>0)),v[d+24>>2]=e}function _6(a,b){a=a|0;b=b|0;return C(b>>>0<=2?C(C(w[(a+b|0)+4232|0])/C(127)):C(0))}function O7(a,b){a=a|0;b=b|0;return C(b>>>0<=3?C(C(w[(a+b|0)+4264|0])/C(255)):C(0))}function Kd(a){var b=0;b=fb-16|0;fb=b;v[b+12>>2]=49400;Tn(a,49296,b+12|0);fb=b+16|0}function xH(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function my(a){var b=0;b=fb-16|0;fb=b;dc(b+8|0,a+116|0);a=dM(a);fb=b+16|0;return a}function mg(a){var b=0;b=fb-16|0;fb=b;a=zo(a,b+8|0);fb=b+16|0;return a?v[b+8>>2]:0}function k6(a){a=a|0;t[a+4202|0]=1;v[a+4256>>2]=v[v[a+16>>2]+24620>>2];cK(a);bK(a)}function ir(a,b,c,d){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,d);return a}function cN(a,b){var c=0;c=b&15;if(c){t[a+830|0]=c}b=b&240;if(b){t[a+829|0]=b>>>4}}function No(a,b,c,d){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<d);return a}function F7(a){a=a|0;t[a+4202|0]=1;v[a+4232>>2]=v[v[a+16>>2]+24620>>2];ws(a);IK(a)}function rP(a){if((w[a+14|0]-53&255)>>>0>=252){a=Mb(a,15518,14)}else{a=1}return!a}function Wn(a,b){a=nc(a,b,34);u[a+34>>1]=x[b+34>>1];nc(a+36|0,b+36|0,68);return a}function VK(a,b,c){while(1){if(b){z[a>>2]=z[c>>2];b=b-1|0;a=a+4|0;continue}break}}function Et(a,b,c){while(1){if(b){u[a>>1]=x[c>>1];b=b-1|0;a=a+2|0;continue}break}}function wf(a){var b=0;b=fb-16|0;fb=b;a=v[dc(b+8|0,Hf(a))>>2];fb=b+16|0;return a}function oj(a){var b=0;b=fb-16|0;fb=b;a=v[dc(b+8|0,Ab(a))>>2];fb=b+16|0;return a}function bl(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;gc(a+8|0,b+8|0)}function Vs(a){var b=0;b=fb-16|0;fb=b;a=v[dc(b+8|0,Ec(a))>>2];fb=b+16|0;return a}function Td(a){var b=0;b=fb-16|0;fb=b;a=v[dc(b+8|0,pc(a))>>2];fb=b+16|0;return a}function Hf(a){var b=0;b=fb-16|0;fb=b;a=v[dc(b+8|0,fc(a))>>2];fb=b+16|0;return a}function Fi(a){var b=0;b=fb-16|0;fb=b;a=v[dc(b+8|0,qd(a))>>2];fb=b+16|0;return a}function FJ(a,b){var c=0;c=fb-16|0;fb=c;v[c+12>>2]=b;hH(92408,a,b,0,0);fb=c+16|0}function Dfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ov(a,b,c,d,e,532)|0}function uZ(){var a=0,b=0,c=0;a=Rd(468064);v[a>>2]=83136;b=a,c=wd(),v[b+8>>2]=c}function oh(a,b,c){a=dc(a,b);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;return a}function gY(a,b,c){a=a|0;b=b|0;c=c|0;return(x[(c<<1)+79024>>1]&b)!=0&c>>>0<=127}function eg(a){var b=0,c=0;lh(a+4|0);mj(a+8|0,0);b=a,c=fc(a),v[b>>2]=c;return a}function cD(a,b,c){while(1){if(b){t[a|0]=w[c|0];b=b-1|0;a=a+1|0;continue}break}}function Xq(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ov(a,b,c,d,e,156)|0}function Th(a){return(xj(v[a>>2],v[a+4>>2])|0)!=(0-xj(v[a+12>>2],v[a+16>>2])|0)}function Ev(a,b){b=a+b|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function BT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ov(a,b,c,d,e,324)|0}function yC(a){var b=0;b=fb-16|0;fb=b;t[b+15|0]=0;Jl(a,Go(a),b+15|0);fb=b+16|0}function wT(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[Cb(a)>>2]){RF(a,b);return}PF(a,b)}function t0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return WH(a-88|0,b,c,d,e)|0}function cX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return jb[a|0](b,c,d,e)|0}function Xx(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[Cb(a)>>2]){VL(a,b);return}_z(a,b)}function Vn(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function QY(a){a=a|0;if(!w[466944]){Sm(466932,83372);t[466944]=1}return 466932}function PY(a){a=a|0;if(!w[466976]){Sm(466964,83456);t[466976]=1}return 466964}function OY(a){a=a|0;if(!w[466880]){Sm(466868,83300);t[466880]=1}return 466868}function NY(a){a=a|0;if(!w[466912]){Sm(466900,83336);t[466912]=1}return 466900}function JY(a){a=a|0;if(!w[466928]){Qb(466916,13464);t[466928]=1}return 466916}function GY(a){a=a|0;if(!w[466896]){Qb(466884,13680);t[466896]=1}return 466884}function Bu(a,b){return Ee(Kj((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function xn(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function xX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Eg(a,v[b+8>>2],0)){Uv(b,c,d)}}function ue(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;Uu(d,a);gl(d,b);fb=c+16|0}function oP(a,b){a=CQ(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function mm(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;VB(d,a);gl(d,b);fb=c+16|0}function l9(a,b){a=a|0;b=b|0;if(y[a+4>>2]<y[Cb(a)>>2]){VL(a,b);return}_z(a,b)}function Wi(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}Fb(b)}function Vi(a,b){var c=0;c=a;a=(b>>>0)/100|0;return Or(Or(c,a),B(a,-100)+b|0)}function NX(a,b){a=a|0;b=b|0;a=Fl(a);v[a>>2]=91520;Xv(a+4|0,Ec(b));return a|0}function Ly(a){var b=0;if(!(w[a+2|0]|(w[a|0]|w[a+1|0]))){b=!w[a+3|0]}return b}function Kx(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function IY(a){a=a|0;if(!w[466960]){Qb(466948,9224);t[466960]=1}return 466948}function IX(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Qb(a,7908);return}tw(a,c)}function HY(a){a=a|0;if(!w[466864]){Qb(466852,5226);t[466864]=1}return 466852}function GX(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Qb(a,7838);return}tw(a,c)}function GN(a){v[a>>2]=0;v[a+4>>2]=0;v[a>>2]=-2078137563;v[a+4>>2]=-873292572}function te(a){var b=0;b=fb-16|0;fb=b;wu(b+8|0,a);fb=b+16|0;return v[b+8>>2]}function sF(a){var b=0;b=fb-16|0;fb=b;v[b+8>>2]=a;fb=b+16|0;return v[b+8>>2]}function m6(a,b){a=a|0;b=b|0;return C(b>>>0<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function Zj(a){var b=0;b=fb-16|0;fb=b;a=v[uf(b+8|0,a)>>2];fb=b+16|0;return a}function Y2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Pm(a,b,c,d,12840,1001)|0}function UF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jb[v[v[a>>2]+32>>2]](a,b,c,d)|0}function U2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Pm(a,b,c,d,12914,1003)|0}function Qd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];Yb(b,c);nv(a,b,d,c)}function OF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jb[v[v[a>>2]+48>>2]](a,b,c,d)|0}function KM(a,b,c){var d=0;return!b|!(w[a+35|0]&4?!a|(c|0)!=1:1)?d:w[b+34|0]}function Ab(a){var b=0;b=fb-16|0;fb=b;a=v[dc(b+8|0,a)>>2];fb=b+16|0;return a}function z_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return BE(b,c,d,e,0)|0}function vk(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function uK(a){a=a|0;v[a>>2]=46404;lc(a+4276|0);lc(a+4264|0);return sf(a)|0}function s_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zE(b,c,d,e,1)|0}function p_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zE(b,c,d,e,0)|0}function fO(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);ZN(a,b,0,0,b+-1,0)}function cY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[(b<<2)+81584>>2]}return b|0}function aY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[(b<<2)+80048>>2]}return b|0}function W2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Pm(a,b,c,d,9542,1002)|0}function S2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Pm(a,b,c,d,9620,1004)|0}function QR(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function Q2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Pm(a,b,c,d,9422,1005)|0}function Hz(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function GG(a,b,c,d,e,f,g,h){return jb[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function Er(a,b,c,d,e,f,g,h){return jb[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function C_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return BE(b,c,d,e,1)|0}function jv(a,b,c){var d=0;d=b-a|0;if((a|0)!=(b|0)){Zi(c,a,d)}return c+d|0}function jg(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function ch(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function c3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Pm(a,b,c,d,9391,998)|0}function Uj(a){var b=0;b=x[a+172>>1];a=x[a+156>>1];return(lP(a)?b:a)&65535}function Or(a,b){b=x[(b<<1)+76176>>1];t[a|0]=b;t[a+1|0]=b>>>8;return a+2|0}function KX(a,b,c){a=a|0;b=b|0;c=c|0;return rc(a,v[b+4>>2])&v[b>>2]==(c|0)}function yk(a,b,c){a=a|0;b=b|0;c=c|0;return jb[v[v[a>>2]+12>>2]](a,b,c)|0}function wD(a,b){a=a|0;b=b|0;a=Fl(a);v[a>>2]=91520;Xv(a+4|0,b);return a|0}function vD(a,b){a=ng(a,b);v[a+8>>2]=v[b+8>>2];ng(a+12|0,b+12|0);return a}function rR(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function qd(a){var b=0,c=0,d=0;return b=v[a>>2],c=a,d=nf(w[a+11|0]),d?b:c}function nm(a,b,c){a=a|0;b=b|0;c=c|0;return jb[v[v[a>>2]+48>>2]](a,b,c)|0}function ht(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function h7(a,b){a=a|0;b=b|0;a=v[a+20>>2];t[a+24|0]=w[a+24|0]&253|(b?2:0)}function Yc(a,b){a=ED(a,b);v[a+8>>2]=v[b+8>>2];ED(a+12|0,b+12|0);return a}function Uc(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function Pt(a,b,c){b=b-a|0;if((b|0)>0){nc(v[c>>2],a,b);v[c>>2]=b+v[c>>2]}}function Lb(a,b,c){a=a|0;b=b|0;c=c|0;return jb[v[v[a>>2]+32>>2]](a,b,c)|0}function Kga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=ro(a,b),v[d>>2]=e}function Jga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Ou(a,b),u[d>>1]=e}function rw(a,b){var c=0;c=ss(a+4|0);v[a>>2]=78040;v[c>>2]=78060;sn(c,b)}function qw(a,b){var c=0;c=xG(a+4|0);v[a>>2]=78208;v[c>>2]=78228;sn(c,b)}function lha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;iE(a,b,c,d,e,100)}
function fP(a,b){t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24}function ZG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ch(a,-1,-1)}function rO(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function pK(a){a=a|0;return C(C(C(z[zb(a+4208|0,5)>>2]*C(198))+C(-99)))}function oc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=Cf(b),v[c+4>>2]=d;return a}function lc(a){var b=0;if(v[a>>2]){Bc(a);b=v[a>>2];si(a);Fb(b)}return a}function lO(a){if(a>>>0<=8){return w[a+29184|0]}return w[a+29175|0]|256}function jB(a,b,c){var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function fd(a){var b=0;if(v[a>>2]){hC(a,v[a>>2]);b=v[a>>2];iC(a);Fb(b)}}function dI(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function co(a){if(nf(w[a+11|0])){a=eB(v[a+8>>2])-1|0}else{a=10}return a}function _v(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}function Tf(a){var b=0;if(v[a>>2]){Bc(a);b=v[a>>2];Ct(a);Fb(b)}return a}function ST(a,b,c){a=a&255;return a>>>0>=(b&255)>>>0&a>>>0<=(c&255)>>>0}function SP(a){var b=0;if(v[a>>2]){RP(a,v[a>>2]);b=v[a>>2];Bj(a);Fb(b)}}function Nw(a){return((fh(a)+(fh(a)<<8)|0)+(fh(a)<<16)|0)+(fh(a)<<24)|0}function Nda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;iE(a,b,c,d,e,126)}function zp(a,b){if(b){zp(a,v[b>>2]);zp(a,v[b+4>>2]);NN(b+16|0);Fb(b)}}function tk(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function mz(a,b){a=Ib(a);Gb(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function gR(a){if(Mb(a,13794,4)){a=1}else{a=Mb(a+8|0,13847,4)}return!a}function bV(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){va();L()}}function Wx(a,b){if(b){Wx(a,v[b>>2]);Wx(a,v[b+4>>2]);bc(b+16|0);Fb(b)}}function Vv(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function Tk(a,b){a=w[Hb(a+62|0,b)|0];return(a<<24>>24>=0?a&127:-1)&255}function Qy(a,b){if(b){Qy(a,v[b>>2]);Qy(a,v[b+4>>2]);Rl(b+16|0);Fb(b)}}function Qq(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function FA(a,b){if(b){FA(a,v[b>>2]);FA(a,v[b+4>>2]);Rt(b+16|0);Fb(b)}}function EA(a,b){if(b){EA(a,v[b>>2]);EA(a,v[b+4>>2]);Rt(b+16|0);Fb(b)}}function Cy(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];t[a+6|0]=w[b+6|0]}function yP(a,b,c,d,e){a=dc(a,b);dc(a+4|0,c);dc(a+8|0,d);dc(a+12|0,e)}function qX(a){a=a|0;if(!a){return 0}return(zy(a,91132,91276)|0)!=0|0}function fJ(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){nn(c+120|0);Fb(c)}}function Hc(a,b,c,d){if((b|0)==(d|0)){a=DS(a,b,c,d)}else{a=1}return!a}function AL(a,b,c,d){if((b|0)==(d|0)){a=iM(a,b,c,d)}else{a=1}return!a}function $v(a){a=a|0;if(v[a+8>>2]!=(wd()|0)){jG(v[a+8>>2])}return a|0}function $L(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function zl(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function pq(a,b){var c=0;c=fb-16|0;fb=c;IC(c,a,64);MC(c,b);fb=c+16|0}function mP(a,b){a=Nz(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function lu(a,b){var c=0;c=fb-16|0;fb=c;IC(c,a,32);MC(c,b);fb=c+16|0}function gC(a){if(a>>>0>=214748365){xf(11129);L()}return tc(B(a,20))}function dX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return jb[a|0](b,c,d)|0}function cS(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];gc(a+8|0,b+8|0)}function _k(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){fc(a);if(b){Fb(b)}}}function W_(a){a=a|0;var b=0;b=v[116684]+1|0;v[116684]=b;v[a+4>>2]=b}function UD(a){if(a>>>0>=357913942){xf(11129);L()}return tc(B(a,12))}function BZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Oh(a,f)}function xS(a){if(a>>>0>=715827883){xf(11129);L()}return tc(B(a,6))}function rM(a,b){v[a+852>>2]=v[a+852>>2]+b;t[a+851|0]=w[a+851|0]|64}function kS(a){t[a+4|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function eL(a){if(a>>>0>=82595525){xf(11129);L()}return tc(B(a,52))}function X2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return HE(a,b,c,d,4)|0}function V2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return HE(a,b,c,d,2)|0}function UL(a,b){var c=0;c=fb-16|0;fb=c;Uz(c,1,b);Ac(a,c);fb=c+16|0}function T2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return GE(a,b,c,d,4)|0}function R2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return GE(a,b,c,d,2)|0}function IB(a,b){return ZD(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?b:a}function Gq(a,b){return Ru(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?b:a}function Gc(a,b,c){if(sc(a,b)>>>0<=c>>>0){Lu();L()}return(c<<2)+a|0}function qF(a,b,c){a:{if((a|0)==(b|0)){t[b+120|0]=0;break a}Fb(b)}}function pi(a){if(a>>>0>=1073741824){xf(11129);L()}return tc(a<<2)}function hL(a,b){if((a|0)!=(b|0)){RR(a,v[b>>2],v[b+4>>2])}return a}function ZX(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function UE(a,b,c,d){b=Oa(928,a|0,b|0,c|0,d|0)|0;ib=O()|0;return b}function LO(a,b){var c=0,d=0;c=dc(a,v[b>>2]),d=w[b+4|0],t[c+4|0]=d}function xi(a,b){if(dg(v[a>>2],v[a+4>>2])>>>0>b>>>0){t[a+16|0]=b}}function x9(a,b){a=a|0;b=b|0;if(!v[23220]){v[23221]=b;v[23220]=a}}function sP(a){if(a>>>0>=134217728){xf(11129);L()}return tc(a<<5)}function qm(a,b){v[a>>2]=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];return a}function pH(a,b){a=nH(a-1|0);if(!a){a=nH(b);a=a?a+32|0:0}return a}function pD(a){if(a>>>0>=536870912){xf(11129);L()}return tc(a<<3)}function bI(a){a=a|0;return+(+v[v[a+32>>2]+1074456>>2]*.00390625)}function _q(a,b){a=a|0;b=b|0;return jb[v[v[a>>2]+32>>2]](a,0,b)|0}function _V(a){a=a|0;a=v[a+4>>2];return jb[v[v[a>>2]+16>>2]](a)|0}function _D(a){if(a>>>0>=268435456){xf(11129);L()}return tc(a<<4)}function Ym(a,b){if(y[a+4>>2]<y[Cb(a)>>2]){RF(a,b);return}PF(a,b)}function MR(a,b,c,d){a=fe(a,b);u[a+22>>1]=d;u[a+20>>1]=c;return a}function Ec(a){var b=0,c=0,d=0;return b=v[a>>2],c=a,d=ve(a),d?b:c}function B5(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,898,86224)|0}function $V(a){a=a|0;a=v[a+4>>2];return jb[v[v[a>>2]+12>>2]](a)|0}function z6(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,891,4276)|0}function r6(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,892,4268)|0}function qy(a){vb(a+48|0);vb(a+36|0);vb(a+24|0);vb(a+12|0);vb(a)}function ln(a,b,c){return ER(v[a>>2],v[a+4>>2],b,v[a+12>>2]+c|0)}function fia(a,b){a=a|0;b=b|0;a=au(a,b);v[a>>2]=91676;return a|0}function dd(a,b){return((a^-2147483648)>>>b)-(-2147483648>>>b)|0}function bx(a,b,c){return Ih(v[a>>2],v[a+4>>2],b,v[a+12>>2]+c|0)}function b7(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,887,4236)|0}function ad(a){a=(a|0)<32767?a:32767;return(a|0)>-32768?a:-32768}function aW(a){a=a|0;a=v[a+4>>2];return jb[v[v[a>>2]+8>>2]](a)|0}function a6(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,894,4228)|0}function ZD(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function WJ(a){return C(C(z[zb(a+4208|0,11)>>2]*C(19980))+C(20))}function T7(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,869,4268)|0}function T5(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,895,5048)|0}function Mp(a,b,c){a=Jb(a&65535);return(a|0)>=(b|0)&(a|0)<=(c|0)}function J5(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,897,4276)|0}function I6(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,890,4280)|0}function CD(a,b,c){a=Em(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=61436}function C7(a,b,c){a=a|0;b=b|0;c=c|0;return Hi(a,b,c,877,4304)|0}function yx(a){var b=0;if(v[a>>2]){Bc(a);b=v[a>>2];Gx(a);Fb(b)}}function ti(a){var b=0;if(v[a>>2]){Bc(a);b=v[a>>2];Xn(a);Fb(b)}}function r5(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function qt(a){var b=0;if(v[a>>2]){Bc(a);b=v[a>>2];Az(a);Fb(b)}}function qh(a){var b=0;if(v[a>>2]){Bc(a);b=v[a>>2];bu(a);Fb(b)}}function pe(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){nJ(b)}return a}function ld(a){var b=0;if(v[a>>2]){Bc(a);b=v[a>>2];wm(a);Fb(b)}}function lH(a){var b=0;b=fb-16|0;z[b+12>>2]=a;return z[b+12>>2]}function kr(a){var b=0;b=fb-16|0;A[b+8>>3]=a;return A[b+8>>3]*a}function jM(a){var b=0;if(v[a>>2]){Bc(a);b=v[a>>2];KT(a);Fb(b)}}function iw(a,b){a=a|0;b=b|0;return jb[v[v[a>>2]+12>>2]](a,b)|0}function iY(a){a=a|0;a=v[a+8>>2];if(!a){return 1}return hF(a)|0}function fl(a,b){a=a|0;b=b|0;return jb[v[v[a>>2]+28>>2]](a,b)|0}function fM(a){var b=0;if(v[a>>2]){Is(a);b=v[a>>2];Hs(a);Fb(b)}}function eO(a,b){a=a|0;b=b|0;a=au(a,b);v[a>>2]=91540;return a|0}function ao(a){var b=0;if(v[a>>2]){Bc(a);b=v[a>>2];eS(a);Fb(b)}}function Yj(a){var b=0;if(v[a>>2]){Bc(a);b=v[a>>2];fr(a);Fb(b)}}function XJ(a){return C(C(z[zb(a+4208|0,0)>>2]*C(1e4))+C(-1e4))}function Wp(a,b,c){if(!b){return 0}return Vt(a,Jf(c<<24>>24),b)}function Wd(a){var b=0;if(v[a>>2]){Bc(a);b=v[a>>2];Hm(a);Fb(b)}}function WL(a){var b=0;if(v[a>>2]){Fo(a);b=v[a>>2];fv(a);Fb(b)}}function Vd(a){var b=0;if(v[a>>2]){oU(a);b=v[a>>2];qB(a);Fb(b)}}function TY(a,b){a=a|0;b=b|0;a=au(a,b);v[a>>2]=91728;return a|0}function Ru(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function Qg(a,b,c,d){v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function QP(a){var b=0;if(v[a>>2]){Bc(a);b=v[a>>2];Bj(a);Fb(b)}}function QN(a){var b=0;if(v[a>>2]){PN(a);b=v[a>>2];Bj(a);Fb(b)}}function Nc(a){var b=0;if(ve(a)){b=v[a>>2];hl(a);Fb(b)}return a}function Jp(a){var b=0;if(v[a>>2]){Bc(a);b=v[a>>2];Cb(a);Fb(b)}}function Fz(a){var b=0;if(v[a>>2]){Bc(a);b=v[a>>2];fv(a);Fb(b)}}function Dr(a,b){a=a|0;b=b|0;return jb[v[v[a>>2]+44>>2]](a,b)|0}function BN(a){var b=0;if(v[a>>2]){Bc(a);b=v[a>>2];Ry(a);Fb(b)}}function AO(a){var b=0;if(v[a>>2]){zO(a);b=v[a>>2];Xn(a);Fb(b)}}function zN(a,b){a=a|0;b=b|0;a=TT(a,b);if(!a){cu(b)}return a|0}function sA(a,b){a=a|0;b=b|0;a=zo(a,b);if(!a){lm(b)}return a|0}function ov(a,b){a=a|0;b=b|0;a=oD(a,b);if(!a){nD(b)}return a|0}function oQ(a){return w[a+15|0]<<12|w[a+14|0]<<4|w[a+13|0]<<20}function nU(a,b){if(!b){return-1}b=Wp(a,b,0);return b?b-a|0:-1}function nK(a){a=a|0;return kj(C(z[zb(a+4208|0,4)>>2]*C(4)))|0}function h2(a,b,c){a=a|0;b=b|0;c=c|0;TO(a,0,v[b+1298404>>2],c)}function gv(a,b){a=Mc(a,b);gc(a+12|0,b+12|0);Rf(a+32|0,b+32|0)}function go(a,b){a=a|0;b=b|0;a=DT(a,b);if(!a){GT(b)}return a|0}function bv(a,b){a=a|0;b=b|0;a=ZC(a,b);if(!a){Pq(b)}return a|0}function bX(a,b){a=a|0;b=b|0;jb[v[v[b>>2]+16>>2]](a,b,0,0,1,8)}function aE(a){u[a+12>>1]=0;v[a+8>>2]=-1;v[a>>2]=0;v[a+4>>2]=0}function _b(a){return a<<8&16711680|a<<24|(a>>>8&65280|a>>>24)}function _9(a,b){a=a|0;b=b|0;a=hS(a,b);if(!a){gS(b)}return a|0}function Xh(a,b){a=a|0;b=b|0;a=Vh(a,b);if(!a){ol(b)}return a|0}function UZ(a,b){a=a|0;b=b|0;LM(a,zw(v[b>>2])<<24>>24,v[b>>2])}function Sf(a,b){return jb[v[v[a>>2]+32>>2]](a,v[a+12>>2],b)|0}function OB(a,b){a=a|0;b=b|0;a=pu(a,b);if(!a){uu(b)}return a|0}function NA(a,b){a=a|0;b=b|0;a=uS(a,b);if(!a){BA(b)}return a|0}function Mq(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function KL(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function At(a,b){a=a|0;b=b|0;a=ET(a,b);if(!a){$t(b)}return a|0}function $q(a,b){a=a|0;b=b|0;a=gD(a,b);if(!a){sv(b)}return a|0}function tI(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function pl(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(c){Cm(c)}return a}function oia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nE(a,b,c,d,126)}function j6(a,b,c){a=a|0;b=b|0;c=c|0;return Dv(a,b,c,0,893)|0}function gM(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Fb($n(c))}}function eh(a,b,c){return(x[((c&255)<<1)+a>>1]&b)!=0&(c|0)>=0}function b6(a,b,c){a=a|0;b=b|0;c=c|0;return Dv(a,b,c,1,893)|0}function Yga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nE(a,b,c,d,100)}function Wga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jE(a,b,c,d,417)}function T6(a,b,c){a=a|0;b=b|0;c=c|0;return Dv(a,b,c,0,889)|0}function QL(a,b){return b>>>0<4e3?((b<<5)+a|0)+946304|0:21598}function Ifa(a,b,c){a=a|0;b=b|0;c=c|0;Mc(a,PR(c,Ec(b),Bb(b)))}function FD(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Fb($b(c))}}function Bha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jE(a,b,c,d,348)}function qs(a){a=a|0;v[a>>2]=76512;ub(a+32|0);return un(a)|0}function pM(a){v[a>>2]=0;Ib(a+4|0);Sb(a+16|0,0,144);return a}function oK(a){a=a|0;return C(C(z[zb(a+4208|0,2)>>2]*C(10)))}function nH(a){return t[(B(0-a&a,124511785)>>>27|0)+72816|0]}function kc(a,b){var c=0;c=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=c}function fI(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function ay(a,b){var c=0;c=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=c}function TV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ec(a,v[d>>2],0)}function J6(a){a=a|0;return C(C(z[zb(a+4208|0,6)>>2]*C(20)))}function Cx(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function Bg(a,b,c,d){ib=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function vn(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function r9(a){a=a|0;a=au(a,21598);v[a>>2]=91620;return a|0}function qA(a,b){if(b){qA(a,v[b>>2]);qA(a,v[b+4>>2]);Fb(b)}}function pA(a,b){if(b){pA(a,v[b>>2]);pA(a,v[b+4>>2]);Fb(b)}}function o7(a){a=a|0;a=Nj(a);if(a){jb[v[v[a>>2]+96>>2]](a)}}function kv(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function gx(a,b,c,d,e,f){return EE(a,b,c,d,e,f,57028,57824)}function fx(a,b,c,d,e,f){return EE(a,b,c,d,e,f,57904,58668)}function eu(a,b,c){a=a|0;b=b|0;c=c|0;return pE(a,b,c,308)|0}function eq(a){return v[a+20>>2]+(v[a+8>>2]-v[a+24>>2]|0)|0}function c6(a){a=a|0;return C(C(z[zb(a+4208|0,6)>>2]*C(4)))}function bY(a,b,c){a=a|0;b=b|0;c=c|0;return xE(b,c,81584)|0}function bU(a){return!Mb(a,14144,4)&(w[a+4|0]-1&255)>>>0<10}function au(a,b){a=Fl(a);v[a>>2]=91500;Xv(a+4|0,b);return a}function aH(a,b){if(b>>>0<=9){return $G(a,b)}return Or(a,b)}function Y3(a,b){a=a|0;b=b|0;return C(ME(a,b,6190,1075834))}function W3(a,b){a=a|0;b=b|0;return C(LE(a,b,6233,1075834))}function VX(a,b,c){a=a|0;b=b|0;c=c|0;return wE(b,c,81584)|0}function V3(a,b){a=a|0;b=b|0;return C(LE(a,b,6135,1075835))}function TX(a,b,c){a=a|0;b=b|0;c=c|0;return wE(b,c,80048)|0}function T3(a,b){a=a|0;b=b|0;return C(ME(a,b,6091,1075835))}function SM(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Fb(Dy(b))}}function SI(a,b){a=a|0;b=b|0;return oi(v[b>>2],v[b+4>>2])|0}function RI(a,b){a=a|0;b=b|0;return ne(v[b>>2],v[b+4>>2])|0}function Os(a,b){if(b){Os(a,v[b>>2]);Os(a,v[b+4>>2]);Fb(b)}}function Ns(a,b){if(b){Ns(a,v[b>>2]);Ns(a,v[b+4>>2]);Fb(b)}}function KR(a){var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b}function GB(a,b,c){a=a|0;b=b|0;c=c|0;return pE(a,b,c,249)|0}function Fk(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Fb(Tf(b))}}function FV(a){a=a|0;a=xD(a,13301);v[a>>2]=26092;return a|0}function Ez(a,b){if(b){Ez(a,v[b>>2]);Ez(a,v[b+4>>2]);Fb(b)}}function Dz(a,b){if(b){Dz(a,v[b>>2]);Dz(a,v[b+4>>2]);Fb(b)}}function Afa(a,b,c){a=a|0;b=b|0;c=c|0;return rE(a,b,c,34)|0}function AD(a,b){return MA(a,qd(b),xd(v[b+4>>2],w[b+11|0]))}function $h(a,b){var c=0,d=0;c=a,d=hG(b),v[c>>2]=d;return a}function $X(a,b,c){a=a|0;b=b|0;c=c|0;return xE(b,c,80048)|0}function s$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib=0;return 0}function mW(a){a=a|0;a=xD(a,8675);v[a>>2]=30500;return a|0}function g2(a){a=a|0;qJ(a,2,100);xi(v[a+24>>2]+484360|0,0)}function dm(a){var b=0;b=v[a>>2];v[b>>2]=v[b>>2]|v[a+4>>2]}function cq(a,b,c){if((a|0)!=(b|0)){b=b-a|0;Zi(c-b|0,a,b)}}function an(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function UW(a){a=a|0;a=eO(a,7943);v[a>>2]=41992;return a|0}function UQ(a){var b=0;a=a+8|0;b=a>>>0<8?1:b;ib=b;return a}function Tx(a,b,c){A[a>>3]=A[a>>3]+b;A[a+8>>3]=A[a+8>>3]+c}function RX(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function Bb(a){if(ve(a)){return v[a+4>>2]}return w[a+11|0]}function ww(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function sp(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function qI(a){a=a|0;v[a>>2]=60780;$b(a+12|0);return a|0}
function lU(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0];return a}function eJ(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){nJ(c)}}function bw(a){if(v[a>>2]){Bc(a);qF(aw(a),v[a>>2],si(a))}}function bg(a){var b=0;pP(a);b=v[a>>2];if(b){wz(a);Fb(b)}}function Yp(a,b){if(nf(w[a+11|0])){Bd(a,b);return}ae(a,b)}function Sw(a,b){return v[((a>>>24^b)<<2)+461760>>2]^a<<8}function Sn(a){v[a>>2]=0;v[a+4>>2]=0;mj(a+8|0,0);return a}function Jt(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Fb(c)}}function Hga(a,b,c){a=a|0;b=b|0;c=c|0;Xf(a,b,Wc(b,c)+b|0)}function Dc(a,b){return qE(a,b,2147483647,-2147483648,-1)}function CH(a){while(1){if((Ur(a)|0)!=-1){continue}break}}function Bo(a){a=BD(a);v[a+8>>2]=0;v[a>>2]=88468;return a}function $1(a,b,c){a=a|0;b=b|0;c=c|0;Eo(a,b,c);return a|0}function pt(a,b){kc(a,b);kc(a+4|0,b+4|0);kc(Cb(a),Cb(b))}function oW(a,b,c){a=a|0;b=b|0;c=c|0;nv(a,b,v[b+8>>2],c)}function o2(a,b,c){a=a|0;b=b|0;c=c|0;Mc(a,PR(c,b,Cf(b)))}function lm(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function lF(a){a=a|0;v[a>>2]=83224;ub(a+16|0);return a|0}function kF(a){a=a|0;v[a>>2]=83184;ub(a+12|0);return a|0}function j0(a,b,c){a=a|0;b=b|0;c=c|0;return Fd(B(b,c))|0}function _y(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function YG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ch(a,-1,-1)}function Xi(a){return Le(a)|Le(a)<<8|Le(a)<<16|Le(a)<<24}function Wg(a,b){var c=0;c=w[a|0];t[a|0]=w[b|0];t[b|0]=c}function OM(a,b){a=NM(a,b);NM(a+12|0,b+12|0);t[a+24|0]=1}function NC(a){if((a|0)<0){xf(11129);L()}return tc(a<<1)}function Ht(a){lc(a+88|0);lc(a+68|0);lc(a+48|0);return a}function AJ(a,b){Cm(v[b>>2]);Gm(v[a>>2]);v[a>>2]=v[b>>2]}function w3(a,b){a=a|0;b=b|0;return Qm(a,b,11791,987)|0}function vI(a){a=a|0;v[a>>2]=61244;$b(a+4|0);return a|0}function un(a){a=a|0;v[a>>2]=76384;Wb(a+4|0);return a|0}function tD(a){a=a|0;v[a>>2]=43264;be(a+4|0);return a|0}function t3(a,b){a=a|0;b=b|0;return Qm(a,b,11821,989)|0}function qL(a){return(a|0)==1179012417|(a|0)==538987841}function pF(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Gm(b)}}function mv(a){a=a|0;v[a>>2]=91520;ZE(a+4|0);return a|0}function l3(a,b){a=a|0;b=b|0;return Qm(a,b,11917,992)|0}function i3(a,b){a=a|0;b=b|0;return Qm(a,b,11885,993)|0}function f6(a){a=a|0;return z[zb(a+4208|0,1)>>2]<C(1)|0}function as(a){a=a|0;v[a>>2]=49444;hs(a+4|0);return a|0}function aG(a,b,c){a=dc(a,b);dc(a+4|0,v[c>>2]);return a}function a4(a,b){a=a|0;b=b|0;return Qm(a,b,11853,972)|0}function ZT(a){a=a|0;v[a>>2]=91500;ZE(a+4|0);return a|0}function ZE(a){a=$w(v[a>>2]);if((kv(a+8|0)|0)<0){Fb(a)}}function W5(a){a=a|0;aK(a);t[a+4202|0]=1;v[a+4224>>2]=0}function Tn(a,b,c){v[a>>2]=b;v[a+4>>2]=v[c>>2];return a}function TE(a,b,c,d,e){return Ha(a|0,b|0,c|0,d|0,e|0)|0}function SA(a){a=a&255;return Oc(a)^1|(a-49&255)>>>0<36}function Qc(a){if(ve(a)){a=hl(a)-1|0}else{a=10}return a}function Pd(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function NH(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function L6(a){a=a|0;return z[zb(a+4208|0,3)>>2]<C(1)|0}function Kr(a){a=a|0;v[a>>2]=76448;Wb(a+4|0);return a|0}function J3(a,b){a=a|0;b=b|0;return Qm(a,b,11756,979)|0}function Ib(a){v[a>>2]=0;v[a+4>>2]=0;lh(a+8|0);return a}function H3(a,b){a=a|0;b=b|0;return RE(a,b,13273,980)|0}function Do(a){var b=0;b=v[a+8>>2];v[a+8>>2]=0;return b}function A8(a,b,c){a=a|0;b=b|0;c=c|0;return ZK(a,b,c)|0}function y$(a){a=a|0;return df(v[v[a>>2]-12>>2]+a|0)|0}function uL(a,b){return B(b&65535,a&65535)+7>>>3&65535}function mL(a,b){return(b>>>0<=15?t[a+b|0]:63)<<24>>24}function lL(a,b){return(b>>>0<=45?t[a+b|0]:63)<<24>>24}function hX(a){a=a|0;a=jb[a|0]()|0;ra(ib|0);return a|0}function fh(a){var b=0;b=Ur(a);v[a+1396>>2]=0;return b}function en(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function ap(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function a5(a,b){a=a|0;b=b|0;return RE(a,b,6393,921)|0}function a$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Xf(a,c,d)}function Z_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dG(a,c,d)}function Xw(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function Ub(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function UG(a){a=a|0;return Jr(v[v[a>>2]-12>>2]+a|0)|0}function To(a){if(ve(a)){a=hl(a)-1|0}else{a=1}return a}function S9(a,b,c){a=a|0;b=b|0;c=c|0;dE(a,b,c,768,767)}function O8(a,b,c){a=a|0;b=b|0;c=c|0;dE(a,b,c,839,838)}function NZ(a,b){a=a|0;b=b|0;cc(a,MG(v[b>>2]),v[b>>2])}function LG(a){a=a|0;return Hr(v[v[a>>2]-12>>2]+a|0)|0}function Gh(a,b){a=a|0;b=b|0;jb[v[v[b>>2]+24>>2]](a,b)}function Gga(a,b){a=a|0;b=b|0;return Qb(a,b?b:21598)|0}function Gg(a,b){a=a|0;b=b|0;jb[v[v[b>>2]+20>>2]](a,b)}function Fh(a,b){a=a|0;b=b|0;jb[v[v[b>>2]+28>>2]](a,b)}function Dca(a,b){a=a|0;b=b|0;if(!SQ(a,b)){Sb(b,0,40)}}function A$(a){a=a|0;return fp(v[v[a>>2]-12>>2]+a|0)|0}function vb(a){if(nf(w[a+11|0])){Fb(v[a>>2])}return a}function v1(a,b){a=a|0;b=b|0;yN(v[a>>2],b);return a|0}function mn(a,b,c,d){return v[(c<<2)+a>>2]+(b+d<<1)|0}function iv(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(c){Cm(c)}}function hB(a,b){a=fe(a,b);Sb(a+20|0,0,1040);return a}function eG(a,b,c){a=fG(a,b,c,0,-2147483648);return a}function _e(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function Yq(a,b){a=gc(a,b);Sb(a+20|0,0,1040);return a}function V6(a,b,c){a=a|0;b=b|0;c=c|0;cc(a,b+4228|0,7)}function Um(a,b){return jb[v[v[a>>2]+36>>2]](a,b,0)|0}function Tm(a,b){return jb[v[v[a>>2]+52>>2]](a,b,0)|0}function Ri(a){a=a|0;return jb[v[v[a>>2]+16>>2]](a)|0}function Qi(a){a=a|0;return jb[v[v[a>>2]+12>>2]](a)|0}function Qb(a,b){a=a|0;b=b|0;Eo(a,b,Cf(b));return a|0}function Nfa(a,b,c){a=a|0;b=b|0;c=c|0;RR(a,b,zb(b,c))}function E7(a,b,c){a=a|0;b=b|0;c=c|0;cc(a,b+4260|0,8)}function Dy(a){vp(a+223860|0);$b(a+223848|0);return a}function Df(a,b,c,d){b=b+d|0;ib=a+c>>>0<c>>>0?b+1|0:b}function AK(a){lc(a+36|0);lc(a+24|0);yx(a+12|0);yx(a)}function $g(a){a=a|0;return jb[v[v[a>>2]+24>>2]](a)|0}function $b(a){if(v[a>>2]){Bc(a);Fb(v[a>>2])}return a}function pz(a){a=Ib(a);v[a+12>>2]=0;u[a+16>>1]=65280}function m7(a){a=a|0;t[a+4202|0]=1;us(a);Ax(a);BK(a)}function kD(a){return mH(a,C(2.524354896707238e-29))}function jD(a,b,c,d){return jr(a,b,c,d,36,119304648)}function iU(a,b,c,d){return jr(a,b,c,d,28,153391690)}function et(a,b,c){t[a|0]=b;t[a+1|0]=w[c|0];return a}function dq(a,b,c,d,e){cc(a,b+d|0,(e|0)==-1?c-d|0:e)}function av(a){a=a|0;return jb[v[v[a>>2]+8>>2]](a)|0}function TC(a,b){return(w[b+34|0]&8)>>>3&(a&2050)==2}function Qea(a,b,c){a=a|0;b=b|0;c=c|0;gE(a,b,c,13,2)}function K7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function HD(a){return mH(a,C(1.5845632502852868e29))}function Ds(a){a=a|0;a=xh(a);v[a+20>>2]=0;return a|0}function Aia(a){if(a){return 31-E(a-1^a)|0}return 32}function zca(a,b){a=a|0;b=b|0;Eo(a,b,12);return a|0}function y0(a,b,c){a=a|0;b=b|0;c=c|0;_H(a-88|0,b,c)}function xb(a,b,c){cc(a,(c>>>3&536870908)+b|0,1<<c)}function vea(a,b){a=a|0;b=b|0;return Nv(a,b,1100)|0}function v0(a,b,c){a=a|0;b=b|0;c=c|0;YH(a-88|0,b,c)}function uv(a,b){a=a|0;b=b|0;return MA(a,b,Cf(b))|0}function uo(a,b,c){cc(a,(c>>>3&536870908)+b|0,c&31)}function qK(a){a=a|0;return C(z[zb(a+4208|0,0)>>2])}function p2(a){a=a|0;a=v[a+4>>2];return(a?a:4972)|0}function lj(a){if(!a){return 0}return v[a+44>>2]!=0}function ffa(a,b,c){a=a|0;b=b|0;c=c|0;gE(a,b,c,5,3)}function ed(a,b){a=a|0;b=b|0;return ZK(a,b,Cf(b))|0}function dp(a,b){b=v[b>>2];v[a>>2]=b;Cm(b);return a}function d6(a){a=a|0;return C(z[zb(a+4208|0,3)>>2])}function cO(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function bM(a){v[a>>2]=49552;v[a>>2]=49524;return a}function aZ(){Rd(468280);nF(468288);v[117070]=85840}function _m(a,b,c){v[a>>2]=b;v[a+4>>2]=c-b;return a}function _Y(){Rd(468296);nF(468304);v[117074]=85996}function Ud(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function Sca(a,b,c){a=a|0;b=b|0;c=c|0;Mc(a,uv(b,c))}function Qj(a){if(!a){return 0}return jj(w[a+31|0])}function NT(a,b,c,d){return jr(a,b,c,d,48,89478486)}function Mr(a,b){v[a>>2]=b;v[a+4>>2]=b>>31;return a}function Ml(a,b,c){if(!c){return 0}return Mb(a,b,c)}function Lfa(a,b,c){a=a|0;b=b|0;c=c|0;mE(a,b,c,256)}function Kw(a){if(!a){return 0}v[115696]=a;return-1}function K6(a){a=a|0;return C(z[zb(a+4208|0,1)>>2])}function Ie(a){var b=0;b=v[a>>2];if(b){Cb(a);Fb(b)}}function IC(a,b,c){t[a+8|0]=1;v[a+4>>2]=c;v[a>>2]=b}function Eea(a,b){a=a|0;b=b|0;return Dj(a,b,1030)|0}function EN(a,b,c,d){return jr(a,b,c,d,7,613566757)}function Bz(a){t[a+6|0]=0;u[a+4>>1]=65535;v[a>>2]=0}function Ao(a){a=a|0;a=vc(a);jb[v[v[a>>2]>>2]](a)|0}function x0(a,b){a=a|0;b=b|0;return ZH(a-88|0,b)|0}function w1(a,b){a=a|0;b=b|0;return Mo(a,b,1073)|0}function w0(a,b){a=a|0;b=b|0;return Mo(a,b,1077)|0}function vfa(a,b){a=a|0;b=b|0;return Dj(a,b,826)|0}function u0(a,b){a=a|0;b=b|0;return XH(a-88|0,b)|0}function n0(a,b,c){a=a|0;b=b|0;c=+c;SH(a-92|0,b,c)}function ll(a,b){return(a&65535)>>>0<(b&65535)>>>0}function l0(a,b,c){a=a|0;b=b|0;c=+c;QH(a-92|0,b,c)}function ho(a){a=(a|0)<120?a:120;return(a|0)>1?a:1}function a2(a,b){a=a|0;b=b|0;return Mo(a,b,1072)|0}function WD(a,b,c){a=a|0;b=b|0;c=c|0;Mc(a,AD(b,c))}function SR(a,b,c){a=a|0;b=b|0;c=c|0;Mc(a,vF(b,c))}function Ol(a){dj(a+724|0);dj(a+732|0);dj(a+740|0)}function Oha(a,b){a=a|0;b=b|0;return kE(a,b,330)|0}function Nea(a,b){a=a|0;b=b|0;if(!pu(a,b)){uu(b)}}
function M0(a,b){a=a|0;b=b|0;return Mo(a,b,1075)|0}function Ln(a,b,c){if((a|0)!=(b|0)){Zi(c,a,b-a|0)}}function H0(a,b){a=a|0;b=b|0;return Mo(a,b,1076)|0}function Cfa(a,b){a=a|0;b=b|0;return Dj(a,b,422)|0}function A0(a,b,c){a=a|0;b=b|0;c=+c;aI(a-88|0,b,c)}function xp(a,b){v[a+4>>2]=256;v[a>>2]=b;return a}function xD(a,b){a=wD(a,b);v[a>>2]=91780;return a}function vC(a){return!Mb(a,26176,25)&w[a+34|0]<65}function tG(a){return(Jj(a)|0)!=0|(a|32)-97>>>0<6}function rL(a,b){return(a|0)==1179011410&b>>>0>80}function qB(a){return(v[Cb(a)>>2]-v[a>>2]|0)/28|0}function lea(a,b){a=a|0;b=b|0;return Dj(a,b,71)|0}function kn(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function iC(a){return(v[Cb(a)>>2]-v[a>>2]|0)/20|0}function hh(a,b){if(ve(a)){Bd(a,b);return}ae(a,b)}function gga(a,b){a=a|0;b=b|0;return Dj(a,b,91)|0}function fv(a){return(v[Cb(a)>>2]-v[a>>2]|0)/36|0}function eS(a){return(v[Cb(a)>>2]-v[a>>2]|0)/33|0}function dia(a,b){a=a|0;b=b|0;if(!TT(a,b)){cu(b)}}function cc(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function bga(a,b){a=a|0;b=b|0;if(!hS(a,b)){gS(b)}}function ZS(a){if(!(a&255)){return 1}return Oc(a)}function XE(a){return(a<<1)+16777216>>>0<16777217}function Ul(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function US(a,b){a=a|0;b=b|0;return kE(a,b,308)|0}function Tl(a,b,c){v[a+4>>2]=c;u[a>>1]=b;return a}function Np(a,b,c){return v[(b<<2)+a>>2]+(c<<2)|0}function N5(a,b){a=a|0;b=b|0;return C(sl(a,b,12))}function N3(a){a=a|0;return Pv(a,12771,1074416)|0}function L8(a,b){a=a|0;b=b|0;return Dj(a,b,225)|0}function KT(a){return(v[Cb(a)>>2]-v[a>>2]|0)/48|0}function I8(a,b){a=a|0;b=b|0;return Dj(a,b,326)|0}function Hs(a){return(v[Cb(a)>>2]-v[a>>2]|0)/52|0}function Hfa(a,b){a=a|0;b=b|0;if(!ZC(a,b)){Pq(b)}}function EQ(a){return(v[Cb(a)>>2]-v[a>>2]|0)/56|0}function Ct(a){return(v[Cb(a)>>2]-v[a>>2]|0)/24|0}function Bj(a){return(v[Cb(a)>>2]-v[a>>2]|0)/12|0}function BD(a){v[a+4>>2]=0;v[a>>2]=91028;return a}function z0(a,b){a=a|0;b=b|0;return+$H(a-88|0,b)}function ys(a){a=a|0;lc(a+4208|0);return sf(a)|0}function yI(a,b){a=a|0;b=b|0;mk(a,b,60340,60348)}function xI(a,b){a=a|0;b=b|0;mk(a,b,60356,60364)}function x5(a,b){a=a|0;b=b|0;return C(sl(a,b,3))}function vA(a,b){a=a|0;b=b|0;if(!uS(a,b)){BA(b)}}function u6(a,b){a=a|0;b=b|0;return C(sl(a,b,4))}function sia(a,b){a=a|0;b=b|0;return ju(a,1,b)|0}function m0(a,b){a=a|0;b=b|0;return+RH(a-92|0,b)}function lK(a){a=a|0;lc(a+4256|0);return sf(a)|0}function kx(a,b){v[a>>2]=v[b>>2];Mc(a+4|0,b+4|0)}function k0(a,b){a=a|0;b=b|0;return+PH(a-92|0,b)}function hq(a,b){a=a|0;b=b|0;if(!Vh(a,b)){ol(b)}}function gT(a,b){v[a>>2]=v[a>>2]+B(b,6);return a}function fz(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function bu(a){return(v[Cb(a)>>2]-v[a>>2]|0)/6|0}function aU(a,b){a=JT(a,b);if(!a){nB(b)}return a}function _n(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function Y5(a,b){a=a|0;b=b|0;return C(sl(a,b,1))}function UU(a,b){a=a|0;b=b|0;if(!TB(a,b)){vu(b)}}function T8(a,b){a=a|0;b=b|0;if(!gD(a,b)){sv(b)}}function Ry(a){return(v[Cb(a)>>2]-v[a>>2]|0)/7|0}function R3(a){a=a|0;return KE(a,8767,1074448)|0}function Q6(a,b){a=a|0;b=b|0;return C(sl(a,b,6))}function O3(a){a=a|0;return Pv(a,5280,1074424)|0}function N8(a,b){a=a|0;b=b|0;return Dj(a,b,73)|0}function MB(a,b){a=a|0;b=b|0;if(!oD(a,b)){nD(b)}}function LM(a,b,c){v[a+4>>2]=c;t[a|0]=b;return a}function KI(a,b){a=a|0;b=b|0;mk(a,b,57864,57872)}function JI(a,b){a=a|0;b=b|0;mk(a,b,57880,57888)}function HK(a){a=a|0;$b(a+4208|0);return sf(a)|0}function G8(a,b){a=a|0;b=b|0;return Dj(a,b,60)|0}function FT(a,b){a=a|0;b=b|0;if(!ET(a,b)){$t(b)}}function FI(a,b){a=a|0;b=b|0;mk(a,b,58684,58692)}function F5(a,b){a=a|0;b=b|0;return C(sl(a,b,2))}function EO(a,b){v[a>>2]=v[a>>2]+(b<<1);return a}function EI(a,b){a=a|0;b=b|0;mk(a,b,58700,58708)}function Co(a,b,c){a=Xd(a);v[a+4>>2]=c;v[a>>2]=b}function CI(a,b){a=a|0;b=b|0;mk(a,b,59512,59520)}function C6(a,b){a=a|0;b=b|0;return C(sl(a,b,5))}function BI(a,b){a=a|0;b=b|0;mk(a,b,59528,59536)}function Au(a,b){a=a|0;b=b|0;if(!Lq(a,b)){Aq(b)}}function $c(a,b,c,d){return yd(a,B(zg(b),c)+d|0)}function xx(a,b){return Lt(z[a>>2],z[b>>2])?b:a}function xea(a,b){a=a|0;b=b|0;Oo(a,b,586,585,8)}function xV(a,b){a=a|0;b=b|0;Ap(a,b);return a|0}function tj(a,b){a=a|0;b=b|0;KB(a,v[a+16>>2]|b)}function t2(a){a=a|0;return FE(a,49192,12495)|0}function pk(a){return jb[v[v[a>>2]+36>>2]](a)|0}function nd(a,b){return Yo(v[b>>2],v[a>>2])?b:a}function nF(a){var b=0,c=0;b=a,c=wd(),v[b>>2]=c}function m3(a){a=a|0;return Pv(a,5777,480272)|0}function lq(a,b,c){if(b){Sb(a,Jf(c),b)}return a}function lS(a){return!Mb(a,13852,4)&w[a+4|0]<32}function iga(a,b){a=a|0;b=b|0;Oo(a,b,462,461,6)}function fea(a,b){a=a|0;b=b|0;Oo(a,b,618,617,8)}function eia(a,b,c){a=a|0;b=b|0;c=c|0;UB(a,b,c)}function dH(a,b){if(!a){return 0}return Iw(a,b)}function _G(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function Tc(a,b){return ll(x[b>>1],x[a>>1])?b:a}function Sc(a,b){return Xp(v[a>>2],v[b>>2])?b:a}function Re(a,b){return ll(x[a>>1],x[b>>1])?b:a}function QB(a,b){return(b&255)==2&(a&255)>>>0<3}function P3(a){a=a|0;return KE(a,7071,480214)|0}function Nt(a,b){a=a|0;b=b|0;return Lb(a,b,1)^1}function Kha(a,b){a=a|0;b=b|0;Oo(a,b,347,346,8)}function Ke(a,b){return Yo(v[a>>2],v[b>>2])?b:a}function Hl(a,b){return Lt(z[b>>2],z[a>>2])?b:a}function HR(a){var b=0;b=v[a>>2];xe(a);return b}function Gy(a){if(w[a+24|0]){TM(a);t[a+24|0]=0}}function Eb(a,b){return Xp(v[b>>2],v[a>>2])?b:a}function Bh(a,b,c){return Ia(933,a|0,b|0,c|0)|0}function $m(a){return jb[v[v[a>>2]+28>>2]](a)|0}function zr(a,b){return(a&255)>>>0<(b&255)>>>0}function xz(a){return a>>>0<=45?w[a+43840|0]:0}function wea(a,b){a=a|0;b=b|0;return SQ(a,b)|0}function s6(a){a=a|0;t[a+4202|0]=1;eK(a);dK(a)}function r2(a){a=a|0;return FE(a,49212,8178)|0}function ph(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function nu(a,b,c){a=a|0;b=b|0;c=c|0;qU(a,b,c)}function iO(a){$y(a);Sb(a+27|0,0,255);return a}function ct(a){return(a>>>0<9?a:a-9|256)&65535}function cf(a,b,c){if(!(w[a|0]&32)){xu(b,c,a)}}function b2(a,b){a=a|0;b=b|0;Mc(a,pJ(b,17587))}function _f(a,b,c){a=Cia(a,b,c,c>>31);return a}function Xj(a,b){return(B(b,104)+a|0)+484380|0}function WO(a){v[a>>2]=0;v[a+4>>2]=-1;return a}function MX(a,b,c){a=a|0;b=b|0;c=c|0;cc(a,c,b)}function L5(a){a=a|0;YJ(a);sx(a);t[a+4202|0]=1}function IA(a,b,c){a=a|0;b=b|0;c=c|0;RB(a,b,c)}function DU(a,b){a=a|0;b=b|0;Oo(a,b,284,283,8)}function AB(a){return!Mb(a,15422,4)&w[a+4|0]<4}function A6(a){a=a|0;t[a+4202|0]=1;gK(a);jK(a)}function z$(a){a=a|0;FG(v[v[a>>2]-12>>2]+a|0)}function yha(a,b){a=a|0;b=b|0;oE(a,b,351,350)}function xm(a){return(a>>>0>127?a^128:-1)&255}function xk(a,b){a=a|0;b=b|0;return OG(a,b)|0}function xG(a){a=wJ(a);v[a>>2]=77904;return a}function x$(a){a=a|0;EG(v[v[a>>2]-12>>2]+a|0)}function uc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function ub(a){if(ve(a)){Fb(v[a>>2])}return a}function uQ(a){a=Bia(a&65535,0,80,0);return a}function tn(a){a=Fl(a);v[a>>2]=91440;return a}function t8(a,b){a=a|0;b=b|0;jy(hL(a+24|0,b))}function ss(a){a=wJ(a);v[a>>2]=77680;return a}function ria(a,b){a=a|0;b=b|0;oE(a,b,290,289)}function rF(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function qg(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function qT(a){ib=0;a=(a&65535)-98|0;return a}function mw(a,b,c){a=fG(a,b,c,-1,-1);return a}function mU(a,b){a=a|0;b=b|0;return vF(a,b)|0}function mS(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function mJ(a){a=a|0;v[a>>2]=49276;return a|0}function h1(a){a=a|0;v[a>>2]=60880;return a|0}function eW(a){a=a|0;v[a>>2]=61300;return a|0}function dt(a,b){a=a|0;b=b|0;return Oh(a,b)|0}function aga(a,b){a=a|0;b=b|0;Jv(a,b,17,3,16)}function a1(a){a=a|0;v[a>>2]=60380;return a|0}function Zo(a,b){a=a|0;b=b|0;return SG(a,b)^1}function YT(a){t[a+12|0]=w[a+12|0]|2;return a}function Xd(a){v[a>>2]=0;v[a+4>>2]=0;return a}function Wk(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function WP(a){return Ee(443250/+(a>>>0)*1e4)}function VW(a,b){a=a|0;b=b|0;return VD(a,b)|0}function Uh(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function UV(a){a=a|0;v[a>>2]=43128;return a|0}function TG(a){a=a|0;Aw(v[v[a>>2]-12>>2]+a|0)}function SV(a){a=a|0;v[a>>2]=42888;return a|0}function Rd(a){a=BD(a);v[a>>2]=83512;return a}function Rb(a,b){return zr(w[b|0],w[a|0])?b:a}function KG(a){a=a|0;xw(v[v[a>>2]-12>>2]+a|0)}function Ir(a,b){a=a|0;b=b|0;return OG(a,b)^1}function Ij(a,b){a=a|0;b=b|0;return SG(a,b)|0}function HW(a,b){a=a|0;b=b|0;return uv(a,b)|0}function Gx(a){return v[Cb(a)>>2]-v[a>>2]>>11}function GJ(a,b){a=a|0;b=b|0;return pJ(a,b)|0}function Eia(a,b,c,d){a=zia(a,b,c,d);return a}function EH(a,b){a=a|0;b=b|0;return AD(a,b)|0}function $e(a,b){return zr(w[a|0],w[b|0])?b:a}function zZ(a){a=a|0;Zd(a,468016,Sd(466544))}function yo(a,b,c,d){a=Cia(a,b,c,d);return a}function yZ(a){a=a|0;Zd(a,468024,Sd(466552))}function xd(a,b){if(!nf(b)){a=Jf(b)}return a}function xZ(a){a=a|0;Zd(a,468032,Sd(466748))}function wz(a){return v[vc(a)>>2]-v[a>>2]>>2}function wm(a){return v[Cb(a)>>2]-v[a>>2]>>1}function wZ(a){a=a|0;Zd(a,468048,Sd(466740))}function vZ(a){a=a|0;Zd(a,468056,Sd(466756))}function ux(a){return C(C(a*C(7900))+C(100))}function tZ(a){a=a|0;Zd(a,468064,Sd(466764))}function si(a){return v[Cb(a)>>2]-v[a>>2]>>2}function sZ(a){a=a|0;Zd(a,468080,Sd(466772))}function rZ(a){a=a|0;Zd(a,468088,Sd(466780))}function qZ(a){a=a|0;Zd(a,468096,Sd(466788))}function pZ(a){a=a|0;Zd(a,468120,Sd(466796))}function oZ(a){a=a|0;Zd(a,468152,Sd(466560))}function nh(a){return v[v[a+8>>2]>>2]==(a|0)}function nZ(a){a=a|0;Zd(a,468160,Sd(466568))}function nJ(a){if(a){jb[v[v[a>>2]+4>>2]](a)}}function n1(a){a=a|0;uI(a);return v[a+16>>2]}function mZ(a){a=a|0;Zd(a,468168,Sd(466576))}function lZ(a){a=a|0;Zd(a,468176,Sd(466584))}function kj(a){return eE(a,C(4294967296),-1)}function kZ(a){a=a|0;Zd(a,468184,Sd(466624))}function jw(){ia(tn(aa(4)|0)|0,91480,25);L()}function jZ(a){a=a|0;Zd(a,468192,Sd(466632))}function iZ(a){a=a|0;Zd(a,468200,Sd(466640))}function hZ(a){a=a|0;Zd(a,468208,Sd(466648))}function gZ(a){a=a|0;Zd(a,468216,Sd(466656))}function fr(a){return v[Cb(a)>>2]-v[a>>2]>>4}function fZ(a){a=a|0;Zd(a,468224,Sd(466664))}function eZ(a){a=a|0;Zd(a,468232,Sd(466672))}function dZ(a){a=a|0;Zd(a,468240,Sd(466680))}function cZ(a){a=a|0;Zd(a,468248,Sd(466592))}function c0(a){a=a|0;return eb(v[a+60>>2])|0}function bZ(a){a=a|0;Zd(a,468264,Sd(466600))}function _3(a){a=a|0;return NE(a,7015,976)|0}function ZY(a){a=a|0;Zd(a,468296,Sd(466616))}function YY(a){a=a|0;Zd(a,468312,Sd(466688))}function Xn(a){return v[Cb(a)>>2]-v[a>>2]>>5}function XY(a){a=a|0;Zd(a,468320,Sd(466696))}function Sda(a,b){a=a|0;b=b|0;Kv(a,b,1042,2)}function SE(a){a=Ga(a|0)|0;ib=O()|0;return a}function Oga(a,b){a=a|0;b=b|0;hr(a,b,1042,2)}function Lj(a){a=a&255;return(a|0)==255?-1:a}function LS(a,b){a=a|0;b=b|0;return(b|0)<6|0}function Jg(a,b,c,d){return(B(b,d)+c<<3)+a|0}function JR(a){if(a){GH(a);oe(v[a+80>>2],a)}}function Ih(a,b,c,d){return(B(b,d)+c<<2)+a|0}function Hm(a){return v[Cb(a)>>2]-v[a>>2]>>3}function F3(a){a=a|0;return NE(a,6552,984)|0}function ER(a,b,c,d){return(B(b,d)+c<<1)+a|0}function Dx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function By(a){t[a+24|0]=0;t[a|0]=0;return a}function Az(a){return v[Cb(a)>>2]-v[a>>2]>>8}function AU(a,b){a=a|0;b=b|0;Jv(a,b,44,2,44)}function $Y(a){a=a|0;Zd(a,468280,Sd(466608))}function tK(a){a=a|0;jb[v[v[a>>2]+4>>2]](a)}function tF(a,b,c){return jv(sF(a),sF(b),c)}function pj(a,b,c){if(c){Zi(a,b,c)}return a}function pc(a){if(ve(a)){a=v[a>>2]}return a}function om(a,b,c){return lf(a,b)>>>0>c>>>0}function o1(a){a=a|0;uI(a);return v[a+4>>2]}function j8(a,b){a=a|0;b=b|0;hr(a,b,1058,1)}function hf(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function h0(a,b){a=a|0;b=b|0;hr(a,b,1025,4)}function gi(a,b){a=a|0;b=b|0;return C(C(0))}function g0(a,b){a=a|0;b=b|0;hr(a,b,1025,2)}function bn(a){a=a|0;MG(v[a>>2]);return a|0}function _W(a,b){a=a|0;b=b|0;Fv(a,b,1058,2)}function Zn(a,b){u[a>>1]=b;u[a+2>>1]=b>>>16}function Vk(a,b){return a<<24>>24<b<<24>>24}function Vj(a,b){return a<<16>>16<b<<16>>16}function Uo(a){return v[Cb(a)>>2]-v[a>>2]|0}function NU(a,b){a=a|0;b=b|0;Kv(a,b,1025,2)}function MJ(a){return Lh(C(OJ(a)*C(32768)))}function MI(a){t[a+4|0]=0;t[a|0]=0;return a}function Fe(a,b,c){if(c){nc(a,b,c)}return a}function Al(a){a=a|0;zw(v[a>>2]);return a|0}function $A(a,b){v[a>>2]=v[a>>2]+b;return a}function yw(a){a=a|0;return vh(a,466740)|0}function vt(a){Ie(a+24|0);$b(a+12|0);$b(a)}function uw(a){a=a|0;return vh(a,466756)|0}function rk(a,b){jb[v[v[b>>2]+44>>2]](a,b)}function qk(a,b){jb[v[v[b>>2]+32>>2]](a,b)}function pw(a){a=a|0;return vh(a,466764)|0}function nr(a,b){jb[v[v[b>>2]+40>>2]](a,b)}function mH(a,b){return C(lH(a?C(-b):b)*b)}function lz(a){v[a>>2]=v[a>>2]+32;return a}function kw(a){a=a|0;return vh(a,466788)|0}function kW(a){a=a|0;return v[a+4>>2]!=0|0}function jm(a){v[a>>2]=v[a>>2]+28;return a}function hl(a){return v[a+8>>2]&2147483647}function g7(a,b,c){a=a|0;b=b|0;c=c|0;Xd(a)}function fw(a){a=a|0;return vh(a,466796)|0}function am(a){nz(v[a+20>>2]);v[a+20>>2]=0}function af(a,b,c){a=Bia(c,0,a,b);return a}function _L(a){v[a>>2]=v[a>>2]+52;return a}function Xr(a){return(a|0)<=65535&(a|0)>=0}function Un(a){v[a>>2]=v[a>>2]+16;return a}function Tu(a){a=a|0;return vh(a,466748)|0}function Sp(a){v[a>>2]=v[a>>2]+12;return a}function Rq(a){Zq(a+32|0);wb(a+12|0);vb(a)}function RJ(a){return C(C(a*C(96))+C(-96))}function Q$(a){a=a|0;return vh(a,466560)|0}function Mk(a){ub(a+36|0);lc(a+24|0);qh(a)}function MM(a,b){return uE(a,b,2147483647)}function IP(a,b,c,d){cc(a,b,(d|0)==-1?c:d)}function I7(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function I$(a){a=a|0;return vh(a,466576)|0}function DW(a,b){a=a|0;b=b|0;Fv(a,b,257,0)}function Cda(a,b){a=a|0;b=b|0;lE(a,b,2,31)}function BU(a,b){a=a|0;b=b|0;Kv(a,b,274,0)}function $W(a,b){a=a|0;b=b|0;Fv(a,b,290,0)}function ye(a){v[a>>2]=v[a>>2]+4;return a}function yY(a,b){a=a|0;b=b|0;Oh(a,b+12|0)}function yU(a,b){a=a|0;b=b|0;Ho(a+12|0,b)}function xe(a){v[a>>2]=v[a>>2]+1;return a}function wia(a,b){a=a|0;b=b|0;Ii(a,b,136)}function vN(a,b){if(z[a>>2]>b){z[a>>2]=b}}function vF(a,b){return mr(a,Ec(b),Bb(b))}function uU(a,b){a=a|0;b=b|0;tq(a+36|0,b)}function s0(a,b){a=a|0;b=b|0;VH(a-88|0,b)}function p0(a,b){a=a|0;b=b|0;UH(a-92|0,b)}function o0(a,b){a=a|0;b=b|0;TH(a-92|0,b)}function m8(a,b){a=a|0;b=b|0;Oh(a,b+36|0)}function gk(a){v[a>>2]=v[a>>2]+6;return a}function g9(a,b){a=a|0;b=b|0;Ho(a+40|0,b)}function dx(a,b,c,d){return Np(a,c,b+d|0)}function bk(a,b){return v[a>>2]-v[b>>2]|0}function bia(a,b){a=a|0;b=b|0;lE(a,b,3,8)}function aF(){if(!w[468497]){t[468497]=1}}function _s(a){v[a>>2]=v[a>>2]+8;return a}function Wr(a){a=a|0;ns(a+8|0);return a|0}function UH(a,b){a=a|0;b=b|0;CE(a,b,2048)}function TH(a,b){a=a|0;b=b|0;CE(a,b,4096)}function T0(a,b){a=a|0;b=b|0;Km(a,b+12|0)}function SJ(a){a=a|0;Sb(a+4296|0,0,81928)}function Oe(a){v[a>>2]=v[a>>2]+2;return a}function Mea(a,b){a=a|0;b=b|0;Ii(a,b,274)}function Kf(a){a=a|0;xh(a+8|0);return a|0}function Jr(a){a=a|0;Ck(a+8|0);return a|0}function J0(a,b){a=a|0;b=b|0;iI(a-88|0,b)}function I0(a,b){a=a|0;b=b|0;hI(a-88|0,b)}function Hr(a){a=a|0;Ck(a+4|0);return a|0}function Hea(a,b){a=a|0;b=b|0;Ii(a,b,106)}function Ef(a,b){v[a>>2]=v[b>>2];return a}function EY(a,b){a=a|0;b=b|0;Oh(a,b+16|0)}function DO(a){v[a>>2]=v[a>>2]-2;return a}function Ak(a){a=a|0;return RG(a)<<24>>24}function $G(a,b){t[a|0]=b+48;return a+1|0}function yf(a,b){v[a+8>>2]=b|-2147483648}function xY(a,b){a=a|0;b=b|0;Qb(a,11254)}function wk(a){return(a|0)==32|a-9>>>0<5}function wY(a,b){a=a|0;b=b|0;Qb(a,11371)}function r0(a){a=a|0;return Wr(a-92|0)|0}function mq(a,b){t[a|0]=b;t[a+1|0]=b>>>8}function ik(a){return B(ym(a),Cd(a))&255}function hc(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function dj(a){u[a+4>>1]=65535;v[a>>2]=0}function cJ(a){return(pc(a)+Bb(a)|0)-1|0}function _fa(a,b){a=a|0;b=b|0;xq(a,b,17)}function YR(a,b){a=a|0;b=b|0;Ii(a,b,284)}function W6(a){a=a|0;t[a+4202|0]=1;wK(a)}function Q5(a){a=a|0;return v[a+4260>>2]}function Md(a,b){return(b|0)!=0&(a|0)!=0}function L0(a){a=a|0;return Wr(a-88|0)|0}function Kh(a,b){return v[a>>2]!=v[b>>2]}function Kfa(a,b){a=a|0;b=b|0;Ii(a,b,42)}function Gr(a,b){v[a+24>>2]=v[a+24>>2]+b}function GM(a,b,c){v[a>>2]=b;v[a+4>>2]=c}function G0(a,b){a=a|0;b=+b;gI(a-88|0,b)}function Fha(a,b){a=a|0;b=b|0;Ii(a,b,34)}function Fea(a,b){a=a|0;b=b|0;Ii(a,b,72)}function E0(a,b){a=a|0;b=+b;eI(a-88|0,b)}function DY(a,b){a=a|0;b=b|0;Sm(a,83256)}function DD(a,b){kc(a,b);kc(a+4|0,b+4|0)}function CY(a,b){a=a|0;b=b|0;Sm(a,83276)}function C0(a,b){a=a|0;b=+b;cI(a-88|0,b)}function Ar(a){a=a|0;Mv(a,155,91828,973)}function yB(a,b){a=a|0;b=b|0;Ii(a,b,50)}function vca(a,b){a=a|0;b=b|0;hE(a,b,3)}function p5(a){a=a|0;return(a|0)==277|0}function jV(a,b){a=a|0;b=b|0;Ii(a,b,59)}function fF(a,b){a=a|0;b=b|0;return b|0}function Zfa(a,b){a=a|0;b=b|0;WB(a,b,8)}function YU(a,b){a=a|0;b=b|0;xq(a,b,11)}function Sg(a,b,c){t[a+4|0]=c;v[a>>2]=b}function Rm(a,b,c){return Xf(a,b,b+c|0)}function Rj(a,b){return Ey(a&255,b&255)}function Ph(a){return(a&65535)>>>0<3999}function PS(a,b){a=a|0;b=b|0;xq(a,b,32)}function Ny(a,b,c){return a<b?b:a>c?c:a}function My(a,b,c){return a<b?b:a>c?c:a}function Lw(a){return(p(a),j(2))>>>20|0}function Jb(a){return(a<<8|a>>>8)&65535}function H7(a){a=a|0;return w[a+4201|0]}function G7(a){a=a|0;return w[a+4202|0]}function Fm(a){a=v[a+8>>2];if(a){Fb(a)}}function EM(a,b){return(Tk(a,b)|0)!=255}function EF(a,b){a=a|0;b=b|0;Ge(a,1,45)}function DI(a){v[a+4>>2]=v[a+4>>2]|8192}function DF(a,b){a=a|0;b=b|0;MF(a,1,45)}function AQ(a,b,c,d){return Wk(c,d,a,b)}function zv(a,b){v[a+4>>2]=4;v[a>>2]=b}function z5(a){a=a|0;return-2013527448}function uca(a){a=a|0;pQ(a);return a|0}function tv(a,b){v[a+4>>2]=3;v[a>>2]=b}function st(a,b,c){return ir(a,b,c,12)}function or(a){a=a|0;return 2147483647}function lk(a,b){v[a+4>>2]=2;v[a>>2]=b}function kA(a,b){a=a|0;b=b|0;hE(a,b,2)}function h6(a){a=a|0;return-271958638}
function ge(a,b,c){_m(a,b,Wc(b,c)+b|0)}function ej(a,b){return pc(a)+(b<<2)|0}function YV(a){a=a|0;return v[a+16>>2]}function YO(a,b,c){return rE(a,b,c,39)}function Ui(a,b){v[a+4>>2]=1;v[a>>2]=b}function SU(a){a=a|0;return v[a+12>>2]}function QT(a,b,c){return ir(a,b,c,48)}function Py(a,b){return qE(a,b,-1,0,0)}function Og(a){return eE(a,C(255),255)}function LK(a){a=a|0;return 1869112133}function Hu(a,b,c){return ir(a,b,c,20)}function F0(a){a=a|0;return+fI(a-88|0)}function Ed(a){v[v[a+8>>2]>>2]=v[a>>2]}function D0(a){a=a|0;return+dI(a-88|0)}function B0(a){a=a|0;return+bI(a-88|0)}function $I(a){return a?(a|0)==2?3:2:1}function zD(a){a=a|0;return v[a+8>>2]}function yz(a,b,c){return No(a,b,c,5)}function x6(a){a=a|0;return-284078960}function wo(a,b,c){return gr(a,b,c,1)}function wJ(a){v[a>>2]=77708;return a}function ve(a){return w[a+11|0]>>>7|0}function tia(a,b){a=a|0;b=b|0;$s(a,b)}function tP(a,b,c){return gr(a,b,c,5)}function s5(a,b){a=a|0;b=b|0;return 3}function ri(a,b,c){return No(a,b,c,2)}function qD(a,b,c){ec(a,b,Dg(b,c)<<3)}function q5(a,b){a=a|0;b=b|0;return 2}function pL(a,b){Uc(a,b&4?16:8,1,0,0)}function pJ(a,b){return mr(a,b,Cf(b))}function p6(a){a=a|0;return-281111764}function oN(a,b){return(0-b|0)!=(a|0)}function nS(a,b,c){ec(a,b,sc(b,c)<<2)}function lf(a,b){return ek(a,b)&65535}function lP(a){return(a&65535)==65534}function lI(a){v[a>>2]=62072;return a}function kI(a){v[a>>2]=62096;return a}function k$(a){a=a|0;return vG(a,0)|0}function jj(a){return(a-1&255)>>>0<17}function jI(a){v[a>>2]=62176;return a}function j1(a){a=a|0;return w[a+40|0]}function j$(a){a=a|0;return vG(a,1)|0}function io(a,b){u[a+8>>1]=b;return a}function il(a,b,c){return gr(a,b,c,2)}function gq(a,b,c){return ir(a,b,c,6)}function g$(a){a=a|0;return uG(a,0)|0}function f$(a){a=a|0;return uG(a,1)|0}function em(a){return(a&740327453)!=0}function di(a,b,c){Mc(Mc(a,b)+12|0,c)}function _h(a){a=v[a>>2];if(a){hG(a)}}function _5(a){a=a|0;return-620920304}function Tq(a,b,c){return No(a,b,c,3)}function St(a,b){a=a|0;b=b|0;return 1}function SG(a,b){return QG(a)^QG(b)^1}function S6(a){a=a|0;return-270114148}function R5(a){a=a|0;return-275227023}function QI(a){v[a>>2]=49608;return a}function Of(a,b,c){return $c(a,b,c,0)}function OG(a,b){return NG(a)^NG(b)^1}function Lr(a,b){a=a|0;b=b|0;return-1}function Lo(a,b,c){return No(a,b,c,4)}function LI(a){v[a>>2]=57848;return a}function He(a,b){v[a+4>>2]=b;return a}function HJ(a,b){a=a|0;b=b|0;return 0}function H5(a){a=a|0;return 302837129}function Fl(a){v[a>>2]=92080;return a}function F6(a){a=a|0;return-285139079}function Eq(a){a=a|0;return v[a+4>>2]}function Em(a){v[a>>2]=60832;return a}function DJ(a){a=C(a-a);return C(a/a)}function Ci(a,b,c){return No(a,b,c,1)}function A7(a){a=a|0;return 542066252}function $D(a,b,c){return gr(a,b,c,4)}function zg(a){return x[a+480188>>1]}function zY(a){a=a|0;return t[a+9|0]}function uR(a,b){if(!oR(a,b)){Xz(b)}}function sW(a){a=a|0;VC(Ec(a),Bb(a))}function rx(a){a=a|0;QE(a,49112,924)}function qx(a,b){a=a|0;b=b|0;Km(a,b)}function nq(a,b){a=a|0;b=b|0;Ix(a,b)}function mQ(a){return(a|0)<120?a:120}function ls(a,b){a=a|0;b=b|0;qx(a,b)}function ks(a){return x[a+480192>>1]}function kQ(a){return(a&255)>>>0<129}function jt(a){return v[Cb(a)>>2]<<5}function js(a){return x[a+480190>>1]}function gP(a,b,c,d){eP(cc(a,b,c),d)}function ei(a,b){a=a|0;b=b|0;Oh(a,b)}function e1(a){a=a|0;return w[a+8|0]}function d7(a,b){a=a|0;b=b|0;dt(a,b)}function aM(a,b,c,d,e){$L(a,b,c,d,e)}function Yca(a){a=a|0;return pi(a)|0}function YM(a){return(a+5&255)>>>0<2}function Wt(a,b){return w[a+b|0]!=63}function WW(a,b){a=a|0;b=b|0;RM(a,b)}function WI(a,b,c,d,e){dJ(a,b,c,d,e)}function Uha(a){a=a|0;return zT(a)|0}function Ug(a){Yj(a+44|0);$b(a+32|0)}function PJ(a){v[a>>2]=0;v[a+4>>2]=0}function Mm(a,b){a=a|0;b=b|0;ls(a,b)}function KK(a,b,c){a=a|0;b=b|0;c=c|0}function Ix(a,b){a=a|0;b=b|0;ei(a,b)}function HP(a,b){return B(b,872)+a|0}function GW(a,b){a=a|0;b=b|0;YD(a,b)}function Dq(a,b){a=a|0;b=b|0;dv(a,b)}function Cm(a){v[a+4>>2]=v[a+4>>2]+1}function CA(a,b){a=a|0;b=b|0;sJ(a,b)}function Bx(a,b){a=a|0;b=b|0;JK(a,b)}function BJ(a){a=a|0;QE(a,49056,922)}function AY(a){a=a|0;return t[a+8|0]}function zB(a){a=a|0;return av(a)|0}function xg(a,b){return B(b,20)+a|0}function xB(a){a=a|0;return tc(a)|0}function wq(a){a=a|0;return Ae(a)|0}function vp(a){if(w[a+24|0]){TM(a)}}function rt(a,b){return B(b,36)+a|0}function rd(a,b){return(b-a|0)/12|0}function rc(a,b){return(a|0)==(b|0)}function rW(a){a=a|0;return mg(a)|0}function pp(a){return ST(a,251,255)}function pn(a,b){return(b-a|0)/24|0}function oq(a,b){return(b-a|0)/28|0}function jS(a,b){return B(b,33)+a|0}function he(a,b,c){return aG(a,b,c)}function gj(a,b){return dg(a,b)&255}function fq(a,b){return(b-a|0)/48|0}function ek(a,b){return(b-a|0)/52|0}function dc(a,b){v[a>>2]=b;return a}function al(a,b){return fu(Ic(a,b))}function ag(a){return C(D(a))==C(N)}function a9(a){a=a|0;return ki(a)|0}function Zk(a,b){return B(b,24)+a|0}function Xp(a,b){return a>>>0<b>>>0}function Wu(a){t[a+2|0]=0;u[a>>1]=0}function Vb(a,b){return le(a,b&255)}function V5(a){a=a|0;v[a+4224>>2]=0}function Up(a){return(a&255)==1?1:2}function Sx(a,b){return B(b,28)+a|0}function Sq(a,b){return(b-a|0)/36|0}function Rf(a,b){return mj(a,Ud(b))}function RV(a){a=a|0;hD(Sb(a,0,36))}function QV(a){a=a|0;return xh(a)|0}function QC(a){a=a|0;return Ag(a)|0}function PA(a,b,c){return Vt(a,b,c)}function Oz(a,b){return B(b,56)+a|0}function Ow(a){return!Mb(a,92396,6)}function Nf(a,b){return B(b,52)+a|0}function Lp(a,b){return(b-a|0)/56|0}function Kt(a,b){return(b-a|0)/33|0}function J9(a){a=a|0;return $g(a)|0}function J$(a){a=a|0;return zk(a)|0}function IR(a,b){return Vg(a,0-b|0)}function IJ(a){a=a|0;return Ck(a)|0}function Gi(a,b,c){return jv(a,b,c)}function Dd(a,b){return B(b,12)+a|0}function CG(a){a=a|0;return mv(a)|0}function Bf(a,b){return(b-a|0)/20|0}function zx(a,b,c,d){Gv(a,b,c,d,9)}function yd(a,b){return B(b,6)+a|0}function xv(a,b){return vk(a,b,12)}function xF(a){return vh(a,466648)}function wF(a){return vh(a,466640)}function vw(a){return rc(a,-1)?0:a}function tJ(a,b,c,d){Gv(a,b,c,d,2)}function sj(a,b){return B(ik(b),a)}function re(a,b){cc(a,Ec(b),Bb(b))}function ox(a,b,c,d){Gv(a,b,c,d,4)}function on(a,b){v[a+1298464>>2]=b}function oD(a,b){return Nv(a,b,20)}function o8(a){a=a|0;xq(a,21598,1)}function nf(a){return(a&128)>>>7|0}function mD(a,b){return vk(a,b,36)}function kU(a,b){return vk(a,b,28)}function i0(a,b){a=a|0;b=b|0;Fb(b)}function hS(a,b){return Nv(a,b,18)}function fi(a){a=a|0;t[a+4202|0]=0}function eB(a){return a&2147483647}function dh(a,b){v[a>>2]=v[a>>2]|b}function cT(a){return w[a+1|0]!=63}function _M(a){Wd(a+8|0);SM(a+4|0)}function Yo(a,b){return(a|0)<(b|0)}function XI(a){return(Lj(a)|0)==-1}function VI(a,b){a=a|0;b=b|0;$b(b)}function UI(a,b){a=a|0;b=b|0;bm(b)}function Sy(a,b){return(b-a|0)/7|0}function Pc(a,b){return uE(a,b,-1)}function Nq(a,b){return(b<<11)+a|0}function Nn(a,b){return(b<<13)+a|0}function LW(a){a=a|0;Im(a,1,13423)}function Il(a){return C(D(a))<C(N)}function Hk(a,b){return(a+b|0)-1|0}function Dh(a,b){a=a|0;b=b|0;Gb(a)}function Bs(a,b){return(a-b|0)/6|0}function BF(a){return vh(a,466632)}function Aq(a){t[a|0]=0;t[a+1|0]=0}function AF(a){return vh(a,466624)}function $j(a,b){return(b-a|0)/6|0}function zb(a,b){return(b<<2)+a|0}function w$(a){a=a|0;return 10367}function vz(a,b){return vk(a,b,4)}function uh(a){v[a>>2]=1;return a}function tf(a){return a!=a?C(0):a}function rh(a){v[a>>2]=v[a>>2]+20}function pI(a){v[a>>2]=v[a>>2]+24}function oX(a){a=a|0;return 12998}function nz(a){if(a){Fb(a+-64|0)}}function ms(a){return fE(a,76384)}function lh(a){v[a>>2]=0;return a}function le(a,b){return(b<<5)+a|0}function jx(a,b){return wL(a,b)^1}function im(a){v[a>>2]=2;return a}function dfa(a){a=a|0;og(a,16763)}function dea(a){a=a|0;VR(a,65535)}function ce(a,b){return!Mb(a,b,4)}function bG(a,b){return aG(a,0,b)}function ac(a,b){return(b<<1)+a|0}function _p(a,b){return je(a,b)^1}function _c(a,b){return(b<<4)+a|0}function Zl(a,b){return(b<<8)+a|0}function Xga(a){a=a|0;og(a,16132)}function Vf(a,b){return Ec(a)+b|0}function VG(a){return fE(a,76448)}function Tv(a,b){return v[a+b>>2]}function SC(a){return(a&16)>>>4|0}function Ql(a){u[a>>1]=0;return a}function Od(a){return v[fc(a)>>2]}function Oc(a){return ST(a,1,120)}function Ne(a,b){return(b<<3)+a|0}function Nb(a,b){return rc(a,b)^1}function Js(a){$b(a+4|0);return a}function Jj(a){return a-48>>>0<10}function JX(a){a=a|0;return 13112}function HX(a){a=a|0;return 10247}function HN(a,b){return vk(a,b,8)}function Fc(a,b){return pc(a)+b|0}function En(a){return a+1074328|0}function zG(a){v[a+72>>2]=465560}function yfa(a){a=a|0;ku(a,4848)}function yK(a){return(a&8)>>>3|0}function yG(a){v[a+72>>2]=465644}function xf(a){Mv(a,24,91708,23)}function vW(a){a=a|0;VC(a,Cf(a))}function pX(a){a=a|0;return 9806}function nX(a){a=a|0;return 5681}function mT(a,b,c){tE(a,b,c,256)}function kq(a,b,c){mE(a,b,c,128)}function k9(a){a=a|0;gg(a,hj(a))}function jq(a){return Sb(a,0,48)}function efa(a){a=a|0;og(a,3968)}function WR(a,b){nc(a,b+4|0,256)}function Uga(a){a=a|0;og(a,4445)}function Su(a,b){return Fia(a,b)}function So(a){Mv(a,24,91760,93)}function Qha(a){a=a|0;og(a,3892)}function Pf(a,b,c,d){_e(a,c,d,b)}function Oy(a){t[a|0]=0;return a}function Oda(a){a=a|0;og(a,4126)}function Nga(a){a=a|0;og(a,4339)}function Mu(a,b,c){tE(a,b,c,128)}function Hg(a,b,c){_m(a,b,b+c|0)}function Gf(a,b){dc(lh(a)+4|0,b)}function DX(a){a=a|0;return 6827}function Ch(a){return!v[a+16>>2]}function Bfa(a){a=a|0;ku(a,3883)}function AW(a){a=a|0;og(a,16790)}function zs(a,b){return Vj(a,b)}function zc(a,b){return Nq(a,b)}function yb(a,b){return(a&b)!=0}function yT(a,b){return Se(b,a)}function xj(a,b){return b-a>>11}function wb(a){be(a+12|0);be(a)}function vg(a,b){return Nb(a,b)}function uf(a,b){return mj(a,b)}function sk(a,b,c){cc(a,b,1<<c)}function rn(a){return a<<24>>24}function rj(a,b,c){_e(a,c,20,b)}function q0(a){a=a|0;_w(a-92|0)}function pr(a){a=a|0;return 127}function pB(a,b){return jo(b,a)}function oi(a,b){return Wc(a,b)}function of(a){vb(a+20|0);vb(a)}function nl(a,b){return xd(a,b)}function nj(a,b){return le(a,b)}function ni(a,b){return(a|b)!=0}function ne(a,b){return sc(a,b)}function mu(a,b,c){_e(a,c,30,b)}function mj(a,b){return dc(a,b)}function mI(a,b){return Dg(a,b)}function jf(a){a=a|0;return a|0}function jG(a){if(kG(a)){Fb(a)}}function gc(a,b){return vD(a,b)}function fy(a){u[a+480214>>1]=0}function ef(a){return rn(Jf(a))}function dl(a,b,c){_e(a,c,22,b)}function cp(a,b){return zb(a,b)}function cG(a,b){return rd(a,b)}function bo(a,b){return ll(a,b)}function aw(a){return Cb(a+8|0)}function ak(a,b,c){_e(a,c,12,b)}function ah(a,b){return!xd(a,b)}function aC(a){return(a&255)==1}function Yv(a,b){return Kg(a,b)}function Ye(a,b){return kg(a,b)}function Xl(a){return Wl(de(a))}function Xb(a,b){return Nf(a,b)}function Uz(a,b,c){_e(a,c,64,b)}function Uk(a){vb(a+12|0);ld(a)}function Ue(a,b,c){_e(a,c,32,b)}function UP(a,b){Hv(a,b,12,-12)}function Ty(a,b){return Ic(a,b)}function TM(a){QM(a+12|0);PM(a)}function Sh(a,b,c){_e(a,c,13,b)}function Rs(a){RN(a+12|0);QN(a)}function Rl(a){ub(a+12|0);ub(a)}function Qu(a,b){return FC(a,b)}function OU(a){a=a|0;og(a,4319)}function Nd(a){return(a&255)!=0}function Mg(a){return YM(a&255)}function MT(a,b){Hv(a,b,48,-48)}function Ki(a,b){return a>>>b&1}function K0(a){a=a|0;_w(a-88|0)}function HC(a,b){return EC(a,b)}function FL(a,b){return DL(a,b)}function Ee(a){return bq(de(a))}function Bn(a,b){return zr(a,b)}function Bi(a,b){return Nu(a,b)}function BW(a){a=a|0;og(a,4493)}function $n(a){Jt(a,0);return a}function $k(a,b,c){_e(a,c,28,b)}function $f(a){return Mh(a)?0:a}function yD(a){return a+1024|0}function xw(a){a=a|0;Fb(Hr(a))}function wx(a){a=a|0;Fb(uK(a))}function wn(a){a=a|0;Fb(ys(a))}function vS(a,b){_m(a,b,pd(b))}function ut(a){return a>>>27^a}function sz(a){return a+4896|0}function sc(a,b){return b-a>>2}function p1(a){a=a|0;Fb(vI(a))}function oe(a,b){if(!a){Fb(b)}}function oY(a){a=a|0;Fb(jF(a))}function mx(a){a=a|0;Fb(oJ(a))}function mh(a,b){return b-a>>8}function mF(a){a=a|0;Fb($v(a))}function kK(a){a=a|0;Fb(lK(a))}function jo(a,b){return a-b>>1}function f1(a){a=a|0;Fb(qI(a))}function dn(a){return(a|0)==-1}function dg(a,b){return b-a>>5}function bh(a,b){return b-a>>4}function bd(a,b){t[a|0]=w[b|0]}function bW(a){a=a|0;Fb(tD(a))}function _w(a){a=a|0;Fb(Wr(a))}function Zb(a,b){v[a+100>>2]=b}function ZJ(a){a=a|0;Fb(_J(a))}function XX(a){a=a|0;Fb(eF(a))}function V1(a){a=a|0;Fb(as(a))}function PX(a){a=a|0;Fb(dF(a))}function P5(a){a=a|0;return 13}function Lm(a){a=a|0;Fb(ZT(a))}function Kk(a){a=a|0;Fb(sf(a))}function KC(a){return tc(a<<2)}function JP(a){return a+4096|0}function Ic(a,b){return b-a>>1}function Gt(a,b){return a-b>>2}function GQ(a,b){Jv(a,b,5,3,4)}function GK(a){a=a|0;Fb(HK(a))}function FY(a){a=a|0;Fb(lF(a))}function FG(a){a=a|0;Fb(fp(a))}function Ey(a,b){return a<<8|b}function EG(a){a=a|0;Fb(df(a))}function Dw(a){a=a|0;Fb(Ck(a))}function Dm(a){a=a|0;Fb(mv(a))}function Dg(a,b){return b-a>>3}function Cw(a){a=a|0;Fb(un(a))}function Cd(a){return a&64?2:1}function C$(a){a=a|0;Fb(qs(a))}function Bw(a){a=a|0;Fb(Kr(a))}function BY(a){a=a|0;Fb(kF(a))}function Aw(a){a=a|0;Fb(Jr(a))}function z7(a){a=a|0;return 9}function ym(a){return a&1?2:1}function xs(a){a=a|0;return 4}function xK(a){a=a|0;return 3}function vL(a,b,c){Ul(a,b,-c)}function se(a){a=a|0;return 1}function sd(a){return(a|0)!=0}function sK(a){a=a|0;return 7}function qo(a){return a>>>0<5}function qe(a){a=a|0;return 2}function pS(a){jq(Sb(a,0,48))}function nT(a,b){_e(a,b,40,2)}function n5(){return 19923968}function mf(a){return mj(a,0)}function lR(a){return a+128|0}function ic(a){a=a|0;return 0}function fs(a,b){v[a+32>>2]=b}function fK(a){a=a|0;return 5}function Yz(a,b){ec(a,b,1024)}function Xe(a){return D(a)==N}function Xc(a,b){dp(a,b+28|0)}function XG(a){a=a|0;return-1}function Wc(a,b){return b-a|0}function Ve(a,b){u[a+28>>1]=b}function Tj(a){return sd(a)^1}function TQ(a,b){ec(a,b,1108)}function Se(a,b){return a-b|0}function On(a,b){v[a+36>>2]=b}function Kq(a,b){_e(a,b,26,3)}function Iu(a){return!v[a>>2]}function Hw(){return kb()<<16}function Hb(a,b){return a+b|0}function HQ(a,b){_e(a,b,33,1)}function Go(a){return a+20|0}
function Gb(a){VE(a);return a}function Ek(a){return(a&5)!=0}function EB(a,b){ec(a,b,1954)}function E6(a){a=a|0;return 6}function DN(a,b){Hv(a,b,7,-7)}function AA(a,b){ec(a,b,4896)}function $p(a){return a+256|0}function zQ(a){return a-28|0}function zO(a){yO(a,v[a>>2])}function xQ(a,b){ec(a,b,146)}function we(a,b){a=a|0;b=b|0}function vc(a){return a+12|0}function uO(a,b,c){Sl(a,c,b)}function tQ(a,b){ec(a,b,608)}function sq(a,b){ec(a,b,192)}function sS(a,b){ec(a,b,128)}function pv(a,b){FD(a,Ud(b))}function pd(a){return a+16|0}function ou(a,b){ec(a,b,512)}function oO(a,b,c){Vl(a,c,b)}function np(a,b){z[a+8>>2]=b}function nR(a,b){ec(a,b,130)}function mp(a,b){z[a+4>>2]=b}function lp(a,b){t[a+33|0]=b}function ko(a,b){fe(a,b+8|0)}function kR(a,b){ec(a,b,600)}function jA(a,b){Jt(a,Ud(b))}function hT(a,b){ec(a,b,218)}function fU(a,b){ec(a,b,610)}function ec(a,b,c){cc(a,b,c)}function eT(a,b){ec(a,b,157)}function eR(a,b){ec(a,b,126)}function dP(a,b){ec(a,b,263)}function ae(a,b){t[a+11|0]=b}function _x(a,b){t[a+34|0]=b}function Zx(a,b){t[a+32|0]=b}function ZO(a){return a+48|0}function Yx(a,b){t[a+35|0]=b}function Yg(a,b,c){jv(a,b,c)}function YS(a,b){ec(a,b,674)}function YP(a,b){ec(a,b,204)}function Wh(a,b,c){cD(a,b,c)}function Vy(a){t[a+6152|0]=0}function VN(a){return D(a)<N}function UA(a,b){_e(a,b,8,2)}function SS(a){return a+36|0}function Rn(a){return a+32|0}function Pp(a){return a+14|0}function PN(a){ON(a,v[a>>2])}function Op(a,b){return a<<b}function LL(a){return a-32|0}function Is(a){eM(a,v[a>>2])}function Gl(a,b){v[a+8>>2]=b}function Fr(a,b){dp(a,b+4|0)}function Bd(a,b){v[a+4>>2]=b}function Bc(a){Bd(a,v[a>>2])}function BC(a,b){ec(a,b,497)}function Aj(a){return a-36|0}function $w(a){return a-12|0}function $l(a,b,c){uo(a,b,c)}function $S(a,b){ec(a,b,576)}function zn(a){return a-4|0}function zi(a){return a+3|0}function ze(a){return!Bb(a)}function xA(a,b){ec(a,b,33)}function vm(a,b){cc(a,b,32)}function vR(a,b){ec(a,b,30)}function tS(a,b){ec(a,b,80)}function tC(a,b){ec(a,b,38)}function so(a,b){t[a+1|0]=b}function rp(a){Sb(a,0,8192)}function rC(a,b){Ii(a,b,37)}function pT(a,b){ec(a,b,98)}function pC(a,b){ec(a,b,41)}function oA(a,b){ec(a,b,40)}function ny(a){Sb(a,0,4096)}function mo(a){v[a+12>>2]=0}function m5(){return 393219}function kf(){xf(10941);L()}function kT(a,b){ec(a,b,48)}function jP(a,b){return a<b}function hu(a,b){ec(a,b,64)}function hO(a,b){ec(a,b,27)}function gu(a,b){ec(a,b,66)}function gd(a){return a+1|0}function fm(){So(10941);L()}function fc(a){return a+4|0}function fB(a,b){ec(a,b,12)}function _B(a,b){ec(a,b,11)}function Zt(a,b){ec(a,b,22)}function YQ(a,b){ec(a,b,32)}function VB(a,b){cc(a,b,20)}function Uu(a,b){cc(a,b,22)}function SB(a,b){ec(a,b,17)}function Qf(a,b){t[a+3|0]=b}function Qe(a){return a+2|0}function PT(a,b){nc(a,b,48)}function Oq(a,b){ec(a,b,36)}function Lt(a,b){return a<b}function KQ(a,b){ec(a,b,96)}function Jf(a){return a&255}function JD(a,b){ec(a,b,24)}function Iq(a){return a&127}function Gu(a,b){ec(a,b,65)}function Fx(a){Sb(a,0,2048)}function Fu(a,b){ec(a,b,16)}function DB(a){Sb(a,0,1954)}function Cb(a){return a+8|0}function CK(a){return 0-a|0}function $R(a,b){ec(a,b,52)}function zz(a){Sb(a,0,256)}function zh(a,b){ec(a,b,4)}function zL(a){Wx(a,Od(a))}function yn(a,b){z[a>>2]=b}function wc(a){v[a+8>>2]=0}function wQ(a){Sb(a,0,146)}function uz(){xf(7636);L()}function td(a,b){v[a>>2]=b}function sQ(a){Sb(a,0,608)}function rK(a,b){VK(a,3,b)}function rA(a){pA(a,Od(a))}function qu(a,b){ec(a,b,5)}function no(a,b){ec(a,b,7)}function kl(a,b){ec(a,b,2)}function jR(a){Sb(a,0,600)}function gaa(a){a=a|0;fb=a}function eU(a){Sb(a,0,610)}function dV(a){a=a|0;xh(a)}function dT(a){Sb(a,0,157)}function dR(a){Sb(a,0,126)}function dC(a,b){Wh(a,2,b)}function cv(a,b){ec(a,b,3)}function cr(a){a=a|0;dr(a)}function _S(a){Sb(a,0,576)}function _A(a,b){ec(a,b,6)}function Xz(a){Sb(a,0,130)}function Xk(a,b){uo(a,b,0)}function XP(a){Sb(a,0,204)}function Wb(a){Gm(v[a>>2])}function VS(a){Sb(a,0,192)}function Rk(a){Qy(a,Od(a))}function RN(a){zp(a,Od(a))}function QM(a){Ns(a,Od(a))}function PM(a){Os(a,Od(a))}function Mh(a){return a!=a}function Lu(){So(7636);L()}function KS(a){EA(a,Od(a))}function IS(a){FA(a,Od(a))}function Ft(a){qA(a,Od(a))}function Fq(a,b){ec(a,b,1)}function Daa(){return fb|0}function Cc(a){a=a|0;Fb(a)}function Bm(a,b){ec(a,b,8)}function BP(a){Dz(a,Od(a))}function Ai(a,b){u[a>>1]=b}function AP(a){Ez(a,Od(a))}function AC(a){Sb(a,0,497)}function z2(){return 2048}function yA(a){Sb(a,0,33)}function sC(a){Sb(a,0,38)}function oT(a){Sb(a,0,98)}function oC(a){Sb(a,0,41)}function nB(a){Sb(a,0,66)}function lT(a){Sb(a,0,48)}function _R(a){Sb(a,0,52)}function Zu(a){return a&1}function Pq(a){Sb(a,0,36)}function MK(a){Om(a,2048)}function LQ(a){Sb(a,0,96)}function Eh(a,b){t[a|0]=b}function BA(a){Sb(a,0,80)}function $t(a){Sb(a,0,64)}function xO(a,b){yO(a,b)}function wu(a,b){XB(a,b)}function wA(a,b){cS(a,b)}function tz(a){v[a>>2]=0}function tO(a,b){If(a,b)}function oB(a,b){bl(a,b)}function hR(a){Lv(a,512)}function gs(a){ub(a+4|0)}function gL(a,b){eM(a,b)}function eC(a){u[a>>1]=0}function ci(a,b){Hh(a,b)}function ZA(a,b){gc(a,b)}function Xs(a,b){NL(a,b)}function Rt(a){vb(a+4|0)}function PQ(a,b){fe(a,b)}function Ot(a,b){yS(a,b)}function Nm(a,b){KB(a,b)}function NN(a){Wd(a+8|0)}function Kp(a,b){td(a,b)}function Ko(a,b){Mc(a,b)}function Jx(a,b){Rf(a,b)}function Jd(a,b){Bd(a,b)}function Jc(a){$b(a+8|0)}function Id(a){wb(a+8|0)}function Hj(a,b){Eh(a,b)}function HB(a,b){uJ(a,b)}function Cg(a){a=a|0;L()}function As(a,b){yn(a,b)}function yh(a){Ev(a,24)}function to(a){vE(a,11)}function rg(a){t[a|0]=0}function kga(){va();L()}function dB(a){vE(a,16)}function cC(a){Lv(a,16)}function br(a){Ev(a,36)}function XD(a){Ev(a,48)}function LT(a){Om(a,48)}function rS(a){Lv(a,4)}function qS(a){Jt(a,0)}function py(a){hM(a,0)}function oy(a){gM(a,0)}function od(){uz();L()}function fg(a){JS(a,0)}function es(a){fJ(a,0)}function _i(a){eJ(a,0)}function Zq(a){FD(a,0)}function Uq(a){Om(a,8)}function Kc(a){Je(a,0)}function IL(a){mM(a,0)}function Di(a){Om(a,2)}function CX(){$E();L()}function CN(a){Om(a,7)}function AS(a){Om(a,6)}function $i(a){gJ(a,0)}function $E(){wa();L()}function kJ(a){xe(a)}function ff(a){a=a|0}function bm(a){lc(a)}function bc(a){vb(a)}function Vz(a){gk(a)}function Pb(a){ub(a)}function OP(a){Ib(a)}function KP(a){ye(a)}function Jo(a){vc(a)}function JN(a){Sn(a)}
// EMSCRIPTEN_END_FUNCS
e=w;var jb=c([null,Qb,WD,Km,NW,Im,DW,vW,ID,sW,nW,_C,tV,qV,Bq,tj,bV,$,Tu,fl,JG,$g,nm,fia,ZT,jf,oga,kga,$fa,Rfa,mA,Afa,qfa,mca,Tea,aR,Z$,Y$,Nr,aR,Raa,Aaa,eO,$s,Ap,X9,N9,ZM,D9,xB,BL,Oh,Qb,b9,A8,Ix,JK,Bx,ei,hK,v6,n6,e6,K5,C5,I$,H$,t$,ls,U3,RM,y2,s2,T1,O1,ei,B1,w1,$0,Q0,N0,M0,H0,w0,h0,EH,g0,d0,jH,MA,zw,va,Lb,TY,bX,aX,$W,_W,ZW,YW,Mm,XW,WW,EH,VW,UW,ia,SW,RW,QW,qx,PW,OW,MW,RD,QD,LW,vv,KW,Io,HW,cr,Ho,ql,og,EW,Io,GW,FW,CW,JW,BW,OD,AW,OD,IW,PD,zW,yW,xW,Mm,wW,Vc,Lb,rW,ov,qW,$g,pW,GD,oW,jk,GD,Xq,mW,mv,lv,RV,lW,dW,cW,QV,Ji,LV,KV,av,hD,JV,_8,$8,yN,Y8,Z8,Xx,Ds,Yb,a9,Qd,eD,GV,FV,QC,DV,CV,QC,yV,Pu,xV,p8,Ze,jfa,K9,EV,wq,Af,IU,J9,$ha,z8,o8,nV,mC,mV,lV,lC,kV,hg,jV,iV,Ac,hV,gV,ig,Xg,fV,oo,eV,jC,dV,$U,YB,_U,ZU,YU,Cu,TO,zC,ix,XU,WU,VU,UU,TU,Eu,RU,OB,zd,tq,OU,NU,tu,NB,MU,LU,KU,MB,JU,LB,Du,jl,Ju,DU,rq,CU,Kb,zf,og,BU,nu,AU,ed,qq,zU,yU,xU,zB,yB,kd,wU,km,vU,uU,tU,uB,tB,Ji,ku,yia,xia,waa,wia,Zg,via,ria,ck,uia,tia,mU,sia,Vh,Kf,oia,nia,mia,$T,jia,ck,qj,iia,hia,iq,gia,lB,eia,dia,cia,bia,aia,jl,IT,FT,Yha,Vha,Zm,Tha,gg,dU,Uha,Cu,BT,Sha,Rha,cB,Qha,lv,Pha,Oha,wT,oda,Nha,jl,Kha,rq,fo,Jha,Iha,yB,Hha,Gha,Fha,Eha,Dha,pm,Cha,Bha,Aha,yha,ck,tT,zha,Vh,Kf,kB,tha,qha,wh,lha,kha,hha,gha,fha,eha,dha,cha,hq,bha,aha,$ga,NA,zV,_ga,Zga,og,Yga,Xga,Wga,wV,Vga,Uga,Tga,Sga,US,TS,Rga,Qga,og,Pga,Oga,_T,mha,Nga,Mga,nha,Lga,Kga,Jga,JA,JA,IA,Iga,Hga,RS,JA,OS,Gga,tY,Fga,Ega,Dga,Cga,Bga,Aga,zga,MS,md,eo,nga,CA,yga,a8,_7,Z7,Y7,X7,W7,xga,wga,If,vga,uga,tga,sga,WD,vaa,taa,l8,x8,y8,rga,qga,pga,i9,U7,ls,raa,qaa,paa,oaa,iga,hga,gga,fga,ega,dga,cga,bga,aga,_fa,Zfa,Yfa,Xfa,Vfa,Ufa,Wfa,dS,Kf,YR,vA,Qfa,uA,Pfa,Ofa,Nfa,Mfa,XR,tA,Lfa,Pu,lC,Kfa,VR,UR,Jq,sA,Jfa,Ge,Ifa,SR,hq,Au,hq,Hfa,Dq,og,$T,hq,Baa,Zm,Efa,Dfa,Cfa,Bfa,kA,Dt,zfa,yfa,xfa,wfa,vfa,ufa,tfa,nC,sfa,rfa,pfa,ofa,nfa,mfa,lfa,kfa,GA,ifa,hfa,gfa,ffa,og,QS,PS,QA,efa,dfa,tu,lv,cfa,bfa,afa,baa,nq,$ea,eu,iu,Xf,I9,faa,Ys,FN,H9,G9,qN,Ss,lN,F9,bN,mO,E9,cz,fj,Xh,Rea,Qea,At,Zea,Nt,Nea,GB,Mea,Lea,bR,eo,Kea,Jea,$Q,Iea,Hea,Gea,zt,Fea,Eea,Dea,Cea,Tz,xea,Qz,wea,vea,uea,ck,Vh,Kf,Xh,rea,qea,pea,oea,uA,lea,kea,zt,jea,oo,B8,gea,fea,qj,QQ,Qz,Du,eea,dea,cea,bea,xt,aea,xt,$da,_q,AV,Yda,ck,Zda,_da,Mz,CQ,Vh,Kf,At,Vda,Sda,vA,Rda,Oda,Nda,pQ,$Q,NA,Mda,tu,og,Dda,Cda,MB,Bda,Ada,zda,yda,VP,xda,km,uda,tda,sda,rda,qda,pda,_l,LP,nda,mda,lda,kda,jda,ida,hda,gda,fda,eda,dda,cda,bda,uA,ada,$ca,_ca,Nt,Zca,Xca,Wca,rq,U9,ov,zB,aaa,$9,rq,_9,Xh,ov,Z9,Y9,W9,Vca,wP,Sca,Rca,Qca,Pca,Oca,Nca,Hq,Kca,Jca,Ica,Hca,Gca,Fca,Eca,Dca,Cca,Bca,Aca,zca,TW,YD,yca,og,xca,wca,el,caa,Caa,xB,BO,yaa,xaa,uaa,saa,dt,naa,nO,laa,kaa,gO,jaa,iaa,haa,YN,WN,Mn,TN,eaa,daa,go,S9,qj,zN,$q,X8,W8,V8,w9,BV,U8,bv,$q,OB,T8,zN,Q9,S8,V9,ck,Vh,Kf,T9,ck,Vh,Kf,R9,ck,Vh,Kf,O9,mU,nq,C9,B9,A9,z9,y9,v9,zaa,uca,_O,u9,tc,s9,s8,r9,uW,PV,IV,NV,p9,o9,HV,OV,tW,MV,YL,n9,m9,l9,XL,ly,k9,j9,maa,h9,g9,f9,e9,bL,j8,uv,VD,cE,Xx,c9,ls,ju,zq,M9,P9,P8,O8,qj,N8,Qz,M8,L8,K8,At,J8,Xh,I8,H8,G8,F8,E8,ck,Vh,Kf,Q8,w8,v8,u8,t8,Hh,Bl,r8,q8,n8,h8,g8,f8,e8,d8,_K,k8,kp,YK,nk,Hh,If,b8,We,V7,c8,i8,S7,R7,k7,Q7,Oj,NK,cg,WK,B7,l7,wl,f7,ei,e7,d7,c7,Xx,dt,a7,iy,vK,G6,y6,q6,i6,$5,S5,U5,I5,A5,JJ,rs,u5,t5,s1,u1,k5,j5,h5,GJ,d9,x1,e5,JJ,d5,d2,W1,g2,b5,_0,BJ,rx,$4,t2,oJ,r2,aJ,Z4,$7,W4,M6,X4,H6,U4,$1,o2,S4,b2,zJ,SR,yJ,xJ,vJ,I4,G4,BJ,rx,D4,C4,B4,A4,z4,y4,x4,w4,v4,u4,t4,s4,r4,q4,p4,o4,n4,m4,l4,k4,j4,i4,h4,g4,d4,b4,$3,wD,S0,h2,Z3,K3,_1,I3,G3,Jk,U0,V0,E3,Z0,x3,v3,m8,s3,rx,n3,k3,h3,qn,T0,f3,d3,b3,$2,Z2,X2,V2,T2,R2,P2,N2,L2,rJ,G2,E2,SL,Bt,qJ,B2,A2,x2,w2,v2,u2,hp,L9,ar,IM,jh,WN,m2,l2,j2,kh,ZM,f2,t9,c2,jH,mr,a2,Z1,oo,jl,jl,X1,q9,e2,n2,i2,Av,ca,v1,iJ,hJ,t1,wI,r1,q1,g1,Y0,X0,W0,R0,ML,vca,j0,i0,f0,e0,$$,_$,DG,CG,OX,Q$,P$,O$,N$,M$,L$,K$,jf,EX,NX,u$,CG,uw,pw,d$,c$,kw,Gh,Fh,vr,Fb,jw,Zo,Ij,Ak,iw,Al,W_,V_,Ri,Gg,UF,Qi,yw,fw,Gh,Fh,tr,Ir,xk,J$,fl,bn,Ri,Gg,OF,Qi,B_,w_,IG,r_,Dr,nm,m_,qr,ff,WZ,Ar,VZ,UZ,TZ,CF,RZ,PZ,OZ,yk,NZ,CF,LZ,KZ,IZ,HZ,EZ,DZ,zZ,yZ,xZ,wZ,vZ,uZ,tZ,sZ,rZ,qZ,pZ,oZ,nZ,mZ,lZ,kZ,jZ,iZ,hZ,gZ,fZ,eZ,dZ,cZ,bZ,aZ,$Y,_Y,ZY,YY,XY,WY,VY,Yca,$E,Dm,Eq,tca,sca,rca,qca,pca,oca,nca,lca,kca,jca,ica,hca,gca,fca,eca,dca,cca,bca,aca,$ba,_ba,Zba,Yba,Xba,Wba,Vba,Uba,Tba,Sba,Rba,Qba,Pba,Oba,Nba,Mba,Lba,Kba,Jba,Iba,Hba,Gba,Fba,Eba,Dba,Cba,Bba,Aba,zba,yba,xba,wba,vba,uba,tba,sba,rba,qba,pba,oba,nba,mba,lba,kba,jba,iba,hba,gba,fba,eba,dba,cba,bba,aba,$aa,_aa,Zaa,Yaa,Xaa,Waa,Vaa,Uaa,Taa,Saa,Qaa,Paa,Oaa,Naa,Maa,Laa,Kaa,Jaa,Iaa,Haa,Gaa,Faa,Eaa,Dm,Mca,Lca,jha,iha,Qda,Pda,Jda,Ida,Tfa,Sfa,Bea,Aea,lga,jga,FU,EU,xha,wha,cV,aV,QU,PU,tea,sea,Uda,Tda,Uca,Tca,lia,kia,_ha,Zha,sV,rV,pV,oV,iea,hea,Xda,Wda,Pea,Oea,mga,mS,sha,rha,pha,oha,qia,pia,Mha,Lha,nea,mea,R8,D8,C8,Uea,Sea,wda,vda,zea,yea,vha,uha,Lda,Kda,Fda,Eda,Xha,Wha,Hda,Gda,_ea,Wea,Vea,vV,uV,HU,GU,Gfa,Ffa,Yea,Xea,Lm,Eq,SV,Cc,Ao,HJ,Cc,jf,Cc,ic,se,se,ic,ic,TV,gW,fW,UV,Cc,Ao,Cc,tD,bW,aW,$V,_V,ZV,YV,XV,WV,VV,ys,wn,wn,LK,ic,ff,ic,ic,ic,we,xs,P7,O7,N7,M7,L7,gi,St,St,Dx,KK,Dx,Dx,K7,ff,mS,J7,I7,H7,G7,F7,fi,IK,h7,ic,ic,se,Cx,qe,qe,se,E7,D7,we,ff,we,ff,HK,GK,GK,A7,ic,ff,ic,ic,ic,we,z7,FK,y7,x7,w7,v7,gi,u7,t7,s7,r7,q7,p7,o7,n7,m7,fi,BK,ic,ic,se,qe,qe,se,EK,DK,sf,Cg,CX,j7,Ex,i7,ic,g7,KK,T6,I6,z6,r6,j6,a6,T5,J5,B5,b6,T7,C7,b7,ys,wn,wn,LK,ic,ff,ic,ic,ic,we,xK,$6,_6,Z6,Y6,X6,gi,W6,fi,wK,ic,ic,se,qe,qe,se,V6,U6,lK,kK,kK,F6,ic,ff,ic,ic,ic,we,E6,D6,C6,B6,gi,A6,fi,gK,ic,ic,se,qe,qe,Kk,Kk,x6,ic,ff,ic,ic,ic,we,fK,w6,u6,t6,gi,s6,fi,dK,ic,ic,se,qe,qe,ys,wn,wn,p6,ic,ff,ic,ic,ic,we,fK,o6,m6,l6,gi,k6,fi,bK,ic,ic,se,qe,qe,uK,wx,wx,h6,ic,ff,ic,ic,ic,we,sK,g6,Q6,P6,gi,O6,fi,N6,ic,ic,se,qe,qe,we,ff,qK,f6,d6,pK,c6,oK,nK,wx,tK,S6,sK,R6,qK,L6,K6,pK,J6,oK,nK,Kk,Kk,_5,ic,ff,ic,ic,ic,we,qe,Z5,Y5,X5,gi,W5,fi,V5,ic,ic,se,qe,qe,_J,ZJ,ZJ,R5,ic,ff,ic,ic,Q5,we,P5,O5,N5,M5,gi,L5,fi,sx,ic,ic,se,qe,qe,we,ff,Kk,Kk,H5,ic,ff,ic,ic,ic,we,xK,G5,F5,E5,gi,D5,fi,UJ,ic,ic,se,qe,qe,Kk,Kk,z5,ic,ff,ic,ic,ic,we,xs,y5,x5,w5,gi,v5,fi,SJ,ic,ic,se,qe,qe,mJ,Cc,q2,mx,p2,mx,mx,Cg,as,V1,k2,jf,Cc,LS,St,Cg,jf,Cg,jf,Cc,U1,S1,Cg,SI,RI,SI,RI,we,cs,we,cs,VI,UI,VI,UI,Cc,Y1,jf,Cc,R1,Q1,Cc,KI,JI,Cg,M1,HI,L1,HI,P1,II,N1,II,Cc,K1,J1,Cc,FI,EI,Zr,Zr,Zr,Zr,I1,ex,ex,ex,Cc,H1,G1,Cc,CI,BI,D1,zI,C1,zI,F1,AI,E1,AI,Cc,A1,z1,Cc,yI,xI,Yr,Yr,Yr,Yr,y1,cx,cx,cx,a1,Cc,Ao,Cc,qI,f1,se,se,e1,d1,Eq,c1,b1,Cg,Cg,h1,Cc,Ao,Cc,vI,p1,se,ic,se,o1,n1,m1,l1,k1,j1,i1,Cg,eW,Cc,Ao,Cc,Cc,kW,se,se,Eq,zD,jW,iW,hW,we,cs,we,cs,Wr,_w,P0,O0,iI,hI,gI,fI,eI,dI,cI,bI,aI,$H,_H,ZH,YH,XH,WH,VH,UH,TH,SH,RH,QH,PH,L0,K0,J0,I0,G0,F0,E0,D0,C0,B0,A0,z0,y0,x0,v0,u0,t0,s0,r0,q0,p0,o0,n0,m0,l0,k0,jf,Cg,jf,Cg,jf,Cg,c0,b0,a0,un,Cw,we,_G,ZG,YG,ic,ic,W$,XG,V$,Lr,U$,Lr,Kr,Bw,we,_G,ZG,YG,ic,ic,T$,XG,S$,Lr,R$,Lr,qs,C$,D$,B$,G$,F$,E$,fp,FG,A$,z$,Hr,xw,LG,KG,df,EG,y$,x$,Jr,Aw,UG,TG,jf,Cc,w$,MX,LX,KX,v$,Dm,X$,ic,s$,Cw,h$,g$,f$,e$,IJ,Dw,Ck,Dw,Bw,l$,k$,j$,i$,Jr,Aw,UG,TG,IJ,Dw,Cw,o$,wG,n$,m$,Bw,r$,wG,q$,p$,Hr,xw,LG,KG,dF,PX,tK,eF,XX,WX,VX,UX,TX,fF,SX,RX,QX,jF,oY,nY,mY,lY,kY,ic,jY,iY,kF,BY,AY,zY,yY,xY,wY,lF,FY,zD,SU,EY,DY,CY,jf,Cc,Cc,gY,fY,eY,dY,cY,bY,aY,$X,fF,_X,ZX,YX,Cc,gF,gF,_v,se,se,hY,se,Cc,rY,qY,_v,ic,ic,pY,xs,Cc,vY,uY,_v,ic,ic,sY,xs,jf,Cc,b$,a$,$_,jf,Cc,__,Z_,Y_,Cc,X_,U_,T_,S_,YF,YF,R_,Q_,P_,O_,N_,Cc,M_,L_,K_,J_,NF,NF,I_,H_,G_,F_,E_,Cc,D_,C_,A_,z_,y_,x_,v_,u_,Cc,t_,s_,q_,p_,o_,n_,l_,k_,jf,Cc,qe,j_,i_,h_,g_,f_,e_,MY,LY,KY,JY,IY,HY,GY,jf,Cc,qe,d_,c_,b_,a_,$Z,_Z,UY,SY,RY,QY,PY,OY,NY,$v,mF,ZZ,$v,mF,YZ,Cc,pr,pr,Dh,Dh,Dh,EF,ic,tk,tk,Cc,pr,pr,Dh,Dh,Dh,EF,ic,tk,tk,Cc,or,or,Dh,Dh,Dh,DF,ic,tk,tk,Cc,or,or,Dh,Dh,Dh,DF,ic,tk,tk,Cc,XZ,SZ,Cc,QZ,MZ,Cc,JZ,GZ,Cc,FZ,CZ,Cc,rF,BZ,we,Cc,rF,AZ,we,jf,Cg,Cc,JX,IX,Cc,HX,FX,GX,Dm,Cg,Cc,DX,wa,jf,Cc,ff,ff,BX,tX,vX,wX,Cc,oX,Lm,Dm,Lm,Lm,Lm,Lm,Dm,Cc,nX,Cc,sX,uX,xX,Cc,AX,zX,yX,Cc,pX]);function kb(){return s.byteLength/65536|0}function pb(qb){qb=qb|0;var lb=kb()|0;var mb=lb+qb|0;if(lb<mb&&mb<65536){var nb=new ArrayBuffer(B(mb,65536));var ob=new Int8Array(nb);ob.set(t);t=new Int8Array(nb);u=new Int16Array(nb);v=new Int32Array(nb);w=new Uint8Array(nb);x=new Uint16Array(nb);y=new Uint32Array(nb);z=new Float32Array(nb);A=new Float64Array(nb);s=nb;r.buffer=s;e=w}return lb}return{"ua":sU,"va":m5,"wa":n5,"xa":Cc,"ya":Fb,"za":l5,"Aa":i5,"Ba":g5,"Ca":rs,"Da":we,"Ea":p5,"Fa":o5,"Ga":s5,"Ha":St,"Ia":q5,"Ja":HJ,"Ka":r5,"La":jf,"Ma":LJ,"Na":KJ,"Oa":LJ,"Pa":z2,"Qa":mX,"Ra":lX,"Sa":kX,"Ta":f5,"Ua":EJ,"Va":c5,"Wa":CJ,"Xa":O4,"Ya":I2,"Za":J2,"_a":M4,"$a":L4,"ab":K4,"bb":N4,"cb":K2,"db":j3,"eb":C2,"fb":m3,"gb":L3,"hb":F2,"ib":p3,"jb":H2,"kb":o3,"lb":D2,"mb":Q2,"nb":M2,"ob":O2,"pb":c3,"qb":_2,"rb":a3,"sb":S2,"tb":U2,"ub":W2,"vb":Y2,"wb":F3,"xb":H3,"yb":S3,"zb":N3,"Ab":M3,"Bb":R3,"Cb":Q3,"Db":O3,"Eb":P3,"Fb":X3,"Gb":Y3,"Hb":T3,"Ib":W3,"Jb":V3,"Kb":y3,"Lb":D3,"Mb":B3,"Nb":A3,"Ob":C3,"Pb":z3,"Qb":i3,"Rb":a4,"Sb":w3,"Tb":t3,"Ub":J3,"Vb":l3,"Wb":u3,"Xb":r3,"Yb":q3,"Zb":c4,"_b":e3,"$b":e4,"ac":g3,"bc":_3,"cc":a5,"dc":_4,"ec":jX,"fc":Y4,"gc":V4,"hc":T4,"ic":R4,"jc":iX,"kc":Q4,"lc":P4,"mc":J4,"nc":H4,"oc":F4,"pc":f4,"qc":E4,"rc":Fd,"sc":jb,"tc":x9,"uc":Daa,"vc":gaa,"wc":rX,"xc":qX,"yc":hX,"zc":gX,"Ac":dX,"Bc":fX,"Cc":eX,"Dc":dX,"Ec":cX,"Fc":cX}}return rb(tb)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


